// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_qshaderimage_wrapper.h"

// Argument includes
#include <QList>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DRender/qabstracttexture.h>
#include <Qt3DRender/qshaderimage.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

using namespace Qt3DRender;

// Native ---------------------------------------------------------

void QShaderImageWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QShaderImageWrapper::QShaderImageWrapper(::Qt3DCore::QNode * parent) : Qt3DRender::QShaderImage(parent)
{
    resetPyMethodCache();
    // ... middle
}

void QShaderImageWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QShaderImageWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QShaderImageWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QShaderImageWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QShaderImageWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QShaderImage", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QShaderImageWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QShaderImage", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QShaderImageWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

const QMetaObject *QShaderImageWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Qt3DRender::QShaderImage::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QShaderImageWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Qt3DRender::QShaderImage::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QShaderImageWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QShaderImageWrapper *>(this));
    return Qt3DRender::QShaderImage::qt_metacast(_clname);
}

QShaderImageWrapper::~QShaderImageWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Qt3DRender_QShaderImage_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Qt3DRender::QShaderImage >()))
        return -1;

    QShaderImageWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DRender.Qt3DRender.QShaderImage.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QShaderImage", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QShaderImage::QShaderImage(Qt3DCore::QNode*=)
    if (numArgs == 0) {
        overloadId = 0; // QShaderImage(Qt3DCore::QNode*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QShaderImage(Qt3DCore::QNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::Qt3DCore::QNode *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QShaderImage(Qt3DCore::QNode*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QShaderImageWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QShaderImageWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Qt3DRender::QShaderImage >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    };


    return 1;
}

static PyObject *Sbk_Qt3DRender_QShaderImageFunc_access(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderImage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DRender.Qt3DRender.QShaderImage.access";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // access()const
            Qt3DRender::QShaderImage::Access cppResult = const_cast<const ::Qt3DRender::QShaderImage *>(cppSelf)->access();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_Access_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderImageFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderImage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DRender.Qt3DRender.QShaderImage.format";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // format()const
            Qt3DRender::QShaderImage::ImageFormat cppResult = const_cast<const ::Qt3DRender::QShaderImage *>(cppSelf)->format();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_ImageFormat_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderImageFunc_layer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderImage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DRender.Qt3DRender.QShaderImage.layer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // layer()const
            int cppResult = const_cast<const ::Qt3DRender::QShaderImage *>(cppSelf)->layer();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderImageFunc_layered(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderImage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DRender.Qt3DRender.QShaderImage.layered";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // layered()const
            bool cppResult = const_cast<const ::Qt3DRender::QShaderImage *>(cppSelf)->layered();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderImageFunc_mipLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderImage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DRender.Qt3DRender.QShaderImage.mipLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mipLevel()const
            int cppResult = const_cast<const ::Qt3DRender::QShaderImage *>(cppSelf)->mipLevel();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Qt3DRender_QShaderImageFunc_setAccess(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderImage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DRender.Qt3DRender.QShaderImage.setAccess";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderImage::setAccess(Qt3DRender::QShaderImage::Access)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_Access_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAccess(Qt3DRender::QShaderImage::Access)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::Qt3DRender::QShaderImage::Access cppArg0{Qt3DRender::QShaderImage::ReadOnly};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAccess(Qt3DRender::QShaderImage::Access)
            cppSelf->setAccess(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderImageFunc_setFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderImage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DRender.Qt3DRender.QShaderImage.setFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderImage::setFormat(Qt3DRender::QShaderImage::ImageFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_ImageFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFormat(Qt3DRender::QShaderImage::ImageFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::Qt3DRender::QShaderImage::ImageFormat cppArg0{Qt3DRender::QShaderImage::NoFormat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFormat(Qt3DRender::QShaderImage::ImageFormat)
            cppSelf->setFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderImageFunc_setLayer(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderImage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DRender.Qt3DRender.QShaderImage.setLayer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderImage::setLayer(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLayer(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayer(int)
            cppSelf->setLayer(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderImageFunc_setLayered(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderImage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DRender.Qt3DRender.QShaderImage.setLayered";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderImage::setLayered(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setLayered(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayered(bool)
            cppSelf->setLayered(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderImageFunc_setMipLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderImage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DRender.Qt3DRender.QShaderImage.setMipLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderImage::setMipLevel(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMipLevel(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMipLevel(int)
            cppSelf->setMipLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderImageFunc_setTexture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderImage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DRender.Qt3DRender.QShaderImage.setTexture";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderImage::setTexture(Qt3DRender::QAbstractTexture*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), (pyArg)))) {
        overloadId = 0; // setTexture(Qt3DRender::QAbstractTexture*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Qt3DRender::QAbstractTexture *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTexture(Qt3DRender::QAbstractTexture*)
            cppSelf->setTexture(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Qt3DRender_QShaderImageFunc_texture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Qt3DRender::QShaderImage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.Qt3DRender.Qt3DRender.QShaderImage.texture";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // texture()const
            Qt3DRender::QAbstractTexture * cppResult = const_cast<const ::Qt3DRender::QShaderImage *>(cppSelf)->texture();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QAbstractTexture_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Qt3DRender_QShaderImage_PropertyStrings[] = {
    "access::",
    "format::",
    "layer::",
    "layered::",
    "mipLevel::",
    "texture::",
    nullptr // Sentinel
};

static const char *Sbk_Qt3DRender_QShaderImage_EnumFlagInfo[] = {
    "Access:Enum",
    "ImageFormat:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_QShaderImage_methods[] = {
    {"access", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderImageFunc_access), METH_NOARGS, nullptr},
    {"format", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderImageFunc_format), METH_NOARGS, nullptr},
    {"layer", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderImageFunc_layer), METH_NOARGS, nullptr},
    {"layered", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderImageFunc_layered), METH_NOARGS, nullptr},
    {"mipLevel", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderImageFunc_mipLevel), METH_NOARGS, nullptr},
    {"setAccess", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderImageFunc_setAccess), METH_O, nullptr},
    {"setFormat", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderImageFunc_setFormat), METH_O, nullptr},
    {"setLayer", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderImageFunc_setLayer), METH_O, nullptr},
    {"setLayered", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderImageFunc_setLayered), METH_O, nullptr},
    {"setMipLevel", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderImageFunc_setMipLevel), METH_O, nullptr},
    {"setTexture", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderImageFunc_setTexture), METH_O, nullptr},
    {"texture", reinterpret_cast<PyCFunction>(Sbk_Qt3DRender_QShaderImageFunc_texture), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Qt3DRender_QShaderImage_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Qt3DRender::QShaderImage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QShaderImageWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Qt3DRender_QShaderImage_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_QShaderImage_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_QShaderImage_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_QShaderImage_TypeF(void)
{
    return _Sbk_Qt3DRender_QShaderImage_Type;
}

static PyType_Slot Sbk_Qt3DRender_QShaderImage_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderImage_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderImage_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderImage_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderImage_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Qt3DRender_QShaderImage_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_QShaderImage_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender.QShaderImage",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_QShaderImage_slots
};

} //extern "C"

static void *Sbk_Qt3DRender_QShaderImage_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Qt3DRender::QShaderImage *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Qt3DRender_QShaderImage_Access_PythonToCpp_Qt3DRender_QShaderImage_Access(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QShaderImage::Access>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QShaderImage::Access *>(cppOut) = value;

}
static PythonToCppFunc is_Qt3DRender_QShaderImage_Access_PythonToCpp_Qt3DRender_QShaderImage_Access_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_Access_IDX])))
        return Qt3DRender_QShaderImage_Access_PythonToCpp_Qt3DRender_QShaderImage_Access;
    return {};
}
static PyObject *Qt3DRender_QShaderImage_Access_CppToPython_Qt3DRender_QShaderImage_Access(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::Qt3DRender::QShaderImage::Access *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_Access_IDX]), castCppIn);

}

static void Qt3DRender_QShaderImage_ImageFormat_PythonToCpp_Qt3DRender_QShaderImage_ImageFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::QShaderImage::ImageFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::QShaderImage::ImageFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Qt3DRender_QShaderImage_ImageFormat_PythonToCpp_Qt3DRender_QShaderImage_ImageFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_ImageFormat_IDX])))
        return Qt3DRender_QShaderImage_ImageFormat_PythonToCpp_Qt3DRender_QShaderImage_ImageFormat;
    return {};
}
static PyObject *Qt3DRender_QShaderImage_ImageFormat_CppToPython_Qt3DRender_QShaderImage_ImageFormat(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::Qt3DRender::QShaderImage::ImageFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_ImageFormat_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QShaderImage_PythonToCpp_QShaderImage_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Qt3DRender_QShaderImage_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QShaderImage_PythonToCpp_QShaderImage_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Qt3DRender_QShaderImage_TypeF()))
        return QShaderImage_PythonToCpp_QShaderImage_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QShaderImage_PTR_CppToPython_QShaderImage(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Qt3DRender::QShaderImage *>(const_cast<void *>(cppIn)), Sbk_Qt3DRender_QShaderImage_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *Qt3DRender_QShaderImage_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.QShaderImage(self,parent:PySide6.Qt3DCore.Qt3DCore.QNode=nullptr)",
    "PySide6.Qt3DRender.Qt3DRender.QShaderImage.access(self)->PySide6.Qt3DRender.Qt3DRender.QShaderImage.Access",
    "PySide6.Qt3DRender.Qt3DRender.QShaderImage.format(self)->PySide6.Qt3DRender.Qt3DRender.QShaderImage.ImageFormat",
    "PySide6.Qt3DRender.Qt3DRender.QShaderImage.layer(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QShaderImage.layered(self)->bool",
    "PySide6.Qt3DRender.Qt3DRender.QShaderImage.mipLevel(self)->int",
    "PySide6.Qt3DRender.Qt3DRender.QShaderImage.setAccess(self,access:PySide6.Qt3DRender.Qt3DRender.QShaderImage.Access)",
    "PySide6.Qt3DRender.Qt3DRender.QShaderImage.setFormat(self,format:PySide6.Qt3DRender.Qt3DRender.QShaderImage.ImageFormat)",
    "PySide6.Qt3DRender.Qt3DRender.QShaderImage.setLayer(self,layer:int)",
    "PySide6.Qt3DRender.Qt3DRender.QShaderImage.setLayered(self,layered:bool)",
    "PySide6.Qt3DRender.Qt3DRender.QShaderImage.setMipLevel(self,mipLevel:int)",
    "PySide6.Qt3DRender.Qt3DRender.QShaderImage.setTexture(self,texture:PySide6.Qt3DRender.Qt3DRender.QAbstractTexture)",
    "PySide6.Qt3DRender.Qt3DRender.QShaderImage.texture(self)->PySide6.Qt3DRender.Qt3DRender.QAbstractTexture",
    nullptr}; // Sentinel

PyTypeObject *init_Qt3DRender_QShaderImage(PyObject *enclosingClass)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_QShaderImage_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_Qt3DCoreTypeStructs[SBK_Qt3DCore_QNode_IDX]))));

    _Sbk_Qt3DRender_QShaderImage_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "QShaderImage",
        "Qt3DRender::QShaderImage*",
        &Sbk_Qt3DRender_QShaderImage_spec,
        &Shiboken::callCppDestructor< Qt3DRender::QShaderImage >,
        Sbk_Qt3DRender_QShaderImage_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
    auto *pyType = Sbk_Qt3DRender_QShaderImage_TypeF(); // references _Sbk_Qt3DRender_QShaderImage_Type
    InitSignatureStrings(pyType, Qt3DRender_QShaderImage_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_QShaderImage_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QShaderImage_PythonToCpp_QShaderImage_PTR,
        is_QShaderImage_PythonToCpp_QShaderImage_PTR_Convertible,
        QShaderImage_PTR_CppToPython_QShaderImage);

    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QShaderImage");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QShaderImage*");
    Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QShaderImage&");
    Shiboken::Conversions::registerConverterName(converter, "QShaderImage");
    Shiboken::Conversions::registerConverterName(converter, "QShaderImage*");
    Shiboken::Conversions::registerConverterName(converter, "QShaderImage&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Qt3DRender::QShaderImage).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QShaderImageWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Qt3DRender_QShaderImage_TypeF(), &Sbk_Qt3DRender_QShaderImage_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DRender_QShaderImage_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Access'.
    const char *Access_Initializer[] = {
        "ReadOnly",
        "WriteOnly",
        "ReadWrite",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Access_InitializerValues[] = {
        uint8_t(Qt3DRender::QShaderImage::Access::ReadOnly),  //  0x00  0
        uint8_t(Qt3DRender::QShaderImage::Access::WriteOnly), //  0x01  1
        uint8_t(Qt3DRender::QShaderImage::Access::ReadWrite)  //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QShaderImage_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QShaderImage.Access",
        Access_Initializer, Access_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_Access_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QShaderImage::Access'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QShaderImage_Access_CppToPython_Qt3DRender_QShaderImage_Access);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Qt3DRender_QShaderImage_Access_PythonToCpp_Qt3DRender_QShaderImage_Access,
            is_Qt3DRender_QShaderImage_Access_PythonToCpp_Qt3DRender_QShaderImage_Access_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QShaderImage::Access");
        Shiboken::Conversions::registerConverterName(converter, "QShaderImage::Access");
        Shiboken::Conversions::registerConverterName(converter, "Access");
    }
    // End of 'Access' enum.

    // Initialization of enum 'ImageFormat'.
    const char *ImageFormat_Initializer[] = {
        "NoFormat",
        "Automatic",
        "R8_UNorm",
        "RG8_UNorm",
        "RGBA8_UNorm",
        "R16_UNorm",
        "RG16_UNorm",
        "RGBA16_UNorm",
        "R8_SNorm",
        "RG8_SNorm",
        "RGBA8_SNorm",
        "R16_SNorm",
        "RG16_SNorm",
        "RGBA16_SNorm",
        "R8U",
        "RG8U",
        "RGBA8U",
        "R16U",
        "RG16U",
        "RGBA16U",
        "R32U",
        "RG32U",
        "RGBA32U",
        "R8I",
        "RG8I",
        "RGBA8I",
        "R16I",
        "RG16I",
        "RGBA16I",
        "R32I",
        "RG32I",
        "RGBA32I",
        "R16F",
        "RG16F",
        "RGBA16F",
        "R32F",
        "RG32F",
        "RGBA32F",
        "RG11B10F",
        "RGB10A2",
        "RGB10A2U",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t ImageFormat_InitializerValues[] = {
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::NoFormat),     //  0x0000  0
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::Automatic),    //  0x0001  1
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::R8_UNorm),     //  0x8229  33321
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RG8_UNorm),    //  0x822b  33323
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RGBA8_UNorm),  //  0x8058  32856
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::R16_UNorm),    //  0x822a  33322
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RG16_UNorm),   //  0x822c  33324
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RGBA16_UNorm), //  0x805b  32859
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::R8_SNorm),     //  0x8f94  36756
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RG8_SNorm),    //  0x8f95  36757
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RGBA8_SNorm),  //  0x8f97  36759
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::R16_SNorm),    //  0x8f98  36760
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RG16_SNorm),   //  0x8f99  36761
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RGBA16_SNorm), //  0x8f9b  36763
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::R8U),          //  0x8232  33330
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RG8U),         //  0x8238  33336
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RGBA8U),       //  0x8d7c  36220
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::R16U),         //  0x8234  33332
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RG16U),        //  0x823a  33338
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RGBA16U),      //  0x8d76  36214
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::R32U),         //  0x8236  33334
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RG32U),        //  0x823c  33340
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RGBA32U),      //  0x8d70  36208
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::R8I),          //  0x8231  33329
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RG8I),         //  0x8237  33335
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RGBA8I),       //  0x8d8e  36238
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::R16I),         //  0x8233  33331
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RG16I),        //  0x8239  33337
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RGBA16I),      //  0x8d88  36232
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::R32I),         //  0x8235  33333
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RG32I),        //  0x823b  33339
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RGBA32I),      //  0x8d82  36226
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::R16F),         //  0x822d  33325
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RG16F),        //  0x822f  33327
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RGBA16F),      //  0x881a  34842
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::R32F),         //  0x822e  33326
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RG32F),        //  0x8230  33328
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RGBA32F),      //  0x8814  34836
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RG11B10F),     //  0x8c3a  35898
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RGB10A2),      //  0x8059  32857
        uint16_t(Qt3DRender::QShaderImage::ImageFormat::RGB10A2U)      //  0x906f  36975
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_QShaderImage_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.QShaderImage.ImageFormat",
        ImageFormat_Initializer, ImageFormat_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QShaderImage_ImageFormat_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::QShaderImage::ImageFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_QShaderImage_ImageFormat_CppToPython_Qt3DRender_QShaderImage_ImageFormat);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Qt3DRender_QShaderImage_ImageFormat_PythonToCpp_Qt3DRender_QShaderImage_ImageFormat,
            is_Qt3DRender_QShaderImage_ImageFormat_PythonToCpp_Qt3DRender_QShaderImage_ImageFormat_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::QShaderImage::ImageFormat");
        Shiboken::Conversions::registerConverterName(converter, "QShaderImage::ImageFormat");
        Shiboken::Conversions::registerConverterName(converter, "ImageFormat");
    }
    // End of 'ImageFormat' enum.

    PySide::Signal::registerSignals(pyType, &::Qt3DRender::QShaderImage::staticMetaObject);
    qRegisterMetaType< ::Qt3DRender::QShaderImage::Access >("QShaderImage::Access");
    qRegisterMetaType< ::Qt3DRender::QShaderImage::Access >("Qt3DRender::QShaderImage::Access");
    qRegisterMetaType< ::Qt3DRender::QShaderImage::ImageFormat >("QShaderImage::ImageFormat");
    qRegisterMetaType< ::Qt3DRender::QShaderImage::ImageFormat >("Qt3DRender::QShaderImage::ImageFormat");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Qt3DRender::QShaderImage::staticMetaObject, sizeof(QShaderImageWrapper));

    return pyType;
}
