// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qt3drender_python.h"

// main header
#include "qt3drender_wrapper.h"

// inner classes
#include "qt3drender_qtexturedataupdate_wrapper.h"
#include "qt3drender_qtexturedata_wrapper.h"
#include "qt3drender_qtechnique_wrapper.h"
#include "qt3drender_qstenciltestarguments_wrapper.h"
#include "qt3drender_qstenciloperationarguments_wrapper.h"
#include "qt3drender_qshaderprogrambuilder_wrapper.h"
#include "qt3drender_qshaderimage_wrapper.h"
#include "qt3drender_qshaderdata_wrapper.h"
#include "qt3drender_propertyreaderinterface_wrapper.h"
#include "qt3drender_qsceneloader_wrapper.h"
#include "qt3drender_qrendersettings_wrapper.h"
#include "qt3drender_qrenderpass_wrapper.h"
#include "qt3drender_qshaderprogram_wrapper.h"
#include "qt3drender_qrendercapturereply_wrapper.h"
#include "qt3drender_qrendercapabilities_wrapper.h"
#include "qt3drender_qrenderaspect_wrapper.h"
#include "qt3drender_qpickingsettings_wrapper.h"
#include "qt3drender_qpickingproxy_wrapper.h"
#include "qt3drender_qpickevent_wrapper.h"
#include "qt3drender_qpicktriangleevent_wrapper.h"
#include "qt3drender_qpickpointevent_wrapper.h"
#include "qt3drender_qpicklineevent_wrapper.h"
#include "qt3drender_qparameter_wrapper.h"
#include "qt3drender_qobjectpicker_wrapper.h"
#include "qt3drender_qmaterial_wrapper.h"
#include "qt3drender_qlevelofdetail_wrapper.h"
#include "qt3drender_qlevelofdetailswitch_wrapper.h"
#include "qt3drender_qlevelofdetailboundingsphere_wrapper.h"
#include "qt3drender_qlayer_wrapper.h"
#include "qt3drender_qgraphicsapifilter_wrapper.h"
#include "qt3drender_qgeometryrenderer_wrapper.h"
#include "qt3drender_qmesh_wrapper.h"
#include "qt3drender_qfilterkey_wrapper.h"
#include "qt3drender_qenvironmentlight_wrapper.h"
#include "qt3drender_qeffect_wrapper.h"
#include "qt3drender_qcomputecommand_wrapper.h"
#include "qt3drender_qcamera_wrapper.h"
#include "qt3drender_qcameralens_wrapper.h"
#include "qt3drender_qrendertarget_wrapper.h"
#include "qt3drender_qrendertargetoutput_wrapper.h"
#include "qt3drender_qframegraphnode_wrapper.h"
#include "qt3drender_qwaitfence_wrapper.h"
#include "qt3drender_qtechniquefilter_wrapper.h"
#include "qt3drender_qsubtreeenabler_wrapper.h"
#include "qt3drender_qsortpolicy_wrapper.h"
#include "qt3drender_qsetfence_wrapper.h"
#include "qt3drender_qrendertargetselector_wrapper.h"
#include "qt3drender_qrendersurfaceselector_wrapper.h"
#include "qt3drender_qrenderstateset_wrapper.h"
#include "qt3drender_qrenderpassfilter_wrapper.h"
#include "qt3drender_qrendercapture_wrapper.h"
#include "qt3drender_qproximityfilter_wrapper.h"
#include "qt3drender_qviewport_wrapper.h"
#include "qt3drender_qnopicking_wrapper.h"
#include "qt3drender_qnodraw_wrapper.h"
#include "qt3drender_qmemorybarrier_wrapper.h"
#include "qt3drender_qlayerfilter_wrapper.h"
#include "qt3drender_qfrustumculling_wrapper.h"
#include "qt3drender_qdispatchcompute_wrapper.h"
#include "qt3drender_qdebugoverlay_wrapper.h"
#include "qt3drender_qclearbuffers_wrapper.h"
#include "qt3drender_qcameraselector_wrapper.h"
#include "qt3drender_qbuffercapture_wrapper.h"
#include "qt3drender_qblitframebuffer_wrapper.h"
#include "qt3drender_qrenderstate_wrapper.h"
#include "qt3drender_qstenciltest_wrapper.h"
#include "qt3drender_qstenciloperation_wrapper.h"
#include "qt3drender_qstencilmask_wrapper.h"
#include "qt3drender_qseamlesscubemap_wrapper.h"
#include "qt3drender_qscissortest_wrapper.h"
#include "qt3drender_qrastermode_wrapper.h"
#include "qt3drender_qpolygonoffset_wrapper.h"
#include "qt3drender_qpointsize_wrapper.h"
#include "qt3drender_qnodepthmask_wrapper.h"
#include "qt3drender_qmultisampleantialiasing_wrapper.h"
#include "qt3drender_qlinewidth_wrapper.h"
#include "qt3drender_qfrontface_wrapper.h"
#include "qt3drender_qdithering_wrapper.h"
#include "qt3drender_qdepthtest_wrapper.h"
#include "qt3drender_qdepthrange_wrapper.h"
#include "qt3drender_qcullface_wrapper.h"
#include "qt3drender_qcolormask_wrapper.h"
#include "qt3drender_qclipplane_wrapper.h"
#include "qt3drender_qblendequationarguments_wrapper.h"
#include "qt3drender_qblendequation_wrapper.h"
#include "qt3drender_qalphatest_wrapper.h"
#include "qt3drender_qalphacoverage_wrapper.h"
#include "qt3drender_qabstracttextureimage_wrapper.h"
#include "qt3drender_qtextureimage_wrapper.h"
#include "qt3drender_qpaintedtextureimage_wrapper.h"
#include "qt3drender_qtextureimagedatagenerator_wrapper.h"
#include "qt3drender_qabstracttexture_wrapper.h"
#include "qt3drender_qsharedgltexture_wrapper.h"
#include "qt3drender_qtextureloader_wrapper.h"
#include "qt3drender_qtexturebuffer_wrapper.h"
#include "qt3drender_qtexturerectangle_wrapper.h"
#include "qt3drender_qtexture2dmultisamplearray_wrapper.h"
#include "qt3drender_qtexture2dmultisample_wrapper.h"
#include "qt3drender_qtexturecubemaparray_wrapper.h"
#include "qt3drender_qtexturecubemap_wrapper.h"
#include "qt3drender_qtexture3d_wrapper.h"
#include "qt3drender_qtexture2darray_wrapper.h"
#include "qt3drender_qtexture2d_wrapper.h"
#include "qt3drender_qtexture1darray_wrapper.h"
#include "qt3drender_qtexture1d_wrapper.h"
#include "qt3drender_qtexturewrapmode_wrapper.h"
#include "qt3drender_qtextureimagedata_wrapper.h"
#include "qt3drender_qabstractraycaster_wrapper.h"
#include "qt3drender_qscreenraycaster_wrapper.h"
#include "qt3drender_qraycaster_wrapper.h"
#include "qt3drender_qraycasterhit_wrapper.h"
#include "qt3drender_qabstractlight_wrapper.h"
#include "qt3drender_qspotlight_wrapper.h"
#include "qt3drender_qpointlight_wrapper.h"
#include "qt3drender_qdirectionallight_wrapper.h"

// Argument includes
#include <Qt3DRender/qtexturedataupdate.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_Qt3DRenderFunc_swap(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.Qt3DRender.Qt3DRender.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "swap", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static Qt3DRender::swap(Qt3DRender::QTextureDataUpdate&,Qt3DRender::QTextureDataUpdate&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureDataUpdate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_QTextureDataUpdate_IDX]), (pyArgs[1])))) {
        overloadId = 0; // swap(Qt3DRender::QTextureDataUpdate&,Qt3DRender::QTextureDataUpdate&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::Qt3DRender::QTextureDataUpdate cppArg0_local;
        ::Qt3DRender::QTextureDataUpdate *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::Qt3DRender::QTextureDataUpdate cppArg1_local;
        ::Qt3DRender::QTextureDataUpdate *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(Qt3DRender::QTextureDataUpdate&,Qt3DRender::QTextureDataUpdate&)
            ::Qt3DRender::swap(*cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_Qt3DRender_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Qt3DRender_EnumFlagInfo[] = {
    "API:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Qt3DRender_methods[] = {
    {"swap", reinterpret_cast<PyCFunction>(Sbk_Qt3DRenderFunc_swap), METH_VARARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Qt3DRender_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Qt3DRender_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Qt3DRender_Type = nullptr;
static PyTypeObject *Sbk_Qt3DRender_TypeF(void)
{
    return _Sbk_Qt3DRender_Type;
}

static PyType_Slot Sbk_Qt3DRender_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(Sbk_object_dealloc /* PYSIDE-832: Prevent replacement of "0" with subtype_dealloc. */)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Qt3DRender_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Qt3DRender_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Qt3DRender_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Qt3DRender_spec = {
    "2:PySide6.Qt3DRender.Qt3DRender",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Qt3DRender_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Qt3DRender_API_PythonToCpp_Qt3DRender_API(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Qt3DRender::API>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Qt3DRender::API *>(cppOut) = value;

}
static PythonToCppFunc is_Qt3DRender_API_PythonToCpp_Qt3DRender_API_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_API_IDX])))
        return Qt3DRender_API_PythonToCpp_Qt3DRender_API;
    return {};
}
static PyObject *Qt3DRender_API_CppToPython_Qt3DRender_API(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::Qt3DRender::API *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_API_IDX]), castCppIn);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *Qt3DRenderQt3DRender_SignatureStrings[] = {
    "PySide6.Qt3DRender.Qt3DRender.swap(lhs:PySide6.Qt3DRender.Qt3DRender.QTextureDataUpdate,rhs:PySide6.Qt3DRender.Qt3DRender.QTextureDataUpdate)",
    nullptr}; // Sentinel

PyTypeObject *init_Qt3DRenderQt3DRender(PyObject *module)
{
    if (SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRenderQt3DRender_IDX].type != nullptr)
        return SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRenderQt3DRender_IDX].type;

    Shiboken::AutoDecRef Sbk_Qt3DRender_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_Qt3DRender_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "Qt3DRender",
        "Qt3DRender",
        &Sbk_Qt3DRender_spec,
        nullptr,
        Sbk_Qt3DRender_Type_bases.object(),
        0);
    auto *pyType = Sbk_Qt3DRender_TypeF(); // references _Sbk_Qt3DRender_Type
    InitSignatureStrings(pyType, Qt3DRenderQt3DRender_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Qt3DRender_PropertyStrings);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRenderQt3DRender_IDX].type = pyType;


    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Qt3DRender_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'API'.
    const char *API_Initializer[] = {
        "OpenGL",
        "Vulkan",
        "DirectX",
        "Metal",
        "RHI",
        "Null",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t API_InitializerValues[] = {
        int8_t(Qt3DRender::API::OpenGL),  //  0x00  0
        int8_t(Qt3DRender::API::Vulkan),  //  0x01  1
        int8_t(Qt3DRender::API::DirectX), //  0x02  2
        int8_t(Qt3DRender::API::Metal),   //  0x03  3
        int8_t(Qt3DRender::API::RHI),     //  0x04  4
        int8_t(Qt3DRender::API::Null)     //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_Qt3DRender_TypeF(),
        "2:PySide6.Qt3DRender.Qt3DRender.API",
        API_Initializer, API_InitializerValues);
    SbkPySide6_Qt3DRenderTypeStructs[SBK_Qt3DRender_API_IDX].type = EType;
    // Register converter for enum 'Qt3DRender::API'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Qt3DRender_API_CppToPython_Qt3DRender_API);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Qt3DRender_API_PythonToCpp_Qt3DRender_API,
            is_Qt3DRender_API_PythonToCpp_Qt3DRender_API_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "Qt3DRender::API");
        Shiboken::Conversions::registerConverterName(converter, "API");
    }
    // End of 'API' enum.

    qRegisterMetaType< ::Qt3DRender::API >("Qt3DRender::API");

    return pyType;
}
