// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qbluetoothdeviceinfo_wrapper.h"

// Argument includes
#include <QList>
#include <QMultiHash>
#include <QString>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtBluetooth/qbluetoothdeviceinfo.h>
#include <QtBluetooth/qbluetoothuuid.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBluetoothDeviceInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QBluetoothDeviceInfo >()))
        return -1;

    ::QBluetoothDeviceInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "QBluetoothDeviceInfo", 0, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QBluetoothDeviceInfo::QBluetoothDeviceInfo()
    // 1: QBluetoothDeviceInfo::QBluetoothDeviceInfo(QBluetoothAddress,QString,quint32)
    // 2: QBluetoothDeviceInfo::QBluetoothDeviceInfo(QBluetoothDeviceInfo)
    // 3: QBluetoothDeviceInfo::QBluetoothDeviceInfo(QBluetoothUuid,QString,quint32)
    if (numArgs == 0) {
        overloadId = 0; // QBluetoothDeviceInfo()
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[2])))) {
        overloadId = 3; // QBluetoothDeviceInfo(QBluetoothUuid,QString,quint32)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QBluetoothDeviceInfo(QBluetoothDeviceInfo)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[2])))) {
        overloadId = 1; // QBluetoothDeviceInfo(QBluetoothAddress,QString,quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QBluetoothDeviceInfo()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothDeviceInfo()
                cptr = new ::QBluetoothDeviceInfo();
            }
            break;
        }
        case 1: // QBluetoothDeviceInfo(const QBluetoothAddress & address, const QString & name, quint32 classOfDevice)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBluetoothAddress cppArg0_local;
            ::QBluetoothAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            quint32 cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothDeviceInfo(QBluetoothAddress,QString,quint32)
                cptr = new ::QBluetoothDeviceInfo(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 2: // QBluetoothDeviceInfo(const QBluetoothDeviceInfo & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBluetoothDeviceInfo cppArg0_local;
            ::QBluetoothDeviceInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothDeviceInfo(QBluetoothDeviceInfo)
                cptr = new ::QBluetoothDeviceInfo(*cppArg0);
            }
            break;
        }
        case 3: // QBluetoothDeviceInfo(const QBluetoothUuid & uuid, const QString & name, quint32 classOfDevice)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QBluetoothUuid cppArg0_local;
            ::QBluetoothUuid *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            quint32 cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QBluetoothDeviceInfo(QBluetoothUuid,QString,quint32)
                cptr = new ::QBluetoothDeviceInfo(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QBluetoothDeviceInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_address(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.address";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // address()const
            QBluetoothAddress cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->address();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_coreConfigurations(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.coreConfigurations";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // coreConfigurations()const
            QFlags<QBluetoothDeviceInfo::CoreConfiguration> cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->coreConfigurations();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetoothDeviceInfo_CoreConfiguration_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_deviceUuid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.deviceUuid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // deviceUuid()const
            QBluetoothUuid cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->deviceUuid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_isCached(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.isCached";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isCached()const
            bool cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->isCached();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_majorDeviceClass(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.majorDeviceClass";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // majorDeviceClass()const
            QBluetoothDeviceInfo::MajorDeviceClass cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->majorDeviceClass();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MajorDeviceClass_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_manufacturerData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.manufacturerData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "manufacturerData", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBluetoothDeviceInfo::manufacturerData()const->QMultiHash< quint16,QByteArray>
    // 1: QBluetoothDeviceInfo::manufacturerData(quint16)const->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // manufacturerData()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[0])))) {
        overloadId = 1; // manufacturerData(quint16)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // manufacturerData() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // manufacturerData()const
                QMultiHash<quint16,QByteArray> cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->manufacturerData();
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QMultiHash_quint16_QByteArray_IDX], &cppResult);
            }
            break;
        }
        case 1: // manufacturerData(quint16 manufacturerId) const
        {
            quint16 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // manufacturerData(quint16)const
                QByteArray cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->manufacturerData(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_manufacturerIds(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.manufacturerIds";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // manufacturerIds()const
            QList<quint16> cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->manufacturerIds();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_quint16_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_minorDeviceClass(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.minorDeviceClass";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minorDeviceClass()const
            quint8 cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->minorDeviceClass();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint8>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.name";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // name()const
            QString cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->name();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_rssi(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.rssi";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // rssi()const
            qint16 cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->rssi();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint16>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_serviceClasses(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.serviceClasses";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // serviceClasses()const
            QFlags<QBluetoothDeviceInfo::ServiceClass> cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->serviceClasses();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetoothDeviceInfo_ServiceClass_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_serviceData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.serviceData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "serviceData", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBluetoothDeviceInfo::serviceData()const->QMultiHash< QBluetoothUuid,QByteArray>
    // 1: QBluetoothDeviceInfo::serviceData(QBluetoothUuid)const->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // serviceData()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArgs[0])))) {
        overloadId = 1; // serviceData(QBluetoothUuid)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // serviceData() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // serviceData()const
                QMultiHash<QBluetoothUuid,QByteArray> cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->serviceData();
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QMultiHash_QBluetoothUuid_QByteArray_IDX], &cppResult);
            }
            break;
        }
        case 1: // serviceData(const QBluetoothUuid & serviceId) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QBluetoothUuid cppArg0_local;
            ::QBluetoothUuid *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // serviceData(QBluetoothUuid)const
                QByteArray cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->serviceData(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_serviceIds(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.serviceIds";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // serviceIds()const
            QList<QBluetoothUuid> cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->serviceIds();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothUuid_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_serviceUuids(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.serviceUuids";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // serviceUuids()const
            QList<QBluetoothUuid> cppResult = const_cast<const ::QBluetoothDeviceInfo *>(cppSelf)->serviceUuids();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothUuid_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_setCached(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.setCached";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothDeviceInfo::setCached(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setCached(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCached(bool)
            cppSelf->setCached(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_setCoreConfigurations(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.setCoreConfigurations";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothDeviceInfo::setCoreConfigurations(QFlags<QBluetoothDeviceInfo::CoreConfiguration>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetoothDeviceInfo_CoreConfiguration_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setCoreConfigurations(QFlags<QBluetoothDeviceInfo::CoreConfiguration>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QBluetoothDeviceInfo::CoreConfiguration> cppArg0 = QFlags<QBluetoothDeviceInfo::CoreConfiguration>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCoreConfigurations(QFlags<QBluetoothDeviceInfo::CoreConfiguration>)
            cppSelf->setCoreConfigurations(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_setDeviceUuid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.setDeviceUuid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothDeviceInfo::setDeviceUuid(QBluetoothUuid)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArg)))) {
        overloadId = 0; // setDeviceUuid(QBluetoothUuid)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBluetoothUuid cppArg0_local;
        ::QBluetoothUuid *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDeviceUuid(QBluetoothUuid)
            cppSelf->setDeviceUuid(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_setManufacturerData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.setManufacturerData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setManufacturerData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBluetoothDeviceInfo::setManufacturerData(quint16,QByteArray)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setManufacturerData(quint16,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        quint16 cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setManufacturerData(quint16,QByteArray)
            bool cppResult = cppSelf->setManufacturerData(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.setName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothDeviceInfo::setName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QString)
            cppSelf->setName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_setRssi(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.setRssi";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothDeviceInfo::setRssi(qint16)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint16>(), (pyArg)))) {
        overloadId = 0; // setRssi(qint16)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qint16 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRssi(qint16)
            cppSelf->setRssi(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_setServiceData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.setServiceData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setServiceData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QBluetoothDeviceInfo::setServiceData(QBluetoothUuid,QByteArray)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setServiceData(QBluetoothUuid,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QBluetoothUuid cppArg0_local;
        ::QBluetoothUuid *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local;
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setServiceData(QBluetoothUuid,QByteArray)
            bool cppResult = cppSelf->setServiceData(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QBluetoothDeviceInfoFunc_setServiceUuids(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QBluetoothDeviceInfo.setServiceUuids";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QBluetoothDeviceInfo::setServiceUuids(QList<QBluetoothUuid>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothUuid_IDX], (pyArg)))) {
        overloadId = 0; // setServiceUuids(QList<QBluetoothUuid>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QBluetoothUuid> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setServiceUuids(QList<QBluetoothUuid>)
            cppSelf->setServiceUuids(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QBluetoothDeviceInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QBluetoothDeviceInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QBluetoothDeviceInfo_EnumFlagInfo[] = {
    "CoreConfiguration:Flag:CoreConfigurations",
    "Field:Flag:Fields",
    "MajorDeviceClass:Enum",
    "MinorAudioVideoClass:Enum",
    "MinorComputerClass:Enum",
    "MinorHealthClass:Enum",
    "MinorImagingClass:Enum",
    "MinorMiscellaneousClass:Enum",
    "MinorNetworkClass:Enum",
    "MinorPeripheralClass:Enum",
    "MinorPhoneClass:Enum",
    "MinorToyClass:Enum",
    "MinorWearableClass:Enum",
    "ServiceClass:Flag:ServiceClasses",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QBluetoothDeviceInfo_methods[] = {
    {"address", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_address), METH_NOARGS, nullptr},
    {"coreConfigurations", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_coreConfigurations), METH_NOARGS, nullptr},
    {"deviceUuid", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_deviceUuid), METH_NOARGS, nullptr},
    {"isCached", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_isCached), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_isValid), METH_NOARGS, nullptr},
    {"majorDeviceClass", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_majorDeviceClass), METH_NOARGS, nullptr},
    {"manufacturerData", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_manufacturerData), METH_VARARGS, nullptr},
    {"manufacturerIds", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_manufacturerIds), METH_NOARGS, nullptr},
    {"minorDeviceClass", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_minorDeviceClass), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_name), METH_NOARGS, nullptr},
    {"rssi", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_rssi), METH_NOARGS, nullptr},
    {"serviceClasses", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_serviceClasses), METH_NOARGS, nullptr},
    {"serviceData", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_serviceData), METH_VARARGS, nullptr},
    {"serviceIds", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_serviceIds), METH_NOARGS, nullptr},
    {"serviceUuids", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_serviceUuids), METH_NOARGS, nullptr},
    {"setCached", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_setCached), METH_O, nullptr},
    {"setCoreConfigurations", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_setCoreConfigurations), METH_O, nullptr},
    {"setDeviceUuid", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_setDeviceUuid), METH_O, nullptr},
    {"setManufacturerData", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_setManufacturerData), METH_VARARGS, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_setName), METH_O, nullptr},
    {"setRssi", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_setRssi), METH_O, nullptr},
    {"setServiceData", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_setServiceData), METH_VARARGS, nullptr},
    {"setServiceUuids", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfoFunc_setServiceUuids), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QBluetoothDeviceInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QBluetoothDeviceInfo_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), (pyArg)))) {
                // operator!=(const QBluetoothDeviceInfo & b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QBluetoothDeviceInfo cppArg0_local;
                ::QBluetoothDeviceInfo *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), (pyArg)))) {
                // operator==(const QBluetoothDeviceInfo & b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QBluetoothDeviceInfo cppArg0_local;
                ::QBluetoothDeviceInfo *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QBluetoothDeviceInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QBluetoothDeviceInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QBluetoothDeviceInfo_Type = nullptr;
static PyTypeObject *Sbk_QBluetoothDeviceInfo_TypeF(void)
{
    return _Sbk_QBluetoothDeviceInfo_Type;
}

static PyType_Slot Sbk_QBluetoothDeviceInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QBluetoothDeviceInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QBluetoothDeviceInfo_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QBluetoothDeviceInfo_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QBluetoothDeviceInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QBluetoothDeviceInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QBluetoothDeviceInfo_spec = {
    "2:PySide6.QtBluetooth.QBluetoothDeviceInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QBluetoothDeviceInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QBluetoothDeviceInfo_MajorDeviceClass_PythonToCpp_QBluetoothDeviceInfo_MajorDeviceClass(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceInfo::MajorDeviceClass>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceInfo::MajorDeviceClass *>(cppOut) = value;

}
static PythonToCppFunc is_QBluetoothDeviceInfo_MajorDeviceClass_PythonToCpp_QBluetoothDeviceInfo_MajorDeviceClass_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MajorDeviceClass_IDX])))
        return QBluetoothDeviceInfo_MajorDeviceClass_PythonToCpp_QBluetoothDeviceInfo_MajorDeviceClass;
    return {};
}
static PyObject *QBluetoothDeviceInfo_MajorDeviceClass_CppToPython_QBluetoothDeviceInfo_MajorDeviceClass(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QBluetoothDeviceInfo::MajorDeviceClass *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MajorDeviceClass_IDX]), castCppIn);

}

static void QBluetoothDeviceInfo_MinorMiscellaneousClass_PythonToCpp_QBluetoothDeviceInfo_MinorMiscellaneousClass(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceInfo::MinorMiscellaneousClass>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceInfo::MinorMiscellaneousClass *>(cppOut) = value;

}
static PythonToCppFunc is_QBluetoothDeviceInfo_MinorMiscellaneousClass_PythonToCpp_QBluetoothDeviceInfo_MinorMiscellaneousClass_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorMiscellaneousClass_IDX])))
        return QBluetoothDeviceInfo_MinorMiscellaneousClass_PythonToCpp_QBluetoothDeviceInfo_MinorMiscellaneousClass;
    return {};
}
static PyObject *QBluetoothDeviceInfo_MinorMiscellaneousClass_CppToPython_QBluetoothDeviceInfo_MinorMiscellaneousClass(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QBluetoothDeviceInfo::MinorMiscellaneousClass *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorMiscellaneousClass_IDX]), castCppIn);

}

static void QBluetoothDeviceInfo_MinorComputerClass_PythonToCpp_QBluetoothDeviceInfo_MinorComputerClass(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceInfo::MinorComputerClass>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceInfo::MinorComputerClass *>(cppOut) = value;

}
static PythonToCppFunc is_QBluetoothDeviceInfo_MinorComputerClass_PythonToCpp_QBluetoothDeviceInfo_MinorComputerClass_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorComputerClass_IDX])))
        return QBluetoothDeviceInfo_MinorComputerClass_PythonToCpp_QBluetoothDeviceInfo_MinorComputerClass;
    return {};
}
static PyObject *QBluetoothDeviceInfo_MinorComputerClass_CppToPython_QBluetoothDeviceInfo_MinorComputerClass(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QBluetoothDeviceInfo::MinorComputerClass *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorComputerClass_IDX]), castCppIn);

}

static void QBluetoothDeviceInfo_MinorPhoneClass_PythonToCpp_QBluetoothDeviceInfo_MinorPhoneClass(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceInfo::MinorPhoneClass>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceInfo::MinorPhoneClass *>(cppOut) = value;

}
static PythonToCppFunc is_QBluetoothDeviceInfo_MinorPhoneClass_PythonToCpp_QBluetoothDeviceInfo_MinorPhoneClass_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorPhoneClass_IDX])))
        return QBluetoothDeviceInfo_MinorPhoneClass_PythonToCpp_QBluetoothDeviceInfo_MinorPhoneClass;
    return {};
}
static PyObject *QBluetoothDeviceInfo_MinorPhoneClass_CppToPython_QBluetoothDeviceInfo_MinorPhoneClass(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QBluetoothDeviceInfo::MinorPhoneClass *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorPhoneClass_IDX]), castCppIn);

}

static void QBluetoothDeviceInfo_MinorNetworkClass_PythonToCpp_QBluetoothDeviceInfo_MinorNetworkClass(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceInfo::MinorNetworkClass>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceInfo::MinorNetworkClass *>(cppOut) = value;

}
static PythonToCppFunc is_QBluetoothDeviceInfo_MinorNetworkClass_PythonToCpp_QBluetoothDeviceInfo_MinorNetworkClass_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorNetworkClass_IDX])))
        return QBluetoothDeviceInfo_MinorNetworkClass_PythonToCpp_QBluetoothDeviceInfo_MinorNetworkClass;
    return {};
}
static PyObject *QBluetoothDeviceInfo_MinorNetworkClass_CppToPython_QBluetoothDeviceInfo_MinorNetworkClass(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QBluetoothDeviceInfo::MinorNetworkClass *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorNetworkClass_IDX]), castCppIn);

}

static void QBluetoothDeviceInfo_MinorAudioVideoClass_PythonToCpp_QBluetoothDeviceInfo_MinorAudioVideoClass(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceInfo::MinorAudioVideoClass>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceInfo::MinorAudioVideoClass *>(cppOut) = value;

}
static PythonToCppFunc is_QBluetoothDeviceInfo_MinorAudioVideoClass_PythonToCpp_QBluetoothDeviceInfo_MinorAudioVideoClass_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorAudioVideoClass_IDX])))
        return QBluetoothDeviceInfo_MinorAudioVideoClass_PythonToCpp_QBluetoothDeviceInfo_MinorAudioVideoClass;
    return {};
}
static PyObject *QBluetoothDeviceInfo_MinorAudioVideoClass_CppToPython_QBluetoothDeviceInfo_MinorAudioVideoClass(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QBluetoothDeviceInfo::MinorAudioVideoClass *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorAudioVideoClass_IDX]), castCppIn);

}

static void QBluetoothDeviceInfo_MinorPeripheralClass_PythonToCpp_QBluetoothDeviceInfo_MinorPeripheralClass(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceInfo::MinorPeripheralClass>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceInfo::MinorPeripheralClass *>(cppOut) = value;

}
static PythonToCppFunc is_QBluetoothDeviceInfo_MinorPeripheralClass_PythonToCpp_QBluetoothDeviceInfo_MinorPeripheralClass_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorPeripheralClass_IDX])))
        return QBluetoothDeviceInfo_MinorPeripheralClass_PythonToCpp_QBluetoothDeviceInfo_MinorPeripheralClass;
    return {};
}
static PyObject *QBluetoothDeviceInfo_MinorPeripheralClass_CppToPython_QBluetoothDeviceInfo_MinorPeripheralClass(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QBluetoothDeviceInfo::MinorPeripheralClass *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorPeripheralClass_IDX]), castCppIn);

}

static void QBluetoothDeviceInfo_MinorImagingClass_PythonToCpp_QBluetoothDeviceInfo_MinorImagingClass(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceInfo::MinorImagingClass>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceInfo::MinorImagingClass *>(cppOut) = value;

}
static PythonToCppFunc is_QBluetoothDeviceInfo_MinorImagingClass_PythonToCpp_QBluetoothDeviceInfo_MinorImagingClass_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorImagingClass_IDX])))
        return QBluetoothDeviceInfo_MinorImagingClass_PythonToCpp_QBluetoothDeviceInfo_MinorImagingClass;
    return {};
}
static PyObject *QBluetoothDeviceInfo_MinorImagingClass_CppToPython_QBluetoothDeviceInfo_MinorImagingClass(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QBluetoothDeviceInfo::MinorImagingClass *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorImagingClass_IDX]), castCppIn);

}

static void QBluetoothDeviceInfo_MinorWearableClass_PythonToCpp_QBluetoothDeviceInfo_MinorWearableClass(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceInfo::MinorWearableClass>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceInfo::MinorWearableClass *>(cppOut) = value;

}
static PythonToCppFunc is_QBluetoothDeviceInfo_MinorWearableClass_PythonToCpp_QBluetoothDeviceInfo_MinorWearableClass_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorWearableClass_IDX])))
        return QBluetoothDeviceInfo_MinorWearableClass_PythonToCpp_QBluetoothDeviceInfo_MinorWearableClass;
    return {};
}
static PyObject *QBluetoothDeviceInfo_MinorWearableClass_CppToPython_QBluetoothDeviceInfo_MinorWearableClass(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QBluetoothDeviceInfo::MinorWearableClass *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorWearableClass_IDX]), castCppIn);

}

static void QBluetoothDeviceInfo_MinorToyClass_PythonToCpp_QBluetoothDeviceInfo_MinorToyClass(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceInfo::MinorToyClass>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceInfo::MinorToyClass *>(cppOut) = value;

}
static PythonToCppFunc is_QBluetoothDeviceInfo_MinorToyClass_PythonToCpp_QBluetoothDeviceInfo_MinorToyClass_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorToyClass_IDX])))
        return QBluetoothDeviceInfo_MinorToyClass_PythonToCpp_QBluetoothDeviceInfo_MinorToyClass;
    return {};
}
static PyObject *QBluetoothDeviceInfo_MinorToyClass_CppToPython_QBluetoothDeviceInfo_MinorToyClass(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QBluetoothDeviceInfo::MinorToyClass *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorToyClass_IDX]), castCppIn);

}

static void QBluetoothDeviceInfo_MinorHealthClass_PythonToCpp_QBluetoothDeviceInfo_MinorHealthClass(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceInfo::MinorHealthClass>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceInfo::MinorHealthClass *>(cppOut) = value;

}
static PythonToCppFunc is_QBluetoothDeviceInfo_MinorHealthClass_PythonToCpp_QBluetoothDeviceInfo_MinorHealthClass_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorHealthClass_IDX])))
        return QBluetoothDeviceInfo_MinorHealthClass_PythonToCpp_QBluetoothDeviceInfo_MinorHealthClass;
    return {};
}
static PyObject *QBluetoothDeviceInfo_MinorHealthClass_CppToPython_QBluetoothDeviceInfo_MinorHealthClass(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QBluetoothDeviceInfo::MinorHealthClass *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorHealthClass_IDX]), castCppIn);

}

static void QBluetoothDeviceInfo_ServiceClass_PythonToCpp_QBluetoothDeviceInfo_ServiceClass(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceInfo::ServiceClass>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceInfo::ServiceClass *>(cppOut) = value;

}
static PythonToCppFunc is_QBluetoothDeviceInfo_ServiceClass_PythonToCpp_QBluetoothDeviceInfo_ServiceClass_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_ServiceClass_IDX])))
        return QBluetoothDeviceInfo_ServiceClass_PythonToCpp_QBluetoothDeviceInfo_ServiceClass;
    return {};
}
static PyObject *QBluetoothDeviceInfo_ServiceClass_CppToPython_QBluetoothDeviceInfo_ServiceClass(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QBluetoothDeviceInfo::ServiceClass *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_ServiceClass_IDX]), castCppIn);

}

static void QBluetoothDeviceInfo_Field_PythonToCpp_QBluetoothDeviceInfo_Field(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceInfo::Field>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceInfo::Field *>(cppOut) = value;

}
static PythonToCppFunc is_QBluetoothDeviceInfo_Field_PythonToCpp_QBluetoothDeviceInfo_Field_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_Field_IDX])))
        return QBluetoothDeviceInfo_Field_PythonToCpp_QBluetoothDeviceInfo_Field;
    return {};
}
static PyObject *QBluetoothDeviceInfo_Field_CppToPython_QBluetoothDeviceInfo_Field(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QBluetoothDeviceInfo::Field *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_Field_IDX]), castCppIn);

}

static void QBluetoothDeviceInfo_CoreConfiguration_PythonToCpp_QBluetoothDeviceInfo_CoreConfiguration(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QBluetoothDeviceInfo::CoreConfiguration>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QBluetoothDeviceInfo::CoreConfiguration *>(cppOut) = value;

}
static PythonToCppFunc is_QBluetoothDeviceInfo_CoreConfiguration_PythonToCpp_QBluetoothDeviceInfo_CoreConfiguration_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_CoreConfiguration_IDX])))
        return QBluetoothDeviceInfo_CoreConfiguration_PythonToCpp_QBluetoothDeviceInfo_CoreConfiguration;
    return {};
}
static PyObject *QBluetoothDeviceInfo_CoreConfiguration_CppToPython_QBluetoothDeviceInfo_CoreConfiguration(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QBluetoothDeviceInfo::CoreConfiguration *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_CoreConfiguration_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QBluetoothDeviceInfo_PythonToCpp_QBluetoothDeviceInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QBluetoothDeviceInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QBluetoothDeviceInfo_PythonToCpp_QBluetoothDeviceInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QBluetoothDeviceInfo_TypeF()))
        return QBluetoothDeviceInfo_PythonToCpp_QBluetoothDeviceInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QBluetoothDeviceInfo_PTR_CppToPython_QBluetoothDeviceInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QBluetoothDeviceInfo *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QBluetoothDeviceInfo_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QBluetoothDeviceInfo_COPY_CppToPython_QBluetoothDeviceInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QBluetoothDeviceInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QBluetoothDeviceInfo_TypeF(), new ::QBluetoothDeviceInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QBluetoothDeviceInfo_PythonToCpp_QBluetoothDeviceInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QBluetoothDeviceInfo *>(cppOut) = *reinterpret_cast< ::QBluetoothDeviceInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QBluetoothDeviceInfo_PythonToCpp_QBluetoothDeviceInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QBluetoothDeviceInfo_TypeF()))
        return QBluetoothDeviceInfo_PythonToCpp_QBluetoothDeviceInfo_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QBluetoothDeviceInfo_SignatureStrings[] = {
    "3:PySide6.QtBluetooth.QBluetoothDeviceInfo(self)",
    "2:PySide6.QtBluetooth.QBluetoothDeviceInfo(self,address:PySide6.QtBluetooth.QBluetoothAddress,name:QString,classOfDevice:quint32)",
    "1:PySide6.QtBluetooth.QBluetoothDeviceInfo(self,other:PySide6.QtBluetooth.QBluetoothDeviceInfo)",
    "0:PySide6.QtBluetooth.QBluetoothDeviceInfo(self,uuid:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid],name:QString,classOfDevice:quint32)",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.address(self)->PySide6.QtBluetooth.QBluetoothAddress",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.coreConfigurations(self)->PySide6.QtBluetooth.QBluetoothDeviceInfo.CoreConfiguration",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.deviceUuid(self)->PySide6.QtBluetooth.QBluetoothUuid",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.isCached(self)->bool",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.isValid(self)->bool",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.majorDeviceClass(self)->PySide6.QtBluetooth.QBluetoothDeviceInfo.MajorDeviceClass",
    "1:PySide6.QtBluetooth.QBluetoothDeviceInfo.manufacturerData(self)->QMultiHash[quint16, PySide6.QtCore.QByteArray]",
    "0:PySide6.QtBluetooth.QBluetoothDeviceInfo.manufacturerData(self,manufacturerId:quint16)->PySide6.QtCore.QByteArray",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.manufacturerIds(self)->QList[quint16]",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.minorDeviceClass(self)->quint8",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.name(self)->QString",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.rssi(self)->qint16",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.serviceClasses(self)->PySide6.QtBluetooth.QBluetoothDeviceInfo.ServiceClass",
    "1:PySide6.QtBluetooth.QBluetoothDeviceInfo.serviceData(self)->QMultiHash[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtCore.QByteArray]",
    "0:PySide6.QtBluetooth.QBluetoothDeviceInfo.serviceData(self,serviceId:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid])->PySide6.QtCore.QByteArray",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.serviceIds(self)->QList[PySide6.QtBluetooth.QBluetoothUuid]",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.serviceUuids(self)->QList[PySide6.QtBluetooth.QBluetoothUuid]",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.setCached(self,cached:bool)",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.setCoreConfigurations(self,coreConfigs:PySide6.QtBluetooth.QBluetoothDeviceInfo.CoreConfiguration)",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.setDeviceUuid(self,uuid:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid])",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.setManufacturerData(self,manufacturerId:quint16,data:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.setName(self,name:QString)",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.setRssi(self,signal:qint16)",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.setServiceData(self,serviceId:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid],data:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.setServiceUuids(self,uuids:QList[PySide6.QtBluetooth.QBluetoothUuid])",
    "PySide6.QtBluetooth.QBluetoothDeviceInfo.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QBluetoothDeviceInfo(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QBluetoothDeviceInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QBluetoothDeviceInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QBluetoothDeviceInfo",
        "QBluetoothDeviceInfo",
        &Sbk_QBluetoothDeviceInfo_spec,
        &Shiboken::callCppDestructor< ::QBluetoothDeviceInfo >,
        Sbk_QBluetoothDeviceInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QBluetoothDeviceInfo_TypeF(); // references _Sbk_QBluetoothDeviceInfo_Type
    InitSignatureStrings(pyType, QBluetoothDeviceInfo_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QBluetoothDeviceInfo_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QBluetoothDeviceInfo_PythonToCpp_QBluetoothDeviceInfo_PTR,
        is_QBluetoothDeviceInfo_PythonToCpp_QBluetoothDeviceInfo_PTR_Convertible,
        QBluetoothDeviceInfo_PTR_CppToPython_QBluetoothDeviceInfo,
        QBluetoothDeviceInfo_COPY_CppToPython_QBluetoothDeviceInfo);

    Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QBluetoothDeviceInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QBluetoothDeviceInfo_PythonToCpp_QBluetoothDeviceInfo_COPY,
        is_QBluetoothDeviceInfo_PythonToCpp_QBluetoothDeviceInfo_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QBluetoothDeviceInfo_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'MajorDeviceClass'.
    const char *MajorDeviceClass_Initializer[] = {
        "MiscellaneousDevice",
        "ComputerDevice",
        "PhoneDevice",
        "NetworkDevice",
        "AudioVideoDevice",
        "PeripheralDevice",
        "ImagingDevice",
        "WearableDevice",
        "ToyDevice",
        "HealthDevice",
        "UncategorizedDevice",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MajorDeviceClass_InitializerValues[] = {
        uint8_t(QBluetoothDeviceInfo::MajorDeviceClass::MiscellaneousDevice), //  0x00  0
        uint8_t(QBluetoothDeviceInfo::MajorDeviceClass::ComputerDevice),      //  0x01  1
        uint8_t(QBluetoothDeviceInfo::MajorDeviceClass::PhoneDevice),         //  0x02  2
        uint8_t(QBluetoothDeviceInfo::MajorDeviceClass::NetworkDevice),       //  0x03  3
        uint8_t(QBluetoothDeviceInfo::MajorDeviceClass::AudioVideoDevice),    //  0x04  4
        uint8_t(QBluetoothDeviceInfo::MajorDeviceClass::PeripheralDevice),    //  0x05  5
        uint8_t(QBluetoothDeviceInfo::MajorDeviceClass::ImagingDevice),       //  0x06  6
        uint8_t(QBluetoothDeviceInfo::MajorDeviceClass::WearableDevice),      //  0x07  7
        uint8_t(QBluetoothDeviceInfo::MajorDeviceClass::ToyDevice),           //  0x08  8
        uint8_t(QBluetoothDeviceInfo::MajorDeviceClass::HealthDevice),        //  0x09  9
        uint8_t(QBluetoothDeviceInfo::MajorDeviceClass::UncategorizedDevice)  //  0x1f  31
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceInfo_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceInfo.MajorDeviceClass",
        MajorDeviceClass_Initializer, MajorDeviceClass_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MajorDeviceClass_IDX].type = EType;
    // Register converter for enum 'QBluetoothDeviceInfo::MajorDeviceClass'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceInfo_MajorDeviceClass_CppToPython_QBluetoothDeviceInfo_MajorDeviceClass);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QBluetoothDeviceInfo_MajorDeviceClass_PythonToCpp_QBluetoothDeviceInfo_MajorDeviceClass,
            is_QBluetoothDeviceInfo_MajorDeviceClass_PythonToCpp_QBluetoothDeviceInfo_MajorDeviceClass_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::MajorDeviceClass");
        Shiboken::Conversions::registerConverterName(converter, "MajorDeviceClass");
    }
    // End of 'MajorDeviceClass' enum.

    // Initialization of enum 'MinorMiscellaneousClass'.
    const char *MinorMiscellaneousClass_Initializer[] = {
        "UncategorizedMiscellaneous",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MinorMiscellaneousClass_InitializerValues[] = {
        uint8_t(QBluetoothDeviceInfo::MinorMiscellaneousClass::UncategorizedMiscellaneous) //  0x00  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceInfo_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorMiscellaneousClass",
        MinorMiscellaneousClass_Initializer, MinorMiscellaneousClass_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorMiscellaneousClass_IDX].type = EType;
    // Register converter for enum 'QBluetoothDeviceInfo::MinorMiscellaneousClass'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceInfo_MinorMiscellaneousClass_CppToPython_QBluetoothDeviceInfo_MinorMiscellaneousClass);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QBluetoothDeviceInfo_MinorMiscellaneousClass_PythonToCpp_QBluetoothDeviceInfo_MinorMiscellaneousClass,
            is_QBluetoothDeviceInfo_MinorMiscellaneousClass_PythonToCpp_QBluetoothDeviceInfo_MinorMiscellaneousClass_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::MinorMiscellaneousClass");
        Shiboken::Conversions::registerConverterName(converter, "MinorMiscellaneousClass");
    }
    // End of 'MinorMiscellaneousClass' enum.

    // Initialization of enum 'MinorComputerClass'.
    const char *MinorComputerClass_Initializer[] = {
        "UncategorizedComputer",
        "DesktopComputer",
        "ServerComputer",
        "LaptopComputer",
        "HandheldClamShellComputer",
        "HandheldComputer",
        "WearableComputer",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MinorComputerClass_InitializerValues[] = {
        uint8_t(QBluetoothDeviceInfo::MinorComputerClass::UncategorizedComputer),     //  0x00  0
        uint8_t(QBluetoothDeviceInfo::MinorComputerClass::DesktopComputer),           //  0x01  1
        uint8_t(QBluetoothDeviceInfo::MinorComputerClass::ServerComputer),            //  0x02  2
        uint8_t(QBluetoothDeviceInfo::MinorComputerClass::LaptopComputer),            //  0x03  3
        uint8_t(QBluetoothDeviceInfo::MinorComputerClass::HandheldClamShellComputer), //  0x04  4
        uint8_t(QBluetoothDeviceInfo::MinorComputerClass::HandheldComputer),          //  0x05  5
        uint8_t(QBluetoothDeviceInfo::MinorComputerClass::WearableComputer)           //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceInfo_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorComputerClass",
        MinorComputerClass_Initializer, MinorComputerClass_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorComputerClass_IDX].type = EType;
    // Register converter for enum 'QBluetoothDeviceInfo::MinorComputerClass'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceInfo_MinorComputerClass_CppToPython_QBluetoothDeviceInfo_MinorComputerClass);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QBluetoothDeviceInfo_MinorComputerClass_PythonToCpp_QBluetoothDeviceInfo_MinorComputerClass,
            is_QBluetoothDeviceInfo_MinorComputerClass_PythonToCpp_QBluetoothDeviceInfo_MinorComputerClass_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::MinorComputerClass");
        Shiboken::Conversions::registerConverterName(converter, "MinorComputerClass");
    }
    // End of 'MinorComputerClass' enum.

    // Initialization of enum 'MinorPhoneClass'.
    const char *MinorPhoneClass_Initializer[] = {
        "UncategorizedPhone",
        "CellularPhone",
        "CordlessPhone",
        "SmartPhone",
        "WiredModemOrVoiceGatewayPhone",
        "CommonIsdnAccessPhone",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MinorPhoneClass_InitializerValues[] = {
        uint8_t(QBluetoothDeviceInfo::MinorPhoneClass::UncategorizedPhone),            //  0x00  0
        uint8_t(QBluetoothDeviceInfo::MinorPhoneClass::CellularPhone),                 //  0x01  1
        uint8_t(QBluetoothDeviceInfo::MinorPhoneClass::CordlessPhone),                 //  0x02  2
        uint8_t(QBluetoothDeviceInfo::MinorPhoneClass::SmartPhone),                    //  0x03  3
        uint8_t(QBluetoothDeviceInfo::MinorPhoneClass::WiredModemOrVoiceGatewayPhone), //  0x04  4
        uint8_t(QBluetoothDeviceInfo::MinorPhoneClass::CommonIsdnAccessPhone)          //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceInfo_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorPhoneClass",
        MinorPhoneClass_Initializer, MinorPhoneClass_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorPhoneClass_IDX].type = EType;
    // Register converter for enum 'QBluetoothDeviceInfo::MinorPhoneClass'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceInfo_MinorPhoneClass_CppToPython_QBluetoothDeviceInfo_MinorPhoneClass);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QBluetoothDeviceInfo_MinorPhoneClass_PythonToCpp_QBluetoothDeviceInfo_MinorPhoneClass,
            is_QBluetoothDeviceInfo_MinorPhoneClass_PythonToCpp_QBluetoothDeviceInfo_MinorPhoneClass_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::MinorPhoneClass");
        Shiboken::Conversions::registerConverterName(converter, "MinorPhoneClass");
    }
    // End of 'MinorPhoneClass' enum.

    // Initialization of enum 'MinorNetworkClass'.
    const char *MinorNetworkClass_Initializer[] = {
        "NetworkFullService",
        "NetworkLoadFactorOne",
        "NetworkLoadFactorTwo",
        "NetworkLoadFactorThree",
        "NetworkLoadFactorFour",
        "NetworkLoadFactorFive",
        "NetworkLoadFactorSix",
        "NetworkNoService",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MinorNetworkClass_InitializerValues[] = {
        uint8_t(QBluetoothDeviceInfo::MinorNetworkClass::NetworkFullService),     //  0x00  0
        uint8_t(QBluetoothDeviceInfo::MinorNetworkClass::NetworkLoadFactorOne),   //  0x08  8
        uint8_t(QBluetoothDeviceInfo::MinorNetworkClass::NetworkLoadFactorTwo),   //  0x10  16
        uint8_t(QBluetoothDeviceInfo::MinorNetworkClass::NetworkLoadFactorThree), //  0x18  24
        uint8_t(QBluetoothDeviceInfo::MinorNetworkClass::NetworkLoadFactorFour),  //  0x20  32
        uint8_t(QBluetoothDeviceInfo::MinorNetworkClass::NetworkLoadFactorFive),  //  0x28  40
        uint8_t(QBluetoothDeviceInfo::MinorNetworkClass::NetworkLoadFactorSix),   //  0x30  48
        uint8_t(QBluetoothDeviceInfo::MinorNetworkClass::NetworkNoService)        //  0x38  56
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceInfo_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorNetworkClass",
        MinorNetworkClass_Initializer, MinorNetworkClass_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorNetworkClass_IDX].type = EType;
    // Register converter for enum 'QBluetoothDeviceInfo::MinorNetworkClass'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceInfo_MinorNetworkClass_CppToPython_QBluetoothDeviceInfo_MinorNetworkClass);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QBluetoothDeviceInfo_MinorNetworkClass_PythonToCpp_QBluetoothDeviceInfo_MinorNetworkClass,
            is_QBluetoothDeviceInfo_MinorNetworkClass_PythonToCpp_QBluetoothDeviceInfo_MinorNetworkClass_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::MinorNetworkClass");
        Shiboken::Conversions::registerConverterName(converter, "MinorNetworkClass");
    }
    // End of 'MinorNetworkClass' enum.

    // Initialization of enum 'MinorAudioVideoClass'.
    const char *MinorAudioVideoClass_Initializer[] = {
        "UncategorizedAudioVideoDevice",
        "WearableHeadsetDevice",
        "HandsFreeDevice",
        "Microphone",
        "Loudspeaker",
        "Headphones",
        "PortableAudioDevice",
        "CarAudio",
        "SetTopBox",
        "HiFiAudioDevice",
        "Vcr",
        "VideoCamera",
        "Camcorder",
        "VideoMonitor",
        "VideoDisplayAndLoudspeaker",
        "VideoConferencing",
        "GamingDevice",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MinorAudioVideoClass_InitializerValues[] = {
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::UncategorizedAudioVideoDevice), //  0x00  0
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::WearableHeadsetDevice),         //  0x01  1
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::HandsFreeDevice),               //  0x02  2
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::Microphone),                    //  0x04  4
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::Loudspeaker),                   //  0x05  5
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::Headphones),                    //  0x06  6
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::PortableAudioDevice),           //  0x07  7
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::CarAudio),                      //  0x08  8
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::SetTopBox),                     //  0x09  9
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::HiFiAudioDevice),               //  0x0a  10
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::Vcr),                           //  0x0b  11
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::VideoCamera),                   //  0x0c  12
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::Camcorder),                     //  0x0d  13
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::VideoMonitor),                  //  0x0e  14
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::VideoDisplayAndLoudspeaker),    //  0x0f  15
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::VideoConferencing),             //  0x10  16
        uint8_t(QBluetoothDeviceInfo::MinorAudioVideoClass::GamingDevice)                   //  0x12  18
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceInfo_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorAudioVideoClass",
        MinorAudioVideoClass_Initializer, MinorAudioVideoClass_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorAudioVideoClass_IDX].type = EType;
    // Register converter for enum 'QBluetoothDeviceInfo::MinorAudioVideoClass'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceInfo_MinorAudioVideoClass_CppToPython_QBluetoothDeviceInfo_MinorAudioVideoClass);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QBluetoothDeviceInfo_MinorAudioVideoClass_PythonToCpp_QBluetoothDeviceInfo_MinorAudioVideoClass,
            is_QBluetoothDeviceInfo_MinorAudioVideoClass_PythonToCpp_QBluetoothDeviceInfo_MinorAudioVideoClass_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::MinorAudioVideoClass");
        Shiboken::Conversions::registerConverterName(converter, "MinorAudioVideoClass");
    }
    // End of 'MinorAudioVideoClass' enum.

    // Initialization of enum 'MinorPeripheralClass'.
    const char *MinorPeripheralClass_Initializer[] = {
        "UncategorizedPeripheral",
        "KeyboardPeripheral",
        "PointingDevicePeripheral",
        "KeyboardWithPointingDevicePeripheral",
        "JoystickPeripheral",
        "GamepadPeripheral",
        "RemoteControlPeripheral",
        "SensingDevicePeripheral",
        "DigitizerTabletPeripheral",
        "CardReaderPeripheral",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MinorPeripheralClass_InitializerValues[] = {
        uint8_t(QBluetoothDeviceInfo::MinorPeripheralClass::UncategorizedPeripheral),              //  0x00  0
        uint8_t(QBluetoothDeviceInfo::MinorPeripheralClass::KeyboardPeripheral),                   //  0x10  16
        uint8_t(QBluetoothDeviceInfo::MinorPeripheralClass::PointingDevicePeripheral),             //  0x20  32
        uint8_t(QBluetoothDeviceInfo::MinorPeripheralClass::KeyboardWithPointingDevicePeripheral), //  0x30  48
        uint8_t(QBluetoothDeviceInfo::MinorPeripheralClass::JoystickPeripheral),                   //  0x01  1
        uint8_t(QBluetoothDeviceInfo::MinorPeripheralClass::GamepadPeripheral),                    //  0x02  2
        uint8_t(QBluetoothDeviceInfo::MinorPeripheralClass::RemoteControlPeripheral),              //  0x03  3
        uint8_t(QBluetoothDeviceInfo::MinorPeripheralClass::SensingDevicePeripheral),              //  0x04  4
        uint8_t(QBluetoothDeviceInfo::MinorPeripheralClass::DigitizerTabletPeripheral),            //  0x05  5
        uint8_t(QBluetoothDeviceInfo::MinorPeripheralClass::CardReaderPeripheral)                  //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceInfo_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorPeripheralClass",
        MinorPeripheralClass_Initializer, MinorPeripheralClass_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorPeripheralClass_IDX].type = EType;
    // Register converter for enum 'QBluetoothDeviceInfo::MinorPeripheralClass'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceInfo_MinorPeripheralClass_CppToPython_QBluetoothDeviceInfo_MinorPeripheralClass);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QBluetoothDeviceInfo_MinorPeripheralClass_PythonToCpp_QBluetoothDeviceInfo_MinorPeripheralClass,
            is_QBluetoothDeviceInfo_MinorPeripheralClass_PythonToCpp_QBluetoothDeviceInfo_MinorPeripheralClass_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::MinorPeripheralClass");
        Shiboken::Conversions::registerConverterName(converter, "MinorPeripheralClass");
    }
    // End of 'MinorPeripheralClass' enum.

    // Initialization of enum 'MinorImagingClass'.
    const char *MinorImagingClass_Initializer[] = {
        "UncategorizedImagingDevice",
        "ImageDisplay",
        "ImageCamera",
        "ImageScanner",
        "ImagePrinter",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MinorImagingClass_InitializerValues[] = {
        uint8_t(QBluetoothDeviceInfo::MinorImagingClass::UncategorizedImagingDevice), //  0x00  0
        uint8_t(QBluetoothDeviceInfo::MinorImagingClass::ImageDisplay),               //  0x04  4
        uint8_t(QBluetoothDeviceInfo::MinorImagingClass::ImageCamera),                //  0x08  8
        uint8_t(QBluetoothDeviceInfo::MinorImagingClass::ImageScanner),               //  0x10  16
        uint8_t(QBluetoothDeviceInfo::MinorImagingClass::ImagePrinter)                //  0x20  32
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceInfo_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorImagingClass",
        MinorImagingClass_Initializer, MinorImagingClass_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorImagingClass_IDX].type = EType;
    // Register converter for enum 'QBluetoothDeviceInfo::MinorImagingClass'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceInfo_MinorImagingClass_CppToPython_QBluetoothDeviceInfo_MinorImagingClass);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QBluetoothDeviceInfo_MinorImagingClass_PythonToCpp_QBluetoothDeviceInfo_MinorImagingClass,
            is_QBluetoothDeviceInfo_MinorImagingClass_PythonToCpp_QBluetoothDeviceInfo_MinorImagingClass_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::MinorImagingClass");
        Shiboken::Conversions::registerConverterName(converter, "MinorImagingClass");
    }
    // End of 'MinorImagingClass' enum.

    // Initialization of enum 'MinorWearableClass'.
    const char *MinorWearableClass_Initializer[] = {
        "UncategorizedWearableDevice",
        "WearableWristWatch",
        "WearablePager",
        "WearableJacket",
        "WearableHelmet",
        "WearableGlasses",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MinorWearableClass_InitializerValues[] = {
        uint8_t(QBluetoothDeviceInfo::MinorWearableClass::UncategorizedWearableDevice), //  0x00  0
        uint8_t(QBluetoothDeviceInfo::MinorWearableClass::WearableWristWatch),          //  0x01  1
        uint8_t(QBluetoothDeviceInfo::MinorWearableClass::WearablePager),               //  0x02  2
        uint8_t(QBluetoothDeviceInfo::MinorWearableClass::WearableJacket),              //  0x03  3
        uint8_t(QBluetoothDeviceInfo::MinorWearableClass::WearableHelmet),              //  0x04  4
        uint8_t(QBluetoothDeviceInfo::MinorWearableClass::WearableGlasses)              //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceInfo_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorWearableClass",
        MinorWearableClass_Initializer, MinorWearableClass_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorWearableClass_IDX].type = EType;
    // Register converter for enum 'QBluetoothDeviceInfo::MinorWearableClass'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceInfo_MinorWearableClass_CppToPython_QBluetoothDeviceInfo_MinorWearableClass);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QBluetoothDeviceInfo_MinorWearableClass_PythonToCpp_QBluetoothDeviceInfo_MinorWearableClass,
            is_QBluetoothDeviceInfo_MinorWearableClass_PythonToCpp_QBluetoothDeviceInfo_MinorWearableClass_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::MinorWearableClass");
        Shiboken::Conversions::registerConverterName(converter, "MinorWearableClass");
    }
    // End of 'MinorWearableClass' enum.

    // Initialization of enum 'MinorToyClass'.
    const char *MinorToyClass_Initializer[] = {
        "UncategorizedToy",
        "ToyRobot",
        "ToyVehicle",
        "ToyDoll",
        "ToyController",
        "ToyGame",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MinorToyClass_InitializerValues[] = {
        uint8_t(QBluetoothDeviceInfo::MinorToyClass::UncategorizedToy), //  0x00  0
        uint8_t(QBluetoothDeviceInfo::MinorToyClass::ToyRobot),         //  0x01  1
        uint8_t(QBluetoothDeviceInfo::MinorToyClass::ToyVehicle),       //  0x02  2
        uint8_t(QBluetoothDeviceInfo::MinorToyClass::ToyDoll),          //  0x03  3
        uint8_t(QBluetoothDeviceInfo::MinorToyClass::ToyController),    //  0x04  4
        uint8_t(QBluetoothDeviceInfo::MinorToyClass::ToyGame)           //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceInfo_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorToyClass",
        MinorToyClass_Initializer, MinorToyClass_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorToyClass_IDX].type = EType;
    // Register converter for enum 'QBluetoothDeviceInfo::MinorToyClass'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceInfo_MinorToyClass_CppToPython_QBluetoothDeviceInfo_MinorToyClass);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QBluetoothDeviceInfo_MinorToyClass_PythonToCpp_QBluetoothDeviceInfo_MinorToyClass,
            is_QBluetoothDeviceInfo_MinorToyClass_PythonToCpp_QBluetoothDeviceInfo_MinorToyClass_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::MinorToyClass");
        Shiboken::Conversions::registerConverterName(converter, "MinorToyClass");
    }
    // End of 'MinorToyClass' enum.

    // Initialization of enum 'MinorHealthClass'.
    const char *MinorHealthClass_Initializer[] = {
        "UncategorizedHealthDevice",
        "HealthBloodPressureMonitor",
        "HealthThermometer",
        "HealthWeightScale",
        "HealthGlucoseMeter",
        "HealthPulseOximeter",
        "HealthDataDisplay",
        "HealthStepCounter",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MinorHealthClass_InitializerValues[] = {
        uint8_t(QBluetoothDeviceInfo::MinorHealthClass::UncategorizedHealthDevice),  //  0x00  0
        uint8_t(QBluetoothDeviceInfo::MinorHealthClass::HealthBloodPressureMonitor), //  0x01  1
        uint8_t(QBluetoothDeviceInfo::MinorHealthClass::HealthThermometer),          //  0x02  2
        uint8_t(QBluetoothDeviceInfo::MinorHealthClass::HealthWeightScale),          //  0x03  3
        uint8_t(QBluetoothDeviceInfo::MinorHealthClass::HealthGlucoseMeter),         //  0x04  4
        uint8_t(QBluetoothDeviceInfo::MinorHealthClass::HealthPulseOximeter),        //  0x05  5
        uint8_t(QBluetoothDeviceInfo::MinorHealthClass::HealthDataDisplay),          //  0x07  7
        uint8_t(QBluetoothDeviceInfo::MinorHealthClass::HealthStepCounter)           //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceInfo_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorHealthClass",
        MinorHealthClass_Initializer, MinorHealthClass_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_MinorHealthClass_IDX].type = EType;
    // Register converter for enum 'QBluetoothDeviceInfo::MinorHealthClass'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceInfo_MinorHealthClass_CppToPython_QBluetoothDeviceInfo_MinorHealthClass);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QBluetoothDeviceInfo_MinorHealthClass_PythonToCpp_QBluetoothDeviceInfo_MinorHealthClass,
            is_QBluetoothDeviceInfo_MinorHealthClass_PythonToCpp_QBluetoothDeviceInfo_MinorHealthClass_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::MinorHealthClass");
        Shiboken::Conversions::registerConverterName(converter, "MinorHealthClass");
    }
    // End of 'MinorHealthClass' enum.

    // Initialization of enum 'ServiceClass'.
    const char *ServiceClass_Initializer[] = {
        "NoService",
        "PositioningService",
        "NetworkingService",
        "RenderingService",
        "CapturingService",
        "ObjectTransferService",
        "AudioService",
        "TelephonyService",
        "InformationService",
        "AllServices",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t ServiceClass_InitializerValues[] = {
        uint16_t(QBluetoothDeviceInfo::ServiceClass::NoService),             //  0x0000  0
        uint16_t(QBluetoothDeviceInfo::ServiceClass::PositioningService),    //  0x0001  1
        uint16_t(QBluetoothDeviceInfo::ServiceClass::NetworkingService),     //  0x0002  2
        uint16_t(QBluetoothDeviceInfo::ServiceClass::RenderingService),      //  0x0004  4
        uint16_t(QBluetoothDeviceInfo::ServiceClass::CapturingService),      //  0x0008  8
        uint16_t(QBluetoothDeviceInfo::ServiceClass::ObjectTransferService), //  0x0010  16
        uint16_t(QBluetoothDeviceInfo::ServiceClass::AudioService),          //  0x0020  32
        uint16_t(QBluetoothDeviceInfo::ServiceClass::TelephonyService),      //  0x0040  64
        uint16_t(QBluetoothDeviceInfo::ServiceClass::InformationService),    //  0x0080  128
        uint16_t(QBluetoothDeviceInfo::ServiceClass::AllServices)            //  0x07ff  2047
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceInfo_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceInfo.ServiceClass",
        ServiceClass_Initializer, ServiceClass_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_ServiceClass_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetoothDeviceInfo_ServiceClass_IDX].type =
        EType;
    // Register converter for enum 'QBluetoothDeviceInfo::ServiceClass'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceInfo_ServiceClass_CppToPython_QBluetoothDeviceInfo_ServiceClass);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QBluetoothDeviceInfo_ServiceClass_PythonToCpp_QBluetoothDeviceInfo_ServiceClass,
            is_QBluetoothDeviceInfo_ServiceClass_PythonToCpp_QBluetoothDeviceInfo_ServiceClass_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::ServiceClass");
        Shiboken::Conversions::registerConverterName(converter, "ServiceClass");
        // Register converter for flag 'QFlags<QBluetoothDeviceInfo::ServiceClass>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QBluetoothDeviceInfo::ServiceClass>");
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::ServiceClasses");
    }
    // End of 'ServiceClass' enum/flags.

    // Initialization of enum 'Field'.
    const char *Field_Initializer[] = {
        "None_",
        "RSSI",
        "ManufacturerData",
        "ServiceData",
        "All",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t Field_InitializerValues[] = {
        int16_t(QBluetoothDeviceInfo::Field::None),             //  0x0000  0
        int16_t(QBluetoothDeviceInfo::Field::RSSI),             //  0x0001  1
        int16_t(QBluetoothDeviceInfo::Field::ManufacturerData), //  0x0002  2
        int16_t(QBluetoothDeviceInfo::Field::ServiceData),      //  0x0004  4
        int16_t(QBluetoothDeviceInfo::Field::All)               //  0x7fff  32767
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceInfo_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceInfo.Field",
        Field_Initializer, Field_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_Field_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetoothDeviceInfo_Field_IDX].type =
        EType;
    // Register converter for enum 'QBluetoothDeviceInfo::Field'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceInfo_Field_CppToPython_QBluetoothDeviceInfo_Field);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QBluetoothDeviceInfo_Field_PythonToCpp_QBluetoothDeviceInfo_Field,
            is_QBluetoothDeviceInfo_Field_PythonToCpp_QBluetoothDeviceInfo_Field_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::Field");
        Shiboken::Conversions::registerConverterName(converter, "Field");
        // Register converter for flag 'QFlags<QBluetoothDeviceInfo::Field>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QBluetoothDeviceInfo::Field>");
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::Fields");
    }
    // End of 'Field' enum/flags.

    // Initialization of enum 'CoreConfiguration'.
    const char *CoreConfiguration_Initializer[] = {
        "UnknownCoreConfiguration",
        "LowEnergyCoreConfiguration",
        "BaseRateCoreConfiguration",
        "BaseRateAndLowEnergyCoreConfiguration",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CoreConfiguration_InitializerValues[] = {
        uint8_t(QBluetoothDeviceInfo::CoreConfiguration::UnknownCoreConfiguration),             //  0x00  0
        uint8_t(QBluetoothDeviceInfo::CoreConfiguration::LowEnergyCoreConfiguration),           //  0x01  1
        uint8_t(QBluetoothDeviceInfo::CoreConfiguration::BaseRateCoreConfiguration),            //  0x02  2
        uint8_t(QBluetoothDeviceInfo::CoreConfiguration::BaseRateAndLowEnergyCoreConfiguration) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QBluetoothDeviceInfo_TypeF(),
        "2:PySide6.QtBluetooth.QBluetoothDeviceInfo.CoreConfiguration",
        CoreConfiguration_Initializer, CoreConfiguration_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_CoreConfiguration_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtBluetoothTypeStructs[SBK_QFlags_QBluetoothDeviceInfo_CoreConfiguration_IDX].type =
        EType;
    // Register converter for enum 'QBluetoothDeviceInfo::CoreConfiguration'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QBluetoothDeviceInfo_CoreConfiguration_CppToPython_QBluetoothDeviceInfo_CoreConfiguration);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QBluetoothDeviceInfo_CoreConfiguration_PythonToCpp_QBluetoothDeviceInfo_CoreConfiguration,
            is_QBluetoothDeviceInfo_CoreConfiguration_PythonToCpp_QBluetoothDeviceInfo_CoreConfiguration_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::CoreConfiguration");
        Shiboken::Conversions::registerConverterName(converter, "CoreConfiguration");
        // Register converter for flag 'QFlags<QBluetoothDeviceInfo::CoreConfiguration>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QBluetoothDeviceInfo::CoreConfiguration>");
        Shiboken::Conversions::registerConverterName(converter, "QBluetoothDeviceInfo::CoreConfigurations");
    }
    // End of 'CoreConfiguration' enum/flags.

    qRegisterMetaType< ::QBluetoothDeviceInfo >("QBluetoothDeviceInfo");
    qRegisterMetaType< ::QBluetoothDeviceInfo::MajorDeviceClass >("QBluetoothDeviceInfo::MajorDeviceClass");
    qRegisterMetaType< ::QBluetoothDeviceInfo::MinorMiscellaneousClass >("QBluetoothDeviceInfo::MinorMiscellaneousClass");
    qRegisterMetaType< ::QBluetoothDeviceInfo::MinorComputerClass >("QBluetoothDeviceInfo::MinorComputerClass");
    qRegisterMetaType< ::QBluetoothDeviceInfo::MinorPhoneClass >("QBluetoothDeviceInfo::MinorPhoneClass");
    qRegisterMetaType< ::QBluetoothDeviceInfo::MinorNetworkClass >("QBluetoothDeviceInfo::MinorNetworkClass");
    qRegisterMetaType< ::QBluetoothDeviceInfo::MinorAudioVideoClass >("QBluetoothDeviceInfo::MinorAudioVideoClass");
    qRegisterMetaType< ::QBluetoothDeviceInfo::MinorPeripheralClass >("QBluetoothDeviceInfo::MinorPeripheralClass");
    qRegisterMetaType< ::QBluetoothDeviceInfo::MinorImagingClass >("QBluetoothDeviceInfo::MinorImagingClass");
    qRegisterMetaType< ::QBluetoothDeviceInfo::MinorWearableClass >("QBluetoothDeviceInfo::MinorWearableClass");
    qRegisterMetaType< ::QBluetoothDeviceInfo::MinorToyClass >("QBluetoothDeviceInfo::MinorToyClass");
    qRegisterMetaType< ::QBluetoothDeviceInfo::MinorHealthClass >("QBluetoothDeviceInfo::MinorHealthClass");
    qRegisterMetaType< ::QBluetoothDeviceInfo::ServiceClass >("QBluetoothDeviceInfo::ServiceClass");
    qRegisterMetaType< ::QBluetoothDeviceInfo::Field >("QBluetoothDeviceInfo::Field");
    qRegisterMetaType< ::QBluetoothDeviceInfo::CoreConfiguration >("QBluetoothDeviceInfo::CoreConfiguration");

    return pyType;
}
