// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtbluetooth_python.h"

// main header
#include "qlowenergyservicedata_wrapper.h"

// Argument includes
#include <QList>
#include <QtBluetooth/qbluetoothuuid.h>
#include <QtBluetooth/qlowenergycharacteristicdata.h>
#include <QtBluetooth/qlowenergyservice.h>
#include <QtBluetooth/qlowenergyservicedata.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLowEnergyServiceData_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLowEnergyServiceData >()))
        return -1;

    ::QLowEnergyServiceData *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyServiceData.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QLowEnergyServiceData", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLowEnergyServiceData::QLowEnergyServiceData()
    // 1: QLowEnergyServiceData::QLowEnergyServiceData(QLowEnergyServiceData)
    if (numArgs == 0) {
        overloadId = 0; // QLowEnergyServiceData()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QLowEnergyServiceData(QLowEnergyServiceData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QLowEnergyServiceData()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QLowEnergyServiceData()
                cptr = new ::QLowEnergyServiceData();
            }
            break;
        }
        case 1: // QLowEnergyServiceData(const QLowEnergyServiceData & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLowEnergyServiceData cppArg0_local;
            ::QLowEnergyServiceData *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLowEnergyServiceData(QLowEnergyServiceData)
                cptr = new ::QLowEnergyServiceData(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLowEnergyServiceData >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_addCharacteristic(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyServiceData.addCharacteristic";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyServiceData::addCharacteristic(QLowEnergyCharacteristicData)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), (pyArg)))) {
        overloadId = 0; // addCharacteristic(QLowEnergyCharacteristicData)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyCharacteristicData cppArg0_local;
        ::QLowEnergyCharacteristicData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // addCharacteristic(QLowEnergyCharacteristicData)
            cppSelf->addCharacteristic(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_addIncludedService(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyServiceData.addIncludedService";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyServiceData::addIncludedService(QLowEnergyService*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), (pyArg)))) {
        overloadId = 0; // addIncludedService(QLowEnergyService*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyService *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addIncludedService(QLowEnergyService*)
            cppSelf->addIncludedService(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_characteristics(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyServiceData.characteristics";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // characteristics()const
            QList<QLowEnergyCharacteristicData> cppResult = const_cast<const ::QLowEnergyServiceData *>(cppSelf)->characteristics();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyCharacteristicData_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_includedServices(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyServiceData.includedServices";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // includedServices()const
            QList<QLowEnergyService*> cppResult = const_cast<const ::QLowEnergyServiceData *>(cppSelf)->includedServices();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyServicePTR_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyServiceData.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QLowEnergyServiceData *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_setCharacteristics(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyServiceData.setCharacteristics";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyServiceData::setCharacteristics(QList<QLowEnergyCharacteristicData>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyCharacteristicData_IDX], (pyArg)))) {
        overloadId = 0; // setCharacteristics(QList<QLowEnergyCharacteristicData>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QLowEnergyCharacteristicData> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCharacteristics(QList<QLowEnergyCharacteristicData>)
            cppSelf->setCharacteristics(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_setIncludedServices(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyServiceData.setIncludedServices";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyServiceData::setIncludedServices(QList<QLowEnergyService*>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyServicePTR_IDX], (pyArg)))) {
        overloadId = 0; // setIncludedServices(QList<QLowEnergyService*>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QLowEnergyService*> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIncludedServices(QList<QLowEnergyService*>)
            cppSelf->setIncludedServices(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_setType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyServiceData.setType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyServiceData::setType(QLowEnergyServiceData::ServiceType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_ServiceType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setType(QLowEnergyServiceData::ServiceType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QLowEnergyServiceData::ServiceType cppArg0 = static_cast< ::QLowEnergyServiceData::ServiceType>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setType(QLowEnergyServiceData::ServiceType)
            cppSelf->setType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_setUuid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyServiceData.setUuid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyServiceData::setUuid(QBluetoothUuid)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), (pyArg)))) {
        overloadId = 0; // setUuid(QBluetoothUuid)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBluetoothUuid cppArg0_local;
        ::QBluetoothUuid *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUuid(QBluetoothUuid)
            cppSelf->setUuid(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyServiceData.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLowEnergyServiceData::swap(QLowEnergyServiceData&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QLowEnergyServiceData&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLowEnergyServiceData cppArg0_local;
        ::QLowEnergyServiceData *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QLowEnergyServiceData&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyServiceData.type";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // type()const
            QLowEnergyServiceData::ServiceType cppResult = const_cast<const ::QLowEnergyServiceData *>(cppSelf)->type();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_ServiceType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceDataFunc_uuid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtBluetooth.QLowEnergyServiceData.uuid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // uuid()const
            QBluetoothUuid cppResult = const_cast<const ::QLowEnergyServiceData *>(cppSelf)->uuid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLowEnergyServiceData__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QLowEnergyServiceData_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QLowEnergyServiceData_EnumFlagInfo[] = {
    "ServiceType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLowEnergyServiceData_methods[] = {
    {"addCharacteristic", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_addCharacteristic), METH_O, nullptr},
    {"addIncludedService", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_addIncludedService), METH_O, nullptr},
    {"characteristics", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_characteristics), METH_NOARGS, nullptr},
    {"includedServices", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_includedServices), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_isValid), METH_NOARGS, nullptr},
    {"setCharacteristics", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_setCharacteristics), METH_O, nullptr},
    {"setIncludedServices", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_setIncludedServices), METH_O, nullptr},
    {"setType", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_setType), METH_O, nullptr},
    {"setUuid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_setUuid), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_swap), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_type), METH_NOARGS, nullptr},
    {"uuid", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceDataFunc_uuid), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QLowEnergyServiceData__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QLowEnergyServiceData_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), (pyArg)))) {
                // operator!=(const QLowEnergyServiceData & b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyServiceData cppArg0_local;
                ::QLowEnergyServiceData *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), (pyArg)))) {
                // operator==(const QLowEnergyServiceData & b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLowEnergyServiceData cppArg0_local;
                ::QLowEnergyServiceData *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QLowEnergyServiceData_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLowEnergyServiceData_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLowEnergyServiceData_Type = nullptr;
static PyTypeObject *Sbk_QLowEnergyServiceData_TypeF(void)
{
    return _Sbk_QLowEnergyServiceData_Type;
}

static PyType_Slot Sbk_QLowEnergyServiceData_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLowEnergyServiceData_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLowEnergyServiceData_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QLowEnergyServiceData_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLowEnergyServiceData_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLowEnergyServiceData_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLowEnergyServiceData_spec = {
    "2:PySide6.QtBluetooth.QLowEnergyServiceData",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLowEnergyServiceData_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QLowEnergyServiceData_ServiceType_PythonToCpp_QLowEnergyServiceData_ServiceType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLowEnergyServiceData::ServiceType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLowEnergyServiceData::ServiceType *>(cppOut) = value;

}
static PythonToCppFunc is_QLowEnergyServiceData_ServiceType_PythonToCpp_QLowEnergyServiceData_ServiceType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_ServiceType_IDX])))
        return QLowEnergyServiceData_ServiceType_PythonToCpp_QLowEnergyServiceData_ServiceType;
    return {};
}
static PyObject *QLowEnergyServiceData_ServiceType_CppToPython_QLowEnergyServiceData_ServiceType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QLowEnergyServiceData::ServiceType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_ServiceType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLowEnergyServiceData_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyServiceData_TypeF()))
        return QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLowEnergyServiceData_PTR_CppToPython_QLowEnergyServiceData(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QLowEnergyServiceData *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QLowEnergyServiceData_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QLowEnergyServiceData_COPY_CppToPython_QLowEnergyServiceData(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QLowEnergyServiceData *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QLowEnergyServiceData_TypeF(), new ::QLowEnergyServiceData(*source), true, true);
}

// Python to C++ copy conversion.
static void QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QLowEnergyServiceData *>(cppOut) = *reinterpret_cast< ::QLowEnergyServiceData *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QLowEnergyServiceData_TypeF()))
        return QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QLowEnergyServiceData_SignatureStrings[] = {
    "1:PySide6.QtBluetooth.QLowEnergyServiceData(self)",
    "0:PySide6.QtBluetooth.QLowEnergyServiceData(self,other:PySide6.QtBluetooth.QLowEnergyServiceData)",
    "PySide6.QtBluetooth.QLowEnergyServiceData.addCharacteristic(self,characteristic:PySide6.QtBluetooth.QLowEnergyCharacteristicData)",
    "PySide6.QtBluetooth.QLowEnergyServiceData.addIncludedService(self,service:PySide6.QtBluetooth.QLowEnergyService)",
    "PySide6.QtBluetooth.QLowEnergyServiceData.characteristics(self)->QList[PySide6.QtBluetooth.QLowEnergyCharacteristicData]",
    "PySide6.QtBluetooth.QLowEnergyServiceData.includedServices(self)->QList[PySide6.QtBluetooth.QLowEnergyService]",
    "PySide6.QtBluetooth.QLowEnergyServiceData.isValid(self)->bool",
    "PySide6.QtBluetooth.QLowEnergyServiceData.setCharacteristics(self,characteristics:QList[PySide6.QtBluetooth.QLowEnergyCharacteristicData])",
    "PySide6.QtBluetooth.QLowEnergyServiceData.setIncludedServices(self,services:QList[PySide6.QtBluetooth.QLowEnergyService])",
    "PySide6.QtBluetooth.QLowEnergyServiceData.setType(self,type:PySide6.QtBluetooth.QLowEnergyServiceData.ServiceType)",
    "PySide6.QtBluetooth.QLowEnergyServiceData.setUuid(self,uuid:typing.Union[PySide6.QtBluetooth.QBluetoothUuid, PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType, PySide6.QtBluetooth.QBluetoothUuid.DescriptorType, PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid, PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid, PySide6.QtCore.QUuid])",
    "PySide6.QtBluetooth.QLowEnergyServiceData.swap(self,other:PySide6.QtBluetooth.QLowEnergyServiceData)",
    "PySide6.QtBluetooth.QLowEnergyServiceData.type(self)->PySide6.QtBluetooth.QLowEnergyServiceData.ServiceType",
    "PySide6.QtBluetooth.QLowEnergyServiceData.uuid(self)->PySide6.QtBluetooth.QBluetoothUuid",
    "PySide6.QtBluetooth.QLowEnergyServiceData.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QLowEnergyServiceData(PyObject *module)
{
    if (SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX].type != nullptr)
        return SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX].type;

    Shiboken::AutoDecRef Sbk_QLowEnergyServiceData_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLowEnergyServiceData_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLowEnergyServiceData",
        "QLowEnergyServiceData",
        &Sbk_QLowEnergyServiceData_spec,
        &Shiboken::callCppDestructor< ::QLowEnergyServiceData >,
        Sbk_QLowEnergyServiceData_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QLowEnergyServiceData_TypeF(); // references _Sbk_QLowEnergyServiceData_Type
    InitSignatureStrings(pyType, QLowEnergyServiceData_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLowEnergyServiceData_PropertyStrings);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_PTR,
        is_QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_PTR_Convertible,
        QLowEnergyServiceData_PTR_CppToPython_QLowEnergyServiceData,
        QLowEnergyServiceData_COPY_CppToPython_QLowEnergyServiceData);

    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyServiceData");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyServiceData*");
    Shiboken::Conversions::registerConverterName(converter, "QLowEnergyServiceData&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLowEnergyServiceData).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_COPY,
        is_QLowEnergyServiceData_PythonToCpp_QLowEnergyServiceData_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QLowEnergyServiceData_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ServiceType'.
    const char *ServiceType_Initializer[] = {
        "ServiceTypePrimary",
        "ServiceTypeSecondary",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t ServiceType_InitializerValues[] = {
        uint16_t(QLowEnergyServiceData::ServiceType::ServiceTypePrimary),  //  0x2800  10240
        uint16_t(QLowEnergyServiceData::ServiceType::ServiceTypeSecondary) //  0x2801  10241
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLowEnergyServiceData_TypeF(),
        "2:PySide6.QtBluetooth.QLowEnergyServiceData.ServiceType",
        ServiceType_Initializer, ServiceType_InitializerValues);
    SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyServiceData_ServiceType_IDX].type = EType;
    // Register converter for enum 'QLowEnergyServiceData::ServiceType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLowEnergyServiceData_ServiceType_CppToPython_QLowEnergyServiceData_ServiceType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QLowEnergyServiceData_ServiceType_PythonToCpp_QLowEnergyServiceData_ServiceType,
            is_QLowEnergyServiceData_ServiceType_PythonToCpp_QLowEnergyServiceData_ServiceType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QLowEnergyServiceData::ServiceType");
        Shiboken::Conversions::registerConverterName(converter, "ServiceType");
    }
    // End of 'ServiceType' enum.

    qRegisterMetaType< ::QLowEnergyServiceData >("QLowEnergyServiceData");
    qRegisterMetaType< ::QLowEnergyServiceData::ServiceType >("QLowEnergyServiceData::ServiceType");

    return pyType;
}
