// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <signature.h>
#include <sbkcontainer.h>
#include <sbkstaticstrings.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysidecleanup.h>
#include <pysideqenum.h>
#include <feature_select.h>
#include <pysidestaticstrings.h>
#include "pyside6_qtbluetooth_python.h"

#include <QList>
#include <QMap>
#include <QMultiHash>
#include <QString>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtBluetooth/qbluetoothdeviceinfo.h>
#include <QtBluetooth/qbluetoothhostinfo.h>
#include <QtBluetooth/qbluetoothserviceinfo.h>
#include <QtBluetooth/qbluetoothuuid.h>
#include <QtBluetooth/qlowenergyadvertisingparameters.h>
#include <QtBluetooth/qlowenergycharacteristic.h>
#include <QtBluetooth/qlowenergycharacteristicdata.h>
#include <QtBluetooth/qlowenergydescriptor.h>
#include <QtBluetooth/qlowenergydescriptordata.h>
#include <QtBluetooth/qlowenergyservice.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qvariant.h>


// Current module's type array.
Shiboken::Module::TypeInitStruct *SbkPySide6_QtBluetoothTypeStructs = nullptr;
// Backwards compatible structure with identical indexing.
PyTypeObject **SbkPySide6_QtBluetoothTypes = nullptr;
// Current module's PyObject pointer.
PyObject *SbkPySide6_QtBluetoothModuleObject = nullptr;
// Current module's converter array.
SbkConverter **SbkPySide6_QtBluetoothTypeConverters = nullptr;

void cleanTypesAttributes() {
    static PyObject *attrName = Shiboken::PyName::qtStaticMetaObject();
    const int imax = SBK_QtBluetooth_IDX_COUNT;
    for (int i = 0; i < imax && SbkPySide6_QtBluetoothTypeStructs[i].fullName != nullptr; ++i) {
        auto *pyType = reinterpret_cast<PyObject *>(SbkPySide6_QtBluetoothTypeStructs[i].type);
        if (pyType != nullptr && PyObject_HasAttr(pyType, attrName))
            PyObject_SetAttr(pyType, attrName, Py_None);
    }
}

// Global functions ------------------------------------------------------------

static PyMethodDef QtBluetooth_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
PyTypeObject *init_QLowEnergyServiceData(PyObject *module);
PyTypeObject *init_QLowEnergyService(PyObject *module);
PyTypeObject *init_QLowEnergyDescriptorData(PyObject *module);
PyTypeObject *init_QLowEnergyDescriptor(PyObject *module);
PyTypeObject *init_QLowEnergyConnectionParameters(PyObject *module);
PyTypeObject *init_QLowEnergyCharacteristicData(PyObject *module);
PyTypeObject *init_QLowEnergyCharacteristic(PyObject *module);
PyTypeObject *init_QLowEnergyCharacteristicStaticFields(PyObject *module);
PyTypeObject *init_QLowEnergyAdvertisingParameters(PyObject *module);
PyTypeObject *init_QLowEnergyAdvertisingData(PyObject *module);
PyTypeObject *init_QLowEnergyController(PyObject *module);
PyTypeObject *init_QBluetoothUuid(PyObject *module);
PyTypeObject *init_QBluetoothSocket(PyObject *module);
PyTypeObject *init_QBluetoothServiceDiscoveryAgent(PyObject *module);
PyTypeObject *init_QBluetoothLocalDevice(PyObject *module);
PyTypeObject *init_QBluetoothHostInfo(PyObject *module);
PyTypeObject *init_QBluetoothDeviceInfo(PyObject *module);
PyTypeObject *init_QBluetoothDeviceDiscoveryAgent(PyObject *module);
PyTypeObject *init_QBluetoothAddress(PyObject *module);
PyTypeObject *init_QLowEnergyAdvertisingParameters_AddressInfo(PyObject *enclosingClass);
PyTypeObject *init_QBluetoothServiceInfo(PyObject *module);
PyTypeObject *init_QBluetoothServiceInfo_Sequence(PyObject *enclosingClass);
PyTypeObject *init_QBluetoothServiceInfo_Alternative(PyObject *enclosingClass);
PyTypeObject *init_QBluetoothServer(PyObject *module);
PyTypeObject *init_QtBluetoothQBluetooth(PyObject *module);

// Required modules' type and converter arrays.
Shiboken::Module::TypeInitStruct *SbkPySide6_QtCoreTypeStructs;
SbkConverter **SbkPySide6_QtCoreTypeConverters;

// Module initialization ------------------------------------------------------------
// Container Type converters.

// C++ to Python conversion for container type 'QList<int>'.
static PyObject *_QList_int__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_int_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        int cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_int__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn))
        return PySequence_PythonToCpp__QList_int_;
    return {};
}


// Binding for QList<int>

template <>
struct ShibokenContainerValueConverter<int>
{
    static bool checkValue(PyObject *pyArg)
    {
        return PyLong_Check(pyArg);
    }

    static PyObject *convertValueToPython(int cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppArg);
    }

    static std::optional<int> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!(PyLong_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        int cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QIntList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QIntList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QIntList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QIntList_spec = {
    "2:PySide6.QtBluetooth.QIntList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QIntList_slots
};

static inline PyTypeObject *createQIntListType()
{
    auto *result = reinterpret_cast<PyTypeObject *>(SbkType_FromSpec(&QIntList_spec));
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QIntList_TypeF()
{
    static PyTypeObject *type = createQIntListType();
    return type;
}

extern "C" PyObject *createQIntList(QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQIntList(const QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = const_cast<QList<int> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QIntList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QIntList_TypeF();
}

extern "C" void PythonToCppQIntList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<int>>::get(pyArg);
    *reinterpret_cast<QList<int>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQIntListPythonToCppConvertible(PyObject *pyArg)
{
    if (QIntList_Check(pyArg))
        return PythonToCppQIntList;
    return {};
}

// C++ to Python conversion for container type 'QList<QLowEnergyCharacteristicData>'.
static PyObject *_QList_QLowEnergyCharacteristicData__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLowEnergyCharacteristicData> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QLowEnergyCharacteristicData_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLowEnergyCharacteristicData> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLowEnergyCharacteristicData cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QLowEnergyCharacteristicData__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristicData_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QLowEnergyCharacteristicData_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLowEnergyService*>'.
static PyObject *_QList_QLowEnergyServicePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLowEnergyService*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QLowEnergyServicePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLowEnergyService*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLowEnergyService* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QLowEnergyServicePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QLowEnergyServicePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLowEnergyCharacteristic>'.
static PyObject *_QList_QLowEnergyCharacteristic__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLowEnergyCharacteristic> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QLowEnergyCharacteristic_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLowEnergyCharacteristic> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLowEnergyCharacteristic cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QLowEnergyCharacteristic__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyCharacteristic_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QLowEnergyCharacteristic_;
    return {};
}

// C++ to Python conversion for container type 'QList<QObject*>'.
static PyObject *_QList_QObjectPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QObject*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QObjectPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QObject*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QObject* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QObjectPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QByteArray>'.
static PyObject *_QList_QByteArray__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QByteArray cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<QBluetoothUuid>'.
static PyObject *_QList_QBluetoothUuid__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QBluetoothUuid> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QBluetoothUuid_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QBluetoothUuid> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QBluetoothUuid cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QBluetoothUuid__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QBluetoothUuid_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLowEnergyDescriptorData>'.
static PyObject *_QList_QLowEnergyDescriptorData__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLowEnergyDescriptorData> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QLowEnergyDescriptorData_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLowEnergyDescriptorData> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLowEnergyDescriptorData cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QLowEnergyDescriptorData__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptorData_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QLowEnergyDescriptorData_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLowEnergyDescriptor>'.
static PyObject *_QList_QLowEnergyDescriptor__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLowEnergyDescriptor> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QLowEnergyDescriptor_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLowEnergyDescriptor> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLowEnergyDescriptor cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QLowEnergyDescriptor__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyDescriptor_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QLowEnergyDescriptor_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLowEnergyAdvertisingParameters::AddressInfo>'.
static PyObject *_QList_QLowEnergyAdvertisingParameters_AddressInfo__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLowEnergyAdvertisingParameters::AddressInfo> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingParameters_AddressInfo_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QLowEnergyAdvertisingParameters_AddressInfo_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLowEnergyAdvertisingParameters::AddressInfo> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLowEnergyAdvertisingParameters::AddressInfo cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingParameters_AddressInfo_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QLowEnergyAdvertisingParameters_AddressInfo__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyAdvertisingParameters_AddressInfo_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QLowEnergyAdvertisingParameters_AddressInfo_;
    return {};
}

// C++ to Python conversion for container type 'QList<QBluetoothServiceInfo>'.
static PyObject *_QList_QBluetoothServiceInfo__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QBluetoothServiceInfo> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QBluetoothServiceInfo_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QBluetoothServiceInfo> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QBluetoothServiceInfo cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QBluetoothServiceInfo__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceInfo_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QBluetoothServiceInfo_;
    return {};
}

// C++ to Python conversion for container type 'QList<QBluetoothHostInfo>'.
static PyObject *_QList_QBluetoothHostInfo__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QBluetoothHostInfo> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QBluetoothHostInfo_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QBluetoothHostInfo> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QBluetoothHostInfo cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QBluetoothHostInfo__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothHostInfo_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QBluetoothHostInfo_;
    return {};
}

// C++ to Python conversion for container type 'QList<QBluetoothAddress>'.
static PyObject *_QList_QBluetoothAddress__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QBluetoothAddress> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QBluetoothAddress_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QBluetoothAddress> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QBluetoothAddress cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QBluetoothAddress__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothAddress_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QBluetoothAddress_;
    return {};
}

// C++ to Python conversion for container type 'QMultiHash<quint16,QByteArray>'.
static PyObject *_QMultiHash_quint16_QByteArray__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMultiHash<quint16,QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmultihash_to_pydict - START
    PyObject *pyOut = PyDict_New();
        for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ) {
            const auto &key = it.key();
            PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &key);
            auto range = cppInRef.equal_range(key);
            const auto count = Py_ssize_t(std::distance(range.first, range.second));
            PyObject *pyValues = PyList_New(count);
            Py_ssize_t idx = 0;
            for (; it != range.second; ++it, ++idx) {
                const auto &cppItem = it.value();
                PyList_SET_ITEM(pyValues, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppItem));
            }
            PyDict_SetItem(pyOut, pyKey, pyValues);
            Py_DECREF(pyKey);
        }
        return pyOut;
    // TEMPLATE - shiboken_conversion_qmultihash_to_pydict - END

}
static void PyDict_PythonToCpp__QMultiHash_quint16_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMultiHash<quint16,QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmultihash - START
    PyObject *key;
        PyObject *values;
        cppOutRef.clear();
        Py_ssize_t pos = 0;
        while (PyDict_Next(pyIn, &pos, &key, &values)) {
            quint16 cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), key, &(cppKey));
            const Py_ssize_t size = PySequence_Size(values);
            for (Py_ssize_t i = 0; i < size; ++i) {
                Shiboken::AutoDecRef value(PySequence_GetItem(values, i));
                ::QByteArray cppValue;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), value, &(cppValue));
                cppOutRef.insert(cppKey, cppValue);
            }
        }
    // TEMPLATE - shiboken_conversion_pydict_to_qmultihash - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMultiHash_quint16_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleMultiDictTypes(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX])))->converter, false, pyIn))
        return PyDict_PythonToCpp__QMultiHash_quint16_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<quint16>'.
static PyObject *_QList_quint16__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<quint16> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_quint16_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<quint16> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        quint16 cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_quint16__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), pyIn))
        return PySequence_PythonToCpp__QList_quint16_;
    return {};
}

// C++ to Python conversion for container type 'QMultiHash<QBluetoothUuid,QByteArray>'.
static PyObject *_QMultiHash_QBluetoothUuid_QByteArray__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMultiHash<QBluetoothUuid,QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmultihash_to_pydict - START
    PyObject *pyOut = PyDict_New();
        for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ) {
            const auto &key = it.key();
            PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), &key);
            auto range = cppInRef.equal_range(key);
            const auto count = Py_ssize_t(std::distance(range.first, range.second));
            PyObject *pyValues = PyList_New(count);
            Py_ssize_t idx = 0;
            for (; it != range.second; ++it, ++idx) {
                const auto &cppItem = it.value();
                PyList_SET_ITEM(pyValues, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppItem));
            }
            PyDict_SetItem(pyOut, pyKey, pyValues);
            Py_DECREF(pyKey);
        }
        return pyOut;
    // TEMPLATE - shiboken_conversion_qmultihash_to_pydict - END

}
static void PyDict_PythonToCpp__QMultiHash_QBluetoothUuid_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMultiHash<QBluetoothUuid,QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmultihash - START
    PyObject *key;
        PyObject *values;
        cppOutRef.clear();
        Py_ssize_t pos = 0;
        while (PyDict_Next(pyIn, &pos, &key, &values)) {
            ::QBluetoothUuid cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]), key, &(cppKey));
            const Py_ssize_t size = PySequence_Size(values);
            for (Py_ssize_t i = 0; i < size; ++i) {
                Shiboken::AutoDecRef value(PySequence_GetItem(values, i));
                ::QByteArray cppValue;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), value, &(cppValue));
                cppOutRef.insert(cppKey, cppValue);
            }
        }
    // TEMPLATE - shiboken_conversion_pydict_to_qmultihash - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMultiHash_QBluetoothUuid_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleMultiDictTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX])))->converter, false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX])))->converter, false, pyIn))
        return PyDict_PythonToCpp__QMultiHash_QBluetoothUuid_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<QBluetoothDeviceInfo>'.
static PyObject *_QList_QBluetoothDeviceInfo__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QBluetoothDeviceInfo> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QBluetoothDeviceInfo_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QBluetoothDeviceInfo> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QBluetoothDeviceInfo cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QBluetoothDeviceInfo__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceInfo_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QBluetoothDeviceInfo_;
    return {};
}

// C++ to Python conversion for container type 'QList<QVariant>'.
static PyObject *_QList_QVariant__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVariant cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QString>'.
static PyObject *_QList_QString__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QString> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QString_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QString> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QString cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QString__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QString_;
    return {};
}

// C++ to Python conversion for container type 'QMap<QString,QVariant>'.
static PyObject *_QMap_QString_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<QString,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_QString_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<QString,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key;
    PyObject *value;
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QString cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_QString_QVariant_;
    return {};
}


static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtBluetooth",
    /* m_doc      */ nullptr,
    /* m_size     */ -1,
    /* m_methods  */ QtBluetooth_methods,
    /* m_reload   */ nullptr,
    /* m_traverse */ nullptr,
    /* m_clear    */ nullptr,
    /* m_free     */ nullptr
};

// The signatures string for the global functions.
// Multiple signatures have their index "n:" in front.
static const char *QtBluetooth_SignatureStrings[] = {
    nullptr}; // Sentinel

static void initInheritance()
{
    auto &bm = Shiboken::BindingManager::instance();
    SBK_UNUSED(bm)
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyService_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtBluetoothTypeStructs[SBK_QLowEnergyController_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QUuid_IDX],
                           &SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothUuid_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX],
                           &SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothSocket_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServiceDiscoveryAgent_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothLocalDevice_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothDeviceDiscoveryAgent_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtBluetoothTypeStructs[SBK_QBluetoothServer_IDX]);
}

extern "C" LIBSHIBOKEN_EXPORT PyObject *PyInit_QtBluetooth()
{
    if (SbkPySide6_QtBluetoothModuleObject != nullptr)
        return SbkPySide6_QtBluetoothModuleObject;
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtCore"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtCoreTypeStructs = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtCoreTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    // Create an array of wrapper types/names for the current module.
    static Shiboken::Module::TypeInitStruct cppApi[] = {
        {nullptr, "PySide6.QtBluetooth.QBluetooth"},
        {nullptr, "PySide6.QtBluetooth.QBluetooth.AttAccessConstraint"},
        {nullptr, "PySide6.QtBluetooth.QBluetooth.Security"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothAddress"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.DiscoveryMethod"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.Error"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.CoreConfiguration"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.Field"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.MajorDeviceClass"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorAudioVideoClass"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorComputerClass"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorHealthClass"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorImagingClass"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorMiscellaneousClass"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorNetworkClass"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorPeripheralClass"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorPhoneClass"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorToyClass"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.MinorWearableClass"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.ServiceClass"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothHostInfo"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothLocalDevice"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothLocalDevice.Error"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothLocalDevice.HostMode"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothLocalDevice.Pairing"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothServer"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothServer.Error"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.DiscoveryMode"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothServiceDiscoveryAgent.Error"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothServiceInfo"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothServiceInfo.Alternative"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothServiceInfo.AttributeId"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothServiceInfo.Protocol"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothServiceInfo.Sequence"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothSocket"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothSocket.SocketError"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothSocket.SocketState"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothUuid"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothUuid.CharacteristicType"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothUuid.DescriptorType"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothUuid.ProtocolUuid"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothUuid.ServiceClassUuid"},
        {nullptr, "PySide6.QtBluetooth.QBluetooth.AttAccessConstraints"},
        {nullptr, "PySide6.QtBluetooth.QBluetooth.SecurityFlags"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceDiscoveryAgent.DiscoveryMethods"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.CoreConfigurations"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.Fields"},
        {nullptr, "PySide6.QtBluetooth.QBluetoothDeviceInfo.ServiceClasses"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyCharacteristic.PropertyTypes"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyService.ServiceTypes"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyAdvertisingData"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyAdvertisingData.Discoverability"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyAdvertisingParameters"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyAdvertisingParameters.AddressInfo"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyAdvertisingParameters.FilterPolicy"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyAdvertisingParameters.Mode"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyCharacteristic"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyCharacteristic.PropertyType"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyCharacteristicData"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyConnectionParameters"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyController"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyController.ControllerState"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyController.Error"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyController.RemoteAddressType"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyController.Role"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyDescriptor"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyDescriptorData"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyService"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyService.DiscoveryMode"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyService.ServiceError"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyService.ServiceState"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyService.ServiceType"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyService.WriteMode"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyServiceData"},
        {nullptr, "PySide6.QtBluetooth.QLowEnergyServiceData.ServiceType"},
        {nullptr, nullptr}
    };
    // The new global structure consisting of (type, name) pairs.
    SbkPySide6_QtBluetoothTypeStructs = cppApi;
    QT_WARNING_PUSH
    QT_WARNING_DISABLE_DEPRECATED
    // The backward compatible alias with upper case indexes.
    SbkPySide6_QtBluetoothTypes = reinterpret_cast<PyTypeObject **>(cppApi);
    QT_WARNING_POP

    // Create an array of primitive type converters for the current module.
    static SbkConverter *sbkConverters[SBK_QtBluetooth_CONVERTERS_IDX_COUNT];
    SbkPySide6_QtBluetoothTypeConverters = sbkConverters;

    PyObject *module = Shiboken::Module::create("QtBluetooth", &moduledef);

    // Make module available from global scope
    SbkPySide6_QtBluetoothModuleObject = module;

    // Initialize classes in the type system
    Shiboken::Module::AddTypeCreationFunction(module, "QLowEnergyServiceData", init_QLowEnergyServiceData);
    Shiboken::Module::AddTypeCreationFunction(module, "QLowEnergyService", init_QLowEnergyService);
    Shiboken::Module::AddTypeCreationFunction(module, "QLowEnergyDescriptorData", init_QLowEnergyDescriptorData);
    Shiboken::Module::AddTypeCreationFunction(module, "QLowEnergyDescriptor", init_QLowEnergyDescriptor);
    Shiboken::Module::AddTypeCreationFunction(module, "QLowEnergyConnectionParameters", init_QLowEnergyConnectionParameters);
    Shiboken::Module::AddTypeCreationFunction(module, "QLowEnergyCharacteristicData", init_QLowEnergyCharacteristicData);
    Shiboken::Module::AddTypeCreationFunction(module, "QLowEnergyCharacteristic", init_QLowEnergyCharacteristic);
    Shiboken::Module::AddTypeCreationFunction(module, "QLowEnergyAdvertisingParameters", init_QLowEnergyAdvertisingParameters);
    Shiboken::Module::AddTypeCreationFunction(module, "QLowEnergyAdvertisingData", init_QLowEnergyAdvertisingData);
    Shiboken::Module::AddTypeCreationFunction(module, "QLowEnergyController", init_QLowEnergyController);
    Shiboken::Module::AddTypeCreationFunction(module, "QBluetoothUuid", init_QBluetoothUuid);
    Shiboken::Module::AddTypeCreationFunction(module, "QBluetoothSocket", init_QBluetoothSocket);
    Shiboken::Module::AddTypeCreationFunction(module, "QBluetoothServiceDiscoveryAgent", init_QBluetoothServiceDiscoveryAgent);
    Shiboken::Module::AddTypeCreationFunction(module, "QBluetoothLocalDevice", init_QBluetoothLocalDevice);
    Shiboken::Module::AddTypeCreationFunction(module, "QBluetoothHostInfo", init_QBluetoothHostInfo);
    Shiboken::Module::AddTypeCreationFunction(module, "QBluetoothDeviceInfo", init_QBluetoothDeviceInfo);
    Shiboken::Module::AddTypeCreationFunction(module, "QBluetoothDeviceDiscoveryAgent", init_QBluetoothDeviceDiscoveryAgent);
    Shiboken::Module::AddTypeCreationFunction(module, "QBluetoothAddress", init_QBluetoothAddress);
    Shiboken::Module::AddTypeCreationFunction(module, "AddressInfo", init_QLowEnergyAdvertisingParameters_AddressInfo, "QLowEnergyAdvertisingParameters");
    Shiboken::Module::AddTypeCreationFunction(module, "QBluetoothServiceInfo", init_QBluetoothServiceInfo);
    Shiboken::Module::AddTypeCreationFunction(module, "Sequence", init_QBluetoothServiceInfo_Sequence, "QBluetoothServiceInfo");
    Shiboken::Module::AddTypeCreationFunction(module, "Alternative", init_QBluetoothServiceInfo_Alternative, "QBluetoothServiceInfo");
    Shiboken::Module::AddTypeCreationFunction(module, "QBluetoothServer", init_QBluetoothServer);
    Shiboken::Module::AddTypeCreationFunction(module, "QBluetooth", init_QtBluetoothQBluetooth);

    // Register converter for type 'QList<int>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_int_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_int__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_int_IDX], "QList<int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_int_IDX],
        PySequence_PythonToCpp__QList_int_,
        is_PySequence_PythonToCpp__QList_int__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_int_IDX],
        PythonToCppQIntList,
        isQIntListPythonToCppConvertible);

    // Register converter for type 'QList<QLowEnergyCharacteristicData>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyCharacteristicData_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QLowEnergyCharacteristicData__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyCharacteristicData_IDX], "QList<QLowEnergyCharacteristicData>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyCharacteristicData_IDX],
        PySequence_PythonToCpp__QList_QLowEnergyCharacteristicData_,
        is_PySequence_PythonToCpp__QList_QLowEnergyCharacteristicData__Convertible);

    // Register converter for type 'QList<QLowEnergyService*>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyServicePTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QLowEnergyServicePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyServicePTR_IDX], "QList<QLowEnergyService*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyServicePTR_IDX],
        PySequence_PythonToCpp__QList_QLowEnergyServicePTR_,
        is_PySequence_PythonToCpp__QList_QLowEnergyServicePTR__Convertible);

    // Register converter for type 'QList<QLowEnergyCharacteristic>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyCharacteristic_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QLowEnergyCharacteristic__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyCharacteristic_IDX], "QList<QLowEnergyCharacteristic>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyCharacteristic_IDX],
        PySequence_PythonToCpp__QList_QLowEnergyCharacteristic_,
        is_PySequence_PythonToCpp__QList_QLowEnergyCharacteristic__Convertible);

    // Register converter for type 'QList<QObject*>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QObjectPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QObjectPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QObjectPTR_IDX], "QList<QObject*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QObjectPTR_IDX],
        PySequence_PythonToCpp__QList_QObjectPTR_,
        is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible);
    // Register converters for type aliases of QList<QObject*>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QObjectPTR_IDX], "QObjectList");

    // Register converter for type 'QList<QByteArray>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QByteArray__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QByteArray_IDX], "QList<QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QByteArray_IDX],
        PySequence_PythonToCpp__QList_QByteArray_,
        is_PySequence_PythonToCpp__QList_QByteArray__Convertible);
    // Register converters for type aliases of QList<QByteArray>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QByteArray_IDX], "QByteArrayList");

    // Register converter for type 'QList<QBluetoothUuid>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothUuid_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QBluetoothUuid__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothUuid_IDX], "QList<QBluetoothUuid>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothUuid_IDX],
        PySequence_PythonToCpp__QList_QBluetoothUuid_,
        is_PySequence_PythonToCpp__QList_QBluetoothUuid__Convertible);

    // Register converter for type 'QList<QLowEnergyDescriptorData>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyDescriptorData_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QLowEnergyDescriptorData__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyDescriptorData_IDX], "QList<QLowEnergyDescriptorData>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyDescriptorData_IDX],
        PySequence_PythonToCpp__QList_QLowEnergyDescriptorData_,
        is_PySequence_PythonToCpp__QList_QLowEnergyDescriptorData__Convertible);

    // Register converter for type 'QList<QLowEnergyDescriptor>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyDescriptor_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QLowEnergyDescriptor__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyDescriptor_IDX], "QList<QLowEnergyDescriptor>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyDescriptor_IDX],
        PySequence_PythonToCpp__QList_QLowEnergyDescriptor_,
        is_PySequence_PythonToCpp__QList_QLowEnergyDescriptor__Convertible);

    // Register converter for type 'QList<QLowEnergyAdvertisingParameters::AddressInfo>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyAdvertisingParameters_AddressInfo_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QLowEnergyAdvertisingParameters_AddressInfo__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyAdvertisingParameters_AddressInfo_IDX], "QList<QLowEnergyAdvertisingParameters::AddressInfo>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QLowEnergyAdvertisingParameters_AddressInfo_IDX],
        PySequence_PythonToCpp__QList_QLowEnergyAdvertisingParameters_AddressInfo_,
        is_PySequence_PythonToCpp__QList_QLowEnergyAdvertisingParameters_AddressInfo__Convertible);

    // Register converter for type 'QList<QBluetoothServiceInfo>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothServiceInfo_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QBluetoothServiceInfo__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothServiceInfo_IDX], "QList<QBluetoothServiceInfo>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothServiceInfo_IDX],
        PySequence_PythonToCpp__QList_QBluetoothServiceInfo_,
        is_PySequence_PythonToCpp__QList_QBluetoothServiceInfo__Convertible);

    // Register converter for type 'QList<QBluetoothHostInfo>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothHostInfo_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QBluetoothHostInfo__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothHostInfo_IDX], "QList<QBluetoothHostInfo>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothHostInfo_IDX],
        PySequence_PythonToCpp__QList_QBluetoothHostInfo_,
        is_PySequence_PythonToCpp__QList_QBluetoothHostInfo__Convertible);

    // Register converter for type 'QList<QBluetoothAddress>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothAddress_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QBluetoothAddress__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothAddress_IDX], "QList<QBluetoothAddress>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothAddress_IDX],
        PySequence_PythonToCpp__QList_QBluetoothAddress_,
        is_PySequence_PythonToCpp__QList_QBluetoothAddress__Convertible);

    // Register converter for type 'QMultiHash<quint16,QByteArray>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QMultiHash_quint16_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMultiHash_quint16_QByteArray__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QMultiHash_quint16_QByteArray_IDX], "QMultiHash<quint16,QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QMultiHash_quint16_QByteArray_IDX],
        PyDict_PythonToCpp__QMultiHash_quint16_QByteArray_,
        is_PyDict_PythonToCpp__QMultiHash_quint16_QByteArray__Convertible);

    // Register converter for type 'QList<quint16>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_quint16_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_quint16__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_quint16_IDX], "QList<quint16>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_quint16_IDX],
        PySequence_PythonToCpp__QList_quint16_,
        is_PySequence_PythonToCpp__QList_quint16__Convertible);

    // Register converter for type 'QMultiHash<QBluetoothUuid,QByteArray>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QMultiHash_QBluetoothUuid_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMultiHash_QBluetoothUuid_QByteArray__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QMultiHash_QBluetoothUuid_QByteArray_IDX], "QMultiHash<QBluetoothUuid,QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QMultiHash_QBluetoothUuid_QByteArray_IDX],
        PyDict_PythonToCpp__QMultiHash_QBluetoothUuid_QByteArray_,
        is_PyDict_PythonToCpp__QMultiHash_QBluetoothUuid_QByteArray__Convertible);

    // Register converter for type 'QList<QBluetoothDeviceInfo>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothDeviceInfo_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QBluetoothDeviceInfo__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothDeviceInfo_IDX], "QList<QBluetoothDeviceInfo>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QBluetoothDeviceInfo_IDX],
        PySequence_PythonToCpp__QList_QBluetoothDeviceInfo_,
        is_PySequence_PythonToCpp__QList_QBluetoothDeviceInfo__Convertible);

    // Register converter for type 'QList<QVariant>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVariant__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], "QList<QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX],
        PySequence_PythonToCpp__QList_QVariant_,
        is_PySequence_PythonToCpp__QList_QVariant__Convertible);
    // Register converters for type aliases of QList<QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], "QVariantList");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QVariant_IDX], "QVariantList");

    // Register converter for type 'QList<QString>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QString_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QString__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QString_IDX], "QList<QString>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QList_QString_IDX],
        PySequence_PythonToCpp__QList_QString_,
        is_PySequence_PythonToCpp__QList_QString__Convertible);
    // Register converters for type aliases of QList<QString>'.

    // Register converter for type 'QMap<QString,QVariant>'.
    SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QMap_QString_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_QString_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QMap_QString_QVariant_IDX], "QMap<QString,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QMap_QString_QVariant_IDX],
        PyDict_PythonToCpp__QMap_QString_QVariant_,
        is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible);
    // Register converters for type aliases of QMap<QString,QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QMap_QString_QVariant_IDX], "QVariantMap");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtBluetoothTypeConverters[SBK_QtBluetooth_QMap_QString_QVariant_IDX], "QSettings::SettingsMap");


    // Opaque container type registration
    PyObject *ob_type{};
    ob_type = reinterpret_cast<PyObject *>(QIntList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QIntList", ob_type);

    // Register primitive types converters.
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "QLowEnergyHandle");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "__caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__clock_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__clockid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_d_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__fsword_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intptr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__sig_atomic_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__socklen_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__syscall_slong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__syscall_ulong_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__time_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint_least16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint_least32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint_least64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint_least8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__useconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blksize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "caddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "comparison_fn_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "daddr_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "dev_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "gid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "id_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "int_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "intmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "key_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "loff_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "mode_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "nlink_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "pid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), "qInternalCallback");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "register_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "ssize_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "suseconds_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_char");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_int16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_int64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_int8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_long");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_quad_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_short");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uid_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast16_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast32_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast64_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uint_fast8_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uintmax_t");
    Shiboken::Conversions::registerConverterName(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "useconds_t");

    Shiboken::Module::registerTypes(module, SbkPySide6_QtBluetoothTypeStructs);
    Shiboken::Module::registerTypeConverters(module, SbkPySide6_QtBluetoothTypeConverters);

    // Static field initialization
    init_QLowEnergyCharacteristicStaticFields(module);

    initInheritance();

    if (Shiboken::Errors::occurred() != nullptr) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtBluetooth");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);

    FinishSignatureInitialization(module, QtBluetooth_SignatureStrings);

    return module;
}
