// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qbytearraymatcher_wrapper.h"

// Argument includes
#include <qbytearray.h>
#include <qbytearraymatcher.h>
#include <qbytearrayview.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QByteArrayMatcher_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QByteArrayMatcher >()))
        return -1;

    ::QByteArrayMatcher *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArrayMatcher.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:QByteArrayMatcher", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QByteArrayMatcher::QByteArrayMatcher()
    // 1: QByteArrayMatcher::QByteArrayMatcher(QByteArrayView)
    // 2: QByteArrayMatcher::QByteArrayMatcher(QByteArray)
    // 3: QByteArrayMatcher::QByteArrayMatcher(QByteArrayMatcher)
    // 4: QByteArrayMatcher::QByteArrayMatcher(const char*,qsizetype=)
    if (numArgs == 0) {
        overloadId = 0; // QByteArrayMatcher()
    } else if (numArgs >= 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 4; // QByteArrayMatcher(const char*,qsizetype)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 4; // QByteArrayMatcher(const char*,qsizetype)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArrayMatcher_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QByteArrayMatcher(QByteArrayMatcher)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QByteArrayMatcher(QByteArray)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QByteArrayMatcher(QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QByteArrayMatcher()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QByteArrayMatcher()
                cptr = new ::QByteArrayMatcher();
            }
            break;
        }
        case 1: // QByteArrayMatcher(QByteArrayView pattern)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QByteArrayMatcher(QByteArrayView)
                cptr = new ::QByteArrayMatcher(QByteArrayView(cppArg0));
            }
            break;
        }
        case 2: // QByteArrayMatcher(const QByteArray & pattern)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QByteArrayMatcher(QByteArray)
                cptr = new ::QByteArrayMatcher(*cppArg0);
            }
            break;
        }
        case 3: // QByteArrayMatcher(const QByteArrayMatcher & other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArrayMatcher cppArg0_local;
            ::QByteArrayMatcher *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QByteArrayMatcher(QByteArrayMatcher)
                cptr = new ::QByteArrayMatcher(*cppArg0);
            }
            break;
        }
        case 4: // QByteArrayMatcher(const char * pattern, qsizetype length)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_length = Shiboken::String::createStaticString("length");
                if (PyDict_Contains(kwds, key_length) != 0) {
                    value = PyDict_GetItem(kwds, key_length);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_length);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_length);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1 = -1;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QByteArrayMatcher(const char*,qsizetype)
                cptr = new ::QByteArrayMatcher(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QByteArrayMatcher >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QByteArrayMatcherFunc_indexIn(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArrayMatcher *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArrayMatcher_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArrayMatcher.indexIn";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:indexIn", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QByteArrayMatcher::indexIn(QByteArrayView,qsizetype=)const->qsizetype
    // 1: QByteArrayMatcher::indexIn(const char*,qsizetype,qsizetype=)const->qsizetype
    if (numArgs >= 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // indexIn(const char*,qsizetype,qsizetype)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[2])))) {
            overloadId = 1; // indexIn(const char*,qsizetype,qsizetype)const
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // indexIn(QByteArrayView,qsizetype)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
            overloadId = 0; // indexIn(QByteArrayView,qsizetype)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // indexIn(QByteArrayView data, qsizetype from) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_from = Shiboken::String::createStaticString("from");
                if (PyDict_Contains(kwds, key_from) != 0) {
                    value = PyDict_GetItem(kwds, key_from);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_from);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_from);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // indexIn(QByteArrayView,qsizetype)const
                qsizetype cppResult = const_cast<const ::QByteArrayMatcher *>(cppSelf)->indexIn(QByteArrayView(cppArg0), cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            }
            break;
        }
        case 1: // indexIn(const char * str, qsizetype len, qsizetype from) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_from = Shiboken::String::createStaticString("from");
                if (PyDict_Contains(kwds, key_from) != 0) {
                    value = PyDict_GetItem(kwds, key_from);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_from);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_from);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qsizetype cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qsizetype cppArg2 = 0;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // indexIn(const char*,qsizetype,qsizetype)const
                qsizetype cppResult = const_cast<const ::QByteArrayMatcher *>(cppSelf)->indexIn(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayMatcherFunc_pattern(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArrayMatcher *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArrayMatcher_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QByteArrayMatcher.pattern";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // pattern()const
            QByteArray cppResult = const_cast<const ::QByteArrayMatcher *>(cppSelf)->pattern();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QByteArrayMatcherFunc_setPattern(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QByteArrayMatcher *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArrayMatcher_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QByteArrayMatcher.setPattern";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QByteArrayMatcher::setPattern(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setPattern(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPattern(QByteArray)
            cppSelf->setPattern(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QByteArrayMatcher__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QByteArrayMatcher *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArrayMatcher_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArrayMatcher_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QByteArrayMatcher_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QByteArrayMatcher_methods[] = {
    {"indexIn", reinterpret_cast<PyCFunction>(Sbk_QByteArrayMatcherFunc_indexIn), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"pattern", reinterpret_cast<PyCFunction>(Sbk_QByteArrayMatcherFunc_pattern), METH_NOARGS, nullptr},
    {"setPattern", reinterpret_cast<PyCFunction>(Sbk_QByteArrayMatcherFunc_setPattern), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QByteArrayMatcher__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QByteArrayMatcher_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QByteArrayMatcher_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QByteArrayMatcher_Type = nullptr;
static PyTypeObject *Sbk_QByteArrayMatcher_TypeF(void)
{
    return _Sbk_QByteArrayMatcher_Type;
}

static PyType_Slot Sbk_QByteArrayMatcher_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QByteArrayMatcher_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QByteArrayMatcher_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QByteArrayMatcher_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QByteArrayMatcher_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QByteArrayMatcher_spec = {
    "2:PySide6.QtCore.QByteArrayMatcher",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QByteArrayMatcher_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QByteArrayMatcher_PythonToCpp_QByteArrayMatcher_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QByteArrayMatcher_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QByteArrayMatcher_PythonToCpp_QByteArrayMatcher_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QByteArrayMatcher_TypeF()))
        return QByteArrayMatcher_PythonToCpp_QByteArrayMatcher_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QByteArrayMatcher_PTR_CppToPython_QByteArrayMatcher(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QByteArrayMatcher *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QByteArrayMatcher_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QByteArrayMatcher_COPY_CppToPython_QByteArrayMatcher(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QByteArrayMatcher *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QByteArrayMatcher_TypeF(), new ::QByteArrayMatcher(*source), true, true);
}

// Python to C++ copy conversion.
static void QByteArrayMatcher_PythonToCpp_QByteArrayMatcher_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QByteArrayMatcher *>(cppOut) = *reinterpret_cast< ::QByteArrayMatcher *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArrayMatcher_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QByteArrayMatcher_PythonToCpp_QByteArrayMatcher_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QByteArrayMatcher_TypeF()))
        return QByteArrayMatcher_PythonToCpp_QByteArrayMatcher_COPY;
    return {};
}

// Implicit conversions.
static void constcharPTR_PythonToCpp_QByteArrayMatcher(PyObject *pyIn, void *cppOut)
{
    const char* cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), pyIn, &cppIn);
    *reinterpret_cast<::QByteArrayMatcher *>(cppOut) = ::QByteArrayMatcher(cppIn);
}
static PythonToCppFunc is_constcharPTR_PythonToCpp_QByteArrayMatcher_Convertible(PyObject *pyIn)
{
    if (Shiboken::String::check(pyIn))
        return constcharPTR_PythonToCpp_QByteArrayMatcher;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QByteArrayMatcher_SignatureStrings[] = {
    "4:PySide6.QtCore.QByteArrayMatcher(self)",
    "3:PySide6.QtCore.QByteArrayMatcher(self,pattern:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "2:PySide6.QtCore.QByteArrayMatcher(self,pattern:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "1:PySide6.QtCore.QByteArrayMatcher(self,other:typing.Union[PySide6.QtCore.QByteArrayMatcher, char*])",
    "0:PySide6.QtCore.QByteArrayMatcher(self,pattern:char*,length:qsizetype=-1)",
    "1:PySide6.QtCore.QByteArrayMatcher.indexIn(self,data:typing.Union[PySide6.QtCore.QByteArray, char*],from:qsizetype=0)->qsizetype",
    "0:PySide6.QtCore.QByteArrayMatcher.indexIn(self,str:char*,len:qsizetype,from:qsizetype=0)->qsizetype",
    "PySide6.QtCore.QByteArrayMatcher.pattern(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QByteArrayMatcher.setPattern(self,pattern:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtCore.QByteArrayMatcher.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QByteArrayMatcher(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QByteArrayMatcher_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QByteArrayMatcher_IDX].type;

    Shiboken::AutoDecRef Sbk_QByteArrayMatcher_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QByteArrayMatcher_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QByteArrayMatcher",
        "QByteArrayMatcher",
        &Sbk_QByteArrayMatcher_spec,
        &Shiboken::callCppDestructor< ::QByteArrayMatcher >,
        Sbk_QByteArrayMatcher_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QByteArrayMatcher_TypeF(); // references _Sbk_QByteArrayMatcher_Type
    InitSignatureStrings(pyType, QByteArrayMatcher_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QByteArrayMatcher_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QByteArrayMatcher_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QByteArrayMatcher_PythonToCpp_QByteArrayMatcher_PTR,
        is_QByteArrayMatcher_PythonToCpp_QByteArrayMatcher_PTR_Convertible,
        QByteArrayMatcher_PTR_CppToPython_QByteArrayMatcher,
        QByteArrayMatcher_COPY_CppToPython_QByteArrayMatcher);

    Shiboken::Conversions::registerConverterName(converter, "QByteArrayMatcher");
    Shiboken::Conversions::registerConverterName(converter, "QByteArrayMatcher*");
    Shiboken::Conversions::registerConverterName(converter, "QByteArrayMatcher&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QByteArrayMatcher).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QByteArrayMatcher_PythonToCpp_QByteArrayMatcher_COPY,
        is_QByteArrayMatcher_PythonToCpp_QByteArrayMatcher_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constcharPTR_PythonToCpp_QByteArrayMatcher,
        is_constcharPTR_PythonToCpp_QByteArrayMatcher_Convertible);

    qRegisterMetaType< ::QByteArrayMatcher >("QByteArrayMatcher");

    return pyType;
}
