// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qcborerror_wrapper.h"

// Argument includes
#include <QString>
#include <qcborcommon.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCborError_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCborError >()))
        return -1;

    ::QCborError *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCborError.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QCborError", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCborError::QCborError()
    // 1: QCborError::QCborError(QCborError)
    if (numArgs == 0) {
        overloadId = 0; // QCborError()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborError_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QCborError(QCborError)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCborError()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborError()
                cptr = new ::QCborError();
            }
            break;
        }
        case 1: // QCborError(const QCborError & QCborError)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCborError cppArg0_local;
            ::QCborError *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QCborError(QCborError)
                cptr = new ::QCborError(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCborError >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCborErrorFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCborError.toString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toString()const
            QString cppResult = const_cast<const ::QCborError *>(cppSelf)->toString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCborError__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCborError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborError_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborError_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCborError_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QCborError_EnumFlagInfo[] = {
    "Code:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCborError_methods[] = {
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QCborErrorFunc_toString), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QCborError__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QCborError_get_c(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCborError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QCborError::Code cppOut_local = cppSelf->c;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborError_Code_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QCborError_set_c(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QCborError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("c");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborError_Code_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("c", "Code");
        return -1;
    }

    auto cppOut_local = cppSelf->c;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->c = cppOut_local;

    return 0;
}

// Getters and Setters for QCborError
static PyGetSetDef Sbk_QCborError_getsetlist[] = {
    {const_cast<char *>("c"), Sbk_QCborError_get_c, Sbk_QCborError_set_c, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QCborError_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCborError_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCborError_Type = nullptr;
static PyTypeObject *Sbk_QCborError_TypeF(void)
{
    return _Sbk_QCborError_Type;
}

static PyType_Slot Sbk_QCborError_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCborError_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCborError_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCborError_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QCborError_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCborError_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCborError_spec = {
    "2:PySide6.QtCore.QCborError",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCborError_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QCborError_Code_PythonToCpp_QCborError_Code(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCborError::Code>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCborError::Code *>(cppOut) = value;

}
static PythonToCppFunc is_QCborError_Code_PythonToCpp_QCborError_Code_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborError_Code_IDX])))
        return QCborError_Code_PythonToCpp_QCborError_Code;
    return {};
}
static PyObject *QCborError_Code_CppToPython_QCborError_Code(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCborError::Code *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborError_Code_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCborError_PythonToCpp_QCborError_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCborError_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCborError_PythonToCpp_QCborError_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCborError_TypeF()))
        return QCborError_PythonToCpp_QCborError_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCborError_PTR_CppToPython_QCborError(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QCborError *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QCborError_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QCborError_COPY_CppToPython_QCborError(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QCborError *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QCborError_TypeF(), new ::QCborError(*source), true, true);
}

// Python to C++ copy conversion.
static void QCborError_PythonToCpp_QCborError_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCborError *>(cppOut) = *reinterpret_cast< ::QCborError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCborError_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QCborError_PythonToCpp_QCborError_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QCborError_TypeF()))
        return QCborError_PythonToCpp_QCborError_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QCborError_SignatureStrings[] = {
    "1:PySide6.QtCore.QCborError(self)",
    "0:PySide6.QtCore.QCborError(self,QCborError:PySide6.QtCore.QCborError)",
    "PySide6.QtCore.QCborError.toString(self)->QString",
    "PySide6.QtCore.QCborError.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QCborError(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QCborError_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QCborError_IDX].type;

    Shiboken::AutoDecRef Sbk_QCborError_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCborError_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCborError",
        "QCborError",
        &Sbk_QCborError_spec,
        &Shiboken::callCppDestructor< ::QCborError >,
        Sbk_QCborError_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QCborError_TypeF(); // references _Sbk_QCborError_Type
    InitSignatureStrings(pyType, QCborError_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCborError_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QCborError_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCborError_PythonToCpp_QCborError_PTR,
        is_QCborError_PythonToCpp_QCborError_PTR_Convertible,
        QCborError_PTR_CppToPython_QCborError,
        QCborError_COPY_CppToPython_QCborError);

    Shiboken::Conversions::registerConverterName(converter, "QCborError");
    Shiboken::Conversions::registerConverterName(converter, "QCborError*");
    Shiboken::Conversions::registerConverterName(converter, "QCborError&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCborError).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QCborError_PythonToCpp_QCborError_COPY,
        is_QCborError_PythonToCpp_QCborError_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCborError_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Code'.
    const char *Code_Initializer[] = {
        "UnknownError",
        "AdvancePastEnd",
        "InputOutputError",
        "GarbageAtEnd",
        "EndOfFile",
        "UnexpectedBreak",
        "UnknownType",
        "IllegalType",
        "IllegalNumber",
        "IllegalSimpleType",
        "InvalidUtf8String",
        "DataTooLarge",
        "NestingTooDeep",
        "UnsupportedType",
        "NoError",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t Code_InitializerValues[] = {
        int16_t(QCborError::Code::UnknownError),      //  0x0001  1
        int16_t(QCborError::Code::AdvancePastEnd),    //  0x0003  3
        int16_t(QCborError::Code::InputOutputError),  //  0x0004  4
        int16_t(QCborError::Code::GarbageAtEnd),      //  0x0100  256
        int16_t(QCborError::Code::EndOfFile),         //  0x0101  257
        int16_t(QCborError::Code::UnexpectedBreak),   //  0x0102  258
        int16_t(QCborError::Code::UnknownType),       //  0x0103  259
        int16_t(QCborError::Code::IllegalType),       //  0x0104  260
        int16_t(QCborError::Code::IllegalNumber),     //  0x0105  261
        int16_t(QCborError::Code::IllegalSimpleType), //  0x0106  262
        int16_t(QCborError::Code::InvalidUtf8String), //  0x0204  516
        int16_t(QCborError::Code::DataTooLarge),      //  0x0400  1024
        int16_t(QCborError::Code::NestingTooDeep),    //  0x0401  1025
        int16_t(QCborError::Code::UnsupportedType),   //  0x0402  1026
        int16_t(QCborError::Code::NoError)            //  0x0000  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCborError_TypeF(),
        "2:PySide6.QtCore.QCborError.Code",
        Code_Initializer, Code_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCborError_Code_IDX].type = EType;
    // Register converter for enum 'QCborError::Code'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCborError_Code_CppToPython_QCborError_Code);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCborError_Code_PythonToCpp_QCborError_Code,
            is_QCborError_Code_PythonToCpp_QCborError_Code_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCborError::Code");
        Shiboken::Conversions::registerConverterName(converter, "Code");
    }
    // End of 'Code' enum.

    qRegisterMetaType< ::QCborError >("QCborError");
    qRegisterMetaType< ::QCborError::Code >("QCborError::Code");

    return pyType;
}
