// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qcryptographichash_wrapper.h"

// Argument includes
#include <qbytearray.h>
#include <qbytearrayview.h>
#include <qcryptographichash.h>
#include <qiodevice.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCryptographicHash_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCryptographicHash >()))
        return -1;

    ::QCryptographicHash *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCryptographicHash.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QCryptographicHash", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCryptographicHash::QCryptographicHash(QCryptographicHash::Algorithm)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_Algorithm_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QCryptographicHash(QCryptographicHash::Algorithm)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        ::QCryptographicHash::Algorithm cppArg0{QCryptographicHash::Md4};
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QCryptographicHash(QCryptographicHash::Algorithm)
            cptr = new ::QCryptographicHash(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCryptographicHash >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCryptographicHashFunc_addData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCryptographicHash *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCryptographicHash.addData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCryptographicHash::addData(QByteArrayView)
    // 1: QCryptographicHash::addData(QIODevice*)->bool
    // 2: QCryptographicHash::addData(const char*,qsizetype)
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 2; // addData(const char*,qsizetype)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 1; // addData(QIODevice*)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // addData(QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // addData(QByteArrayView data)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addData(QByteArrayView)
                cppSelf->addData(QByteArrayView(cppArg0));
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 1: // addData(QIODevice * device)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QIODevice *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // addData(QIODevice*)
                bool cppResult = cppSelf->addData(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // addData(const char * data, qsizetype length)
        {
            Shiboken::Warnings::warnDeprecated("QCryptographicHash", "addData(const char * data, qsizetype length)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};

            if (Shiboken::Errors::occurred() == nullptr) {
                // addData(const char*,qsizetype)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qcryptographichash-adddata)]
                cppSelf->addData(Shiboken::String::toCString(pyArg), Shiboken::String::len(pyArg));
                // END of custom code block [file: ../glue/qtcore.cpp (qcryptographichash-adddata)]
                // ========================================================================
                // End of code injection

                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCryptographicHashFunc_algorithm(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCryptographicHash *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCryptographicHash.algorithm";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // algorithm()const
            QCryptographicHash::Algorithm cppResult = const_cast<const ::QCryptographicHash *>(cppSelf)->algorithm();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_Algorithm_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCryptographicHashFunc_hash(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCryptographicHash.hash";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "hash", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QCryptographicHash::hash(QByteArrayView,QCryptographicHash::Algorithm)->QByteArray
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_Algorithm_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // hash(QByteArrayView,QCryptographicHash::Algorithm)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QCryptographicHash::Algorithm cppArg1{QCryptographicHash::Md4};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hash(QByteArrayView,QCryptographicHash::Algorithm)
            QByteArray cppResult = ::QCryptographicHash::hash(QByteArrayView(cppArg0), cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCryptographicHashFunc_hashLength(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCryptographicHash.hashLength";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCryptographicHash::hashLength(QCryptographicHash::Algorithm)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_Algorithm_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // hashLength(QCryptographicHash::Algorithm)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCryptographicHash::Algorithm cppArg0{QCryptographicHash::Md4};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hashLength(QCryptographicHash::Algorithm)
            int cppResult = ::QCryptographicHash::hashLength(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCryptographicHashFunc_reset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCryptographicHash *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QCryptographicHash.reset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // reset()
            cppSelf->reset();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCryptographicHashFunc_result(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCryptographicHash *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCryptographicHash.result";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // result()const
            QByteArray cppResult = const_cast<const ::QCryptographicHash *>(cppSelf)->result();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCryptographicHashFunc_resultView(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCryptographicHash *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QCryptographicHash.resultView";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // resultView()const
            QByteArrayView cppResult = const_cast<const ::QCryptographicHash *>(cppSelf)->resultView();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QByteArrayView_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCryptographicHashFunc_supportsAlgorithm(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCryptographicHash.supportsAlgorithm";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QCryptographicHash::supportsAlgorithm(QCryptographicHash::Algorithm)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_Algorithm_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // supportsAlgorithm(QCryptographicHash::Algorithm)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCryptographicHash::Algorithm cppArg0{QCryptographicHash::Md4};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportsAlgorithm(QCryptographicHash::Algorithm)
            bool cppResult = ::QCryptographicHash::supportsAlgorithm(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCryptographicHashFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCryptographicHash *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QCryptographicHash.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCryptographicHash::swap(QCryptographicHash&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QCryptographicHash&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCryptographicHash *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QCryptographicHash&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QCryptographicHash_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QCryptographicHash_EnumFlagInfo[] = {
    "Algorithm:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCryptographicHash_methods[] = {
    {"addData", reinterpret_cast<PyCFunction>(Sbk_QCryptographicHashFunc_addData), METH_O, nullptr},
    {"algorithm", reinterpret_cast<PyCFunction>(Sbk_QCryptographicHashFunc_algorithm), METH_NOARGS, nullptr},
    {"hash", reinterpret_cast<PyCFunction>(Sbk_QCryptographicHashFunc_hash), METH_VARARGS|METH_STATIC, nullptr},
    {"hashLength", reinterpret_cast<PyCFunction>(Sbk_QCryptographicHashFunc_hashLength), METH_O|METH_STATIC, nullptr},
    {"reset", reinterpret_cast<PyCFunction>(Sbk_QCryptographicHashFunc_reset), METH_NOARGS, nullptr},
    {"result", reinterpret_cast<PyCFunction>(Sbk_QCryptographicHashFunc_result), METH_NOARGS, nullptr},
    {"resultView", reinterpret_cast<PyCFunction>(Sbk_QCryptographicHashFunc_resultView), METH_NOARGS, nullptr},
    {"supportsAlgorithm", reinterpret_cast<PyCFunction>(Sbk_QCryptographicHashFunc_supportsAlgorithm), METH_O|METH_STATIC, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QCryptographicHashFunc_swap), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QCryptographicHash_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCryptographicHash_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCryptographicHash_Type = nullptr;
static PyTypeObject *Sbk_QCryptographicHash_TypeF(void)
{
    return _Sbk_QCryptographicHash_Type;
}

static PyType_Slot Sbk_QCryptographicHash_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCryptographicHash_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCryptographicHash_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCryptographicHash_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCryptographicHash_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCryptographicHash_spec = {
    "2:PySide6.QtCore.QCryptographicHash",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCryptographicHash_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QCryptographicHash_Algorithm_PythonToCpp_QCryptographicHash_Algorithm(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCryptographicHash::Algorithm>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCryptographicHash::Algorithm *>(cppOut) = value;

}
static PythonToCppFunc is_QCryptographicHash_Algorithm_PythonToCpp_QCryptographicHash_Algorithm_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_Algorithm_IDX])))
        return QCryptographicHash_Algorithm_PythonToCpp_QCryptographicHash_Algorithm;
    return {};
}
static PyObject *QCryptographicHash_Algorithm_CppToPython_QCryptographicHash_Algorithm(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCryptographicHash::Algorithm *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_Algorithm_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCryptographicHash_PythonToCpp_QCryptographicHash_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCryptographicHash_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCryptographicHash_PythonToCpp_QCryptographicHash_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCryptographicHash_TypeF()))
        return QCryptographicHash_PythonToCpp_QCryptographicHash_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCryptographicHash_PTR_CppToPython_QCryptographicHash(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QCryptographicHash *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QCryptographicHash_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QCryptographicHash_SignatureStrings[] = {
    "PySide6.QtCore.QCryptographicHash(self,method:PySide6.QtCore.QCryptographicHash.Algorithm)",
    "2:PySide6.QtCore.QCryptographicHash.addData(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "1:PySide6.QtCore.QCryptographicHash.addData(self,device:PySide6.QtCore.QIODevice)->bool",
    "0:PySide6.QtCore.QCryptographicHash.addData(self,data:char*)",
    "PySide6.QtCore.QCryptographicHash.algorithm(self)->PySide6.QtCore.QCryptographicHash.Algorithm",
    "PySide6.QtCore.QCryptographicHash.hash(data:typing.Union[PySide6.QtCore.QByteArray, char*],method:PySide6.QtCore.QCryptographicHash.Algorithm)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QCryptographicHash.hashLength(method:PySide6.QtCore.QCryptographicHash.Algorithm)->int",
    "PySide6.QtCore.QCryptographicHash.reset(self)",
    "PySide6.QtCore.QCryptographicHash.result(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QCryptographicHash.resultView(self)->QByteArrayView",
    "PySide6.QtCore.QCryptographicHash.supportsAlgorithm(method:PySide6.QtCore.QCryptographicHash.Algorithm)->bool",
    "PySide6.QtCore.QCryptographicHash.swap(self,other:PySide6.QtCore.QCryptographicHash)",
    nullptr}; // Sentinel

PyTypeObject *init_QCryptographicHash(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_IDX].type;

    Shiboken::AutoDecRef Sbk_QCryptographicHash_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCryptographicHash_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCryptographicHash",
        "QCryptographicHash*",
        &Sbk_QCryptographicHash_spec,
        &Shiboken::callCppDestructor< ::QCryptographicHash >,
        Sbk_QCryptographicHash_Type_bases.object(),
        0);
    auto *pyType = Sbk_QCryptographicHash_TypeF(); // references _Sbk_QCryptographicHash_Type
    InitSignatureStrings(pyType, QCryptographicHash_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCryptographicHash_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCryptographicHash_PythonToCpp_QCryptographicHash_PTR,
        is_QCryptographicHash_PythonToCpp_QCryptographicHash_PTR_Convertible,
        QCryptographicHash_PTR_CppToPython_QCryptographicHash);

    Shiboken::Conversions::registerConverterName(converter, "QCryptographicHash");
    Shiboken::Conversions::registerConverterName(converter, "QCryptographicHash*");
    Shiboken::Conversions::registerConverterName(converter, "QCryptographicHash&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCryptographicHash).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCryptographicHash_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Algorithm'.
    const char *Algorithm_Initializer[] = {
        "Md4",
        "Md5",
        "Sha1",
        "Sha224",
        "Sha256",
        "Sha384",
        "Sha512",
        "Keccak_224",
        "Keccak_256",
        "Keccak_384",
        "Keccak_512",
        "RealSha3_224",
        "RealSha3_256",
        "RealSha3_384",
        "RealSha3_512",
        "Sha3_224",
        "Sha3_256",
        "Sha3_384",
        "Sha3_512",
        "Blake2b_160",
        "Blake2b_256",
        "Blake2b_384",
        "Blake2b_512",
        "Blake2s_128",
        "Blake2s_160",
        "Blake2s_224",
        "Blake2s_256",
        "NumAlgorithms",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Algorithm_InitializerValues[] = {
        uint8_t(QCryptographicHash::Algorithm::Md4),          //  0x00  0
        uint8_t(QCryptographicHash::Algorithm::Md5),          //  0x01  1
        uint8_t(QCryptographicHash::Algorithm::Sha1),         //  0x02  2
        uint8_t(QCryptographicHash::Algorithm::Sha224),       //  0x03  3
        uint8_t(QCryptographicHash::Algorithm::Sha256),       //  0x04  4
        uint8_t(QCryptographicHash::Algorithm::Sha384),       //  0x05  5
        uint8_t(QCryptographicHash::Algorithm::Sha512),       //  0x06  6
        uint8_t(QCryptographicHash::Algorithm::Keccak_224),   //  0x07  7
        uint8_t(QCryptographicHash::Algorithm::Keccak_256),   //  0x08  8
        uint8_t(QCryptographicHash::Algorithm::Keccak_384),   //  0x09  9
        uint8_t(QCryptographicHash::Algorithm::Keccak_512),   //  0x0a  10
        uint8_t(QCryptographicHash::Algorithm::RealSha3_224), //  0x0b  11
        uint8_t(QCryptographicHash::Algorithm::RealSha3_256), //  0x0c  12
        uint8_t(QCryptographicHash::Algorithm::RealSha3_384), //  0x0d  13
        uint8_t(QCryptographicHash::Algorithm::RealSha3_512), //  0x0e  14
        uint8_t(QCryptographicHash::Algorithm::Sha3_224),     //  0x0b  11
        uint8_t(QCryptographicHash::Algorithm::Sha3_256),     //  0x0c  12
        uint8_t(QCryptographicHash::Algorithm::Sha3_384),     //  0x0d  13
        uint8_t(QCryptographicHash::Algorithm::Sha3_512),     //  0x0e  14
        uint8_t(QCryptographicHash::Algorithm::Blake2b_160),  //  0x0f  15
        uint8_t(QCryptographicHash::Algorithm::Blake2b_256),  //  0x10  16
        uint8_t(QCryptographicHash::Algorithm::Blake2b_384),  //  0x11  17
        uint8_t(QCryptographicHash::Algorithm::Blake2b_512),  //  0x12  18
        uint8_t(QCryptographicHash::Algorithm::Blake2s_128),  //  0x13  19
        uint8_t(QCryptographicHash::Algorithm::Blake2s_160),  //  0x14  20
        uint8_t(QCryptographicHash::Algorithm::Blake2s_224),  //  0x15  21
        uint8_t(QCryptographicHash::Algorithm::Blake2s_256),  //  0x16  22
        uint8_t(QCryptographicHash::Algorithm::NumAlgorithms) //  0x17  23
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCryptographicHash_TypeF(),
        "2:PySide6.QtCore.QCryptographicHash.Algorithm",
        Algorithm_Initializer, Algorithm_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QCryptographicHash_Algorithm_IDX].type = EType;
    // Register converter for enum 'QCryptographicHash::Algorithm'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCryptographicHash_Algorithm_CppToPython_QCryptographicHash_Algorithm);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCryptographicHash_Algorithm_PythonToCpp_QCryptographicHash_Algorithm,
            is_QCryptographicHash_Algorithm_PythonToCpp_QCryptographicHash_Algorithm_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCryptographicHash::Algorithm");
        Shiboken::Conversions::registerConverterName(converter, "Algorithm");
    }
    // End of 'Algorithm' enum.

    qRegisterMetaType< ::QCryptographicHash *>();
    qRegisterMetaType< ::QCryptographicHash::Algorithm >("QCryptographicHash::Algorithm");

    return pyType;
}
