// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qelapsedtimer_wrapper.h"

// Argument includes
#include <qelapsedtimer.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QElapsedTimer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QElapsedTimer >()))
        return -1;

    ::QElapsedTimer *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QElapsedTimer.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QElapsedTimer", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QElapsedTimer::QElapsedTimer()
    // 1: QElapsedTimer::QElapsedTimer(QElapsedTimer)
    if (numArgs == 0) {
        overloadId = 0; // QElapsedTimer()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QElapsedTimer(QElapsedTimer)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QElapsedTimer()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QElapsedTimer()
                cptr = new ::QElapsedTimer();
            }
            break;
        }
        case 1: // QElapsedTimer(const QElapsedTimer & QElapsedTimer)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QElapsedTimer cppArg0_local;
            ::QElapsedTimer *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QElapsedTimer(QElapsedTimer)
                cptr = new ::QElapsedTimer(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QElapsedTimer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QElapsedTimerFunc_clockType(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QElapsedTimer.clockType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clockType()
            QElapsedTimer::ClockType cppResult = ::QElapsedTimer::clockType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_ClockType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_elapsed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QElapsedTimer.elapsed";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // elapsed()const
            qint64 cppResult = const_cast<const ::QElapsedTimer *>(cppSelf)->elapsed();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_hasExpired(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QElapsedTimer.hasExpired";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QElapsedTimer::hasExpired(qint64)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // hasExpired(qint64)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasExpired(qint64)const
            bool cppResult = const_cast<const ::QElapsedTimer *>(cppSelf)->hasExpired(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_invalidate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QElapsedTimer.invalidate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // invalidate()
            cppSelf->invalidate();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QElapsedTimerFunc_isMonotonic(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QElapsedTimer.isMonotonic";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isMonotonic()
            bool cppResult = ::QElapsedTimer::isMonotonic();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QElapsedTimer.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QElapsedTimer *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_msecsSinceReference(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QElapsedTimer.msecsSinceReference";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // msecsSinceReference()const
            qint64 cppResult = const_cast<const ::QElapsedTimer *>(cppSelf)->msecsSinceReference();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_msecsTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QElapsedTimer.msecsTo";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QElapsedTimer::msecsTo(QElapsedTimer)const->qint64
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), (pyArg)))) {
        overloadId = 0; // msecsTo(QElapsedTimer)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QElapsedTimer cppArg0_local;
        ::QElapsedTimer *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // msecsTo(QElapsedTimer)const
            qint64 cppResult = const_cast<const ::QElapsedTimer *>(cppSelf)->msecsTo(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_nsecsElapsed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QElapsedTimer.nsecsElapsed";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // nsecsElapsed()const
            qint64 cppResult = const_cast<const ::QElapsedTimer *>(cppSelf)->nsecsElapsed();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_restart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QElapsedTimer.restart";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // restart()
            qint64 cppResult = cppSelf->restart();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_secsTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QElapsedTimer.secsTo";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QElapsedTimer::secsTo(QElapsedTimer)const->qint64
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), (pyArg)))) {
        overloadId = 0; // secsTo(QElapsedTimer)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QElapsedTimer cppArg0_local;
        ::QElapsedTimer *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // secsTo(QElapsedTimer)const
            qint64 cppResult = const_cast<const ::QElapsedTimer *>(cppSelf)->secsTo(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QElapsedTimerFunc_start(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QElapsedTimer.start";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // start()
            cppSelf->start();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QElapsedTimer__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QElapsedTimer_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QElapsedTimer_EnumFlagInfo[] = {
    "ClockType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QElapsedTimer_methods[] = {
    {"clockType", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_clockType), METH_NOARGS|METH_STATIC, nullptr},
    {"elapsed", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_elapsed), METH_NOARGS, nullptr},
    {"hasExpired", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_hasExpired), METH_O, nullptr},
    {"invalidate", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_invalidate), METH_NOARGS, nullptr},
    {"isMonotonic", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_isMonotonic), METH_NOARGS|METH_STATIC, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_isValid), METH_NOARGS, nullptr},
    {"msecsSinceReference", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_msecsSinceReference), METH_NOARGS, nullptr},
    {"msecsTo", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_msecsTo), METH_O, nullptr},
    {"nsecsElapsed", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_nsecsElapsed), METH_NOARGS, nullptr},
    {"restart", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_restart), METH_NOARGS, nullptr},
    {"secsTo", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_secsTo), METH_O, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimerFunc_start), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QElapsedTimer__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QElapsedTimer_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), (pyArg)))) {
                // operator!=(const QElapsedTimer & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QElapsedTimer cppArg0_local;
                ::QElapsedTimer *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), (pyArg)))) {
                // operator==(const QElapsedTimer & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QElapsedTimer cppArg0_local;
                ::QElapsedTimer *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QElapsedTimer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QElapsedTimer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QElapsedTimer_Type = nullptr;
static PyTypeObject *Sbk_QElapsedTimer_TypeF(void)
{
    return _Sbk_QElapsedTimer_Type;
}

static PyType_Slot Sbk_QElapsedTimer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QElapsedTimer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QElapsedTimer_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QElapsedTimer_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QElapsedTimer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QElapsedTimer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QElapsedTimer_spec = {
    "2:PySide6.QtCore.QElapsedTimer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QElapsedTimer_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QElapsedTimer_ClockType_PythonToCpp_QElapsedTimer_ClockType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QElapsedTimer::ClockType>(Shiboken::Enum::getValue(pyIn));
    switch (value) {
    case QElapsedTimer::ClockType::TickCounter:
        Shiboken::Warnings::warnDeprecatedEnumValue("QElapsedTimer::ClockType", "TickCounter");
        break;
    default:
        break;
    }
    *reinterpret_cast<::QElapsedTimer::ClockType *>(cppOut) = value;

}
static PythonToCppFunc is_QElapsedTimer_ClockType_PythonToCpp_QElapsedTimer_ClockType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_ClockType_IDX])))
        return QElapsedTimer_ClockType_PythonToCpp_QElapsedTimer_ClockType;
    return {};
}
static PyObject *QElapsedTimer_ClockType_CppToPython_QElapsedTimer_ClockType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QElapsedTimer::ClockType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_ClockType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QElapsedTimer_PythonToCpp_QElapsedTimer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QElapsedTimer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QElapsedTimer_PythonToCpp_QElapsedTimer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QElapsedTimer_TypeF()))
        return QElapsedTimer_PythonToCpp_QElapsedTimer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QElapsedTimer_PTR_CppToPython_QElapsedTimer(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QElapsedTimer *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QElapsedTimer_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QElapsedTimer_COPY_CppToPython_QElapsedTimer(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QElapsedTimer *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QElapsedTimer_TypeF(), new ::QElapsedTimer(*source), true, true);
}

// Python to C++ copy conversion.
static void QElapsedTimer_PythonToCpp_QElapsedTimer_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QElapsedTimer *>(cppOut) = *reinterpret_cast< ::QElapsedTimer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QElapsedTimer_PythonToCpp_QElapsedTimer_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QElapsedTimer_TypeF()))
        return QElapsedTimer_PythonToCpp_QElapsedTimer_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QElapsedTimer_SignatureStrings[] = {
    "1:PySide6.QtCore.QElapsedTimer(self)",
    "0:PySide6.QtCore.QElapsedTimer(self,QElapsedTimer:PySide6.QtCore.QElapsedTimer)",
    "PySide6.QtCore.QElapsedTimer.clockType()->PySide6.QtCore.QElapsedTimer.ClockType",
    "PySide6.QtCore.QElapsedTimer.elapsed(self)->qint64",
    "PySide6.QtCore.QElapsedTimer.hasExpired(self,timeout:qint64)->bool",
    "PySide6.QtCore.QElapsedTimer.invalidate(self)",
    "PySide6.QtCore.QElapsedTimer.isMonotonic()->bool",
    "PySide6.QtCore.QElapsedTimer.isValid(self)->bool",
    "PySide6.QtCore.QElapsedTimer.msecsSinceReference(self)->qint64",
    "PySide6.QtCore.QElapsedTimer.msecsTo(self,other:PySide6.QtCore.QElapsedTimer)->qint64",
    "PySide6.QtCore.QElapsedTimer.nsecsElapsed(self)->qint64",
    "PySide6.QtCore.QElapsedTimer.restart(self)->qint64",
    "PySide6.QtCore.QElapsedTimer.secsTo(self,other:PySide6.QtCore.QElapsedTimer)->qint64",
    "PySide6.QtCore.QElapsedTimer.start(self)",
    "PySide6.QtCore.QElapsedTimer.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QElapsedTimer(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX].type;

    Shiboken::AutoDecRef Sbk_QElapsedTimer_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QElapsedTimer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QElapsedTimer",
        "QElapsedTimer",
        &Sbk_QElapsedTimer_spec,
        &Shiboken::callCppDestructor< ::QElapsedTimer >,
        Sbk_QElapsedTimer_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QElapsedTimer_TypeF(); // references _Sbk_QElapsedTimer_Type
    InitSignatureStrings(pyType, QElapsedTimer_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QElapsedTimer_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QElapsedTimer_PythonToCpp_QElapsedTimer_PTR,
        is_QElapsedTimer_PythonToCpp_QElapsedTimer_PTR_Convertible,
        QElapsedTimer_PTR_CppToPython_QElapsedTimer,
        QElapsedTimer_COPY_CppToPython_QElapsedTimer);

    Shiboken::Conversions::registerConverterName(converter, "QElapsedTimer");
    Shiboken::Conversions::registerConverterName(converter, "QElapsedTimer*");
    Shiboken::Conversions::registerConverterName(converter, "QElapsedTimer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QElapsedTimer).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QElapsedTimer_PythonToCpp_QElapsedTimer_COPY,
        is_QElapsedTimer_PythonToCpp_QElapsedTimer_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QElapsedTimer_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ClockType'.
    const char *ClockType_Initializer[] = {
        "SystemTime",
        "MonotonicClock",
        "TickCounter",
        "MachAbsoluteTime",
        "PerformanceCounter",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ClockType_InitializerValues[] = {
        uint8_t(QElapsedTimer::ClockType::SystemTime),        //  0x00  0
        uint8_t(QElapsedTimer::ClockType::MonotonicClock),    //  0x01  1
        uint8_t(QElapsedTimer::ClockType::TickCounter),       //  0x02  2
        uint8_t(QElapsedTimer::ClockType::MachAbsoluteTime),  //  0x03  3
        uint8_t(QElapsedTimer::ClockType::PerformanceCounter) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QElapsedTimer_TypeF(),
        "2:PySide6.QtCore.QElapsedTimer.ClockType",
        ClockType_Initializer, ClockType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QElapsedTimer_ClockType_IDX].type = EType;
    // Register converter for enum 'QElapsedTimer::ClockType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QElapsedTimer_ClockType_CppToPython_QElapsedTimer_ClockType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QElapsedTimer_ClockType_PythonToCpp_QElapsedTimer_ClockType,
            is_QElapsedTimer_ClockType_PythonToCpp_QElapsedTimer_ClockType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QElapsedTimer::ClockType");
        Shiboken::Conversions::registerConverterName(converter, "ClockType");
    }
    // End of 'ClockType' enum.

    qRegisterMetaType< ::QElapsedTimer >("QElapsedTimer");
    qRegisterMetaType< ::QElapsedTimer::ClockType >("QElapsedTimer::ClockType");

    return pyType;
}
