// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qloggingcategory_wrapper.h"

// Argument includes
#include <QString>
#include <qlogging.h>
#include <qloggingcategory.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLoggingCategory_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLoggingCategory >()))
        return -1;

    ::QLoggingCategory *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLoggingCategory.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:QLoggingCategory", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLoggingCategory::QLoggingCategory(const char*,QtMsgType=)
    if (numArgs >= 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QLoggingCategory(const char*,QtMsgType)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtMsgType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // QLoggingCategory(const char*,QtMsgType)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_severityLevel = Shiboken::String::createStaticString("severityLevel");
            if (PyDict_Contains(kwds, key_severityLevel) != 0) {
                value = PyDict_GetItem(kwds, key_severityLevel);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_severityLevel);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtMsgType_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_severityLevel);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
        }
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QtMsgType cppArg1(QtDebugMsg);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QLoggingCategory(const char*,QtMsgType)
            cptr = new ::QLoggingCategory(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLoggingCategory >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLoggingCategoryFunc_categoryName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLoggingCategory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLoggingCategory.categoryName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // categoryName()const
            const char * cppResult = const_cast<const ::QLoggingCategory *>(cppSelf)->categoryName();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLoggingCategoryFunc_defaultCategory(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLoggingCategory.defaultCategory";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultCategory()
            QLoggingCategory * cppResult = ::QLoggingCategory::defaultCategory();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLoggingCategoryFunc_isCriticalEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLoggingCategory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLoggingCategory.isCriticalEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isCriticalEnabled()const
            bool cppResult = const_cast<const ::QLoggingCategory *>(cppSelf)->isCriticalEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLoggingCategoryFunc_isDebugEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLoggingCategory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLoggingCategory.isDebugEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDebugEnabled()const
            bool cppResult = const_cast<const ::QLoggingCategory *>(cppSelf)->isDebugEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLoggingCategoryFunc_isEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLoggingCategory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLoggingCategory.isEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLoggingCategory::isEnabled(QtMsgType)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtMsgType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isEnabled(QtMsgType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QtMsgType cppArg0{QtDebugMsg};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isEnabled(QtMsgType)const
            bool cppResult = const_cast<const ::QLoggingCategory *>(cppSelf)->isEnabled(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLoggingCategoryFunc_isInfoEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLoggingCategory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLoggingCategory.isInfoEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isInfoEnabled()const
            bool cppResult = const_cast<const ::QLoggingCategory *>(cppSelf)->isInfoEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLoggingCategoryFunc_isWarningEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLoggingCategory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLoggingCategory.isWarningEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isWarningEnabled()const
            bool cppResult = const_cast<const ::QLoggingCategory *>(cppSelf)->isWarningEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLoggingCategoryFunc___call__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLoggingCategory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLoggingCategory.__call__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // operator()()
            QLoggingCategory & cppResult = cppSelf->operator()();
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLoggingCategoryFunc_setEnabled(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLoggingCategory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLoggingCategory.setEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setEnabled", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLoggingCategory::setEnabled(QtMsgType,bool)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtMsgType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
        overloadId = 0; // setEnabled(QtMsgType,bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QtMsgType cppArg0{QtDebugMsg};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEnabled(QtMsgType,bool)
            cppSelf->setEnabled(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLoggingCategoryFunc_setFilterRules(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLoggingCategory.setFilterRules";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLoggingCategory::setFilterRules(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFilterRules(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFilterRules(QString)
            ::QLoggingCategory::setFilterRules(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QLoggingCategory_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLoggingCategory_methods[] = {
    {"categoryName", reinterpret_cast<PyCFunction>(Sbk_QLoggingCategoryFunc_categoryName), METH_NOARGS, nullptr},
    {"defaultCategory", reinterpret_cast<PyCFunction>(Sbk_QLoggingCategoryFunc_defaultCategory), METH_NOARGS|METH_STATIC, nullptr},
    {"isCriticalEnabled", reinterpret_cast<PyCFunction>(Sbk_QLoggingCategoryFunc_isCriticalEnabled), METH_NOARGS, nullptr},
    {"isDebugEnabled", reinterpret_cast<PyCFunction>(Sbk_QLoggingCategoryFunc_isDebugEnabled), METH_NOARGS, nullptr},
    {"isEnabled", reinterpret_cast<PyCFunction>(Sbk_QLoggingCategoryFunc_isEnabled), METH_O, nullptr},
    {"isInfoEnabled", reinterpret_cast<PyCFunction>(Sbk_QLoggingCategoryFunc_isInfoEnabled), METH_NOARGS, nullptr},
    {"isWarningEnabled", reinterpret_cast<PyCFunction>(Sbk_QLoggingCategoryFunc_isWarningEnabled), METH_NOARGS, nullptr},
    {"setEnabled", reinterpret_cast<PyCFunction>(Sbk_QLoggingCategoryFunc_setEnabled), METH_VARARGS, nullptr},
    {"setFilterRules", reinterpret_cast<PyCFunction>(Sbk_QLoggingCategoryFunc_setFilterRules), METH_O|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QLoggingCategory_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLoggingCategory_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLoggingCategory_Type = nullptr;
static PyTypeObject *Sbk_QLoggingCategory_TypeF(void)
{
    return _Sbk_QLoggingCategory_Type;
}

static PyType_Slot Sbk_QLoggingCategory_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_call,        reinterpret_cast<void *>(&Sbk_QLoggingCategoryFunc___call__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLoggingCategory_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLoggingCategory_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLoggingCategory_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLoggingCategory_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLoggingCategory_spec = {
    "2:PySide6.QtCore.QLoggingCategory",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLoggingCategory_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLoggingCategory_PythonToCpp_QLoggingCategory_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLoggingCategory_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLoggingCategory_PythonToCpp_QLoggingCategory_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLoggingCategory_TypeF()))
        return QLoggingCategory_PythonToCpp_QLoggingCategory_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLoggingCategory_PTR_CppToPython_QLoggingCategory(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QLoggingCategory *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QLoggingCategory_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QLoggingCategory_SignatureStrings[] = {
    "PySide6.QtCore.QLoggingCategory(self,category:char*,severityLevel:PySide6.QtCore.QtMsgType=QtDebugMsg)",
    "PySide6.QtCore.QLoggingCategory.categoryName(self)->char*",
    "PySide6.QtCore.QLoggingCategory.defaultCategory()->PySide6.QtCore.QLoggingCategory",
    "PySide6.QtCore.QLoggingCategory.isCriticalEnabled(self)->bool",
    "PySide6.QtCore.QLoggingCategory.isDebugEnabled(self)->bool",
    "PySide6.QtCore.QLoggingCategory.isEnabled(self,type:PySide6.QtCore.QtMsgType)->bool",
    "PySide6.QtCore.QLoggingCategory.isInfoEnabled(self)->bool",
    "PySide6.QtCore.QLoggingCategory.isWarningEnabled(self)->bool",
    "PySide6.QtCore.QLoggingCategory.__call__(self)->PySide6.QtCore.QLoggingCategory",
    "PySide6.QtCore.QLoggingCategory.setEnabled(self,type:PySide6.QtCore.QtMsgType,enable:bool)",
    "PySide6.QtCore.QLoggingCategory.setFilterRules(rules:QString)",
    nullptr}; // Sentinel

PyTypeObject *init_QLoggingCategory(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX].type;

    Shiboken::AutoDecRef Sbk_QLoggingCategory_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLoggingCategory_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLoggingCategory",
        "QLoggingCategory*",
        &Sbk_QLoggingCategory_spec,
        &Shiboken::callCppDestructor< ::QLoggingCategory >,
        Sbk_QLoggingCategory_Type_bases.object(),
        0);
    auto *pyType = Sbk_QLoggingCategory_TypeF(); // references _Sbk_QLoggingCategory_Type
    InitSignatureStrings(pyType, QLoggingCategory_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLoggingCategory_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLoggingCategory_PythonToCpp_QLoggingCategory_PTR,
        is_QLoggingCategory_PythonToCpp_QLoggingCategory_PTR_Convertible,
        QLoggingCategory_PTR_CppToPython_QLoggingCategory);

    Shiboken::Conversions::registerConverterName(converter, "QLoggingCategory");
    Shiboken::Conversions::registerConverterName(converter, "QLoggingCategory*");
    Shiboken::Conversions::registerConverterName(converter, "QLoggingCategory&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLoggingCategory).name());

    qRegisterMetaType< ::QLoggingCategory *>();

    return pyType;
}
