// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qmimedatabase_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <qbytearray.h>
#include <qfileinfo.h>
#include <qiodevice.h>
#include <qmimedatabase.h>
#include <qmimetype.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMimeDatabase_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMimeDatabase >()))
        return -1;

    ::QMimeDatabase *cptr{};
    static const char fullName[] = "PySide6.QtCore.QMimeDatabase.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QMimeDatabase()
            cptr = new ::QMimeDatabase();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMimeDatabase >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMimeDatabaseFunc_allMimeTypes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMimeDatabase.allMimeTypes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // allMimeTypes()const
            QList<QMimeType> cppResult = const_cast<const ::QMimeDatabase *>(cppSelf)->allMimeTypes();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QMimeType_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeDatabaseFunc_mimeTypeForData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMimeDatabase.mimeTypeForData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMimeDatabase::mimeTypeForData(QIODevice*)const->QMimeType
    // 1: QMimeDatabase::mimeTypeForData(QByteArray)const->QMimeType
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 1; // mimeTypeForData(QByteArray)const
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArg)))) {
        overloadId = 0; // mimeTypeForData(QIODevice*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // mimeTypeForData(QIODevice * device) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QIODevice *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mimeTypeForData(QIODevice*)const
                QMimeType cppResult = const_cast<const ::QMimeDatabase *>(cppSelf)->mimeTypeForData(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), &cppResult);
            }
            break;
        }
        case 1: // mimeTypeForData(const QByteArray & data) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // mimeTypeForData(QByteArray)const
                QMimeType cppResult = const_cast<const ::QMimeDatabase *>(cppSelf)->mimeTypeForData(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeDatabaseFunc_mimeTypeForFile(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMimeDatabase.mimeTypeForFile";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:mimeTypeForFile", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMimeDatabase::mimeTypeForFile(QFileInfo,QMimeDatabase::MatchMode=)const->QMimeType
    // 1: QMimeDatabase::mimeTypeForFile(QString,QMimeDatabase::MatchMode=)const->QMimeType
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // mimeTypeForFile(QString,QMimeDatabase::MatchMode)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_MatchMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // mimeTypeForFile(QString,QMimeDatabase::MatchMode)const
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFileInfo_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // mimeTypeForFile(QFileInfo,QMimeDatabase::MatchMode)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_MatchMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // mimeTypeForFile(QFileInfo,QMimeDatabase::MatchMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // mimeTypeForFile(const QFileInfo & fileInfo, QMimeDatabase::MatchMode mode) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_MatchMode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QFileInfo cppArg0_local;
            ::QFileInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QMimeDatabase::MatchMode cppArg1(QMimeDatabase::MatchMode::MatchDefault);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mimeTypeForFile(QFileInfo,QMimeDatabase::MatchMode)const
                QMimeType cppResult = const_cast<const ::QMimeDatabase *>(cppSelf)->mimeTypeForFile(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), &cppResult);
            }
            break;
        }
        case 1: // mimeTypeForFile(const QString & fileName, QMimeDatabase::MatchMode mode) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_MatchMode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QMimeDatabase::MatchMode cppArg1(QMimeDatabase::MatchMode::MatchDefault);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mimeTypeForFile(QString,QMimeDatabase::MatchMode)const
                QMimeType cppResult = const_cast<const ::QMimeDatabase *>(cppSelf)->mimeTypeForFile(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeDatabaseFunc_mimeTypeForFileNameAndData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMimeDatabase.mimeTypeForFileNameAndData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "mimeTypeForFileNameAndData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMimeDatabase::mimeTypeForFileNameAndData(QString,QIODevice*)const->QMimeType
    // 1: QMimeDatabase::mimeTypeForFileNameAndData(QString,QByteArray)const->QMimeType
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 1; // mimeTypeForFileNameAndData(QString,QByteArray)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]), (pyArgs[1])))) {
            overloadId = 0; // mimeTypeForFileNameAndData(QString,QIODevice*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // mimeTypeForFileNameAndData(const QString & fileName, QIODevice * device) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QIODevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mimeTypeForFileNameAndData(QString,QIODevice*)const
                QMimeType cppResult = const_cast<const ::QMimeDatabase *>(cppSelf)->mimeTypeForFileNameAndData(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), &cppResult);
            }
            break;
        }
        case 1: // mimeTypeForFileNameAndData(const QString & fileName, const QByteArray & data) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QByteArray cppArg1_local;
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // mimeTypeForFileNameAndData(QString,QByteArray)const
                QMimeType cppResult = const_cast<const ::QMimeDatabase *>(cppSelf)->mimeTypeForFileNameAndData(cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeDatabaseFunc_mimeTypeForName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMimeDatabase.mimeTypeForName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMimeDatabase::mimeTypeForName(QString)const->QMimeType
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // mimeTypeForName(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mimeTypeForName(QString)const
            QMimeType cppResult = const_cast<const ::QMimeDatabase *>(cppSelf)->mimeTypeForName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeDatabaseFunc_mimeTypeForUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMimeDatabase.mimeTypeForUrl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMimeDatabase::mimeTypeForUrl(QUrl)const->QMimeType
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // mimeTypeForUrl(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mimeTypeForUrl(QUrl)const
            QMimeType cppResult = const_cast<const ::QMimeDatabase *>(cppSelf)->mimeTypeForUrl(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeType_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeDatabaseFunc_mimeTypesForFileName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMimeDatabase.mimeTypesForFileName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMimeDatabase::mimeTypesForFileName(QString)const->QList< QMimeType>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // mimeTypesForFileName(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mimeTypesForFileName(QString)const
            QList<QMimeType> cppResult = const_cast<const ::QMimeDatabase *>(cppSelf)->mimeTypesForFileName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QMimeType_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMimeDatabaseFunc_suffixForFileName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMimeDatabase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMimeDatabase.suffixForFileName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMimeDatabase::suffixForFileName(QString)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // suffixForFileName(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // suffixForFileName(QString)const
            QString cppResult = const_cast<const ::QMimeDatabase *>(cppSelf)->suffixForFileName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMimeDatabase_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QMimeDatabase_EnumFlagInfo[] = {
    "MatchMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMimeDatabase_methods[] = {
    {"allMimeTypes", reinterpret_cast<PyCFunction>(Sbk_QMimeDatabaseFunc_allMimeTypes), METH_NOARGS, nullptr},
    {"mimeTypeForData", reinterpret_cast<PyCFunction>(Sbk_QMimeDatabaseFunc_mimeTypeForData), METH_O, nullptr},
    {"mimeTypeForFile", reinterpret_cast<PyCFunction>(Sbk_QMimeDatabaseFunc_mimeTypeForFile), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"mimeTypeForFileNameAndData", reinterpret_cast<PyCFunction>(Sbk_QMimeDatabaseFunc_mimeTypeForFileNameAndData), METH_VARARGS, nullptr},
    {"mimeTypeForName", reinterpret_cast<PyCFunction>(Sbk_QMimeDatabaseFunc_mimeTypeForName), METH_O, nullptr},
    {"mimeTypeForUrl", reinterpret_cast<PyCFunction>(Sbk_QMimeDatabaseFunc_mimeTypeForUrl), METH_O, nullptr},
    {"mimeTypesForFileName", reinterpret_cast<PyCFunction>(Sbk_QMimeDatabaseFunc_mimeTypesForFileName), METH_O, nullptr},
    {"suffixForFileName", reinterpret_cast<PyCFunction>(Sbk_QMimeDatabaseFunc_suffixForFileName), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QMimeDatabase_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMimeDatabase_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMimeDatabase_Type = nullptr;
static PyTypeObject *Sbk_QMimeDatabase_TypeF(void)
{
    return _Sbk_QMimeDatabase_Type;
}

static PyType_Slot Sbk_QMimeDatabase_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMimeDatabase_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMimeDatabase_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMimeDatabase_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMimeDatabase_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMimeDatabase_spec = {
    "2:PySide6.QtCore.QMimeDatabase",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMimeDatabase_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QMimeDatabase_MatchMode_PythonToCpp_QMimeDatabase_MatchMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMimeDatabase::MatchMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMimeDatabase::MatchMode *>(cppOut) = value;

}
static PythonToCppFunc is_QMimeDatabase_MatchMode_PythonToCpp_QMimeDatabase_MatchMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_MatchMode_IDX])))
        return QMimeDatabase_MatchMode_PythonToCpp_QMimeDatabase_MatchMode;
    return {};
}
static PyObject *QMimeDatabase_MatchMode_CppToPython_QMimeDatabase_MatchMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QMimeDatabase::MatchMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_MatchMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMimeDatabase_PythonToCpp_QMimeDatabase_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMimeDatabase_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMimeDatabase_PythonToCpp_QMimeDatabase_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMimeDatabase_TypeF()))
        return QMimeDatabase_PythonToCpp_QMimeDatabase_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMimeDatabase_PTR_CppToPython_QMimeDatabase(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QMimeDatabase *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QMimeDatabase_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QMimeDatabase_SignatureStrings[] = {
    "PySide6.QtCore.QMimeDatabase(self)",
    "PySide6.QtCore.QMimeDatabase.allMimeTypes(self)->QList[PySide6.QtCore.QMimeType]",
    "1:PySide6.QtCore.QMimeDatabase.mimeTypeForData(self,device:PySide6.QtCore.QIODevice)->PySide6.QtCore.QMimeType",
    "0:PySide6.QtCore.QMimeDatabase.mimeTypeForData(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QMimeType",
    "1:PySide6.QtCore.QMimeDatabase.mimeTypeForFile(self,fileInfo:PySide6.QtCore.QFileInfo,mode:PySide6.QtCore.QMimeDatabase.MatchMode=QMimeDatabase.MatchMode.MatchDefault)->PySide6.QtCore.QMimeType",
    "0:PySide6.QtCore.QMimeDatabase.mimeTypeForFile(self,fileName:QString,mode:PySide6.QtCore.QMimeDatabase.MatchMode=QMimeDatabase.MatchMode.MatchDefault)->PySide6.QtCore.QMimeType",
    "1:PySide6.QtCore.QMimeDatabase.mimeTypeForFileNameAndData(self,fileName:QString,device:PySide6.QtCore.QIODevice)->PySide6.QtCore.QMimeType",
    "0:PySide6.QtCore.QMimeDatabase.mimeTypeForFileNameAndData(self,fileName:QString,data:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QMimeType",
    "PySide6.QtCore.QMimeDatabase.mimeTypeForName(self,nameOrAlias:QString)->PySide6.QtCore.QMimeType",
    "PySide6.QtCore.QMimeDatabase.mimeTypeForUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])->PySide6.QtCore.QMimeType",
    "PySide6.QtCore.QMimeDatabase.mimeTypesForFileName(self,fileName:QString)->QList[PySide6.QtCore.QMimeType]",
    "PySide6.QtCore.QMimeDatabase.suffixForFileName(self,fileName:QString)->QString",
    nullptr}; // Sentinel

PyTypeObject *init_QMimeDatabase(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_IDX].type;

    Shiboken::AutoDecRef Sbk_QMimeDatabase_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QMimeDatabase_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMimeDatabase",
        "QMimeDatabase*",
        &Sbk_QMimeDatabase_spec,
        &Shiboken::callCppDestructor< ::QMimeDatabase >,
        Sbk_QMimeDatabase_Type_bases.object(),
        0);
    auto *pyType = Sbk_QMimeDatabase_TypeF(); // references _Sbk_QMimeDatabase_Type
    InitSignatureStrings(pyType, QMimeDatabase_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMimeDatabase_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMimeDatabase_PythonToCpp_QMimeDatabase_PTR,
        is_QMimeDatabase_PythonToCpp_QMimeDatabase_PTR_Convertible,
        QMimeDatabase_PTR_CppToPython_QMimeDatabase);

    Shiboken::Conversions::registerConverterName(converter, "QMimeDatabase");
    Shiboken::Conversions::registerConverterName(converter, "QMimeDatabase*");
    Shiboken::Conversions::registerConverterName(converter, "QMimeDatabase&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMimeDatabase).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QMimeDatabase_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'MatchMode'.
    const char *MatchMode_Initializer[] = {
        "MatchDefault",
        "MatchExtension",
        "MatchContent",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MatchMode_InitializerValues[] = {
        uint8_t(QMimeDatabase::MatchMode::MatchDefault),   //  0x00  0
        uint8_t(QMimeDatabase::MatchMode::MatchExtension), //  0x01  1
        uint8_t(QMimeDatabase::MatchMode::MatchContent)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMimeDatabase_TypeF(),
        "2:PySide6.QtCore.QMimeDatabase.MatchMode",
        MatchMode_Initializer, MatchMode_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QMimeDatabase_MatchMode_IDX].type = EType;
    // Register converter for enum 'QMimeDatabase::MatchMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMimeDatabase_MatchMode_CppToPython_QMimeDatabase_MatchMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QMimeDatabase_MatchMode_PythonToCpp_QMimeDatabase_MatchMode,
            is_QMimeDatabase_MatchMode_PythonToCpp_QMimeDatabase_MatchMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QMimeDatabase::MatchMode");
        Shiboken::Conversions::registerConverterName(converter, "MatchMode");
    }
    // End of 'MatchMode' enum.

    qRegisterMetaType< ::QMimeDatabase *>();
    qRegisterMetaType< ::QMimeDatabase::MatchMode >("QMimeDatabase::MatchMode");

    return pyType;
}
