// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qprocessenvironment_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <qprocess.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QProcessEnvironment_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QProcessEnvironment >()))
        return -1;

    ::QProcessEnvironment *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QProcessEnvironment.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QProcessEnvironment", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QProcessEnvironment::QProcessEnvironment()
    // 1: QProcessEnvironment::QProcessEnvironment(QProcessEnvironment::Initialization)
    // 2: QProcessEnvironment::QProcessEnvironment(QProcessEnvironment)
    if (numArgs == 0) {
        overloadId = 0; // QProcessEnvironment()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_Initialization_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // QProcessEnvironment(QProcessEnvironment::Initialization)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QProcessEnvironment(QProcessEnvironment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QProcessEnvironment()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QProcessEnvironment()
                cptr = new ::QProcessEnvironment();
            }
            break;
        }
        case 1: // QProcessEnvironment(QProcessEnvironment::Initialization arg__1)
        {
            ::QProcessEnvironment::Initialization cppArg0{QProcessEnvironment::InheritFromParent};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QProcessEnvironment(QProcessEnvironment::Initialization)
                cptr = new ::QProcessEnvironment(cppArg0);
            }
            break;
        }
        case 2: // QProcessEnvironment(const QProcessEnvironment & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QProcessEnvironment cppArg0_local;
            ::QProcessEnvironment *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QProcessEnvironment(QProcessEnvironment)
                cptr = new ::QProcessEnvironment(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QProcessEnvironment >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QProcessEnvironmentFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcessEnvironment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtCore.QProcessEnvironment.clear";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clear()
            cppSelf->clear();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QProcessEnvironmentFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcessEnvironment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QProcessEnvironment.contains";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcessEnvironment::contains(QString)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // contains(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contains(QString)const
            bool cppResult = const_cast<const ::QProcessEnvironment *>(cppSelf)->contains(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QProcessEnvironmentFunc_inheritsFromParent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcessEnvironment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QProcessEnvironment.inheritsFromParent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // inheritsFromParent()const
            bool cppResult = const_cast<const ::QProcessEnvironment *>(cppSelf)->inheritsFromParent();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QProcessEnvironmentFunc_insert(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcessEnvironment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QProcessEnvironment.insert";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insert", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QProcessEnvironment::insert(QProcessEnvironment)
    // 1: QProcessEnvironment::insert(QString,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 1; // insert(QString,QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), (pyArgs[0])))) {
        overloadId = 0; // insert(QProcessEnvironment)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // insert(const QProcessEnvironment & e)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QProcessEnvironment cppArg0_local;
            ::QProcessEnvironment *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // insert(QProcessEnvironment)
                cppSelf->insert(*cppArg0);
            }
            break;
        }
        case 1: // insert(const QString & name, const QString & value)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // insert(QString,QString)
                cppSelf->insert(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QProcessEnvironmentFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcessEnvironment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QProcessEnvironment.isEmpty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isEmpty()const
            bool cppResult = const_cast<const ::QProcessEnvironment *>(cppSelf)->isEmpty();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QProcessEnvironmentFunc_keys(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcessEnvironment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QProcessEnvironment.keys";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // keys()const
            QStringList cppResult = const_cast<const ::QProcessEnvironment *>(cppSelf)->keys();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QProcessEnvironmentFunc_remove(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcessEnvironment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QProcessEnvironment.remove";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcessEnvironment::remove(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // remove(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // remove(QString)
            cppSelf->remove(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QProcessEnvironmentFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcessEnvironment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QProcessEnvironment.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QProcessEnvironment::swap(QProcessEnvironment&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QProcessEnvironment&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QProcessEnvironment cppArg0_local;
        ::QProcessEnvironment *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QProcessEnvironment&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QProcessEnvironmentFunc_systemEnvironment(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QProcessEnvironment.systemEnvironment";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // systemEnvironment()
            QProcessEnvironment cppResult = ::QProcessEnvironment::systemEnvironment();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QProcessEnvironmentFunc_toStringList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcessEnvironment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QProcessEnvironment.toStringList";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toStringList()const
            QStringList cppResult = const_cast<const ::QProcessEnvironment *>(cppSelf)->toStringList();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QProcessEnvironmentFunc_value(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QProcessEnvironment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QProcessEnvironment.value";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:value", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QProcessEnvironment::value(QString,const QString&=)const->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // value(QString,QString)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // value(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // value(QString,QString)const
            QString cppResult = const_cast<const ::QProcessEnvironment *>(cppSelf)->value(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QProcessEnvironment__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QProcessEnvironment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QProcessEnvironment_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QProcessEnvironment_EnumFlagInfo[] = {
    "Initialization:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QProcessEnvironment_methods[] = {
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QProcessEnvironmentFunc_clear), METH_NOARGS, nullptr},
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QProcessEnvironmentFunc_contains), METH_O, nullptr},
    {"inheritsFromParent", reinterpret_cast<PyCFunction>(Sbk_QProcessEnvironmentFunc_inheritsFromParent), METH_NOARGS, nullptr},
    {"insert", reinterpret_cast<PyCFunction>(Sbk_QProcessEnvironmentFunc_insert), METH_VARARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QProcessEnvironmentFunc_isEmpty), METH_NOARGS, nullptr},
    {"keys", reinterpret_cast<PyCFunction>(Sbk_QProcessEnvironmentFunc_keys), METH_NOARGS, nullptr},
    {"remove", reinterpret_cast<PyCFunction>(Sbk_QProcessEnvironmentFunc_remove), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QProcessEnvironmentFunc_swap), METH_O, nullptr},
    {"systemEnvironment", reinterpret_cast<PyCFunction>(Sbk_QProcessEnvironmentFunc_systemEnvironment), METH_NOARGS|METH_STATIC, nullptr},
    {"toStringList", reinterpret_cast<PyCFunction>(Sbk_QProcessEnvironmentFunc_toStringList), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QProcessEnvironmentFunc_value), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QProcessEnvironment__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QProcessEnvironment_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QProcessEnvironment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), (pyArg)))) {
                // operator!=(const QProcessEnvironment & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QProcessEnvironment cppArg0_local;
                ::QProcessEnvironment *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), (pyArg)))) {
                // operator==(const QProcessEnvironment & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QProcessEnvironment cppArg0_local;
                ::QProcessEnvironment *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QProcessEnvironment_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QProcessEnvironment_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QProcessEnvironment_Type = nullptr;
static PyTypeObject *Sbk_QProcessEnvironment_TypeF(void)
{
    return _Sbk_QProcessEnvironment_Type;
}

static PyType_Slot Sbk_QProcessEnvironment_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QProcessEnvironment_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QProcessEnvironment_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QProcessEnvironment_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QProcessEnvironment_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QProcessEnvironment_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QProcessEnvironment_spec = {
    "2:PySide6.QtCore.QProcessEnvironment",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QProcessEnvironment_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QProcessEnvironment_Initialization_PythonToCpp_QProcessEnvironment_Initialization(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QProcessEnvironment::Initialization>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QProcessEnvironment::Initialization *>(cppOut) = value;

}
static PythonToCppFunc is_QProcessEnvironment_Initialization_PythonToCpp_QProcessEnvironment_Initialization_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_Initialization_IDX])))
        return QProcessEnvironment_Initialization_PythonToCpp_QProcessEnvironment_Initialization;
    return {};
}
static PyObject *QProcessEnvironment_Initialization_CppToPython_QProcessEnvironment_Initialization(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QProcessEnvironment::Initialization *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_Initialization_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QProcessEnvironment_PythonToCpp_QProcessEnvironment_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QProcessEnvironment_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QProcessEnvironment_PythonToCpp_QProcessEnvironment_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QProcessEnvironment_TypeF()))
        return QProcessEnvironment_PythonToCpp_QProcessEnvironment_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QProcessEnvironment_PTR_CppToPython_QProcessEnvironment(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QProcessEnvironment *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QProcessEnvironment_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QProcessEnvironment_COPY_CppToPython_QProcessEnvironment(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QProcessEnvironment *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QProcessEnvironment_TypeF(), new ::QProcessEnvironment(*source), true, true);
}

// Python to C++ copy conversion.
static void QProcessEnvironment_PythonToCpp_QProcessEnvironment_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QProcessEnvironment *>(cppOut) = *reinterpret_cast< ::QProcessEnvironment *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QProcessEnvironment_PythonToCpp_QProcessEnvironment_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QProcessEnvironment_TypeF()))
        return QProcessEnvironment_PythonToCpp_QProcessEnvironment_COPY;
    return {};
}

// Implicit conversions.
static void QProcessEnvironment_Initialization_PythonToCpp_QProcessEnvironment(PyObject *pyIn, void *cppOut)
{
    ::QProcessEnvironment::Initialization cppIn{QProcessEnvironment::InheritFromParent};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_Initialization_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QProcessEnvironment *>(cppOut) = ::QProcessEnvironment(cppIn);
}
static PythonToCppFunc is_QProcessEnvironment_Initialization_PythonToCpp_QProcessEnvironment_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_Initialization_IDX]), pyIn))
        return QProcessEnvironment_Initialization_PythonToCpp_QProcessEnvironment;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QProcessEnvironment_SignatureStrings[] = {
    "2:PySide6.QtCore.QProcessEnvironment(self)",
    "1:PySide6.QtCore.QProcessEnvironment(self,arg__1:PySide6.QtCore.QProcessEnvironment.Initialization)",
    "0:PySide6.QtCore.QProcessEnvironment(self,other:typing.Union[PySide6.QtCore.QProcessEnvironment, PySide6.QtCore.QProcessEnvironment.Initialization])",
    "PySide6.QtCore.QProcessEnvironment.clear(self)",
    "PySide6.QtCore.QProcessEnvironment.contains(self,name:QString)->bool",
    "PySide6.QtCore.QProcessEnvironment.inheritsFromParent(self)->bool",
    "1:PySide6.QtCore.QProcessEnvironment.insert(self,e:typing.Union[PySide6.QtCore.QProcessEnvironment, PySide6.QtCore.QProcessEnvironment.Initialization])",
    "0:PySide6.QtCore.QProcessEnvironment.insert(self,name:QString,value:QString)",
    "PySide6.QtCore.QProcessEnvironment.isEmpty(self)->bool",
    "PySide6.QtCore.QProcessEnvironment.keys(self)->QStringList",
    "PySide6.QtCore.QProcessEnvironment.remove(self,name:QString)",
    "PySide6.QtCore.QProcessEnvironment.swap(self,other:typing.Union[PySide6.QtCore.QProcessEnvironment, PySide6.QtCore.QProcessEnvironment.Initialization])",
    "PySide6.QtCore.QProcessEnvironment.systemEnvironment()->PySide6.QtCore.QProcessEnvironment",
    "PySide6.QtCore.QProcessEnvironment.toStringList(self)->QStringList",
    "PySide6.QtCore.QProcessEnvironment.value(self,name:QString,defaultValue:QString=QString())->QString",
    "PySide6.QtCore.QProcessEnvironment.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QProcessEnvironment(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX].type;

    Shiboken::AutoDecRef Sbk_QProcessEnvironment_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QProcessEnvironment_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QProcessEnvironment",
        "QProcessEnvironment",
        &Sbk_QProcessEnvironment_spec,
        &Shiboken::callCppDestructor< ::QProcessEnvironment >,
        Sbk_QProcessEnvironment_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QProcessEnvironment_TypeF(); // references _Sbk_QProcessEnvironment_Type
    InitSignatureStrings(pyType, QProcessEnvironment_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QProcessEnvironment_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QProcessEnvironment_PythonToCpp_QProcessEnvironment_PTR,
        is_QProcessEnvironment_PythonToCpp_QProcessEnvironment_PTR_Convertible,
        QProcessEnvironment_PTR_CppToPython_QProcessEnvironment,
        QProcessEnvironment_COPY_CppToPython_QProcessEnvironment);

    Shiboken::Conversions::registerConverterName(converter, "QProcessEnvironment");
    Shiboken::Conversions::registerConverterName(converter, "QProcessEnvironment*");
    Shiboken::Conversions::registerConverterName(converter, "QProcessEnvironment&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QProcessEnvironment).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QProcessEnvironment_PythonToCpp_QProcessEnvironment_COPY,
        is_QProcessEnvironment_PythonToCpp_QProcessEnvironment_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QProcessEnvironment_Initialization_PythonToCpp_QProcessEnvironment,
        is_QProcessEnvironment_Initialization_PythonToCpp_QProcessEnvironment_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QProcessEnvironment_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Initialization'.
    const char *Initialization_Initializer[] = {
        "InheritFromParent",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Initialization_InitializerValues[] = {
        uint8_t(QProcessEnvironment::Initialization::InheritFromParent) //  0x00  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QProcessEnvironment_TypeF(),
        "2:PySide6.QtCore.QProcessEnvironment.Initialization",
        Initialization_Initializer, Initialization_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QProcessEnvironment_Initialization_IDX].type = EType;
    // Register converter for enum 'QProcessEnvironment::Initialization'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QProcessEnvironment_Initialization_CppToPython_QProcessEnvironment_Initialization);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QProcessEnvironment_Initialization_PythonToCpp_QProcessEnvironment_Initialization,
            is_QProcessEnvironment_Initialization_PythonToCpp_QProcessEnvironment_Initialization_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QProcessEnvironment::Initialization");
        Shiboken::Conversions::registerConverterName(converter, "Initialization");
    }
    // End of 'Initialization' enum.

    qRegisterMetaType< ::QProcessEnvironment >("QProcessEnvironment");
    qRegisterMetaType< ::QProcessEnvironment::Initialization >("QProcessEnvironment::Initialization");

    return pyType;
}
