// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qstringdecoder_wrapper.h"

// Argument includes
#include <QString>
#include <QStringList>
#include <qbytearrayview.h>
#include <qchar.h>
#include <qstringconverter.h>
#include <qstringconverter_base.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStringDecoder_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStringDecoder >()))
        return -1;

    ::QStringDecoder *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QStringDecoder.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:QStringDecoder", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStringDecoder::QStringDecoder()
    // 1: QStringDecoder::QStringDecoder(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>=)
    // 2: QStringDecoder::QStringDecoder(const char*,QFlags<QStringConverterBase::Flag>=)
    if (numArgs == 0) {
        overloadId = 0; // QStringDecoder()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_Encoding_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QStringDecoder(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // QStringDecoder(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>)
        }
    } else if (numArgs >= 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QStringDecoder(const char*,QFlags<QStringConverterBase::Flag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 2; // QStringDecoder(const char*,QFlags<QStringConverterBase::Flag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStringDecoder()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStringDecoder()
                cptr = new ::QStringDecoder();
            }
            break;
        }
        case 1: // QStringDecoder(QStringConverter::Encoding encoding, QFlags<QStringConverterBase::Flag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            ::QStringConverter::Encoding cppArg0{QStringConverter::Utf8};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QStringConverterBase::Flag> cppArg1(QStringConverterBase::Flag::Default);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStringDecoder(QStringConverter::Encoding,QFlags<QStringConverterBase::Flag>)
                cptr = new ::QStringDecoder(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QStringDecoder(const char * name, QFlags<QStringConverterBase::Flag> f)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_f = Shiboken::String::createStaticString("f");
                if (PyDict_Contains(kwds, key_f) != 0) {
                    value = PyDict_GetItem(kwds, key_f);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_f);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QStringConverterBase_Flag_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_f);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QStringConverterBase::Flag> cppArg1(QStringConverterBase::Flag::Default);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStringDecoder(const char*,QFlags<QStringConverterBase::Flag>)
                cptr = new ::QStringDecoder(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStringDecoder >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QStringDecoderFunc_appendToBuffer(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringDecoder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QStringDecoder.appendToBuffer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "appendToBuffer", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QStringDecoder::appendToBuffer(QChar*,QByteArrayView)->QChar*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
        overloadId = 0; // appendToBuffer(QChar*,QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QChar *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // appendToBuffer(QChar*,QByteArrayView)
            QChar * cppResult = cppSelf->appendToBuffer(cppArg0, QByteArrayView(cppArg1));
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStringDecoderFunc_decoderForHtml(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QStringDecoder.decoderForHtml";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QStringDecoder::decoderForHtml(QByteArrayView)->QStringDecoder
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // decoderForHtml(QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // decoderForHtml(QByteArrayView)
            QStringDecoder* cppResult = new QStringDecoder(::QStringDecoder::decoderForHtml(QByteArrayView(cppArg0)));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QStringDecoderFunc_requiredSpace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStringDecoder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QStringDecoder.requiredSpace";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QStringDecoder::requiredSpace(qsizetype)const->qsizetype
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // requiredSpace(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // requiredSpace(qsizetype)const
            qsizetype cppResult = const_cast<const ::QStringDecoder *>(cppSelf)->requiredSpace(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QStringDecoder_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStringDecoder_methods[] = {
    {"appendToBuffer", reinterpret_cast<PyCFunction>(Sbk_QStringDecoderFunc_appendToBuffer), METH_VARARGS, nullptr},
    {"decoderForHtml", reinterpret_cast<PyCFunction>(Sbk_QStringDecoderFunc_decoderForHtml), METH_O|METH_STATIC, nullptr},
    {"requiredSpace", reinterpret_cast<PyCFunction>(Sbk_QStringDecoderFunc_requiredSpace), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStringDecoder_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStringDecoder_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStringDecoder_Type = nullptr;
static PyTypeObject *Sbk_QStringDecoder_TypeF(void)
{
    return _Sbk_QStringDecoder_Type;
}

static PyType_Slot Sbk_QStringDecoder_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStringDecoder_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStringDecoder_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStringDecoder_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStringDecoder_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStringDecoder_spec = {
    "2:PySide6.QtCore.QStringDecoder",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStringDecoder_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStringDecoder_PythonToCpp_QStringDecoder_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStringDecoder_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStringDecoder_PythonToCpp_QStringDecoder_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStringDecoder_TypeF()))
        return QStringDecoder_PythonToCpp_QStringDecoder_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStringDecoder_PTR_CppToPython_QStringDecoder(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QStringDecoder *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QStringDecoder_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QStringDecoder_SignatureStrings[] = {
    "2:PySide6.QtCore.QStringDecoder(self)",
    "1:PySide6.QtCore.QStringDecoder(self,encoding:PySide6.QtCore.QStringConverter.Encoding,flags:PySide6.QtCore.QStringConverterBase.Flag=QStringConverterBase.Flag.Default)",
    "0:PySide6.QtCore.QStringDecoder(self,name:char*,f:PySide6.QtCore.QStringConverterBase.Flag=QStringConverterBase.Flag.Default)",
    "PySide6.QtCore.QStringDecoder.appendToBuffer(self,out:QChar*,ba:typing.Union[PySide6.QtCore.QByteArray, char*])->QChar*",
    "PySide6.QtCore.QStringDecoder.decoderForHtml(data:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtCore.QStringDecoder",
    "PySide6.QtCore.QStringDecoder.requiredSpace(self,inputLength:qsizetype)->qsizetype",
    nullptr}; // Sentinel

PyTypeObject *init_QStringDecoder(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX].type;

    Shiboken::AutoDecRef Sbk_QStringDecoder_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QStringConverter_IDX]))));

    _Sbk_QStringDecoder_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStringDecoder",
        "QStringDecoder*",
        &Sbk_QStringDecoder_spec,
        &Shiboken::callCppDestructor< ::QStringDecoder >,
        Sbk_QStringDecoder_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStringDecoder_TypeF(); // references _Sbk_QStringDecoder_Type
    InitSignatureStrings(pyType, QStringDecoder_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStringDecoder_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QStringDecoder_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStringDecoder_PythonToCpp_QStringDecoder_PTR,
        is_QStringDecoder_PythonToCpp_QStringDecoder_PTR_Convertible,
        QStringDecoder_PTR_CppToPython_QStringDecoder);

    Shiboken::Conversions::registerConverterName(converter, "QStringDecoder");
    Shiboken::Conversions::registerConverterName(converter, "QStringDecoder*");
    Shiboken::Conversions::registerConverterName(converter, "QStringDecoder&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStringDecoder).name());

    qRegisterMetaType< ::QStringDecoder *>();

    return pyType;
}
