// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtdbus_python.h"

// main header
#include "qdbusabstractinterface_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtDBus/qdbusconnection.h>
#include <QtDBus/qdbuserror.h>
#include <QtDBus/qdbusmessage.h>
#include <QtDBus/qdbuspendingcall.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QDBusAbstractInterfaceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QDBusAbstractInterfaceWrapper::QDBusAbstractInterfaceWrapper(const ::QString & service, const ::QString & path, const char * interface, const ::QDBusConnection & connection, ::QObject * parent) : QDBusAbstractInterface(service, path, interface, connection, parent)
{
    resetPyMethodCache();
    // ... middle
}

void QDBusAbstractInterfaceWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QDBusAbstractInterfaceWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QDBusAbstractInterface::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QDBusAbstractInterface::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QDBusAbstractInterfaceWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QDBusAbstractInterfaceWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QDBusAbstractInterface::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QDBusAbstractInterface::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QDBusAbstractInterfaceWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDBusAbstractInterface", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QDBusAbstractInterfaceWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QDBusAbstractInterface", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QDBusAbstractInterfaceWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

const QMetaObject *QDBusAbstractInterfaceWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QDBusAbstractInterface::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QDBusAbstractInterfaceWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QDBusAbstractInterface::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QDBusAbstractInterfaceWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QDBusAbstractInterfaceWrapper *>(this));
    return QDBusAbstractInterface::qt_metacast(_clname);
}

QDBusAbstractInterfaceWrapper::~QDBusAbstractInterfaceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDBusAbstractInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDBusAbstractInterface >()))
        return -1;

    QDBusAbstractInterfaceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDBusAbstractInterface", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDBusAbstractInterface::QDBusAbstractInterface(QString,QString,const char*,QDBusConnection,QObject*)
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && Shiboken::String::check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4])))) {
        overloadId = 0; // QDBusAbstractInterface(QString,QString,const char*,QDBusConnection,QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        const char* cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return -1;
        ::QDBusConnection cppArg3_local = ::QDBusConnection(::QString());
        ::QDBusConnection *cppArg3 = &cppArg3_local;
        if (pythonToCpp[3].isValue())
            pythonToCpp[3](pyArgs[3], &cppArg3_local);
        else
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (!Shiboken::Object::isValid(pyArgs[4]))
            return -1;
        ::QObject *cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QDBusAbstractInterface(QString,QString,const char*,QDBusConnection,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QDBusAbstractInterfaceWrapper(cppArg0, cppArg1, cppArg2, *cppArg3, cppArg4);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QDBusAbstractInterfaceWrapper(cppArg0, cppArg1, cppArg2, *cppArg3, cppArg4);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[4], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QDBusAbstractInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    };


    return 1;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_asyncCall(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.asyncCall";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusAbstractInterface::asyncCall(QString)->QDBusPendingCall
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // asyncCall(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // asyncCall(QString)
            QDBusPendingCall* cppResult = new QDBusPendingCall(cppSelf->asyncCall(cppArg0));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_asyncCallWithArgumentList(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.asyncCallWithArgumentList";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "asyncCallWithArgumentList", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusAbstractInterface::asyncCallWithArgumentList(QString,QList<QVariant>)->QDBusPendingCall
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDBusTypeConverters[SBK_QtDBus_QList_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // asyncCallWithArgumentList(QString,QList<QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QList<QVariant> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // asyncCallWithArgumentList(QString,QList<QVariant>)
            QDBusPendingCall* cppResult = new QDBusPendingCall(cppSelf->asyncCallWithArgumentList(cppArg0, cppArg1));
            pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusPendingCall_IDX]), cppResult, true, true);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_call(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.call";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[10];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "call", 1, 10, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusAbstractInterface::call(QDBus::CallMode,QString,QVariant)->QDBusMessage
    // 1: QDBusAbstractInterface::call(QDBus::CallMode,QString,QVariant,QVariant)->QDBusMessage
    // 2: QDBusAbstractInterface::call(QDBus::CallMode,QString,QVariant,QVariant,QVariant)->QDBusMessage
    // 3: QDBusAbstractInterface::call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant)->QDBusMessage
    // 4: QDBusAbstractInterface::call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant,QVariant)->QDBusMessage
    // 5: QDBusAbstractInterface::call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant)->QDBusMessage
    // 6: QDBusAbstractInterface::call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant)->QDBusMessage
    // 7: QDBusAbstractInterface::call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant)->QDBusMessage
    // 8: QDBusAbstractInterface::call(QDBus::CallMode,QString)->QDBusMessage
    // 9: QDBusAbstractInterface::call(QString,QVariant)->QDBusMessage
    // 10: QDBusAbstractInterface::call(QString,QVariant,QVariant)->QDBusMessage
    // 11: QDBusAbstractInterface::call(QString,QVariant,QVariant,QVariant)->QDBusMessage
    // 12: QDBusAbstractInterface::call(QString,QVariant,QVariant,QVariant,QVariant)->QDBusMessage
    // 13: QDBusAbstractInterface::call(QString)->QDBusMessage
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 13; // call(QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 9; // call(QString,QVariant)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 10; // call(QString,QVariant,QVariant)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 11; // call(QString,QVariant,QVariant,QVariant)
                    } else if (numArgs == 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[4])))) {
                        overloadId = 12; // call(QString,QVariant,QVariant,QVariant,QVariant)
                    }
                }
            }
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBus_CallMode_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 8; // call(QDBus::CallMode,QString)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // call(QDBus::CallMode,QString,QVariant)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // call(QDBus::CallMode,QString,QVariant,QVariant)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 2; // call(QDBus::CallMode,QString,QVariant,QVariant,QVariant)
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[5])))) {
                        if (numArgs == 6) {
                            overloadId = 3; // call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant)
                        } else if (numArgs >= 7
                            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[6])))) {
                            if (numArgs == 7) {
                                overloadId = 4; // call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant,QVariant)
                            } else if (numArgs >= 8
                                && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[7])))) {
                                if (numArgs == 8) {
                                    overloadId = 5; // call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant)
                                } else if (numArgs >= 9
                                    && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[8])))) {
                                    if (numArgs == 9) {
                                        overloadId = 6; // call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant)
                                    } else if (numArgs == 10
                                        && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[9])))) {
                                        overloadId = 7; // call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant)
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // call(QDBus::CallMode arg__1, const QString & arg__2, const QVariant & arg__3)
        {
            ::QDBus::CallMode cppArg0{QDBus::NoBlock};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QVariant cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // call(QDBus::CallMode,QString,QVariant)
                QDBusMessage cppResult = cppSelf->call(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 1: // call(QDBus::CallMode arg__1, const QString & arg__2, const QVariant & arg__3, const QVariant & arg__4)
        {
            ::QDBus::CallMode cppArg0{QDBus::NoBlock};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QVariant cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QVariant cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // call(QDBus::CallMode,QString,QVariant,QVariant)
                QDBusMessage cppResult = cppSelf->call(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 2: // call(QDBus::CallMode arg__1, const QString & arg__2, const QVariant & arg__3, const QVariant & arg__4, const QVariant & arg__5)
        {
            ::QDBus::CallMode cppArg0{QDBus::NoBlock};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QVariant cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QVariant cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QVariant cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // call(QDBus::CallMode,QString,QVariant,QVariant,QVariant)
                QDBusMessage cppResult = cppSelf->call(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 3: // call(QDBus::CallMode arg__1, const QString & arg__2, const QVariant & arg__3, const QVariant & arg__4, const QVariant & arg__5, const QVariant & arg__6)
        {
            ::QDBus::CallMode cppArg0{QDBus::NoBlock};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QVariant cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QVariant cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QVariant cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QVariant cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant)
                QDBusMessage cppResult = cppSelf->call(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 4: // call(QDBus::CallMode arg__1, const QString & arg__2, const QVariant & arg__3, const QVariant & arg__4, const QVariant & arg__5, const QVariant & arg__6, const QVariant & arg__7)
        {
            ::QDBus::CallMode cppArg0{QDBus::NoBlock};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QVariant cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QVariant cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QVariant cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QVariant cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            ::QVariant cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant,QVariant)
                QDBusMessage cppResult = cppSelf->call(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 5: // call(QDBus::CallMode arg__1, const QString & arg__2, const QVariant & arg__3, const QVariant & arg__4, const QVariant & arg__5, const QVariant & arg__6, const QVariant & arg__7, const QVariant & arg__8)
        {
            ::QDBus::CallMode cppArg0{QDBus::NoBlock};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QVariant cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QVariant cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QVariant cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QVariant cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            ::QVariant cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            ::QVariant cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant)
                QDBusMessage cppResult = cppSelf->call(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 6: // call(QDBus::CallMode arg__1, const QString & arg__2, const QVariant & arg__3, const QVariant & arg__4, const QVariant & arg__5, const QVariant & arg__6, const QVariant & arg__7, const QVariant & arg__8, const QVariant & arg__9)
        {
            ::QDBus::CallMode cppArg0{QDBus::NoBlock};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QVariant cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QVariant cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QVariant cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QVariant cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            ::QVariant cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            ::QVariant cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);
            ::QVariant cppArg8;
            pythonToCpp[8](pyArgs[8], &cppArg8);

            if (Shiboken::Errors::occurred() == nullptr) {
                // call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant)
                QDBusMessage cppResult = cppSelf->call(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 7: // call(QDBus::CallMode arg__1, const QString & arg__2, const QVariant & arg__3, const QVariant & arg__4, const QVariant & arg__5, const QVariant & arg__6, const QVariant & arg__7, const QVariant & arg__8, const QVariant & arg__9, const QVariant & arg__10)
        {
            ::QDBus::CallMode cppArg0{QDBus::NoBlock};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QVariant cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QVariant cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QVariant cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QVariant cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            ::QVariant cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            ::QVariant cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);
            ::QVariant cppArg8;
            pythonToCpp[8](pyArgs[8], &cppArg8);
            ::QVariant cppArg9;
            pythonToCpp[9](pyArgs[9], &cppArg9);

            if (Shiboken::Errors::occurred() == nullptr) {
                // call(QDBus::CallMode,QString,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant,QVariant)
                QDBusMessage cppResult = cppSelf->call(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 8: // call(QDBus::CallMode mode, const QString & method)
        {
            ::QDBus::CallMode cppArg0{QDBus::NoBlock};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // call(QDBus::CallMode,QString)
                QDBusMessage cppResult = cppSelf->call(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 9: // call(const QString & arg__1, const QVariant & arg__2)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // call(QString,QVariant)
                QDBusMessage cppResult = cppSelf->call(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 10: // call(const QString & arg__1, const QVariant & arg__2, const QVariant & arg__3)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QVariant cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // call(QString,QVariant,QVariant)
                QDBusMessage cppResult = cppSelf->call(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 11: // call(const QString & arg__1, const QVariant & arg__2, const QVariant & arg__3, const QVariant & arg__4)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QVariant cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QVariant cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // call(QString,QVariant,QVariant,QVariant)
                QDBusMessage cppResult = cppSelf->call(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 12: // call(const QString & arg__1, const QVariant & arg__2, const QVariant & arg__3, const QVariant & arg__4, const QVariant & arg__5)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QVariant cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QVariant cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QVariant cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // call(QString,QVariant,QVariant,QVariant,QVariant)
                QDBusMessage cppResult = cppSelf->call(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
        case 13: // call(const QString & method)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // call(QString)
                QDBusMessage cppResult = cppSelf->call(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_callWithArgumentList(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.callWithArgumentList";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "callWithArgumentList", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusAbstractInterface::callWithArgumentList(QDBus::CallMode,QString,QList<QVariant>)->QDBusMessage
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBus_CallMode_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDBusTypeConverters[SBK_QtDBus_QList_QVariant_IDX], (pyArgs[2])))) {
        overloadId = 0; // callWithArgumentList(QDBus::CallMode,QString,QList<QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QDBus::CallMode cppArg0{QDBus::NoBlock};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QList<QVariant> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // callWithArgumentList(QDBus::CallMode,QString,QList<QVariant>)
            QDBusMessage cppResult = cppSelf->callWithArgumentList(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_callWithCallback(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.callWithCallback";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "callWithCallback", 4, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusAbstractInterface::callWithCallback(QString,QList<QVariant>,QObject*,const char*)->bool
    // 1: QDBusAbstractInterface::callWithCallback(QString,QList<QVariant>,QObject*,const char*,const char*)->bool
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDBusTypeConverters[SBK_QtDBus_QList_QVariant_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
        && Shiboken::String::check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 0; // callWithCallback(QString,QList<QVariant>,QObject*,const char*)
        } else if (numArgs == 5
            && Shiboken::String::check(pyArgs[4]) && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[4])))) {
            overloadId = 1; // callWithCallback(QString,QList<QVariant>,QObject*,const char*,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // callWithCallback(const QString & method, const QList<QVariant> & args, QObject * receiver, const char * member)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QList<QVariant> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            const char* cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // callWithCallback(QString,QList<QVariant>,QObject*,const char*)
                bool cppResult = cppSelf->callWithCallback(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // callWithCallback(const QString & method, const QList<QVariant> & args, QObject * receiver, const char * member, const char * errorSlot)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QList<QVariant> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QObject *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            const char* cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            const char* cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // callWithCallback(QString,QList<QVariant>,QObject*,const char*,const char*)
                bool cppResult = cppSelf->callWithCallback(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_connectNotify(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.connectNotify";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::connectNotify(QMetaMethod)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArg)))) {
        overloadId = 0; // connectNotify(QMetaMethod)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaMethod cppArg0_local;
        ::QMetaMethod *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // connectNotify(QMetaMethod)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDBusAbstractInterface::connectNotify(*cppArg0)
                : cppSelf->connectNotify(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_connection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.connection";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // connection()const
            QDBusConnection cppResult = const_cast<const ::QDBusAbstractInterface *>(cppSelf)->connection();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusConnection_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_disconnectNotify(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.disconnectNotify";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::disconnectNotify(QMetaMethod)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArg)))) {
        overloadId = 0; // disconnectNotify(QMetaMethod)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaMethod cppArg0_local;
        ::QMetaMethod *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // disconnectNotify(QMetaMethod)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QDBusAbstractInterface::disconnectNotify(*cppArg0)
                : cppSelf->disconnectNotify(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_interface(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.interface";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // interface()const
            QString cppResult = const_cast<const ::QDBusAbstractInterface *>(cppSelf)->interface();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_internalConstCall(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.internalConstCall";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:internalConstCall", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusAbstractInterface::internalConstCall(QDBus::CallMode,QString,const QList<QVariant>&=)const->QDBusMessage
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBus_CallMode_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // internalConstCall(QDBus::CallMode,QString,QList<QVariant>)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDBusTypeConverters[SBK_QtDBus_QList_QVariant_IDX], (pyArgs[2])))) {
            overloadId = 0; // internalConstCall(QDBus::CallMode,QString,QList<QVariant>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_args = Shiboken::String::createStaticString("args");
            if (PyDict_Contains(kwds, key_args) != 0) {
                value = PyDict_GetItem(kwds, key_args);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_args);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtDBusTypeConverters[SBK_QtDBus_QList_QVariant_IDX], (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_args);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QDBus::CallMode cppArg0{QDBus::NoBlock};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QList<QVariant> cppArg2 = QList<QVariant>();
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // internalConstCall(QDBus::CallMode,QString,QList<QVariant>)const
            QDBusMessage cppResult = const_cast<const ::QDBusAbstractInterface *>(cppSelf)->internalConstCall(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusMessage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_internalPropGet(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.internalPropGet";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusAbstractInterface::internalPropGet(const char*)const->QVariant
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // internalPropGet(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // internalPropGet(const char*)const
            QVariant cppResult = const_cast<const ::QDBusAbstractInterface *>(cppSelf)->internalPropGet(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_internalPropSet(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.internalPropSet";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "internalPropSet", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDBusAbstractInterface::internalPropSet(const char*,QVariant)
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // internalPropSet(const char*,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // internalPropSet(const char*,QVariant)
            cppSelf->internalPropSet(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_isInteractiveAuthorizationAllowed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.isInteractiveAuthorizationAllowed";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isInteractiveAuthorizationAllowed()const
            bool cppResult = const_cast<const ::QDBusAbstractInterface *>(cppSelf)->isInteractiveAuthorizationAllowed();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QDBusAbstractInterface *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_lastError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.lastError";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // lastError()const
            QDBusError cppResult = const_cast<const ::QDBusAbstractInterface *>(cppSelf)->lastError();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusError_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_path(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.path";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // path()const
            QString cppResult = const_cast<const ::QDBusAbstractInterface *>(cppSelf)->path();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_service(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.service";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // service()const
            QString cppResult = const_cast<const ::QDBusAbstractInterface *>(cppSelf)->service();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_setInteractiveAuthorizationAllowed(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.setInteractiveAuthorizationAllowed";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusAbstractInterface::setInteractiveAuthorizationAllowed(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setInteractiveAuthorizationAllowed(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInteractiveAuthorizationAllowed(bool)
            cppSelf->setInteractiveAuthorizationAllowed(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_setTimeout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.setTimeout";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDBusAbstractInterface::setTimeout(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setTimeout(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTimeout(int)
            cppSelf->setTimeout(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDBusAbstractInterfaceFunc_timeout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtDBus.QDBusAbstractInterface.timeout";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // timeout()const
            int cppResult = const_cast<const ::QDBusAbstractInterface *>(cppSelf)->timeout();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDBusAbstractInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDBusAbstractInterface_methods[] = {
    {"asyncCall", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_asyncCall), METH_O, nullptr},
    {"asyncCallWithArgumentList", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_asyncCallWithArgumentList), METH_VARARGS, nullptr},
    {"call", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_call), METH_VARARGS, nullptr},
    {"callWithArgumentList", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_callWithArgumentList), METH_VARARGS, nullptr},
    {"callWithCallback", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_callWithCallback), METH_VARARGS, nullptr},
    {"connectNotify", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_connectNotify), METH_O, nullptr},
    {"connection", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_connection), METH_NOARGS, nullptr},
    {"disconnectNotify", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_disconnectNotify), METH_O, nullptr},
    {"interface", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_interface), METH_NOARGS, nullptr},
    {"internalConstCall", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_internalConstCall), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"internalPropGet", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_internalPropGet), METH_O, nullptr},
    {"internalPropSet", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_internalPropSet), METH_VARARGS, nullptr},
    {"isInteractiveAuthorizationAllowed", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_isInteractiveAuthorizationAllowed), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_isValid), METH_NOARGS, nullptr},
    {"lastError", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_lastError), METH_NOARGS, nullptr},
    {"path", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_path), METH_NOARGS, nullptr},
    {"service", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_service), METH_NOARGS, nullptr},
    {"setInteractiveAuthorizationAllowed", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_setInteractiveAuthorizationAllowed), METH_O, nullptr},
    {"setTimeout", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_setTimeout), METH_O, nullptr},
    {"timeout", reinterpret_cast<PyCFunction>(Sbk_QDBusAbstractInterfaceFunc_timeout), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDBusAbstractInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QDBusAbstractInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QDBusAbstractInterfaceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QDBusAbstractInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDBusAbstractInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDBusAbstractInterface_Type = nullptr;
static PyTypeObject *Sbk_QDBusAbstractInterface_TypeF(void)
{
    return _Sbk_QDBusAbstractInterface_Type;
}

static PyType_Slot Sbk_QDBusAbstractInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QDBusAbstractInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDBusAbstractInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDBusAbstractInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDBusAbstractInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDBusAbstractInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDBusAbstractInterface_spec = {
    "2:PySide6.QtDBus.QDBusAbstractInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDBusAbstractInterface_slots
};

} //extern "C"

static void *Sbk_QDBusAbstractInterface_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QDBusAbstractInterface *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDBusAbstractInterface_PythonToCpp_QDBusAbstractInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDBusAbstractInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDBusAbstractInterface_PythonToCpp_QDBusAbstractInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDBusAbstractInterface_TypeF()))
        return QDBusAbstractInterface_PythonToCpp_QDBusAbstractInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDBusAbstractInterface_PTR_CppToPython_QDBusAbstractInterface(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QDBusAbstractInterface *>(const_cast<void *>(cppIn)), Sbk_QDBusAbstractInterface_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QDBusAbstractInterface_SignatureStrings[] = {
    "PySide6.QtDBus.QDBusAbstractInterface(self,service:QString,path:QString,interface:char*,connection:PySide6.QtDBus.QDBusConnection,parent:PySide6.QtCore.QObject)",
    "PySide6.QtDBus.QDBusAbstractInterface.asyncCall(self,method:QString)->PySide6.QtDBus.QDBusPendingCall",
    "PySide6.QtDBus.QDBusAbstractInterface.asyncCallWithArgumentList(self,method:QString,args:QList[QVariant])->PySide6.QtDBus.QDBusPendingCall",
    "13:PySide6.QtDBus.QDBusAbstractInterface.call(self,arg__1:PySide6.QtDBus.QDBus.CallMode,arg__2:QString,arg__3:QVariant)->PySide6.QtDBus.QDBusMessage",
    "12:PySide6.QtDBus.QDBusAbstractInterface.call(self,arg__1:PySide6.QtDBus.QDBus.CallMode,arg__2:QString,arg__3:QVariant,arg__4:QVariant)->PySide6.QtDBus.QDBusMessage",
    "11:PySide6.QtDBus.QDBusAbstractInterface.call(self,arg__1:PySide6.QtDBus.QDBus.CallMode,arg__2:QString,arg__3:QVariant,arg__4:QVariant,arg__5:QVariant)->PySide6.QtDBus.QDBusMessage",
    "10:PySide6.QtDBus.QDBusAbstractInterface.call(self,arg__1:PySide6.QtDBus.QDBus.CallMode,arg__2:QString,arg__3:QVariant,arg__4:QVariant,arg__5:QVariant,arg__6:QVariant)->PySide6.QtDBus.QDBusMessage",
    "9:PySide6.QtDBus.QDBusAbstractInterface.call(self,arg__1:PySide6.QtDBus.QDBus.CallMode,arg__2:QString,arg__3:QVariant,arg__4:QVariant,arg__5:QVariant,arg__6:QVariant,arg__7:QVariant)->PySide6.QtDBus.QDBusMessage",
    "8:PySide6.QtDBus.QDBusAbstractInterface.call(self,arg__1:PySide6.QtDBus.QDBus.CallMode,arg__2:QString,arg__3:QVariant,arg__4:QVariant,arg__5:QVariant,arg__6:QVariant,arg__7:QVariant,arg__8:QVariant)->PySide6.QtDBus.QDBusMessage",
    "7:PySide6.QtDBus.QDBusAbstractInterface.call(self,arg__1:PySide6.QtDBus.QDBus.CallMode,arg__2:QString,arg__3:QVariant,arg__4:QVariant,arg__5:QVariant,arg__6:QVariant,arg__7:QVariant,arg__8:QVariant,arg__9:QVariant)->PySide6.QtDBus.QDBusMessage",
    "6:PySide6.QtDBus.QDBusAbstractInterface.call(self,arg__1:PySide6.QtDBus.QDBus.CallMode,arg__2:QString,arg__3:QVariant,arg__4:QVariant,arg__5:QVariant,arg__6:QVariant,arg__7:QVariant,arg__8:QVariant,arg__9:QVariant,arg__10:QVariant)->PySide6.QtDBus.QDBusMessage",
    "5:PySide6.QtDBus.QDBusAbstractInterface.call(self,mode:PySide6.QtDBus.QDBus.CallMode,method:QString)->PySide6.QtDBus.QDBusMessage",
    "4:PySide6.QtDBus.QDBusAbstractInterface.call(self,arg__1:QString,arg__2:QVariant)->PySide6.QtDBus.QDBusMessage",
    "3:PySide6.QtDBus.QDBusAbstractInterface.call(self,arg__1:QString,arg__2:QVariant,arg__3:QVariant)->PySide6.QtDBus.QDBusMessage",
    "2:PySide6.QtDBus.QDBusAbstractInterface.call(self,arg__1:QString,arg__2:QVariant,arg__3:QVariant,arg__4:QVariant)->PySide6.QtDBus.QDBusMessage",
    "1:PySide6.QtDBus.QDBusAbstractInterface.call(self,arg__1:QString,arg__2:QVariant,arg__3:QVariant,arg__4:QVariant,arg__5:QVariant)->PySide6.QtDBus.QDBusMessage",
    "0:PySide6.QtDBus.QDBusAbstractInterface.call(self,method:QString)->PySide6.QtDBus.QDBusMessage",
    "PySide6.QtDBus.QDBusAbstractInterface.callWithArgumentList(self,mode:PySide6.QtDBus.QDBus.CallMode,method:QString,args:QList[QVariant])->PySide6.QtDBus.QDBusMessage",
    "1:PySide6.QtDBus.QDBusAbstractInterface.callWithCallback(self,method:QString,args:QList[QVariant],receiver:PySide6.QtCore.QObject,member:char*)->bool",
    "0:PySide6.QtDBus.QDBusAbstractInterface.callWithCallback(self,method:QString,args:QList[QVariant],receiver:PySide6.QtCore.QObject,member:char*,errorSlot:char*)->bool",
    "PySide6.QtDBus.QDBusAbstractInterface.connectNotify(self,signal:PySide6.QtCore.QMetaMethod)",
    "PySide6.QtDBus.QDBusAbstractInterface.connection(self)->PySide6.QtDBus.QDBusConnection",
    "PySide6.QtDBus.QDBusAbstractInterface.disconnectNotify(self,signal:PySide6.QtCore.QMetaMethod)",
    "PySide6.QtDBus.QDBusAbstractInterface.interface(self)->QString",
    "PySide6.QtDBus.QDBusAbstractInterface.internalConstCall(self,mode:PySide6.QtDBus.QDBus.CallMode,method:QString,args:QList[QVariant]=QList<QVariant>())->PySide6.QtDBus.QDBusMessage",
    "PySide6.QtDBus.QDBusAbstractInterface.internalPropGet(self,propname:char*)->QVariant",
    "PySide6.QtDBus.QDBusAbstractInterface.internalPropSet(self,propname:char*,value:QVariant)",
    "PySide6.QtDBus.QDBusAbstractInterface.isInteractiveAuthorizationAllowed(self)->bool",
    "PySide6.QtDBus.QDBusAbstractInterface.isValid(self)->bool",
    "PySide6.QtDBus.QDBusAbstractInterface.lastError(self)->PySide6.QtDBus.QDBusError",
    "PySide6.QtDBus.QDBusAbstractInterface.path(self)->QString",
    "PySide6.QtDBus.QDBusAbstractInterface.service(self)->QString",
    "PySide6.QtDBus.QDBusAbstractInterface.setInteractiveAuthorizationAllowed(self,enable:bool)",
    "PySide6.QtDBus.QDBusAbstractInterface.setTimeout(self,timeout:int)",
    "PySide6.QtDBus.QDBusAbstractInterface.timeout(self)->int",
    nullptr}; // Sentinel

PyTypeObject *init_QDBusAbstractInterface(PyObject *module)
{
    if (SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX].type != nullptr)
        return SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QDBusAbstractInterface_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterfaceBase_IDX]))));

    _Sbk_QDBusAbstractInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDBusAbstractInterface",
        "QDBusAbstractInterface*",
        &Sbk_QDBusAbstractInterface_spec,
        &Shiboken::callCppDestructor< QDBusAbstractInterface >,
        Sbk_QDBusAbstractInterface_Type_bases.object(),
        0);
    auto *pyType = Sbk_QDBusAbstractInterface_TypeF(); // references _Sbk_QDBusAbstractInterface_Type
    InitSignatureStrings(pyType, QDBusAbstractInterface_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDBusAbstractInterface_PropertyStrings);
    SbkPySide6_QtDBusTypeStructs[SBK_QDBusAbstractInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDBusAbstractInterface_PythonToCpp_QDBusAbstractInterface_PTR,
        is_QDBusAbstractInterface_PythonToCpp_QDBusAbstractInterface_PTR_Convertible,
        QDBusAbstractInterface_PTR_CppToPython_QDBusAbstractInterface);

    Shiboken::Conversions::registerConverterName(converter, "QDBusAbstractInterface");
    Shiboken::Conversions::registerConverterName(converter, "QDBusAbstractInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QDBusAbstractInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDBusAbstractInterface).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QDBusAbstractInterfaceWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QDBusAbstractInterface_TypeF(), &Sbk_QDBusAbstractInterface_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QDBusAbstractInterface::staticMetaObject, sizeof(QDBusAbstractInterfaceWrapper));

    return pyType;
}
