// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qgradient_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGradient_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGradient >()))
        return -1;

    ::QGradient *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QGradient.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QGradient", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGradient::QGradient()
    // 1: QGradient::QGradient(QGradient::Preset)
    // 2: QGradient::QGradient(QGradient)
    if (numArgs == 0) {
        overloadId = 0; // QGradient()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Preset_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // QGradient(QGradient::Preset)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QGradient(QGradient)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGradient()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGradient()
                cptr = new ::QGradient();
            }
            break;
        }
        case 1: // QGradient(QGradient::Preset arg__1)
        {
            ::QGradient::Preset cppArg0 = static_cast< ::QGradient::Preset>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGradient(QGradient::Preset)
                cptr = new ::QGradient(cppArg0);
            }
            break;
        }
        case 2: // QGradient(const QGradient & QGradient)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QGradient cppArg0_local;
            ::QGradient *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QGradient(QGradient)
                cptr = new ::QGradient(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QGradient >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QGradientFunc_coordinateMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QGradient.coordinateMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // coordinateMode()const
            QGradient::CoordinateMode cppResult = const_cast<const ::QGradient *>(cppSelf)->coordinateMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_CoordinateMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGradientFunc_interpolationMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QGradient.interpolationMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // interpolationMode()const
            QGradient::InterpolationMode cppResult = const_cast<const ::QGradient *>(cppSelf)->interpolationMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_InterpolationMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGradientFunc_setColorAt(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QGradient.setColorAt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setColorAt", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGradient::setColorAt(qreal,QColor)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[1])))) {
        overloadId = 0; // setColorAt(qreal,QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QColor cppArg1_local;
        ::QColor *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setColorAt(qreal,QColor)
            cppSelf->setColorAt(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGradientFunc_setCoordinateMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QGradient.setCoordinateMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGradient::setCoordinateMode(QGradient::CoordinateMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_CoordinateMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setCoordinateMode(QGradient::CoordinateMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QGradient::CoordinateMode cppArg0{QGradient::LogicalMode};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCoordinateMode(QGradient::CoordinateMode)
            cppSelf->setCoordinateMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGradientFunc_setInterpolationMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QGradient.setInterpolationMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGradient::setInterpolationMode(QGradient::InterpolationMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_InterpolationMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setInterpolationMode(QGradient::InterpolationMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QGradient::InterpolationMode cppArg0{QGradient::ColorInterpolation};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInterpolationMode(QGradient::InterpolationMode)
            cppSelf->setInterpolationMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGradientFunc_setSpread(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QGradient.setSpread";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGradient::setSpread(QGradient::Spread)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Spread_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSpread(QGradient::Spread)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QGradient::Spread cppArg0{QGradient::PadSpread};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSpread(QGradient::Spread)
            cppSelf->setSpread(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGradientFunc_setStops(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QGradient.setStops";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGradient::setStops(QList<std::pair<qreal,QColor>>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_std_pair_qreal_QColor_IDX], (pyArg)))) {
        overloadId = 0; // setStops(QList<std::pair<qreal,QColor>>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<std::pair< qreal,QColor>> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStops(QList<std::pair<qreal,QColor>>)
            cppSelf->setStops(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGradientFunc_spread(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QGradient.spread";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // spread()const
            QGradient::Spread cppResult = const_cast<const ::QGradient *>(cppSelf)->spread();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Spread_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGradientFunc_stops(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QGradient.stops";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // stops()const
            QList<std::pair< qreal,QColor>> cppResult = const_cast<const ::QGradient *>(cppSelf)->stops();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_std_pair_qreal_QColor_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGradientFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QGradient.type";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // type()const
            QGradient::Type cppResult = const_cast<const ::QGradient *>(cppSelf)->type();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Type_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGradient__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGradient_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QGradient_EnumFlagInfo[] = {
    "CoordinateMode:Enum",
    "InterpolationMode:Enum",
    "Preset:Enum",
    "Spread:Enum",
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGradient_methods[] = {
    {"coordinateMode", reinterpret_cast<PyCFunction>(Sbk_QGradientFunc_coordinateMode), METH_NOARGS, nullptr},
    {"interpolationMode", reinterpret_cast<PyCFunction>(Sbk_QGradientFunc_interpolationMode), METH_NOARGS, nullptr},
    {"setColorAt", reinterpret_cast<PyCFunction>(Sbk_QGradientFunc_setColorAt), METH_VARARGS, nullptr},
    {"setCoordinateMode", reinterpret_cast<PyCFunction>(Sbk_QGradientFunc_setCoordinateMode), METH_O, nullptr},
    {"setInterpolationMode", reinterpret_cast<PyCFunction>(Sbk_QGradientFunc_setInterpolationMode), METH_O, nullptr},
    {"setSpread", reinterpret_cast<PyCFunction>(Sbk_QGradientFunc_setSpread), METH_O, nullptr},
    {"setStops", reinterpret_cast<PyCFunction>(Sbk_QGradientFunc_setStops), METH_O, nullptr},
    {"spread", reinterpret_cast<PyCFunction>(Sbk_QGradientFunc_spread), METH_NOARGS, nullptr},
    {"stops", reinterpret_cast<PyCFunction>(Sbk_QGradientFunc_stops), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QGradientFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QGradient__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QGradient_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), (pyArg)))) {
                // operator!=(const QGradient & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGradient cppArg0_local;
                ::QGradient *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), (pyArg)))) {
                // operator==(const QGradient & gradient) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QGradient cppArg0_local;
                ::QGradient *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QGradient_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGradient_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGradient_Type = nullptr;
static PyTypeObject *Sbk_QGradient_TypeF(void)
{
    return _Sbk_QGradient_Type;
}

static PyType_Slot Sbk_QGradient_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGradient_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGradient_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QGradient_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGradient_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGradient_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGradient_spec = {
    "2:PySide6.QtGui.QGradient",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGradient_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QGradient_Type_PythonToCpp_QGradient_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGradient::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGradient::Type *>(cppOut) = value;

}
static PythonToCppFunc is_QGradient_Type_PythonToCpp_QGradient_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Type_IDX])))
        return QGradient_Type_PythonToCpp_QGradient_Type;
    return {};
}
static PyObject *QGradient_Type_CppToPython_QGradient_Type(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QGradient::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Type_IDX]), castCppIn);

}

static void QGradient_Spread_PythonToCpp_QGradient_Spread(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGradient::Spread>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGradient::Spread *>(cppOut) = value;

}
static PythonToCppFunc is_QGradient_Spread_PythonToCpp_QGradient_Spread_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Spread_IDX])))
        return QGradient_Spread_PythonToCpp_QGradient_Spread;
    return {};
}
static PyObject *QGradient_Spread_CppToPython_QGradient_Spread(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QGradient::Spread *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Spread_IDX]), castCppIn);

}

static void QGradient_CoordinateMode_PythonToCpp_QGradient_CoordinateMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGradient::CoordinateMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGradient::CoordinateMode *>(cppOut) = value;

}
static PythonToCppFunc is_QGradient_CoordinateMode_PythonToCpp_QGradient_CoordinateMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_CoordinateMode_IDX])))
        return QGradient_CoordinateMode_PythonToCpp_QGradient_CoordinateMode;
    return {};
}
static PyObject *QGradient_CoordinateMode_CppToPython_QGradient_CoordinateMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QGradient::CoordinateMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_CoordinateMode_IDX]), castCppIn);

}

static void QGradient_InterpolationMode_PythonToCpp_QGradient_InterpolationMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGradient::InterpolationMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGradient::InterpolationMode *>(cppOut) = value;

}
static PythonToCppFunc is_QGradient_InterpolationMode_PythonToCpp_QGradient_InterpolationMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_InterpolationMode_IDX])))
        return QGradient_InterpolationMode_PythonToCpp_QGradient_InterpolationMode;
    return {};
}
static PyObject *QGradient_InterpolationMode_CppToPython_QGradient_InterpolationMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QGradient::InterpolationMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_InterpolationMode_IDX]), castCppIn);

}

static void QGradient_Preset_PythonToCpp_QGradient_Preset(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGradient::Preset>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGradient::Preset *>(cppOut) = value;

}
static PythonToCppFunc is_QGradient_Preset_PythonToCpp_QGradient_Preset_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Preset_IDX])))
        return QGradient_Preset_PythonToCpp_QGradient_Preset;
    return {};
}
static PyObject *QGradient_Preset_CppToPython_QGradient_Preset(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QGradient::Preset *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Preset_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGradient_PythonToCpp_QGradient_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGradient_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGradient_PythonToCpp_QGradient_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGradient_TypeF()))
        return QGradient_PythonToCpp_QGradient_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGradient_PTR_CppToPython_QGradient(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QGradient *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QGradient_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QGradient_COPY_CppToPython_QGradient(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QGradient *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QGradient_TypeF(), new ::QGradient(*source), true, true);
}

// Python to C++ copy conversion.
static void QGradient_PythonToCpp_QGradient_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QGradient *>(cppOut) = *reinterpret_cast< ::QGradient *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QGradient_PythonToCpp_QGradient_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QGradient_TypeF()))
        return QGradient_PythonToCpp_QGradient_COPY;
    return {};
}

// Implicit conversions.
static void QGradient_Preset_PythonToCpp_QGradient(PyObject *pyIn, void *cppOut)
{
    ::QGradient::Preset cppIn = static_cast< ::QGradient::Preset>(0);
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Preset_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QGradient *>(cppOut) = ::QGradient(cppIn);
}
static PythonToCppFunc is_QGradient_Preset_PythonToCpp_QGradient_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Preset_IDX]), pyIn))
        return QGradient_Preset_PythonToCpp_QGradient;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QGradient_SignatureStrings[] = {
    "2:PySide6.QtGui.QGradient(self)",
    "1:PySide6.QtGui.QGradient(self,arg__1:PySide6.QtGui.QGradient.Preset)",
    "0:PySide6.QtGui.QGradient(self,QGradient:typing.Union[PySide6.QtGui.QGradient, PySide6.QtGui.QGradient.Preset])",
    "PySide6.QtGui.QGradient.coordinateMode(self)->PySide6.QtGui.QGradient.CoordinateMode",
    "PySide6.QtGui.QGradient.interpolationMode(self)->PySide6.QtGui.QGradient.InterpolationMode",
    "PySide6.QtGui.QGradient.setColorAt(self,pos:qreal,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGui.QGradient.setCoordinateMode(self,mode:PySide6.QtGui.QGradient.CoordinateMode)",
    "PySide6.QtGui.QGradient.setInterpolationMode(self,mode:PySide6.QtGui.QGradient.InterpolationMode)",
    "PySide6.QtGui.QGradient.setSpread(self,spread:PySide6.QtGui.QGradient.Spread)",
    "PySide6.QtGui.QGradient.setStops(self,stops:QList[std.pair[qreal, PySide6.QtGui.QColor]])",
    "PySide6.QtGui.QGradient.spread(self)->PySide6.QtGui.QGradient.Spread",
    "PySide6.QtGui.QGradient.stops(self)->QList[std.pair[qreal, PySide6.QtGui.QColor]]",
    "PySide6.QtGui.QGradient.type(self)->PySide6.QtGui.QGradient.Type",
    "PySide6.QtGui.QGradient.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QGradient(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX].type;

    Shiboken::AutoDecRef Sbk_QGradient_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QGradient_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGradient",
        "QGradient",
        &Sbk_QGradient_spec,
        &Shiboken::callCppDestructor< ::QGradient >,
        Sbk_QGradient_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QGradient_TypeF(); // references _Sbk_QGradient_Type
    InitSignatureStrings(pyType, QGradient_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGradient_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QGradient_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGradient_PythonToCpp_QGradient_PTR,
        is_QGradient_PythonToCpp_QGradient_PTR_Convertible,
        QGradient_PTR_CppToPython_QGradient,
        QGradient_COPY_CppToPython_QGradient);

    Shiboken::Conversions::registerConverterName(converter, "QGradient");
    Shiboken::Conversions::registerConverterName(converter, "QGradient*");
    Shiboken::Conversions::registerConverterName(converter, "QGradient&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGradient).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGradient_PythonToCpp_QGradient_COPY,
        is_QGradient_PythonToCpp_QGradient_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QGradient_Preset_PythonToCpp_QGradient,
        is_QGradient_Preset_PythonToCpp_QGradient_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QGradient_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "LinearGradient",
        "RadialGradient",
        "ConicalGradient",
        "NoGradient",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QGradient::Type::LinearGradient),  //  0x00  0
        uint8_t(QGradient::Type::RadialGradient),  //  0x01  1
        uint8_t(QGradient::Type::ConicalGradient), //  0x02  2
        uint8_t(QGradient::Type::NoGradient)       //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGradient_TypeF(),
        "2:PySide6.QtGui.QGradient.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Type_IDX].type = EType;
    // Register converter for enum 'QGradient::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGradient_Type_CppToPython_QGradient_Type);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QGradient_Type_PythonToCpp_QGradient_Type,
            is_QGradient_Type_PythonToCpp_QGradient_Type_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QGradient::Type");
        Shiboken::Conversions::registerConverterName(converter, "Type");
    }
    // End of 'Type' enum.

    // Initialization of enum 'Spread'.
    const char *Spread_Initializer[] = {
        "PadSpread",
        "ReflectSpread",
        "RepeatSpread",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Spread_InitializerValues[] = {
        uint8_t(QGradient::Spread::PadSpread),     //  0x00  0
        uint8_t(QGradient::Spread::ReflectSpread), //  0x01  1
        uint8_t(QGradient::Spread::RepeatSpread)   //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGradient_TypeF(),
        "2:PySide6.QtGui.QGradient.Spread",
        Spread_Initializer, Spread_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Spread_IDX].type = EType;
    // Register converter for enum 'QGradient::Spread'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGradient_Spread_CppToPython_QGradient_Spread);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QGradient_Spread_PythonToCpp_QGradient_Spread,
            is_QGradient_Spread_PythonToCpp_QGradient_Spread_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QGradient::Spread");
        Shiboken::Conversions::registerConverterName(converter, "Spread");
    }
    // End of 'Spread' enum.

    // Initialization of enum 'CoordinateMode'.
    const char *CoordinateMode_Initializer[] = {
        "LogicalMode",
        "StretchToDeviceMode",
        "ObjectBoundingMode",
        "ObjectMode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CoordinateMode_InitializerValues[] = {
        uint8_t(QGradient::CoordinateMode::LogicalMode),         //  0x00  0
        uint8_t(QGradient::CoordinateMode::StretchToDeviceMode), //  0x01  1
        uint8_t(QGradient::CoordinateMode::ObjectBoundingMode),  //  0x02  2
        uint8_t(QGradient::CoordinateMode::ObjectMode)           //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGradient_TypeF(),
        "2:PySide6.QtGui.QGradient.CoordinateMode",
        CoordinateMode_Initializer, CoordinateMode_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QGradient_CoordinateMode_IDX].type = EType;
    // Register converter for enum 'QGradient::CoordinateMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGradient_CoordinateMode_CppToPython_QGradient_CoordinateMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QGradient_CoordinateMode_PythonToCpp_QGradient_CoordinateMode,
            is_QGradient_CoordinateMode_PythonToCpp_QGradient_CoordinateMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QGradient::CoordinateMode");
        Shiboken::Conversions::registerConverterName(converter, "CoordinateMode");
    }
    // End of 'CoordinateMode' enum.

    // Initialization of enum 'InterpolationMode'.
    const char *InterpolationMode_Initializer[] = {
        "ColorInterpolation",
        "ComponentInterpolation",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t InterpolationMode_InitializerValues[] = {
        uint8_t(QGradient::InterpolationMode::ColorInterpolation),    //  0x00  0
        uint8_t(QGradient::InterpolationMode::ComponentInterpolation) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGradient_TypeF(),
        "2:PySide6.QtGui.QGradient.InterpolationMode",
        InterpolationMode_Initializer, InterpolationMode_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QGradient_InterpolationMode_IDX].type = EType;
    // Register converter for enum 'QGradient::InterpolationMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGradient_InterpolationMode_CppToPython_QGradient_InterpolationMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QGradient_InterpolationMode_PythonToCpp_QGradient_InterpolationMode,
            is_QGradient_InterpolationMode_PythonToCpp_QGradient_InterpolationMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QGradient::InterpolationMode");
        Shiboken::Conversions::registerConverterName(converter, "InterpolationMode");
    }
    // End of 'InterpolationMode' enum.

    // Initialization of enum 'Preset'.
    const char *Preset_Initializer[] = {
        "WarmFlame",
        "NightFade",
        "SpringWarmth",
        "JuicyPeach",
        "YoungPassion",
        "LadyLips",
        "SunnyMorning",
        "RainyAshville",
        "FrozenDreams",
        "WinterNeva",
        "DustyGrass",
        "TemptingAzure",
        "HeavyRain",
        "AmyCrisp",
        "MeanFruit",
        "DeepBlue",
        "RipeMalinka",
        "CloudyKnoxville",
        "MalibuBeach",
        "NewLife",
        "TrueSunset",
        "MorpheusDen",
        "RareWind",
        "NearMoon",
        "WildApple",
        "SaintPetersburg",
        "PlumPlate",
        "EverlastingSky",
        "HappyFisher",
        "Blessing",
        "SharpeyeEagle",
        "LadogaBottom",
        "LemonGate",
        "ItmeoBranding",
        "ZeusMiracle",
        "OldHat",
        "StarWine",
        "HappyAcid",
        "AwesomePine",
        "NewYork",
        "ShyRainbow",
        "MixedHopes",
        "FlyHigh",
        "StrongBliss",
        "FreshMilk",
        "SnowAgain",
        "FebruaryInk",
        "KindSteel",
        "SoftGrass",
        "GrownEarly",
        "SharpBlues",
        "ShadyWater",
        "DirtyBeauty",
        "GreatWhale",
        "TeenNotebook",
        "PoliteRumors",
        "SweetPeriod",
        "WideMatrix",
        "SoftCherish",
        "RedSalvation",
        "BurningSpring",
        "NightParty",
        "SkyGlider",
        "HeavenPeach",
        "PurpleDivision",
        "AquaSplash",
        "SpikyNaga",
        "LoveKiss",
        "CleanMirror",
        "PremiumDark",
        "ColdEvening",
        "CochitiLake",
        "SummerGames",
        "PassionateBed",
        "MountainRock",
        "DesertHump",
        "JungleDay",
        "PhoenixStart",
        "OctoberSilence",
        "FarawayRiver",
        "AlchemistLab",
        "OverSun",
        "PremiumWhite",
        "MarsParty",
        "EternalConstance",
        "JapanBlush",
        "SmilingRain",
        "CloudyApple",
        "BigMango",
        "HealthyWater",
        "AmourAmour",
        "RiskyConcrete",
        "StrongStick",
        "ViciousStance",
        "PaloAlto",
        "HappyMemories",
        "MidnightBloom",
        "Crystalline",
        "PartyBliss",
        "ConfidentCloud",
        "LeCocktail",
        "RiverCity",
        "FrozenBerry",
        "ChildCare",
        "FlyingLemon",
        "NewRetrowave",
        "HiddenJaguar",
        "AboveTheSky",
        "Nega",
        "DenseWater",
        "Seashore",
        "MarbleWall",
        "CheerfulCaramel",
        "NightSky",
        "MagicLake",
        "YoungGrass",
        "ColorfulPeach",
        "GentleCare",
        "PlumBath",
        "HappyUnicorn",
        "AfricanField",
        "SolidStone",
        "OrangeJuice",
        "GlassWater",
        "NorthMiracle",
        "FruitBlend",
        "MillenniumPine",
        "HighFlight",
        "MoleHall",
        "SpaceShift",
        "ForestInei",
        "RoyalGarden",
        "RichMetal",
        "JuicyCake",
        "SmartIndigo",
        "SandStrike",
        "NorseBeauty",
        "AquaGuidance",
        "SunVeggie",
        "SeaLord",
        "BlackSea",
        "GrassShampoo",
        "LandingAircraft",
        "WitchDance",
        "SleeplessNight",
        "AngelCare",
        "CrystalRiver",
        "SoftLipstick",
        "SaltMountain",
        "PerfectWhite",
        "FreshOasis",
        "StrictNovember",
        "MorningSalad",
        "DeepRelief",
        "SeaStrike",
        "NightCall",
        "SupremeSky",
        "LightBlue",
        "MindCrawl",
        "LilyMeadow",
        "SugarLollipop",
        "SweetDessert",
        "MagicRay",
        "TeenParty",
        "FrozenHeat",
        "GagarinView",
        "FabledSunset",
        "PerfectBlue",
        "NumPresets",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Preset_InitializerValues[] = {
        uint8_t(QGradient::Preset::WarmFlame),        //  0x01  1
        uint8_t(QGradient::Preset::NightFade),        //  0x02  2
        uint8_t(QGradient::Preset::SpringWarmth),     //  0x03  3
        uint8_t(QGradient::Preset::JuicyPeach),       //  0x04  4
        uint8_t(QGradient::Preset::YoungPassion),     //  0x05  5
        uint8_t(QGradient::Preset::LadyLips),         //  0x06  6
        uint8_t(QGradient::Preset::SunnyMorning),     //  0x07  7
        uint8_t(QGradient::Preset::RainyAshville),    //  0x08  8
        uint8_t(QGradient::Preset::FrozenDreams),     //  0x09  9
        uint8_t(QGradient::Preset::WinterNeva),       //  0x0a  10
        uint8_t(QGradient::Preset::DustyGrass),       //  0x0b  11
        uint8_t(QGradient::Preset::TemptingAzure),    //  0x0c  12
        uint8_t(QGradient::Preset::HeavyRain),        //  0x0d  13
        uint8_t(QGradient::Preset::AmyCrisp),         //  0x0e  14
        uint8_t(QGradient::Preset::MeanFruit),        //  0x0f  15
        uint8_t(QGradient::Preset::DeepBlue),         //  0x10  16
        uint8_t(QGradient::Preset::RipeMalinka),      //  0x11  17
        uint8_t(QGradient::Preset::CloudyKnoxville),  //  0x12  18
        uint8_t(QGradient::Preset::MalibuBeach),      //  0x13  19
        uint8_t(QGradient::Preset::NewLife),          //  0x14  20
        uint8_t(QGradient::Preset::TrueSunset),       //  0x15  21
        uint8_t(QGradient::Preset::MorpheusDen),      //  0x16  22
        uint8_t(QGradient::Preset::RareWind),         //  0x17  23
        uint8_t(QGradient::Preset::NearMoon),         //  0x18  24
        uint8_t(QGradient::Preset::WildApple),        //  0x19  25
        uint8_t(QGradient::Preset::SaintPetersburg),  //  0x1a  26
        uint8_t(QGradient::Preset::PlumPlate),        //  0x1c  28
        uint8_t(QGradient::Preset::EverlastingSky),   //  0x1d  29
        uint8_t(QGradient::Preset::HappyFisher),      //  0x1e  30
        uint8_t(QGradient::Preset::Blessing),         //  0x1f  31
        uint8_t(QGradient::Preset::SharpeyeEagle),    //  0x20  32
        uint8_t(QGradient::Preset::LadogaBottom),     //  0x21  33
        uint8_t(QGradient::Preset::LemonGate),        //  0x22  34
        uint8_t(QGradient::Preset::ItmeoBranding),    //  0x23  35
        uint8_t(QGradient::Preset::ZeusMiracle),      //  0x24  36
        uint8_t(QGradient::Preset::OldHat),           //  0x25  37
        uint8_t(QGradient::Preset::StarWine),         //  0x26  38
        uint8_t(QGradient::Preset::HappyAcid),        //  0x29  41
        uint8_t(QGradient::Preset::AwesomePine),      //  0x2a  42
        uint8_t(QGradient::Preset::NewYork),          //  0x2b  43
        uint8_t(QGradient::Preset::ShyRainbow),       //  0x2c  44
        uint8_t(QGradient::Preset::MixedHopes),       //  0x2e  46
        uint8_t(QGradient::Preset::FlyHigh),          //  0x2f  47
        uint8_t(QGradient::Preset::StrongBliss),      //  0x30  48
        uint8_t(QGradient::Preset::FreshMilk),        //  0x31  49
        uint8_t(QGradient::Preset::SnowAgain),        //  0x32  50
        uint8_t(QGradient::Preset::FebruaryInk),      //  0x33  51
        uint8_t(QGradient::Preset::KindSteel),        //  0x34  52
        uint8_t(QGradient::Preset::SoftGrass),        //  0x35  53
        uint8_t(QGradient::Preset::GrownEarly),       //  0x36  54
        uint8_t(QGradient::Preset::SharpBlues),       //  0x37  55
        uint8_t(QGradient::Preset::ShadyWater),       //  0x38  56
        uint8_t(QGradient::Preset::DirtyBeauty),      //  0x39  57
        uint8_t(QGradient::Preset::GreatWhale),       //  0x3a  58
        uint8_t(QGradient::Preset::TeenNotebook),     //  0x3b  59
        uint8_t(QGradient::Preset::PoliteRumors),     //  0x3c  60
        uint8_t(QGradient::Preset::SweetPeriod),      //  0x3d  61
        uint8_t(QGradient::Preset::WideMatrix),       //  0x3e  62
        uint8_t(QGradient::Preset::SoftCherish),      //  0x3f  63
        uint8_t(QGradient::Preset::RedSalvation),     //  0x40  64
        uint8_t(QGradient::Preset::BurningSpring),    //  0x41  65
        uint8_t(QGradient::Preset::NightParty),       //  0x42  66
        uint8_t(QGradient::Preset::SkyGlider),        //  0x43  67
        uint8_t(QGradient::Preset::HeavenPeach),      //  0x44  68
        uint8_t(QGradient::Preset::PurpleDivision),   //  0x45  69
        uint8_t(QGradient::Preset::AquaSplash),       //  0x46  70
        uint8_t(QGradient::Preset::SpikyNaga),        //  0x48  72
        uint8_t(QGradient::Preset::LoveKiss),         //  0x49  73
        uint8_t(QGradient::Preset::CleanMirror),      //  0x4b  75
        uint8_t(QGradient::Preset::PremiumDark),      //  0x4c  76
        uint8_t(QGradient::Preset::ColdEvening),      //  0x4d  77
        uint8_t(QGradient::Preset::CochitiLake),      //  0x4e  78
        uint8_t(QGradient::Preset::SummerGames),      //  0x4f  79
        uint8_t(QGradient::Preset::PassionateBed),    //  0x50  80
        uint8_t(QGradient::Preset::MountainRock),     //  0x51  81
        uint8_t(QGradient::Preset::DesertHump),       //  0x52  82
        uint8_t(QGradient::Preset::JungleDay),        //  0x53  83
        uint8_t(QGradient::Preset::PhoenixStart),     //  0x54  84
        uint8_t(QGradient::Preset::OctoberSilence),   //  0x55  85
        uint8_t(QGradient::Preset::FarawayRiver),     //  0x56  86
        uint8_t(QGradient::Preset::AlchemistLab),     //  0x57  87
        uint8_t(QGradient::Preset::OverSun),          //  0x58  88
        uint8_t(QGradient::Preset::PremiumWhite),     //  0x59  89
        uint8_t(QGradient::Preset::MarsParty),        //  0x5a  90
        uint8_t(QGradient::Preset::EternalConstance), //  0x5b  91
        uint8_t(QGradient::Preset::JapanBlush),       //  0x5c  92
        uint8_t(QGradient::Preset::SmilingRain),      //  0x5d  93
        uint8_t(QGradient::Preset::CloudyApple),      //  0x5e  94
        uint8_t(QGradient::Preset::BigMango),         //  0x5f  95
        uint8_t(QGradient::Preset::HealthyWater),     //  0x60  96
        uint8_t(QGradient::Preset::AmourAmour),       //  0x61  97
        uint8_t(QGradient::Preset::RiskyConcrete),    //  0x62  98
        uint8_t(QGradient::Preset::StrongStick),      //  0x63  99
        uint8_t(QGradient::Preset::ViciousStance),    //  0x64  100
        uint8_t(QGradient::Preset::PaloAlto),         //  0x65  101
        uint8_t(QGradient::Preset::HappyMemories),    //  0x66  102
        uint8_t(QGradient::Preset::MidnightBloom),    //  0x67  103
        uint8_t(QGradient::Preset::Crystalline),      //  0x68  104
        uint8_t(QGradient::Preset::PartyBliss),       //  0x6a  106
        uint8_t(QGradient::Preset::ConfidentCloud),   //  0x6b  107
        uint8_t(QGradient::Preset::LeCocktail),       //  0x6c  108
        uint8_t(QGradient::Preset::RiverCity),        //  0x6d  109
        uint8_t(QGradient::Preset::FrozenBerry),      //  0x6e  110
        uint8_t(QGradient::Preset::ChildCare),        //  0x70  112
        uint8_t(QGradient::Preset::FlyingLemon),      //  0x71  113
        uint8_t(QGradient::Preset::NewRetrowave),     //  0x72  114
        uint8_t(QGradient::Preset::HiddenJaguar),     //  0x73  115
        uint8_t(QGradient::Preset::AboveTheSky),      //  0x74  116
        uint8_t(QGradient::Preset::Nega),             //  0x75  117
        uint8_t(QGradient::Preset::DenseWater),       //  0x76  118
        uint8_t(QGradient::Preset::Seashore),         //  0x78  120
        uint8_t(QGradient::Preset::MarbleWall),       //  0x79  121
        uint8_t(QGradient::Preset::CheerfulCaramel),  //  0x7a  122
        uint8_t(QGradient::Preset::NightSky),         //  0x7b  123
        uint8_t(QGradient::Preset::MagicLake),        //  0x7c  124
        uint8_t(QGradient::Preset::YoungGrass),       //  0x7d  125
        uint8_t(QGradient::Preset::ColorfulPeach),    //  0x7e  126
        uint8_t(QGradient::Preset::GentleCare),       //  0x7f  127
        uint8_t(QGradient::Preset::PlumBath),         //  0x80  128
        uint8_t(QGradient::Preset::HappyUnicorn),     //  0x81  129
        uint8_t(QGradient::Preset::AfricanField),     //  0x83  131
        uint8_t(QGradient::Preset::SolidStone),       //  0x84  132
        uint8_t(QGradient::Preset::OrangeJuice),      //  0x85  133
        uint8_t(QGradient::Preset::GlassWater),       //  0x86  134
        uint8_t(QGradient::Preset::NorthMiracle),     //  0x88  136
        uint8_t(QGradient::Preset::FruitBlend),       //  0x89  137
        uint8_t(QGradient::Preset::MillenniumPine),   //  0x8a  138
        uint8_t(QGradient::Preset::HighFlight),       //  0x8b  139
        uint8_t(QGradient::Preset::MoleHall),         //  0x8c  140
        uint8_t(QGradient::Preset::SpaceShift),       //  0x8e  142
        uint8_t(QGradient::Preset::ForestInei),       //  0x8f  143
        uint8_t(QGradient::Preset::RoyalGarden),      //  0x90  144
        uint8_t(QGradient::Preset::RichMetal),        //  0x91  145
        uint8_t(QGradient::Preset::JuicyCake),        //  0x92  146
        uint8_t(QGradient::Preset::SmartIndigo),      //  0x93  147
        uint8_t(QGradient::Preset::SandStrike),       //  0x94  148
        uint8_t(QGradient::Preset::NorseBeauty),      //  0x95  149
        uint8_t(QGradient::Preset::AquaGuidance),     //  0x96  150
        uint8_t(QGradient::Preset::SunVeggie),        //  0x97  151
        uint8_t(QGradient::Preset::SeaLord),          //  0x98  152
        uint8_t(QGradient::Preset::BlackSea),         //  0x99  153
        uint8_t(QGradient::Preset::GrassShampoo),     //  0x9a  154
        uint8_t(QGradient::Preset::LandingAircraft),  //  0x9b  155
        uint8_t(QGradient::Preset::WitchDance),       //  0x9c  156
        uint8_t(QGradient::Preset::SleeplessNight),   //  0x9d  157
        uint8_t(QGradient::Preset::AngelCare),        //  0x9e  158
        uint8_t(QGradient::Preset::CrystalRiver),     //  0x9f  159
        uint8_t(QGradient::Preset::SoftLipstick),     //  0xa0  160
        uint8_t(QGradient::Preset::SaltMountain),     //  0xa1  161
        uint8_t(QGradient::Preset::PerfectWhite),     //  0xa2  162
        uint8_t(QGradient::Preset::FreshOasis),       //  0xa3  163
        uint8_t(QGradient::Preset::StrictNovember),   //  0xa4  164
        uint8_t(QGradient::Preset::MorningSalad),     //  0xa5  165
        uint8_t(QGradient::Preset::DeepRelief),       //  0xa6  166
        uint8_t(QGradient::Preset::SeaStrike),        //  0xa7  167
        uint8_t(QGradient::Preset::NightCall),        //  0xa8  168
        uint8_t(QGradient::Preset::SupremeSky),       //  0xa9  169
        uint8_t(QGradient::Preset::LightBlue),        //  0xaa  170
        uint8_t(QGradient::Preset::MindCrawl),        //  0xab  171
        uint8_t(QGradient::Preset::LilyMeadow),       //  0xac  172
        uint8_t(QGradient::Preset::SugarLollipop),    //  0xad  173
        uint8_t(QGradient::Preset::SweetDessert),     //  0xae  174
        uint8_t(QGradient::Preset::MagicRay),         //  0xaf  175
        uint8_t(QGradient::Preset::TeenParty),        //  0xb0  176
        uint8_t(QGradient::Preset::FrozenHeat),       //  0xb1  177
        uint8_t(QGradient::Preset::GagarinView),      //  0xb2  178
        uint8_t(QGradient::Preset::FabledSunset),     //  0xb3  179
        uint8_t(QGradient::Preset::PerfectBlue),      //  0xb4  180
        uint8_t(QGradient::Preset::NumPresets)        //  0xb5  181
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGradient_TypeF(),
        "2:PySide6.QtGui.QGradient.Preset",
        Preset_Initializer, Preset_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Preset_IDX].type = EType;
    // Register converter for enum 'QGradient::Preset'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGradient_Preset_CppToPython_QGradient_Preset);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QGradient_Preset_PythonToCpp_QGradient_Preset,
            is_QGradient_Preset_PythonToCpp_QGradient_Preset_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QGradient::Preset");
        Shiboken::Conversions::registerConverterName(converter, "Preset");
    }
    // End of 'Preset' enum.

    qRegisterMetaType< ::QGradient >("QGradient");
    qRegisterMetaType< ::QGradient::Type >("QGradient::Type");
    qRegisterMetaType< ::QGradient::Spread >("QGradient::Spread");
    qRegisterMetaType< ::QGradient::CoordinateMode >("QGradient::CoordinateMode");
    qRegisterMetaType< ::QGradient::InterpolationMode >("QGradient::InterpolationMode");
    qRegisterMetaType< ::QGradient::Preset >("QGradient::Preset");

    return pyType;
}
