// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qinputmethodevent_wrapper.h"

// inner classes
#include "qinputmethodevent_attribute_wrapper.h"

// Argument includes
#include <QInputMethodEvent>
#include <QList>
#include <QString>
#include <QtGui/qevent.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QInputMethodEventWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QInputMethodEventWrapper::QInputMethodEventWrapper() : QInputMethodEvent()
{
    resetPyMethodCache();
    // ... middle
}

QInputMethodEventWrapper::QInputMethodEventWrapper(const ::QString & preeditText, const ::QList<QInputMethodEvent::Attribute> & attributes) : QInputMethodEvent(preeditText, attributes)
{
    resetPyMethodCache();
    // ... middle
}

::QInputMethodEvent * QInputMethodEventWrapper::clone() const
{
    if (m_PyMethodCache[0])
        return this->::QInputMethodEvent::clone();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clone";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QInputMethodEvent::clone();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QInputMethodEvent", funcName, Shiboken::SbkType< QInputMethodEvent >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QInputMethodEvent *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QInputMethodEventWrapper::setAccepted(bool accepted)
{
    if (m_PyMethodCache[1]) {
        return this->::QEvent::setAccepted(accepted);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setAccepted";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QEvent::setAccepted(accepted);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &accepted)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QInputMethodEventWrapper::~QInputMethodEventWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QInputMethodEvent_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QInputMethodEvent >()))
        return -1;

    QInputMethodEventWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QInputMethodEvent.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QInputMethodEvent", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QInputMethodEvent::QInputMethodEvent()
    // 1: QInputMethodEvent::QInputMethodEvent(QInputMethodEvent)
    // 2: QInputMethodEvent::QInputMethodEvent(QString,QList<QInputMethodEvent::Attribute>)
    if (numArgs == 0) {
        overloadId = 0; // QInputMethodEvent()
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QInputMethodEvent_Attribute_IDX], (pyArgs[1])))) {
        overloadId = 2; // QInputMethodEvent(QString,QList<QInputMethodEvent::Attribute>)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QInputMethodEvent(QInputMethodEvent)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QInputMethodEvent()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QInputMethodEvent()
                cptr = new QInputMethodEventWrapper();
            }
            break;
        }
        case 1: // QInputMethodEvent(const QInputMethodEvent & arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QInputMethodEvent *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QInputMethodEvent(QInputMethodEvent)
                cptr = new QInputMethodEventWrapper(*cppArg0);
            }
            break;
        }
        case 2: // QInputMethodEvent(const QString & preeditText, const QList<QInputMethodEvent::Attribute> & attributes)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QList<QInputMethodEvent::Attribute> cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QInputMethodEvent(QString,QList<QInputMethodEvent::Attribute>)
                cptr = new QInputMethodEventWrapper(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QInputMethodEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QInputMethodEventFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethodEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QInputMethodEvent.__repr__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __repr__()
            // Begin code injection
            // TEMPLATE - repr_qdebug_gui - START
            // TEMPLATE - repr_qdebug - START
            QString result;
            QDebug(&result).nospace() << "<PySide6.QtGui." << cppSelf << '>';
            pyResult = Shiboken::String::fromCString(qPrintable(result));
            // TEMPLATE - repr_qdebug - END
            // TEMPLATE - repr_qdebug_gui - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodEventFunc_attributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethodEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QInputMethodEvent.attributes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // attributes()const
            const QList<QInputMethodEvent::Attribute> & cppResult = const_cast<const ::QInputMethodEvent *>(cppSelf)->attributes();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QInputMethodEvent_Attribute_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodEventFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethodEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QInputMethodEvent.clone";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clone()const
            QInputMethodEvent * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QInputMethodEvent *>(cppSelf)->::QInputMethodEvent::clone()
                : const_cast<const ::QInputMethodEvent *>(cppSelf)->clone();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodEventFunc_commitString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethodEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QInputMethodEvent.commitString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // commitString()const
            const QString & cppResult = const_cast<const ::QInputMethodEvent *>(cppSelf)->commitString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodEventFunc_preeditString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethodEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QInputMethodEvent.preeditString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // preeditString()const
            const QString & cppResult = const_cast<const ::QInputMethodEvent *>(cppSelf)->preeditString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodEventFunc_replacementLength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethodEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QInputMethodEvent.replacementLength";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // replacementLength()const
            int cppResult = const_cast<const ::QInputMethodEvent *>(cppSelf)->replacementLength();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodEventFunc_replacementStart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethodEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QInputMethodEvent.replacementStart";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // replacementStart()const
            int cppResult = const_cast<const ::QInputMethodEvent *>(cppSelf)->replacementStart();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QInputMethodEventFunc_setCommitString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QInputMethodEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QInputMethodEvent.setCommitString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:setCommitString", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QInputMethodEvent::setCommitString(QString,int=,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setCommitString(QString,int,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setCommitString(QString,int,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 0; // setCommitString(QString,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_replaceFrom = Shiboken::String::createStaticString("replaceFrom");
            if (PyDict_Contains(kwds, key_replaceFrom) != 0) {
                value = PyDict_GetItem(kwds, key_replaceFrom);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_replaceFrom);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_replaceFrom);
            }
            static PyObject *const key_replaceLength = Shiboken::String::createStaticString("replaceLength");
            if (PyDict_Contains(kwds, key_replaceLength) != 0) {
                value = PyDict_GetItem(kwds, key_replaceLength);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_replaceLength);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_replaceLength);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = 0;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCommitString(QString,int,int)
            cppSelf->setCommitString(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QInputMethodEvent_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QInputMethodEvent_EnumFlagInfo[] = {
    "AttributeType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QInputMethodEvent_methods[] = {
    {"attributes", reinterpret_cast<PyCFunction>(Sbk_QInputMethodEventFunc_attributes), METH_NOARGS, nullptr},
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QInputMethodEventFunc_clone), METH_NOARGS, nullptr},
    {"commitString", reinterpret_cast<PyCFunction>(Sbk_QInputMethodEventFunc_commitString), METH_NOARGS, nullptr},
    {"preeditString", reinterpret_cast<PyCFunction>(Sbk_QInputMethodEventFunc_preeditString), METH_NOARGS, nullptr},
    {"replacementLength", reinterpret_cast<PyCFunction>(Sbk_QInputMethodEventFunc_replacementLength), METH_NOARGS, nullptr},
    {"replacementStart", reinterpret_cast<PyCFunction>(Sbk_QInputMethodEventFunc_replacementStart), METH_NOARGS, nullptr},
    {"setCommitString", reinterpret_cast<PyCFunction>(Sbk_QInputMethodEventFunc_setCommitString), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QInputMethodEvent_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QInputMethodEvent *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QInputMethodEventWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QInputMethodEvent_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QInputMethodEvent_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QInputMethodEvent_Type = nullptr;
static PyTypeObject *Sbk_QInputMethodEvent_TypeF(void)
{
    return _Sbk_QInputMethodEvent_Type;
}

static PyType_Slot Sbk_QInputMethodEvent_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QInputMethodEventFunc___repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QInputMethodEvent_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QInputMethodEvent_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QInputMethodEvent_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QInputMethodEvent_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QInputMethodEvent_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QInputMethodEvent_spec = {
    "2:PySide6.QtGui.QInputMethodEvent",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QInputMethodEvent_slots
};

} //extern "C"

static void *Sbk_QInputMethodEvent_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if ( reinterpret_cast< ::QEvent *>(cptr)->type() == QEvent::InputMethod)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QInputMethodEvent_AttributeType_PythonToCpp_QInputMethodEvent_AttributeType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QInputMethodEvent::AttributeType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QInputMethodEvent::AttributeType *>(cppOut) = value;

}
static PythonToCppFunc is_QInputMethodEvent_AttributeType_PythonToCpp_QInputMethodEvent_AttributeType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_AttributeType_IDX])))
        return QInputMethodEvent_AttributeType_PythonToCpp_QInputMethodEvent_AttributeType;
    return {};
}
static PyObject *QInputMethodEvent_AttributeType_CppToPython_QInputMethodEvent_AttributeType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QInputMethodEvent::AttributeType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_AttributeType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QInputMethodEvent_PythonToCpp_QInputMethodEvent_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QInputMethodEvent_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QInputMethodEvent_PythonToCpp_QInputMethodEvent_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QInputMethodEvent_TypeF()))
        return QInputMethodEvent_PythonToCpp_QInputMethodEvent_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QInputMethodEvent_PTR_CppToPython_QInputMethodEvent(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QInputMethodEvent *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QInputMethodEvent_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QInputMethodEvent_SignatureStrings[] = {
    "2:PySide6.QtGui.QInputMethodEvent(self)",
    "1:PySide6.QtGui.QInputMethodEvent(self,arg__1:PySide6.QtGui.QInputMethodEvent)",
    "0:PySide6.QtGui.QInputMethodEvent(self,preeditText:QString,attributes:QList[PySide6.QtGui.QInputMethodEvent.Attribute])",
    "PySide6.QtGui.QInputMethodEvent.__repr__(self)->PyObject",
    "PySide6.QtGui.QInputMethodEvent.attributes(self)->QList[PySide6.QtGui.QInputMethodEvent.Attribute]",
    "PySide6.QtGui.QInputMethodEvent.clone(self)->PySide6.QtGui.QInputMethodEvent",
    "PySide6.QtGui.QInputMethodEvent.commitString(self)->QString",
    "PySide6.QtGui.QInputMethodEvent.preeditString(self)->QString",
    "PySide6.QtGui.QInputMethodEvent.replacementLength(self)->int",
    "PySide6.QtGui.QInputMethodEvent.replacementStart(self)->int",
    "PySide6.QtGui.QInputMethodEvent.setCommitString(self,commitString:QString,replaceFrom:int=0,replaceLength:int=0)",
    nullptr}; // Sentinel

PyTypeObject *init_QInputMethodEvent(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX].type;

    Shiboken::AutoDecRef Sbk_QInputMethodEvent_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]))));

    _Sbk_QInputMethodEvent_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QInputMethodEvent",
        "QInputMethodEvent*",
        &Sbk_QInputMethodEvent_spec,
        &Shiboken::callCppDestructor< QInputMethodEvent >,
        Sbk_QInputMethodEvent_Type_bases.object(),
        0);
    auto *pyType = Sbk_QInputMethodEvent_TypeF(); // references _Sbk_QInputMethodEvent_Type
    InitSignatureStrings(pyType, QInputMethodEvent_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QInputMethodEvent_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QInputMethodEvent_PythonToCpp_QInputMethodEvent_PTR,
        is_QInputMethodEvent_PythonToCpp_QInputMethodEvent_PTR_Convertible,
        QInputMethodEvent_PTR_CppToPython_QInputMethodEvent);

    Shiboken::Conversions::registerConverterName(converter, "QInputMethodEvent");
    Shiboken::Conversions::registerConverterName(converter, "QInputMethodEvent*");
    Shiboken::Conversions::registerConverterName(converter, "QInputMethodEvent&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QInputMethodEvent).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QInputMethodEventWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QInputMethodEvent_TypeF(), &Sbk_QInputMethodEvent_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QInputMethodEvent_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'AttributeType'.
    const char *AttributeType_Initializer[] = {
        "TextFormat",
        "Cursor",
        "Language",
        "Ruby",
        "Selection",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AttributeType_InitializerValues[] = {
        uint8_t(QInputMethodEvent::AttributeType::TextFormat), //  0x00  0
        uint8_t(QInputMethodEvent::AttributeType::Cursor),     //  0x01  1
        uint8_t(QInputMethodEvent::AttributeType::Language),   //  0x02  2
        uint8_t(QInputMethodEvent::AttributeType::Ruby),       //  0x03  3
        uint8_t(QInputMethodEvent::AttributeType::Selection)   //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QInputMethodEvent_TypeF(),
        "2:PySide6.QtGui.QInputMethodEvent.AttributeType",
        AttributeType_Initializer, AttributeType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_AttributeType_IDX].type = EType;
    // Register converter for enum 'QInputMethodEvent::AttributeType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QInputMethodEvent_AttributeType_CppToPython_QInputMethodEvent_AttributeType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QInputMethodEvent_AttributeType_PythonToCpp_QInputMethodEvent_AttributeType,
            is_QInputMethodEvent_AttributeType_PythonToCpp_QInputMethodEvent_AttributeType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QInputMethodEvent::AttributeType");
        Shiboken::Conversions::registerConverterName(converter, "AttributeType");
    }
    // End of 'AttributeType' enum.

    qRegisterMetaType< ::QInputMethodEvent::AttributeType >("QInputMethodEvent::AttributeType");

    return pyType;
}
