// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qpagesize_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qpagesize.h>
#include <qrect.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPageSize_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPageSize >()))
        return -1;

    ::QPageSize *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:QPageSize", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPageSize::QPageSize()
    // 1: QPageSize::QPageSize(QPageSize::PageSizeId)
    // 2: QPageSize::QPageSize(QPageSize)
    // 3: QPageSize::QPageSize(QSize,const QString&=,QPageSize::SizeMatchPolicy=)
    // 4: QPageSize::QPageSize(QSizeF,QPageSize::Unit,const QString&=,QPageSize::SizeMatchPolicy=)
    if (numArgs == 0) {
        overloadId = 0; // QPageSize()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // QPageSize(QSize,QString,QPageSize::SizeMatchPolicy)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 3; // QPageSize(QSize,QString,QPageSize::SizeMatchPolicy)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_SizeMatchPolicy_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 3; // QPageSize(QSize,QString,QPageSize::SizeMatchPolicy)
            }
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_Unit_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 4; // QPageSize(QSizeF,QPageSize::Unit,QString,QPageSize::SizeMatchPolicy)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 4; // QPageSize(QSizeF,QPageSize::Unit,QString,QPageSize::SizeMatchPolicy)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_SizeMatchPolicy_IDX])))->converter, (pyArgs[3])))) {
                overloadId = 4; // QPageSize(QSizeF,QPageSize::Unit,QString,QPageSize::SizeMatchPolicy)
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // QPageSize(QPageSize::PageSizeId)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QPageSize(QPageSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPageSize()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPageSize()
                cptr = new ::QPageSize();
            }
            break;
        }
        case 1: // QPageSize(QPageSize::PageSizeId pageSizeId)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QPageSize::PageSizeId cppArg0{QPageSize::AnsiA};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPageSize(QPageSize::PageSizeId)
                cptr = new ::QPageSize(cppArg0);
            }
            break;
        }
        case 2: // QPageSize(const QPageSize & other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPageSize cppArg0_local;
            ::QPageSize *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QPageSize(QPageSize)
                cptr = new ::QPageSize(*cppArg0);
            }
            break;
        }
        case 3: // QPageSize(const QSize & pointSize, const QString & name, QPageSize::SizeMatchPolicy matchPolicy)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_name = Shiboken::String::createStaticString("name");
                if (PyDict_Contains(kwds, key_name) != 0) {
                    value = PyDict_GetItem(kwds, key_name);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_name);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_name);
                }
                static PyObject *const key_matchPolicy = Shiboken::String::createStaticString("matchPolicy");
                if (PyDict_Contains(kwds, key_matchPolicy) != 0) {
                    value = PyDict_GetItem(kwds, key_matchPolicy);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_matchPolicy);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_SizeMatchPolicy_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_matchPolicy);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSize cppArg0_local;
            ::QSize *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QPageSize::SizeMatchPolicy cppArg2(QPageSize::SizeMatchPolicy::FuzzyMatch);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPageSize(QSize,QString,QPageSize::SizeMatchPolicy)
                cptr = new ::QPageSize(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 4: // QPageSize(const QSizeF & size, QPageSize::Unit units, const QString & name, QPageSize::SizeMatchPolicy matchPolicy)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_name = Shiboken::String::createStaticString("name");
                if (PyDict_Contains(kwds, key_name) != 0) {
                    value = PyDict_GetItem(kwds, key_name);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_name);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_name);
                }
                static PyObject *const key_matchPolicy = Shiboken::String::createStaticString("matchPolicy");
                if (PyDict_Contains(kwds, key_matchPolicy) != 0) {
                    value = PyDict_GetItem(kwds, key_matchPolicy);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_matchPolicy);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_SizeMatchPolicy_IDX])))->converter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_matchPolicy);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QSizeF cppArg0_local;
            ::QSizeF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QPageSize::Unit cppArg1{QPageSize::Millimeter};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2 = QString();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QPageSize::SizeMatchPolicy cppArg3(QPageSize::SizeMatchPolicy::FuzzyMatch);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPageSize(QSizeF,QPageSize::Unit,QString,QPageSize::SizeMatchPolicy)
                cptr = new ::QPageSize(*cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPageSize >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPageSizeFunc_definitionSize(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QPageSize *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.definitionSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "definitionSize", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPageSize::definitionSize()const->QSizeF
    // 1: static QPageSize::definitionSize(QPageSize::PageSizeId)->QSizeF
    if (numArgs == 0) {
        overloadId = 0; // definitionSize()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // definitionSize(QPageSize::PageSizeId)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // definitionSize() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // definitionSize()const
                QSizeF cppResult = const_cast<const ::QPageSize *>(cppSelf)->definitionSize();
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
            }
            break;
        }
        case 1: // definitionSize(QPageSize::PageSizeId pageSizeId)
        {
            ::QPageSize::PageSizeId cppArg0{QPageSize::AnsiA};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // definitionSize(QPageSize::PageSizeId)
                QSizeF cppResult = ::QPageSize::definitionSize(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageSizeFunc_definitionUnits(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QPageSize *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.definitionUnits";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "definitionUnits", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPageSize::definitionUnits()const->QPageSize::Unit
    // 1: static QPageSize::definitionUnits(QPageSize::PageSizeId)->QPageSize::Unit
    if (numArgs == 0) {
        overloadId = 0; // definitionUnits()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // definitionUnits(QPageSize::PageSizeId)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // definitionUnits() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // definitionUnits()const
                QPageSize::Unit cppResult = const_cast<const ::QPageSize *>(cppSelf)->definitionUnits();
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_Unit_IDX])))->converter, &cppResult);
            }
            break;
        }
        case 1: // definitionUnits(QPageSize::PageSizeId pageSizeId)
        {
            ::QPageSize::PageSizeId cppArg0{QPageSize::AnsiA};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // definitionUnits(QPageSize::PageSizeId)
                QPageSize::Unit cppResult = ::QPageSize::definitionUnits(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_Unit_IDX])))->converter, &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageSizeFunc_id(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QPageSize *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.id";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:id", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPageSize::id()const->QPageSize::PageSizeId
    // 1: static QPageSize::id(QSize,QPageSize::SizeMatchPolicy=)->QPageSize::PageSizeId
    // 2: static QPageSize::id(QSizeF,QPageSize::Unit,QPageSize::SizeMatchPolicy=)->QPageSize::PageSizeId
    // 3: static QPageSize::id(int)->QPageSize::PageSizeId
    if (numArgs == 0) {
        overloadId = 0; // id()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 3; // id(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // id(QSize,QPageSize::SizeMatchPolicy)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_SizeMatchPolicy_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // id(QSize,QPageSize::SizeMatchPolicy)
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_Unit_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // id(QSizeF,QPageSize::Unit,QPageSize::SizeMatchPolicy)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_SizeMatchPolicy_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 2; // id(QSizeF,QPageSize::Unit,QPageSize::SizeMatchPolicy)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // id() const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // id()const
                QPageSize::PageSizeId cppResult = const_cast<const ::QPageSize *>(cppSelf)->id();
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))->converter, &cppResult);
            }
            break;
        }
        case 1: // id(const QSize & pointSize, QPageSize::SizeMatchPolicy matchPolicy)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_matchPolicy = Shiboken::String::createStaticString("matchPolicy");
                if (PyDict_Contains(kwds, key_matchPolicy) != 0) {
                    value = PyDict_GetItem(kwds, key_matchPolicy);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_matchPolicy);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_SizeMatchPolicy_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_matchPolicy);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSize cppArg0_local;
            ::QSize *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QPageSize::SizeMatchPolicy cppArg1(QPageSize::SizeMatchPolicy::FuzzyMatch);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // id(QSize,QPageSize::SizeMatchPolicy)
                QPageSize::PageSizeId cppResult = ::QPageSize::id(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))->converter, &cppResult);
            }
            break;
        }
        case 2: // id(const QSizeF & size, QPageSize::Unit units, QPageSize::SizeMatchPolicy matchPolicy)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_matchPolicy = Shiboken::String::createStaticString("matchPolicy");
                if (PyDict_Contains(kwds, key_matchPolicy) != 0) {
                    value = PyDict_GetItem(kwds, key_matchPolicy);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_matchPolicy);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_SizeMatchPolicy_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_matchPolicy);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSizeF cppArg0_local;
            ::QSizeF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QPageSize::Unit cppArg1{QPageSize::Millimeter};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QPageSize::SizeMatchPolicy cppArg2(QPageSize::SizeMatchPolicy::FuzzyMatch);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // id(QSizeF,QPageSize::Unit,QPageSize::SizeMatchPolicy)
                QPageSize::PageSizeId cppResult = ::QPageSize::id(*cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))->converter, &cppResult);
            }
            break;
        }
        case 3: // id(int windowsId)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // id(int)
                QPageSize::PageSizeId cppResult = ::QPageSize::id(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))->converter, &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageSizeFunc_isEquivalentTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.isEquivalentTo";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPageSize::isEquivalentTo(QPageSize)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), (pyArg)))) {
        overloadId = 0; // isEquivalentTo(QPageSize)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPageSize cppArg0_local;
        ::QPageSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isEquivalentTo(QPageSize)const
            bool cppResult = const_cast<const ::QPageSize *>(cppSelf)->isEquivalentTo(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageSizeFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QPageSize *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageSizeFunc_key(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QPageSize *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.key";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "key", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPageSize::key()const->QString
    // 1: static QPageSize::key(QPageSize::PageSizeId)->QString
    if (numArgs == 0) {
        overloadId = 0; // key()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // key(QPageSize::PageSizeId)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // key() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // key()const
                QString cppResult = const_cast<const ::QPageSize *>(cppSelf)->key();
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // key(QPageSize::PageSizeId pageSizeId)
        {
            ::QPageSize::PageSizeId cppArg0{QPageSize::AnsiA};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // key(QPageSize::PageSizeId)
                QString cppResult = ::QPageSize::key(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageSizeFunc_name(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QPageSize *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.name";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "name", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPageSize::name()const->QString
    // 1: static QPageSize::name(QPageSize::PageSizeId)->QString
    if (numArgs == 0) {
        overloadId = 0; // name()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // name(QPageSize::PageSizeId)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // name() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // name()const
                QString cppResult = const_cast<const ::QPageSize *>(cppSelf)->name();
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // name(QPageSize::PageSizeId pageSizeId)
        {
            ::QPageSize::PageSizeId cppArg0{QPageSize::AnsiA};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // name(QPageSize::PageSizeId)
                QString cppResult = ::QPageSize::name(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageSizeFunc_rect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.rect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPageSize::rect(QPageSize::Unit)const->QRectF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_Unit_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // rect(QPageSize::Unit)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QPageSize::Unit cppArg0{QPageSize::Millimeter};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rect(QPageSize::Unit)const
            QRectF cppResult = const_cast<const ::QPageSize *>(cppSelf)->rect(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageSizeFunc_rectPixels(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.rectPixels";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPageSize::rectPixels(int)const->QRect
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // rectPixels(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rectPixels(int)const
            QRect cppResult = const_cast<const ::QPageSize *>(cppSelf)->rectPixels(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageSizeFunc_rectPoints(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.rectPoints";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // rectPoints()const
            QRect cppResult = const_cast<const ::QPageSize *>(cppSelf)->rectPoints();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageSizeFunc_size(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QPageSize *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.size";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "size", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QPageSize::size(QPageSize::PageSizeId,QPageSize::Unit)->QSizeF
    // 1: QPageSize::size(QPageSize::Unit)const->QSizeF
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_Unit_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // size(QPageSize::Unit)const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_Unit_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // size(QPageSize::PageSizeId,QPageSize::Unit)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // size(QPageSize::PageSizeId pageSizeId, QPageSize::Unit units)
        {
            ::QPageSize::PageSizeId cppArg0{QPageSize::AnsiA};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QPageSize::Unit cppArg1{QPageSize::Millimeter};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // size(QPageSize::PageSizeId,QPageSize::Unit)
                QSizeF cppResult = ::QPageSize::size(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
            }
            break;
        }
        case 1: // size(QPageSize::Unit units) const
        {
            ::QPageSize::Unit cppArg0{QPageSize::Millimeter};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // size(QPageSize::Unit)const
                QSizeF cppResult = const_cast<const ::QPageSize *>(cppSelf)->size(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageSizeFunc_sizePixels(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QPageSize *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.sizePixels";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sizePixels", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QPageSize::sizePixels(QPageSize::PageSizeId,int)->QSize
    // 1: QPageSize::sizePixels(int)const->QSize
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // sizePixels(QPageSize::PageSizeId,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 1; // sizePixels(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // sizePixels(QPageSize::PageSizeId pageSizeId, int resolution)
        {
            ::QPageSize::PageSizeId cppArg0{QPageSize::AnsiA};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sizePixels(QPageSize::PageSizeId,int)
                QSize cppResult = ::QPageSize::sizePixels(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
            }
            break;
        }
        case 1: // sizePixels(int resolution) const
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sizePixels(int)const
                QSize cppResult = const_cast<const ::QPageSize *>(cppSelf)->sizePixels(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageSizeFunc_sizePoints(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QPageSize *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.sizePoints";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sizePoints", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPageSize::sizePoints()const->QSize
    // 1: static QPageSize::sizePoints(QPageSize::PageSizeId)->QSize
    if (numArgs == 0) {
        overloadId = 0; // sizePoints()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // sizePoints(QPageSize::PageSizeId)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // sizePoints() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // sizePoints()const
                QSize cppResult = const_cast<const ::QPageSize *>(cppSelf)->sizePoints();
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
            }
            break;
        }
        case 1: // sizePoints(QPageSize::PageSizeId pageSizeId)
        {
            ::QPageSize::PageSizeId cppArg0{QPageSize::AnsiA};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sizePoints(QPageSize::PageSizeId)
                QSize cppResult = ::QPageSize::sizePoints(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageSizeFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPageSize::swap(QPageSize&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QPageSize&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPageSize cppArg0_local;
        ::QPageSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QPageSize&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPageSizeFunc_windowsId(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QPageSize *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPageSize.windowsId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "windowsId", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPageSize::windowsId()const->int
    // 1: static QPageSize::windowsId(QPageSize::PageSizeId)->int
    if (numArgs == 0) {
        overloadId = 0; // windowsId()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // windowsId(QPageSize::PageSizeId)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // windowsId() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // windowsId()const
                int cppResult = const_cast<const ::QPageSize *>(cppSelf)->windowsId();
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
        case 1: // windowsId(QPageSize::PageSizeId pageSizeId)
        {
            ::QPageSize::PageSizeId cppArg0{QPageSize::AnsiA};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // windowsId(QPageSize::PageSizeId)
                int cppResult = ::QPageSize::windowsId(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPageSize__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QPageSizeMethod_definitionSize = {"definitionSize", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_definitionSize), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QPageSizeMethod_definitionUnits = {"definitionUnits", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_definitionUnits), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QPageSizeMethod_id = {"id", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_id), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QPageSizeMethod_key = {"key", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_key), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QPageSizeMethod_name = {"name", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_name), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QPageSizeMethod_size = {"size", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_size), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QPageSizeMethod_sizePixels = {"sizePixels", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_sizePixels), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QPageSizeMethod_sizePoints = {"sizePoints", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_sizePoints), METH_VARARGS|METH_STATIC, nullptr};

static PyMethodDef Sbk_QPageSizeMethod_windowsId = {"windowsId", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_windowsId), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_QPageSize_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QPageSize_EnumFlagInfo[] = {
    "PageSizeId:Enum",
    "SizeMatchPolicy:Enum",
    "Unit:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPageSize_methods[] = {
    {"definitionSize", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_definitionSize), METH_VARARGS|METH_STATIC, nullptr},
    {"definitionUnits", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_definitionUnits), METH_VARARGS|METH_STATIC, nullptr},
    {"id", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_id), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"isEquivalentTo", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_isEquivalentTo), METH_O, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_isValid), METH_NOARGS, nullptr},
    {"key", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_key), METH_VARARGS|METH_STATIC, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_name), METH_VARARGS|METH_STATIC, nullptr},
    {"rect", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_rect), METH_O, nullptr},
    {"rectPixels", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_rectPixels), METH_O, nullptr},
    {"rectPoints", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_rectPoints), METH_NOARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_size), METH_VARARGS|METH_STATIC, nullptr},
    {"sizePixels", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_sizePixels), METH_VARARGS|METH_STATIC, nullptr},
    {"sizePoints", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_sizePoints), METH_VARARGS|METH_STATIC, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_swap), METH_O, nullptr},
    {"windowsId", reinterpret_cast<PyCFunction>(Sbk_QPageSizeFunc_windowsId), METH_VARARGS|METH_STATIC, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPageSize__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QPageSize_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QPageSizeMethod_definitionSize = {
        Sbk_QPageSizeMethod_definitionSize.ml_name,
        Sbk_QPageSizeMethod_definitionSize.ml_meth,
        Sbk_QPageSizeMethod_definitionSize.ml_flags & (~METH_STATIC),
        Sbk_QPageSizeMethod_definitionSize.ml_doc,
    };
    if (Shiboken::String::compare(name, "definitionSize") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QPageSizeMethod_definitionSize, self, 0);
    static PyMethodDef non_static_Sbk_QPageSizeMethod_definitionUnits = {
        Sbk_QPageSizeMethod_definitionUnits.ml_name,
        Sbk_QPageSizeMethod_definitionUnits.ml_meth,
        Sbk_QPageSizeMethod_definitionUnits.ml_flags & (~METH_STATIC),
        Sbk_QPageSizeMethod_definitionUnits.ml_doc,
    };
    if (Shiboken::String::compare(name, "definitionUnits") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QPageSizeMethod_definitionUnits, self, 0);
    static PyMethodDef non_static_Sbk_QPageSizeMethod_id = {
        Sbk_QPageSizeMethod_id.ml_name,
        Sbk_QPageSizeMethod_id.ml_meth,
        Sbk_QPageSizeMethod_id.ml_flags & (~METH_STATIC),
        Sbk_QPageSizeMethod_id.ml_doc,
    };
    if (Shiboken::String::compare(name, "id") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QPageSizeMethod_id, self, 0);
    static PyMethodDef non_static_Sbk_QPageSizeMethod_key = {
        Sbk_QPageSizeMethod_key.ml_name,
        Sbk_QPageSizeMethod_key.ml_meth,
        Sbk_QPageSizeMethod_key.ml_flags & (~METH_STATIC),
        Sbk_QPageSizeMethod_key.ml_doc,
    };
    if (Shiboken::String::compare(name, "key") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QPageSizeMethod_key, self, 0);
    static PyMethodDef non_static_Sbk_QPageSizeMethod_name = {
        Sbk_QPageSizeMethod_name.ml_name,
        Sbk_QPageSizeMethod_name.ml_meth,
        Sbk_QPageSizeMethod_name.ml_flags & (~METH_STATIC),
        Sbk_QPageSizeMethod_name.ml_doc,
    };
    if (Shiboken::String::compare(name, "name") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QPageSizeMethod_name, self, 0);
    static PyMethodDef non_static_Sbk_QPageSizeMethod_size = {
        Sbk_QPageSizeMethod_size.ml_name,
        Sbk_QPageSizeMethod_size.ml_meth,
        Sbk_QPageSizeMethod_size.ml_flags & (~METH_STATIC),
        Sbk_QPageSizeMethod_size.ml_doc,
    };
    if (Shiboken::String::compare(name, "size") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QPageSizeMethod_size, self, 0);
    static PyMethodDef non_static_Sbk_QPageSizeMethod_sizePixels = {
        Sbk_QPageSizeMethod_sizePixels.ml_name,
        Sbk_QPageSizeMethod_sizePixels.ml_meth,
        Sbk_QPageSizeMethod_sizePixels.ml_flags & (~METH_STATIC),
        Sbk_QPageSizeMethod_sizePixels.ml_doc,
    };
    if (Shiboken::String::compare(name, "sizePixels") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QPageSizeMethod_sizePixels, self, 0);
    static PyMethodDef non_static_Sbk_QPageSizeMethod_sizePoints = {
        Sbk_QPageSizeMethod_sizePoints.ml_name,
        Sbk_QPageSizeMethod_sizePoints.ml_meth,
        Sbk_QPageSizeMethod_sizePoints.ml_flags & (~METH_STATIC),
        Sbk_QPageSizeMethod_sizePoints.ml_doc,
    };
    if (Shiboken::String::compare(name, "sizePoints") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QPageSizeMethod_sizePoints, self, 0);
    static PyMethodDef non_static_Sbk_QPageSizeMethod_windowsId = {
        Sbk_QPageSizeMethod_windowsId.ml_name,
        Sbk_QPageSizeMethod_windowsId.ml_meth,
        Sbk_QPageSizeMethod_windowsId.ml_flags & (~METH_STATIC),
        Sbk_QPageSizeMethod_windowsId.ml_doc,
    };
    if (Shiboken::String::compare(name, "windowsId") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QPageSizeMethod_windowsId, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

// Rich comparison
static PyObject * Sbk_QPageSize_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), (pyArg)))) {
                // operator!=(const QPageSize & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPageSize cppArg0_local;
                ::QPageSize *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), (pyArg)))) {
                // operator==(const QPageSize & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPageSize cppArg0_local;
                ::QPageSize *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QPageSize_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPageSize_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QPageSize__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPageSize_Type = nullptr;
static PyTypeObject *Sbk_QPageSize_TypeF(void)
{
    return _Sbk_QPageSize_Type;
}

static PyType_Slot Sbk_QPageSize_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QPageSize__repr__)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QPageSize_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPageSize_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPageSize_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QPageSize_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPageSize_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPageSize_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPageSize_spec = {
    "2:PySide6.QtGui.QPageSize",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPageSize_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QPageSize_PageSizeId_PythonToCpp_QPageSize_PageSizeId(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPageSize::PageSizeId>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPageSize::PageSizeId *>(cppOut) = value;

}
static PythonToCppFunc is_QPageSize_PageSizeId_PythonToCpp_QPageSize_PageSizeId_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))
        return QPageSize_PageSizeId_PythonToCpp_QPageSize_PageSizeId;
    return {};
}
static PyObject *QPageSize_PageSizeId_CppToPython_QPageSize_PageSizeId(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPageSize::PageSizeId *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX]), castCppIn);

}

static void QPageSize_Unit_PythonToCpp_QPageSize_Unit(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPageSize::Unit>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPageSize::Unit *>(cppOut) = value;

}
static PythonToCppFunc is_QPageSize_Unit_PythonToCpp_QPageSize_Unit_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_Unit_IDX])))
        return QPageSize_Unit_PythonToCpp_QPageSize_Unit;
    return {};
}
static PyObject *QPageSize_Unit_CppToPython_QPageSize_Unit(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPageSize::Unit *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_Unit_IDX]), castCppIn);

}

static void QPageSize_SizeMatchPolicy_PythonToCpp_QPageSize_SizeMatchPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPageSize::SizeMatchPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPageSize::SizeMatchPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_QPageSize_SizeMatchPolicy_PythonToCpp_QPageSize_SizeMatchPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_SizeMatchPolicy_IDX])))
        return QPageSize_SizeMatchPolicy_PythonToCpp_QPageSize_SizeMatchPolicy;
    return {};
}
static PyObject *QPageSize_SizeMatchPolicy_CppToPython_QPageSize_SizeMatchPolicy(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPageSize::SizeMatchPolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_SizeMatchPolicy_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPageSize_PythonToCpp_QPageSize_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPageSize_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPageSize_PythonToCpp_QPageSize_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPageSize_TypeF()))
        return QPageSize_PythonToCpp_QPageSize_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPageSize_PTR_CppToPython_QPageSize(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QPageSize *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QPageSize_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QPageSize_COPY_CppToPython_QPageSize(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPageSize *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPageSize_TypeF(), new ::QPageSize(*source), true, true);
}

// Python to C++ copy conversion.
static void QPageSize_PythonToCpp_QPageSize_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPageSize *>(cppOut) = *reinterpret_cast< ::QPageSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QPageSize_PythonToCpp_QPageSize_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPageSize_TypeF()))
        return QPageSize_PythonToCpp_QPageSize_COPY;
    return {};
}

// Implicit conversions.
static void QPageSize_PageSizeId_PythonToCpp_QPageSize(PyObject *pyIn, void *cppOut)
{
    ::QPageSize::PageSizeId cppIn{QPageSize::AnsiA};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QPageSize *>(cppOut) = ::QPageSize(cppIn);
}
static PythonToCppFunc is_QPageSize_PageSizeId_PythonToCpp_QPageSize_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX]), pyIn))
        return QPageSize_PageSizeId_PythonToCpp_QPageSize;
    return {};
}

static void PySide6_QtCore_constQSizeREF_PythonToCpp_QPageSize(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPageSize *>(cppOut) = ::QPageSize( *reinterpret_cast< ::QSize *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_PySide6_QtCore_constQSizeREF_PythonToCpp_QPageSize_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyIn))
        return PySide6_QtCore_constQSizeREF_PythonToCpp_QPageSize;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QPageSize_SignatureStrings[] = {
    "4:PySide6.QtGui.QPageSize(self)",
    "3:PySide6.QtGui.QPageSize(self,pageSizeId:PySide6.QtGui.QPageSize.PageSizeId)",
    "2:PySide6.QtGui.QPageSize(self,other:typing.Union[PySide6.QtGui.QPageSize, PySide6.QtGui.QPageSize.PageSizeId, PySide6.QtCore.QSize])",
    "1:PySide6.QtGui.QPageSize(self,pointSize:PySide6.QtCore.QSize,name:QString=QString(),matchPolicy:PySide6.QtGui.QPageSize.SizeMatchPolicy=QPageSize.SizeMatchPolicy.FuzzyMatch)",
    "0:PySide6.QtGui.QPageSize(self,size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize],units:PySide6.QtGui.QPageSize.Unit,name:QString=QString(),matchPolicy:PySide6.QtGui.QPageSize.SizeMatchPolicy=QPageSize.SizeMatchPolicy.FuzzyMatch)",
    "1:PySide6.QtGui.QPageSize.definitionSize(self)->PySide6.QtCore.QSizeF",
    "0:PySide6.QtGui.QPageSize.definitionSize(pageSizeId:PySide6.QtGui.QPageSize.PageSizeId)->PySide6.QtCore.QSizeF",
    "1:PySide6.QtGui.QPageSize.definitionUnits(self)->PySide6.QtGui.QPageSize.Unit",
    "0:PySide6.QtGui.QPageSize.definitionUnits(pageSizeId:PySide6.QtGui.QPageSize.PageSizeId)->PySide6.QtGui.QPageSize.Unit",
    "3:PySide6.QtGui.QPageSize.id(self)->PySide6.QtGui.QPageSize.PageSizeId",
    "2:PySide6.QtGui.QPageSize.id(pointSize:PySide6.QtCore.QSize,matchPolicy:PySide6.QtGui.QPageSize.SizeMatchPolicy=QPageSize.SizeMatchPolicy.FuzzyMatch)->PySide6.QtGui.QPageSize.PageSizeId",
    "1:PySide6.QtGui.QPageSize.id(size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize],units:PySide6.QtGui.QPageSize.Unit,matchPolicy:PySide6.QtGui.QPageSize.SizeMatchPolicy=QPageSize.SizeMatchPolicy.FuzzyMatch)->PySide6.QtGui.QPageSize.PageSizeId",
    "0:PySide6.QtGui.QPageSize.id(windowsId:int)->PySide6.QtGui.QPageSize.PageSizeId",
    "PySide6.QtGui.QPageSize.isEquivalentTo(self,other:typing.Union[PySide6.QtGui.QPageSize, PySide6.QtGui.QPageSize.PageSizeId, PySide6.QtCore.QSize])->bool",
    "PySide6.QtGui.QPageSize.isValid(self)->bool",
    "1:PySide6.QtGui.QPageSize.key(self)->QString",
    "0:PySide6.QtGui.QPageSize.key(pageSizeId:PySide6.QtGui.QPageSize.PageSizeId)->QString",
    "1:PySide6.QtGui.QPageSize.name(self)->QString",
    "0:PySide6.QtGui.QPageSize.name(pageSizeId:PySide6.QtGui.QPageSize.PageSizeId)->QString",
    "PySide6.QtGui.QPageSize.rect(self,units:PySide6.QtGui.QPageSize.Unit)->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QPageSize.rectPixels(self,resolution:int)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QPageSize.rectPoints(self)->PySide6.QtCore.QRect",
    "1:PySide6.QtGui.QPageSize.size(pageSizeId:PySide6.QtGui.QPageSize.PageSizeId,units:PySide6.QtGui.QPageSize.Unit)->PySide6.QtCore.QSizeF",
    "0:PySide6.QtGui.QPageSize.size(self,units:PySide6.QtGui.QPageSize.Unit)->PySide6.QtCore.QSizeF",
    "1:PySide6.QtGui.QPageSize.sizePixels(pageSizeId:PySide6.QtGui.QPageSize.PageSizeId,resolution:int)->PySide6.QtCore.QSize",
    "0:PySide6.QtGui.QPageSize.sizePixels(self,resolution:int)->PySide6.QtCore.QSize",
    "1:PySide6.QtGui.QPageSize.sizePoints(self)->PySide6.QtCore.QSize",
    "0:PySide6.QtGui.QPageSize.sizePoints(pageSizeId:PySide6.QtGui.QPageSize.PageSizeId)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QPageSize.swap(self,other:typing.Union[PySide6.QtGui.QPageSize, PySide6.QtGui.QPageSize.PageSizeId, PySide6.QtCore.QSize])",
    "1:PySide6.QtGui.QPageSize.windowsId(self)->int",
    "0:PySide6.QtGui.QPageSize.windowsId(pageSizeId:PySide6.QtGui.QPageSize.PageSizeId)->int",
    "PySide6.QtGui.QPageSize.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QPageSize(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX].type;

    Shiboken::AutoDecRef Sbk_QPageSize_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPageSize_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPageSize",
        "QPageSize",
        &Sbk_QPageSize_spec,
        &Shiboken::callCppDestructor< ::QPageSize >,
        Sbk_QPageSize_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPageSize_TypeF(); // references _Sbk_QPageSize_Type
    InitSignatureStrings(pyType, QPageSize_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPageSize_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPageSize_PythonToCpp_QPageSize_PTR,
        is_QPageSize_PythonToCpp_QPageSize_PTR_Convertible,
        QPageSize_PTR_CppToPython_QPageSize,
        QPageSize_COPY_CppToPython_QPageSize);

    Shiboken::Conversions::registerConverterName(converter, "QPageSize");
    Shiboken::Conversions::registerConverterName(converter, "QPageSize*");
    Shiboken::Conversions::registerConverterName(converter, "QPageSize&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPageSize).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPageSize_PythonToCpp_QPageSize_COPY,
        is_QPageSize_PythonToCpp_QPageSize_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPageSize_PageSizeId_PythonToCpp_QPageSize,
        is_QPageSize_PageSizeId_PythonToCpp_QPageSize_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_constQSizeREF_PythonToCpp_QPageSize,
        is_PySide6_QtCore_constQSizeREF_PythonToCpp_QPageSize_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPageSize_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'PageSizeId'.
    const char *PageSizeId_Initializer[] = {
        "Letter",
        "Legal",
        "Executive",
        "A0",
        "A1",
        "A2",
        "A3",
        "A4",
        "A5",
        "A6",
        "A7",
        "A8",
        "A9",
        "A10",
        "B0",
        "B1",
        "B2",
        "B3",
        "B4",
        "B5",
        "B6",
        "B7",
        "B8",
        "B9",
        "B10",
        "C5E",
        "Comm10E",
        "DLE",
        "Folio",
        "Ledger",
        "Tabloid",
        "Custom",
        "A3Extra",
        "A4Extra",
        "A4Plus",
        "A4Small",
        "A5Extra",
        "B5Extra",
        "JisB0",
        "JisB1",
        "JisB2",
        "JisB3",
        "JisB4",
        "JisB5",
        "JisB6",
        "JisB7",
        "JisB8",
        "JisB9",
        "JisB10",
        "AnsiC",
        "AnsiD",
        "AnsiE",
        "LegalExtra",
        "LetterExtra",
        "LetterPlus",
        "LetterSmall",
        "TabloidExtra",
        "ArchA",
        "ArchB",
        "ArchC",
        "ArchD",
        "ArchE",
        "Imperial7x9",
        "Imperial8x10",
        "Imperial9x11",
        "Imperial9x12",
        "Imperial10x11",
        "Imperial10x13",
        "Imperial10x14",
        "Imperial12x11",
        "Imperial15x11",
        "ExecutiveStandard",
        "Note",
        "Quarto",
        "Statement",
        "SuperA",
        "SuperB",
        "Postcard",
        "DoublePostcard",
        "Prc16K",
        "Prc32K",
        "Prc32KBig",
        "FanFoldUS",
        "FanFoldGerman",
        "FanFoldGermanLegal",
        "EnvelopeB4",
        "EnvelopeB5",
        "EnvelopeB6",
        "EnvelopeC0",
        "EnvelopeC1",
        "EnvelopeC2",
        "EnvelopeC3",
        "EnvelopeC4",
        "EnvelopeC6",
        "EnvelopeC65",
        "EnvelopeC7",
        "Envelope9",
        "Envelope11",
        "Envelope12",
        "Envelope14",
        "EnvelopeMonarch",
        "EnvelopePersonal",
        "EnvelopeChou3",
        "EnvelopeChou4",
        "EnvelopeInvite",
        "EnvelopeItalian",
        "EnvelopeKaku2",
        "EnvelopeKaku3",
        "EnvelopePrc1",
        "EnvelopePrc2",
        "EnvelopePrc3",
        "EnvelopePrc4",
        "EnvelopePrc5",
        "EnvelopePrc6",
        "EnvelopePrc7",
        "EnvelopePrc8",
        "EnvelopePrc9",
        "EnvelopePrc10",
        "EnvelopeYou4",
        "LastPageSize",
        "AnsiA",
        "AnsiB",
        "EnvelopeC5",
        "EnvelopeDL",
        "Envelope10",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PageSizeId_InitializerValues[] = {
        uint8_t(QPageSize::PageSizeId::Letter),             //  0x00  0
        uint8_t(QPageSize::PageSizeId::Legal),              //  0x01  1
        uint8_t(QPageSize::PageSizeId::Executive),          //  0x02  2
        uint8_t(QPageSize::PageSizeId::A0),                 //  0x03  3
        uint8_t(QPageSize::PageSizeId::A1),                 //  0x04  4
        uint8_t(QPageSize::PageSizeId::A2),                 //  0x05  5
        uint8_t(QPageSize::PageSizeId::A3),                 //  0x06  6
        uint8_t(QPageSize::PageSizeId::A4),                 //  0x07  7
        uint8_t(QPageSize::PageSizeId::A5),                 //  0x08  8
        uint8_t(QPageSize::PageSizeId::A6),                 //  0x09  9
        uint8_t(QPageSize::PageSizeId::A7),                 //  0x0a  10
        uint8_t(QPageSize::PageSizeId::A8),                 //  0x0b  11
        uint8_t(QPageSize::PageSizeId::A9),                 //  0x0c  12
        uint8_t(QPageSize::PageSizeId::A10),                //  0x0d  13
        uint8_t(QPageSize::PageSizeId::B0),                 //  0x0e  14
        uint8_t(QPageSize::PageSizeId::B1),                 //  0x0f  15
        uint8_t(QPageSize::PageSizeId::B2),                 //  0x10  16
        uint8_t(QPageSize::PageSizeId::B3),                 //  0x11  17
        uint8_t(QPageSize::PageSizeId::B4),                 //  0x12  18
        uint8_t(QPageSize::PageSizeId::B5),                 //  0x13  19
        uint8_t(QPageSize::PageSizeId::B6),                 //  0x14  20
        uint8_t(QPageSize::PageSizeId::B7),                 //  0x15  21
        uint8_t(QPageSize::PageSizeId::B8),                 //  0x16  22
        uint8_t(QPageSize::PageSizeId::B9),                 //  0x17  23
        uint8_t(QPageSize::PageSizeId::B10),                //  0x18  24
        uint8_t(QPageSize::PageSizeId::C5E),                //  0x19  25
        uint8_t(QPageSize::PageSizeId::Comm10E),            //  0x1a  26
        uint8_t(QPageSize::PageSizeId::DLE),                //  0x1b  27
        uint8_t(QPageSize::PageSizeId::Folio),              //  0x1c  28
        uint8_t(QPageSize::PageSizeId::Ledger),             //  0x1d  29
        uint8_t(QPageSize::PageSizeId::Tabloid),            //  0x1e  30
        uint8_t(QPageSize::PageSizeId::Custom),             //  0x1f  31
        uint8_t(QPageSize::PageSizeId::A3Extra),            //  0x20  32
        uint8_t(QPageSize::PageSizeId::A4Extra),            //  0x21  33
        uint8_t(QPageSize::PageSizeId::A4Plus),             //  0x22  34
        uint8_t(QPageSize::PageSizeId::A4Small),            //  0x23  35
        uint8_t(QPageSize::PageSizeId::A5Extra),            //  0x24  36
        uint8_t(QPageSize::PageSizeId::B5Extra),            //  0x25  37
        uint8_t(QPageSize::PageSizeId::JisB0),              //  0x26  38
        uint8_t(QPageSize::PageSizeId::JisB1),              //  0x27  39
        uint8_t(QPageSize::PageSizeId::JisB2),              //  0x28  40
        uint8_t(QPageSize::PageSizeId::JisB3),              //  0x29  41
        uint8_t(QPageSize::PageSizeId::JisB4),              //  0x2a  42
        uint8_t(QPageSize::PageSizeId::JisB5),              //  0x2b  43
        uint8_t(QPageSize::PageSizeId::JisB6),              //  0x2c  44
        uint8_t(QPageSize::PageSizeId::JisB7),              //  0x2d  45
        uint8_t(QPageSize::PageSizeId::JisB8),              //  0x2e  46
        uint8_t(QPageSize::PageSizeId::JisB9),              //  0x2f  47
        uint8_t(QPageSize::PageSizeId::JisB10),             //  0x30  48
        uint8_t(QPageSize::PageSizeId::AnsiC),              //  0x31  49
        uint8_t(QPageSize::PageSizeId::AnsiD),              //  0x32  50
        uint8_t(QPageSize::PageSizeId::AnsiE),              //  0x33  51
        uint8_t(QPageSize::PageSizeId::LegalExtra),         //  0x34  52
        uint8_t(QPageSize::PageSizeId::LetterExtra),        //  0x35  53
        uint8_t(QPageSize::PageSizeId::LetterPlus),         //  0x36  54
        uint8_t(QPageSize::PageSizeId::LetterSmall),        //  0x37  55
        uint8_t(QPageSize::PageSizeId::TabloidExtra),       //  0x38  56
        uint8_t(QPageSize::PageSizeId::ArchA),              //  0x39  57
        uint8_t(QPageSize::PageSizeId::ArchB),              //  0x3a  58
        uint8_t(QPageSize::PageSizeId::ArchC),              //  0x3b  59
        uint8_t(QPageSize::PageSizeId::ArchD),              //  0x3c  60
        uint8_t(QPageSize::PageSizeId::ArchE),              //  0x3d  61
        uint8_t(QPageSize::PageSizeId::Imperial7x9),        //  0x3e  62
        uint8_t(QPageSize::PageSizeId::Imperial8x10),       //  0x3f  63
        uint8_t(QPageSize::PageSizeId::Imperial9x11),       //  0x40  64
        uint8_t(QPageSize::PageSizeId::Imperial9x12),       //  0x41  65
        uint8_t(QPageSize::PageSizeId::Imperial10x11),      //  0x42  66
        uint8_t(QPageSize::PageSizeId::Imperial10x13),      //  0x43  67
        uint8_t(QPageSize::PageSizeId::Imperial10x14),      //  0x44  68
        uint8_t(QPageSize::PageSizeId::Imperial12x11),      //  0x45  69
        uint8_t(QPageSize::PageSizeId::Imperial15x11),      //  0x46  70
        uint8_t(QPageSize::PageSizeId::ExecutiveStandard),  //  0x47  71
        uint8_t(QPageSize::PageSizeId::Note),               //  0x48  72
        uint8_t(QPageSize::PageSizeId::Quarto),             //  0x49  73
        uint8_t(QPageSize::PageSizeId::Statement),          //  0x4a  74
        uint8_t(QPageSize::PageSizeId::SuperA),             //  0x4b  75
        uint8_t(QPageSize::PageSizeId::SuperB),             //  0x4c  76
        uint8_t(QPageSize::PageSizeId::Postcard),           //  0x4d  77
        uint8_t(QPageSize::PageSizeId::DoublePostcard),     //  0x4e  78
        uint8_t(QPageSize::PageSizeId::Prc16K),             //  0x4f  79
        uint8_t(QPageSize::PageSizeId::Prc32K),             //  0x50  80
        uint8_t(QPageSize::PageSizeId::Prc32KBig),          //  0x51  81
        uint8_t(QPageSize::PageSizeId::FanFoldUS),          //  0x52  82
        uint8_t(QPageSize::PageSizeId::FanFoldGerman),      //  0x53  83
        uint8_t(QPageSize::PageSizeId::FanFoldGermanLegal), //  0x54  84
        uint8_t(QPageSize::PageSizeId::EnvelopeB4),         //  0x55  85
        uint8_t(QPageSize::PageSizeId::EnvelopeB5),         //  0x56  86
        uint8_t(QPageSize::PageSizeId::EnvelopeB6),         //  0x57  87
        uint8_t(QPageSize::PageSizeId::EnvelopeC0),         //  0x58  88
        uint8_t(QPageSize::PageSizeId::EnvelopeC1),         //  0x59  89
        uint8_t(QPageSize::PageSizeId::EnvelopeC2),         //  0x5a  90
        uint8_t(QPageSize::PageSizeId::EnvelopeC3),         //  0x5b  91
        uint8_t(QPageSize::PageSizeId::EnvelopeC4),         //  0x5c  92
        uint8_t(QPageSize::PageSizeId::EnvelopeC6),         //  0x5d  93
        uint8_t(QPageSize::PageSizeId::EnvelopeC65),        //  0x5e  94
        uint8_t(QPageSize::PageSizeId::EnvelopeC7),         //  0x5f  95
        uint8_t(QPageSize::PageSizeId::Envelope9),          //  0x60  96
        uint8_t(QPageSize::PageSizeId::Envelope11),         //  0x61  97
        uint8_t(QPageSize::PageSizeId::Envelope12),         //  0x62  98
        uint8_t(QPageSize::PageSizeId::Envelope14),         //  0x63  99
        uint8_t(QPageSize::PageSizeId::EnvelopeMonarch),    //  0x64  100
        uint8_t(QPageSize::PageSizeId::EnvelopePersonal),   //  0x65  101
        uint8_t(QPageSize::PageSizeId::EnvelopeChou3),      //  0x66  102
        uint8_t(QPageSize::PageSizeId::EnvelopeChou4),      //  0x67  103
        uint8_t(QPageSize::PageSizeId::EnvelopeInvite),     //  0x68  104
        uint8_t(QPageSize::PageSizeId::EnvelopeItalian),    //  0x69  105
        uint8_t(QPageSize::PageSizeId::EnvelopeKaku2),      //  0x6a  106
        uint8_t(QPageSize::PageSizeId::EnvelopeKaku3),      //  0x6b  107
        uint8_t(QPageSize::PageSizeId::EnvelopePrc1),       //  0x6c  108
        uint8_t(QPageSize::PageSizeId::EnvelopePrc2),       //  0x6d  109
        uint8_t(QPageSize::PageSizeId::EnvelopePrc3),       //  0x6e  110
        uint8_t(QPageSize::PageSizeId::EnvelopePrc4),       //  0x6f  111
        uint8_t(QPageSize::PageSizeId::EnvelopePrc5),       //  0x70  112
        uint8_t(QPageSize::PageSizeId::EnvelopePrc6),       //  0x71  113
        uint8_t(QPageSize::PageSizeId::EnvelopePrc7),       //  0x72  114
        uint8_t(QPageSize::PageSizeId::EnvelopePrc8),       //  0x73  115
        uint8_t(QPageSize::PageSizeId::EnvelopePrc9),       //  0x74  116
        uint8_t(QPageSize::PageSizeId::EnvelopePrc10),      //  0x75  117
        uint8_t(QPageSize::PageSizeId::EnvelopeYou4),       //  0x76  118
        uint8_t(QPageSize::PageSizeId::LastPageSize),       //  0x76  118
        uint8_t(QPageSize::PageSizeId::AnsiA),              //  0x00  0
        uint8_t(QPageSize::PageSizeId::AnsiB),              //  0x1d  29
        uint8_t(QPageSize::PageSizeId::EnvelopeC5),         //  0x19  25
        uint8_t(QPageSize::PageSizeId::EnvelopeDL),         //  0x1b  27
        uint8_t(QPageSize::PageSizeId::Envelope10)          //  0x1a  26
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPageSize_TypeF(),
        "2:PySide6.QtGui.QPageSize.PageSizeId",
        PageSizeId_Initializer, PageSizeId_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_PageSizeId_IDX].type = EType;
    // Register converter for enum 'QPageSize::PageSizeId'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPageSize_PageSizeId_CppToPython_QPageSize_PageSizeId);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QPageSize_PageSizeId_PythonToCpp_QPageSize_PageSizeId,
            is_QPageSize_PageSizeId_PythonToCpp_QPageSize_PageSizeId_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPageSize::PageSizeId");
        Shiboken::Conversions::registerConverterName(converter, "PageSizeId");
    }
    // End of 'PageSizeId' enum.

    // Initialization of enum 'Unit'.
    const char *Unit_Initializer[] = {
        "Millimeter",
        "Point",
        "Inch",
        "Pica",
        "Didot",
        "Cicero",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Unit_InitializerValues[] = {
        uint8_t(QPageSize::Unit::Millimeter), //  0x00  0
        uint8_t(QPageSize::Unit::Point),      //  0x01  1
        uint8_t(QPageSize::Unit::Inch),       //  0x02  2
        uint8_t(QPageSize::Unit::Pica),       //  0x03  3
        uint8_t(QPageSize::Unit::Didot),      //  0x04  4
        uint8_t(QPageSize::Unit::Cicero)      //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPageSize_TypeF(),
        "2:PySide6.QtGui.QPageSize.Unit",
        Unit_Initializer, Unit_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_Unit_IDX].type = EType;
    // Register converter for enum 'QPageSize::Unit'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPageSize_Unit_CppToPython_QPageSize_Unit);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QPageSize_Unit_PythonToCpp_QPageSize_Unit,
            is_QPageSize_Unit_PythonToCpp_QPageSize_Unit_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPageSize::Unit");
        Shiboken::Conversions::registerConverterName(converter, "Unit");
    }
    // End of 'Unit' enum.

    // Initialization of enum 'SizeMatchPolicy'.
    const char *SizeMatchPolicy_Initializer[] = {
        "FuzzyMatch",
        "FuzzyOrientationMatch",
        "ExactMatch",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SizeMatchPolicy_InitializerValues[] = {
        uint8_t(QPageSize::SizeMatchPolicy::FuzzyMatch),            //  0x00  0
        uint8_t(QPageSize::SizeMatchPolicy::FuzzyOrientationMatch), //  0x01  1
        uint8_t(QPageSize::SizeMatchPolicy::ExactMatch)             //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPageSize_TypeF(),
        "2:PySide6.QtGui.QPageSize.SizeMatchPolicy",
        SizeMatchPolicy_Initializer, SizeMatchPolicy_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_SizeMatchPolicy_IDX].type = EType;
    // Register converter for enum 'QPageSize::SizeMatchPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPageSize_SizeMatchPolicy_CppToPython_QPageSize_SizeMatchPolicy);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QPageSize_SizeMatchPolicy_PythonToCpp_QPageSize_SizeMatchPolicy,
            is_QPageSize_SizeMatchPolicy_PythonToCpp_QPageSize_SizeMatchPolicy_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPageSize::SizeMatchPolicy");
        Shiboken::Conversions::registerConverterName(converter, "SizeMatchPolicy");
    }
    // End of 'SizeMatchPolicy' enum.

    qRegisterMetaType< ::QPageSize::PageSizeId >("QPageSize::PageSizeId");
    qRegisterMetaType< ::QPageSize::Unit >("QPageSize::Unit");
    qRegisterMetaType< ::QPageSize::SizeMatchPolicy >("QPageSize::SizeMatchPolicy");

    return pyType;
}
