// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QPaintEngineWrapper_H
#define SBK_QPaintEngineWrapper_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtGui/qpaintengine.h>

// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
class QPaintEngineWrapper : public QPaintEngine
{
public:
    QPaintEngineWrapper(const QPaintEngineWrapper &) = delete;
    QPaintEngineWrapper& operator=(const QPaintEngineWrapper &) = delete;
    QPaintEngineWrapper(QPaintEngineWrapper &&) = delete;
    QPaintEngineWrapper& operator=(QPaintEngineWrapper &&) = delete;

    QPaintEngineWrapper(::QFlags<QPaintEngine::PaintEngineFeature> features = QPaintEngine::PaintEngineFeatures());
    bool begin(::QPaintDevice * pdev) override;
    ::QPoint coordinateOffset() const override;
    ::QPixmap createPixmap(::QSize size) override;
    ::QPixmap createPixmapFromImage(::QImage image, ::QFlags<Qt::ImageConversionFlag> flags = Qt::AutoColor) override;
    void drawEllipse(const ::QRect & r) override;
    void drawEllipse(const ::QRectF & r) override;
    void drawImage(const ::QRectF & r, const ::QImage & pm, const ::QRectF & sr, ::QFlags<Qt::ImageConversionFlag> flags = Qt::AutoColor) override;
    void drawLines(const ::QLine * lines, int lineCount) override;
    void drawLines(const ::QLineF * lines, int lineCount) override;
    void drawPath(const ::QPainterPath & path) override;
    void drawPixmap(const ::QRectF & r, const ::QPixmap & pm, const ::QRectF & sr) override;
    void drawPoints(const ::QPoint * points, int pointCount) override;
    void drawPoints(const ::QPointF * points, int pointCount) override;
    void drawPolygon(const ::QPoint * points, int pointCount, ::QPaintEngine::PolygonDrawMode mode) override;
    void drawPolygon(const ::QPointF * points, int pointCount, ::QPaintEngine::PolygonDrawMode mode) override;
    void drawRects(const ::QRect * rects, int rectCount) override;
    void drawRects(const ::QRectF * rects, int rectCount) override;
    void drawTextItem(const ::QPointF & p, const ::QTextItem & textItem) override;
    void drawTiledPixmap(const ::QRectF & r, const ::QPixmap & pixmap, const ::QPointF & s) override;
    bool end() override;
    ::QPaintEngine::Type type() const override;
    void updateState(const ::QPaintEngineState & state) override;
    ~QPaintEngineWrapper() override;
    static void pysideInitQtMetaTypes();
    void resetPyMethodCache();
private:
    mutable bool m_PyMethodCache[22];
};

#endif // SBK_QPaintEngineWrapper_H

