// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qpixmapcache_wrapper.h"

// inner classes
#include "qpixmapcache_key_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qpixmap.h>
#include <QtGui/qpixmapcache.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPixmapCache_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPixmapCache >()))
        return -1;

    ::QPixmapCache *cptr{};
    static const char fullName[] = "PySide6.QtGui.QPixmapCache.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPixmapCache()
            cptr = new ::QPixmapCache();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPixmapCache >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPixmapCacheFunc_cacheLimit(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QPixmapCache.cacheLimit";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cacheLimit()
            int cppResult = ::QPixmapCache::cacheLimit();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPixmapCacheFunc_clear(PyObject *self)
{
    SBK_UNUSED(self)
    static const char fullName[] = "PySide6.QtGui.QPixmapCache.clear";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clear()
            ::QPixmapCache::clear();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPixmapCacheFunc_find(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QPixmapCache *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QPixmapCache *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPixmapCache.find";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "find", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPixmapCache::find(QPixmapCache::Key&)
    // 1: static QPixmapCache::find(QPixmapCache::Key,QPixmap*)->bool
    // 2: QPixmapCache::find(QString)
    // 3: static QPixmapCache::find(QString,QPixmap*)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // find(QString)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[1])))) {
            overloadId = 3; // find(QString,QPixmap*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // find(QPixmapCache::Key&)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[1])))) {
            overloadId = 1; // find(QPixmapCache::Key,QPixmap*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // find(QPixmapCache::Key & arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPixmapCache::Key cppArg0_local;
            ::QPixmapCache::Key *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // find(QPixmapCache::Key&)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qpixmapcache-find)]
                QPixmap p;
                if (cppSelf->find((*cppArg0), &p)) {
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &p);
                } else {
                    pyResult = Py_None;
                    Py_INCREF(pyResult);
                }
                // END of custom code block [file: ../glue/qtgui.cpp (qpixmapcache-find)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // find(const QPixmapCache::Key & key, QPixmap * pixmap)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPixmapCache::Key cppArg0_local;
            ::QPixmapCache::Key *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPixmap *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // find(QPixmapCache::Key,QPixmap*)
                bool cppResult = ::QPixmapCache::find(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // find(const QString & arg__1)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // find(QString)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qpixmapcache-find)]
                QPixmap p;
                if (cppSelf->find(cppArg0, &p)) {
                    pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), &p);
                } else {
                    pyResult = Py_None;
                    Py_INCREF(pyResult);
                }
                // END of custom code block [file: ../glue/qtgui.cpp (qpixmapcache-find)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 3: // find(const QString & key, QPixmap * pixmap)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPixmap *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // find(QString,QPixmap*)
                bool cppResult = ::QPixmapCache::find(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPixmapCacheFunc_insert(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPixmapCache.insert";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insert", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QPixmapCache::insert(QPixmap)->QPixmapCache::Key
    // 1: static QPixmapCache::insert(QString,QPixmap)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[1])))) {
        overloadId = 1; // insert(QString,QPixmap)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[0])))) {
        overloadId = 0; // insert(QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // insert(const QPixmap & pixmap)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPixmap cppArg0_local;
            ::QPixmap *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // insert(QPixmap)
                QPixmapCache::Key cppResult = ::QPixmapCache::insert(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), &cppResult);
            }
            break;
        }
        case 1: // insert(const QString & key, const QPixmap & pixmap)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPixmap cppArg1_local;
            ::QPixmap *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // insert(QString,QPixmap)
                bool cppResult = ::QPixmapCache::insert(cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPixmapCacheFunc_remove(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPixmapCache.remove";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QPixmapCache::remove(QPixmapCache::Key)
    // 1: static QPixmapCache::remove(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // remove(QString)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), (pyArg)))) {
        overloadId = 0; // remove(QPixmapCache::Key)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // remove(const QPixmapCache::Key & key)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QPixmapCache::Key cppArg0_local;
            ::QPixmapCache::Key *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // remove(QPixmapCache::Key)
                ::QPixmapCache::remove(*cppArg0);
            }
            break;
        }
        case 1: // remove(const QString & key)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // remove(QString)
                ::QPixmapCache::remove(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPixmapCacheFunc_replace(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPixmapCache.replace";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "replace", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QPixmapCache::replace(QPixmapCache::Key,QPixmap)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_Key_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[1])))) {
        overloadId = 0; // replace(QPixmapCache::Key,QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QPixmapCache", "replace(const QPixmapCache.Key & key, const QPixmap & pixmap)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPixmapCache::Key cppArg0_local;
        ::QPixmapCache::Key *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPixmap cppArg1_local;
        ::QPixmap *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // replace(QPixmapCache::Key,QPixmap)
            bool cppResult = ::QPixmapCache::replace(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPixmapCacheFunc_setCacheLimit(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QPixmapCache.setCacheLimit";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QPixmapCache::setCacheLimit(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCacheLimit(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCacheLimit(int)
            ::QPixmapCache::setCacheLimit(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_QPixmapCacheMethod_find = {"find", reinterpret_cast<PyCFunction>(Sbk_QPixmapCacheFunc_find), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_QPixmapCache_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPixmapCache_methods[] = {
    {"cacheLimit", reinterpret_cast<PyCFunction>(Sbk_QPixmapCacheFunc_cacheLimit), METH_NOARGS|METH_STATIC, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QPixmapCacheFunc_clear), METH_NOARGS|METH_STATIC, nullptr},
    {"find", reinterpret_cast<PyCFunction>(Sbk_QPixmapCacheFunc_find), METH_VARARGS|METH_STATIC, nullptr},
    {"insert", reinterpret_cast<PyCFunction>(Sbk_QPixmapCacheFunc_insert), METH_VARARGS|METH_STATIC, nullptr},
    {"remove", reinterpret_cast<PyCFunction>(Sbk_QPixmapCacheFunc_remove), METH_O|METH_STATIC, nullptr},
    {"replace", reinterpret_cast<PyCFunction>(Sbk_QPixmapCacheFunc_replace), METH_VARARGS|METH_STATIC, nullptr},
    {"setCacheLimit", reinterpret_cast<PyCFunction>(Sbk_QPixmapCacheFunc_setCacheLimit), METH_O|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QPixmapCache_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QPixmapCacheMethod_find = {
        Sbk_QPixmapCacheMethod_find.ml_name,
        Sbk_QPixmapCacheMethod_find.ml_meth,
        Sbk_QPixmapCacheMethod_find.ml_flags & (~METH_STATIC),
        Sbk_QPixmapCacheMethod_find.ml_doc,
    };
    if (Shiboken::String::compare(name, "find") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QPixmapCacheMethod_find, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

} // extern "C"

static int Sbk_QPixmapCache_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPixmapCache_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPixmapCache_Type = nullptr;
static PyTypeObject *Sbk_QPixmapCache_TypeF(void)
{
    return _Sbk_QPixmapCache_Type;
}

static PyType_Slot Sbk_QPixmapCache_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QPixmapCache_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPixmapCache_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPixmapCache_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPixmapCache_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPixmapCache_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPixmapCache_spec = {
    "2:PySide6.QtGui.QPixmapCache",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPixmapCache_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPixmapCache_PythonToCpp_QPixmapCache_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPixmapCache_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPixmapCache_PythonToCpp_QPixmapCache_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPixmapCache_TypeF()))
        return QPixmapCache_PythonToCpp_QPixmapCache_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPixmapCache_PTR_CppToPython_QPixmapCache(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QPixmapCache *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QPixmapCache_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QPixmapCache_SignatureStrings[] = {
    "PySide6.QtGui.QPixmapCache(self)",
    "PySide6.QtGui.QPixmapCache.cacheLimit()->int",
    "PySide6.QtGui.QPixmapCache.clear()",
    "3:PySide6.QtGui.QPixmapCache.find(self,arg__1:PySide6.QtGui.QPixmapCache.Key)",
    "2:PySide6.QtGui.QPixmapCache.find(key:PySide6.QtGui.QPixmapCache.Key,pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage])->bool",
    "1:PySide6.QtGui.QPixmapCache.find(self,arg__1:QString)",
    "0:PySide6.QtGui.QPixmapCache.find(key:QString,pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage])->bool",
    "1:PySide6.QtGui.QPixmapCache.insert(pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage])->PySide6.QtGui.QPixmapCache.Key",
    "0:PySide6.QtGui.QPixmapCache.insert(key:QString,pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage])->bool",
    "1:PySide6.QtGui.QPixmapCache.remove(key:PySide6.QtGui.QPixmapCache.Key)",
    "0:PySide6.QtGui.QPixmapCache.remove(key:QString)",
    "PySide6.QtGui.QPixmapCache.replace(key:PySide6.QtGui.QPixmapCache.Key,pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage])->bool",
    "PySide6.QtGui.QPixmapCache.setCacheLimit(arg__1:int)",
    nullptr}; // Sentinel

PyTypeObject *init_QPixmapCache(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_IDX].type;

    Shiboken::AutoDecRef Sbk_QPixmapCache_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPixmapCache_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPixmapCache",
        "QPixmapCache*",
        &Sbk_QPixmapCache_spec,
        &Shiboken::callCppDestructor< ::QPixmapCache >,
        Sbk_QPixmapCache_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPixmapCache_TypeF(); // references _Sbk_QPixmapCache_Type
    InitSignatureStrings(pyType, QPixmapCache_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPixmapCache_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QPixmapCache_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPixmapCache_PythonToCpp_QPixmapCache_PTR,
        is_QPixmapCache_PythonToCpp_QPixmapCache_PTR_Convertible,
        QPixmapCache_PTR_CppToPython_QPixmapCache);

    Shiboken::Conversions::registerConverterName(converter, "QPixmapCache");
    Shiboken::Conversions::registerConverterName(converter, "QPixmapCache*");
    Shiboken::Conversions::registerConverterName(converter, "QPixmapCache&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPixmapCache).name());

    qRegisterMetaType< ::QPixmapCache *>();

    return pyType;
}
