// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhi_wrapper.h"

// Argument includes
#include <QList>
#include <QtGui/qmatrix4x4.h>
#include <qbytearray.h>
#include <qsize.h>
#include <qthread.h>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRhi_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QRhi >()))
        return -1;

    ::QRhi *cptr{};
    static const char fullName[] = "PySide6.QtGui.QRhi.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QRhi()
            cptr = new ::QRhi();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QRhi >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QRhiFunc_backend(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.backend";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // backend()const
            QRhi::Implementation cppResult = const_cast<const ::QRhi *>(cppSelf)->backend();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_Implementation_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_backendName(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QRhi *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.backendName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "backendName", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhi::backendName()const->const char*
    // 1: static QRhi::backendName(QRhi::Implementation)->const char*
    if (numArgs == 0) {
        overloadId = 0; // backendName()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_Implementation_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // backendName(QRhi::Implementation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // backendName() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // backendName()const
                const char * cppResult = const_cast<const ::QRhi *>(cppSelf)->backendName();
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
            }
            break;
        }
        case 1: // backendName(QRhi::Implementation impl)
        {
            ::QRhi::Implementation cppArg0{QRhi::Null};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // backendName(QRhi::Implementation)
                const char * cppResult = ::QRhi::backendName(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_beginFrame(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.beginFrame";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:beginFrame", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhi::beginFrame(QRhiSwapChain*,QFlags<QRhi::BeginFrameFlag>=)->QRhi::FrameOpResult
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // beginFrame(QRhiSwapChain*,QFlags<QRhi::BeginFrameFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhi_BeginFrameFlag_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // beginFrame(QRhiSwapChain*,QFlags<QRhi::BeginFrameFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhi_BeginFrameFlag_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRhiSwapChain *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhi::BeginFrameFlag> cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // beginFrame(QRhiSwapChain*,QFlags<QRhi::BeginFrameFlag>)
            QRhi::FrameOpResult cppResult = cppSelf->beginFrame(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_FrameOpResult_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_beginOffscreenFrame(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.beginOffscreenFrame";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:beginOffscreenFrame", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhi::beginOffscreenFrame(QRhiCommandBuffer**,QFlags<QRhi::BeginFrameFlag>=)->QRhi::FrameOpResult
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiCommandBuffer_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // beginOffscreenFrame(QRhiCommandBuffer**,QFlags<QRhi::BeginFrameFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhi_BeginFrameFlag_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // beginOffscreenFrame(QRhiCommandBuffer**,QFlags<QRhi::BeginFrameFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhi_BeginFrameFlag_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRhiCommandBuffer *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhi::BeginFrameFlag> cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // beginOffscreenFrame(QRhiCommandBuffer**,QFlags<QRhi::BeginFrameFlag>)
            QRhi::FrameOpResult cppResult = cppSelf->beginOffscreenFrame(&cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_FrameOpResult_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_clipSpaceCorrMatrix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.clipSpaceCorrMatrix";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clipSpaceCorrMatrix()const
            QMatrix4x4 cppResult = const_cast<const ::QRhi *>(cppSelf)->clipSpaceCorrMatrix();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_create(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.create";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:create", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhi::create(QRhi::Implementation,QRhiInitParams*,QFlags<QRhi::Flag>=,QRhiNativeHandles*=)->QRhi*
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_Implementation_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiInitParams_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // create(QRhi::Implementation,QRhiInitParams*,QFlags<QRhi::Flag>,QRhiNativeHandles*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhi_Flag_IDX])))->converter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // create(QRhi::Implementation,QRhiInitParams*,QFlags<QRhi::Flag>,QRhiNativeHandles*)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiNativeHandles_IDX]), (pyArgs[3])))) {
                overloadId = 0; // create(QRhi::Implementation,QRhiInitParams*,QFlags<QRhi::Flag>,QRhiNativeHandles*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhi_Flag_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            static PyObject *const key_importDevice = Shiboken::String::createStaticString("importDevice");
            if (PyDict_Contains(kwds, key_importDevice) != 0) {
                value = PyDict_GetItem(kwds, key_importDevice);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_importDevice);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiNativeHandles_IDX]), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_importDevice);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QRhi::Implementation cppArg0{QRhi::Null};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRhiInitParams *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFlags<QRhi::Flag> cppArg2{};
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QRhiNativeHandles *cppArg3 = nullptr;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // create(QRhi::Implementation,QRhiInitParams*,QFlags<QRhi::Flag>,QRhiNativeHandles*)
            QRhi * cppResult = ::QRhi::create(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_currentFrameSlot(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.currentFrameSlot";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // currentFrameSlot()const
            int cppResult = const_cast<const ::QRhi *>(cppSelf)->currentFrameSlot();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_driverInfo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.driverInfo";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // driverInfo()const
            QRhiDriverInfo cppResult = const_cast<const ::QRhi *>(cppSelf)->driverInfo();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiDriverInfo_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_endFrame(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.endFrame";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:endFrame", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhi::endFrame(QRhiSwapChain*,QFlags<QRhi::EndFrameFlag>=)->QRhi::FrameOpResult
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // endFrame(QRhiSwapChain*,QFlags<QRhi::EndFrameFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhi_EndFrameFlag_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // endFrame(QRhiSwapChain*,QFlags<QRhi::EndFrameFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhi_EndFrameFlag_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRhiSwapChain *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhi::EndFrameFlag> cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // endFrame(QRhiSwapChain*,QFlags<QRhi::EndFrameFlag>)
            QRhi::FrameOpResult cppResult = cppSelf->endFrame(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_FrameOpResult_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_endOffscreenFrame(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.endOffscreenFrame";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:endOffscreenFrame", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhi::endOffscreenFrame(QFlags<QRhi::EndFrameFlag>=)->QRhi::FrameOpResult
    if (numArgs == 0) {
        overloadId = 0; // endOffscreenFrame(QFlags<QRhi::EndFrameFlag>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhi_EndFrameFlag_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // endOffscreenFrame(QFlags<QRhi::EndFrameFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhi_EndFrameFlag_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QFlags<QRhi::EndFrameFlag> cppArg0{};
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // endOffscreenFrame(QFlags<QRhi::EndFrameFlag>)
            QRhi::FrameOpResult cppResult = cppSelf->endOffscreenFrame(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_FrameOpResult_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_finish(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.finish";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // finish()
            QRhi::FrameOpResult cppResult = cppSelf->finish();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_FrameOpResult_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_isClipDepthZeroToOne(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.isClipDepthZeroToOne";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isClipDepthZeroToOne()const
            bool cppResult = const_cast<const ::QRhi *>(cppSelf)->isClipDepthZeroToOne();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_isDeviceLost(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.isDeviceLost";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDeviceLost()const
            bool cppResult = const_cast<const ::QRhi *>(cppSelf)->isDeviceLost();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_isFeatureSupported(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.isFeatureSupported";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhi::isFeatureSupported(QRhi::Feature)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_Feature_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isFeatureSupported(QRhi::Feature)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhi::Feature cppArg0 = static_cast< ::QRhi::Feature>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isFeatureSupported(QRhi::Feature)const
            bool cppResult = const_cast<const ::QRhi *>(cppSelf)->isFeatureSupported(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_isRecordingFrame(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.isRecordingFrame";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isRecordingFrame()const
            bool cppResult = const_cast<const ::QRhi *>(cppSelf)->isRecordingFrame();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_isTextureFormatSupported(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.isTextureFormatSupported";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:isTextureFormatSupported", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhi::isTextureFormatSupported(QRhiTexture::Format,QFlags<QRhiTexture::Flag>=)const->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // isTextureFormatSupported(QRhiTexture::Format,QFlags<QRhiTexture::Flag>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTexture_Flag_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // isTextureFormatSupported(QRhiTexture::Format,QFlags<QRhiTexture::Flag>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTexture_Flag_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QRhiTexture::Format cppArg0{QRhiTexture::UnknownFormat};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhiTexture::Flag> cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isTextureFormatSupported(QRhiTexture::Format,QFlags<QRhiTexture::Flag>)const
            bool cppResult = const_cast<const ::QRhi *>(cppSelf)->isTextureFormatSupported(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_isYUpInFramebuffer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.isYUpInFramebuffer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isYUpInFramebuffer()const
            bool cppResult = const_cast<const ::QRhi *>(cppSelf)->isYUpInFramebuffer();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_isYUpInNDC(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.isYUpInNDC";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isYUpInNDC()const
            bool cppResult = const_cast<const ::QRhi *>(cppSelf)->isYUpInNDC();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_makeThreadLocalNativeContextCurrent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.makeThreadLocalNativeContextCurrent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // makeThreadLocalNativeContextCurrent()
            bool cppResult = cppSelf->makeThreadLocalNativeContextCurrent();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_mipLevelsForSize(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.mipLevelsForSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QRhi::mipLevelsForSize(QSize)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArg)))) {
        overloadId = 0; // mipLevelsForSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSize cppArg0_local;
        ::QSize *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mipLevelsForSize(QSize)
            int cppResult = ::QRhi::mipLevelsForSize(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_nativeHandles(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.nativeHandles";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // nativeHandles()
            const QRhiNativeHandles * cppResult = cppSelf->nativeHandles();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiNativeHandles_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_newBuffer(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.newBuffer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "newBuffer", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhi::newBuffer(QRhiBuffer::Type,QFlags<QRhiBuffer::UsageFlag>,quint32)->QRhiBuffer*
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_Type_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiBuffer_UsageFlag_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[2])))) {
        overloadId = 0; // newBuffer(QRhiBuffer::Type,QFlags<QRhiBuffer::UsageFlag>,quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QRhiBuffer::Type cppArg0{QRhiBuffer::Immutable};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QRhiBuffer::UsageFlag> cppArg1 = QFlags<QRhiBuffer::UsageFlag>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);
        quint32 cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // newBuffer(QRhiBuffer::Type,QFlags<QRhiBuffer::UsageFlag>,quint32)
            QRhiBuffer * cppResult = cppSelf->newBuffer(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiBuffer_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_newComputePipeline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.newComputePipeline";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // newComputePipeline()
            QRhiComputePipeline * cppResult = cppSelf->newComputePipeline();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiComputePipeline_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_newGraphicsPipeline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.newGraphicsPipeline";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // newGraphicsPipeline()
            QRhiGraphicsPipeline * cppResult = cppSelf->newGraphicsPipeline();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_newRenderBuffer(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.newRenderBuffer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:newRenderBuffer", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhi::newRenderBuffer(QRhiRenderBuffer::Type,QSize,int=,QFlags<QRhiRenderBuffer::Flag>=,QRhiTexture::Format=)->QRhiRenderBuffer*
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_Type_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // newRenderBuffer(QRhiRenderBuffer::Type,QSize,int,QFlags<QRhiRenderBuffer::Flag>,QRhiTexture::Format)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // newRenderBuffer(QRhiRenderBuffer::Type,QSize,int,QFlags<QRhiRenderBuffer::Flag>,QRhiTexture::Format)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiRenderBuffer_Flag_IDX])))->converter, (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 0; // newRenderBuffer(QRhiRenderBuffer::Type,QSize,int,QFlags<QRhiRenderBuffer::Flag>,QRhiTexture::Format)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, (pyArgs[4])))) {
                    overloadId = 0; // newRenderBuffer(QRhiRenderBuffer::Type,QSize,int,QFlags<QRhiRenderBuffer::Flag>,QRhiTexture::Format)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_sampleCount = Shiboken::String::createStaticString("sampleCount");
            if (PyDict_Contains(kwds, key_sampleCount) != 0) {
                value = PyDict_GetItem(kwds, key_sampleCount);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_sampleCount);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_sampleCount);
            }
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiRenderBuffer_Flag_IDX])))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            static PyObject *const key_backingFormatHint = Shiboken::String::createStaticString("backingFormatHint");
            if (PyDict_Contains(kwds, key_backingFormatHint) != 0) {
                value = PyDict_GetItem(kwds, key_backingFormatHint);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_backingFormatHint);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_backingFormatHint);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QRhiRenderBuffer::Type cppArg0{QRhiRenderBuffer::DepthStencil};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSize cppArg1_local;
        ::QSize *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        int cppArg2 = 1;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QFlags<QRhiRenderBuffer::Flag> cppArg3{};
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QRhiTexture::Format cppArg4(QRhiTexture::UnknownFormat);
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // newRenderBuffer(QRhiRenderBuffer::Type,QSize,int,QFlags<QRhiRenderBuffer::Flag>,QRhiTexture::Format)
            QRhiRenderBuffer * cppResult = cppSelf->newRenderBuffer(cppArg0, *cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderBuffer_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_newSampler(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.newSampler";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 5, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOO:newSampler", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhi::newSampler(QRhiSampler::Filter,QRhiSampler::Filter,QRhiSampler::Filter,QRhiSampler::AddressMode,QRhiSampler::AddressMode,QRhiSampler::AddressMode=)->QRhiSampler*
    if (numArgs >= 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_Filter_IDX])))->converter, (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, (pyArgs[4])))) {
        if (numArgs == 5) {
            overloadId = 0; // newSampler(QRhiSampler::Filter,QRhiSampler::Filter,QRhiSampler::Filter,QRhiSampler::AddressMode,QRhiSampler::AddressMode,QRhiSampler::AddressMode)
        } else if (numArgs >= 6
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, (pyArgs[5])))) {
            overloadId = 0; // newSampler(QRhiSampler::Filter,QRhiSampler::Filter,QRhiSampler::Filter,QRhiSampler::AddressMode,QRhiSampler::AddressMode,QRhiSampler::AddressMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_addressW = Shiboken::String::createStaticString("addressW");
            if (PyDict_Contains(kwds, key_addressW) != 0) {
                value = PyDict_GetItem(kwds, key_addressW);
                if (value != nullptr && pyArgs[5] != nullptr ) {
                    errInfo.reset(key_addressW);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[5] = value;
                    if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_AddressMode_IDX])))->converter, (pyArgs[5]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_addressW);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QRhiSampler::Filter cppArg0{QRhiSampler::None};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QRhiSampler::Filter cppArg1{QRhiSampler::None};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QRhiSampler::Filter cppArg2{QRhiSampler::None};
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QRhiSampler::AddressMode cppArg3{QRhiSampler::Repeat};
        pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QRhiSampler::AddressMode cppArg4{QRhiSampler::Repeat};
        pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QRhiSampler::AddressMode cppArg5(QRhiSampler::Repeat);
        if (pythonToCpp[5])
            pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // newSampler(QRhiSampler::Filter,QRhiSampler::Filter,QRhiSampler::Filter,QRhiSampler::AddressMode,QRhiSampler::AddressMode,QRhiSampler::AddressMode)
            QRhiSampler * cppResult = cppSelf->newSampler(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSampler_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_newShaderResourceBindings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.newShaderResourceBindings";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // newShaderResourceBindings()
            QRhiShaderResourceBindings * cppResult = cppSelf->newShaderResourceBindings();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_newSwapChain(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.newSwapChain";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // newSwapChain()
            QRhiSwapChain * cppResult = cppSelf->newSwapChain();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiSwapChain_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_newTexture(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.newTexture";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOO:newTexture", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhi::newTexture(QRhiTexture::Format,QSize,int=,QFlags<QRhiTexture::Flag>=)->QRhiTexture*
    // 1: QRhi::newTexture(QRhiTexture::Format,int,int,int,int=,QFlags<QRhiTexture::Flag>=)->QRhiTexture*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs >= 4
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 1; // newTexture(QRhiTexture::Format,int,int,int,int,QFlags<QRhiTexture::Flag>)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 1; // newTexture(QRhiTexture::Format,int,int,int,int,QFlags<QRhiTexture::Flag>)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTexture_Flag_IDX])))->converter, (pyArgs[5])))) {
                    overloadId = 1; // newTexture(QRhiTexture::Format,int,int,int,int,QFlags<QRhiTexture::Flag>)
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // newTexture(QRhiTexture::Format,QSize,int,QFlags<QRhiTexture::Flag>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // newTexture(QRhiTexture::Format,QSize,int,QFlags<QRhiTexture::Flag>)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTexture_Flag_IDX])))->converter, (pyArgs[3])))) {
                    overloadId = 0; // newTexture(QRhiTexture::Format,QSize,int,QFlags<QRhiTexture::Flag>)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // newTexture(QRhiTexture::Format format, const QSize & pixelSize, int sampleCount, QFlags<QRhiTexture::Flag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sampleCount = Shiboken::String::createStaticString("sampleCount");
                if (PyDict_Contains(kwds, key_sampleCount) != 0) {
                    value = PyDict_GetItem(kwds, key_sampleCount);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_sampleCount);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sampleCount);
                }
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTexture_Flag_IDX])))->converter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QRhiTexture::Format cppArg0{QRhiTexture::UnknownFormat};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QSize cppArg1_local;
            ::QSize *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            int cppArg2 = 1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<QRhiTexture::Flag> cppArg3{};
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // newTexture(QRhiTexture::Format,QSize,int,QFlags<QRhiTexture::Flag>)
                QRhiTexture * cppResult = cppSelf->newTexture(cppArg0, *cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), cppResult);
            }
            break;
        }
        case 1: // newTexture(QRhiTexture::Format format, int width, int height, int depth, int sampleCount, QFlags<QRhiTexture::Flag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sampleCount = Shiboken::String::createStaticString("sampleCount");
                if (PyDict_Contains(kwds, key_sampleCount) != 0) {
                    value = PyDict_GetItem(kwds, key_sampleCount);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_sampleCount);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sampleCount);
                }
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTexture_Flag_IDX])))->converter, (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QRhiTexture::Format cppArg0{QRhiTexture::UnknownFormat};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = 1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QFlags<QRhiTexture::Flag> cppArg5{};
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // newTexture(QRhiTexture::Format,int,int,int,int,QFlags<QRhiTexture::Flag>)
                QRhiTexture * cppResult = cppSelf->newTexture(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_newTextureArray(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.newTextureArray";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:newTextureArray", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhi::newTextureArray(QRhiTexture::Format,int,QSize,int=,QFlags<QRhiTexture::Flag>=)->QRhiTexture*
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_Format_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // newTextureArray(QRhiTexture::Format,int,QSize,int,QFlags<QRhiTexture::Flag>)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // newTextureArray(QRhiTexture::Format,int,QSize,int,QFlags<QRhiTexture::Flag>)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTexture_Flag_IDX])))->converter, (pyArgs[4])))) {
                overloadId = 0; // newTextureArray(QRhiTexture::Format,int,QSize,int,QFlags<QRhiTexture::Flag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_sampleCount = Shiboken::String::createStaticString("sampleCount");
            if (PyDict_Contains(kwds, key_sampleCount) != 0) {
                value = PyDict_GetItem(kwds, key_sampleCount);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_sampleCount);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_sampleCount);
            }
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTexture_Flag_IDX])))->converter, (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QRhiTexture::Format cppArg0{QRhiTexture::UnknownFormat};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QSize cppArg2_local;
        ::QSize *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        int cppArg3 = 1;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QFlags<QRhiTexture::Flag> cppArg4{};
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // newTextureArray(QRhiTexture::Format,int,QSize,int,QFlags<QRhiTexture::Flag>)
            QRhiTexture * cppResult = cppSelf->newTextureArray(cppArg0, cppArg1, *cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTexture_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_newTextureRenderTarget(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.newTextureRenderTarget";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:newTextureRenderTarget", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QRhi::newTextureRenderTarget(QRhiTextureRenderTargetDescription,QFlags<QRhiTextureRenderTarget::Flag>=)->QRhiTextureRenderTarget*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTargetDescription_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // newTextureRenderTarget(QRhiTextureRenderTargetDescription,QFlags<QRhiTextureRenderTarget::Flag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTextureRenderTarget_Flag_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // newTextureRenderTarget(QRhiTextureRenderTargetDescription,QFlags<QRhiTextureRenderTarget::Flag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
            if (PyDict_Contains(kwds, key_flags) != 0) {
                value = PyDict_GetItem(kwds, key_flags);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_flags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiTextureRenderTarget_Flag_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_flags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRhiTextureRenderTargetDescription cppArg0_local;
        ::QRhiTextureRenderTargetDescription *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QFlags<QRhiTextureRenderTarget::Flag> cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // newTextureRenderTarget(QRhiTextureRenderTargetDescription,QFlags<QRhiTextureRenderTarget::Flag>)
            QRhiTextureRenderTarget * cppResult = cppSelf->newTextureRenderTarget(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiTextureRenderTarget_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_nextResourceUpdateBatch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.nextResourceUpdateBatch";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // nextResourceUpdateBatch()
            QRhiResourceUpdateBatch * cppResult = cppSelf->nextResourceUpdateBatch();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResourceUpdateBatch_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_pipelineCacheData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.pipelineCacheData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // pipelineCacheData()
            QByteArray cppResult = cppSelf->pipelineCacheData();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_probe(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.probe";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "probe", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhi::probe(QRhi::Implementation,QRhiInitParams*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_Implementation_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiInitParams_IDX]), (pyArgs[1])))) {
        overloadId = 0; // probe(QRhi::Implementation,QRhiInitParams*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QRhi::Implementation cppArg0{QRhi::Null};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRhiInitParams *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // probe(QRhi::Implementation,QRhiInitParams*)
            bool cppResult = ::QRhi::probe(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_releaseCachedResources(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtGui.QRhi.releaseCachedResources";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // releaseCachedResources()
            cppSelf->releaseCachedResources();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiFunc_removeCleanupCallback(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.removeCleanupCallback";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhi::removeCleanupCallback(const void*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArg)))) {
        overloadId = 0; // removeCleanupCallback(const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        void* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeCleanupCallback(const void*)
            cppSelf->removeCleanupCallback(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiFunc_resourceLimit(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.resourceLimit";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhi::resourceLimit(QRhi::ResourceLimit)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_ResourceLimit_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // resourceLimit(QRhi::ResourceLimit)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QRhi::ResourceLimit cppArg0 = static_cast< ::QRhi::ResourceLimit>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resourceLimit(QRhi::ResourceLimit)const
            int cppResult = const_cast<const ::QRhi *>(cppSelf)->resourceLimit(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_runCleanup(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtGui.QRhi.runCleanup";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // runCleanup()
            cppSelf->runCleanup();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiFunc_setPipelineCacheData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.setPipelineCacheData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhi::setPipelineCacheData(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setPipelineCacheData(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPipelineCacheData(QByteArray)
            cppSelf->setPipelineCacheData(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiFunc_sizeForMipLevel(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.sizeForMipLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sizeForMipLevel", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QRhi::sizeForMipLevel(int,QSize)->QSize
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[1])))) {
        overloadId = 0; // sizeForMipLevel(int,QSize)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSize cppArg1_local;
        ::QSize *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // sizeForMipLevel(int,QSize)
            QSize cppResult = ::QRhi::sizeForMipLevel(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_statistics(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.statistics";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // statistics()const
            QRhiStats cppResult = const_cast<const ::QRhi *>(cppSelf)->statistics();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiStats_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_supportedSampleCounts(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.supportedSampleCounts";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportedSampleCounts()const
            QList<int> cppResult = const_cast<const ::QRhi *>(cppSelf)->supportedSampleCounts();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_int_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_thread(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.thread";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // thread()const
            QThread * cppResult = const_cast<const ::QRhi *>(cppSelf)->thread();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QThread_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_ubufAligned(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QRhi.ubufAligned";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhi::ubufAligned(int)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // ubufAligned(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ubufAligned(int)const
            int cppResult = const_cast<const ::QRhi *>(cppSelf)->ubufAligned(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiFunc_ubufAlignment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhi *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QRhi.ubufAlignment";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // ubufAlignment()const
            int cppResult = const_cast<const ::QRhi *>(cppSelf)->ubufAlignment();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QRhiMethod_backendName = {"backendName", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_backendName), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_QRhi_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhi_EnumFlagInfo[] = {
    "BeginFrameFlag:Flag:BeginFrameFlags",
    "EndFrameFlag:Flag:EndFrameFlags",
    "Feature:Enum",
    "Flag:Flag:Flags",
    "FrameOpResult:Enum",
    "Implementation:Enum",
    "ResourceLimit:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhi_methods[] = {
    {"backend", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_backend), METH_NOARGS, nullptr},
    {"backendName", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_backendName), METH_VARARGS|METH_STATIC, nullptr},
    {"beginFrame", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_beginFrame), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"beginOffscreenFrame", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_beginOffscreenFrame), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"clipSpaceCorrMatrix", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_clipSpaceCorrMatrix), METH_NOARGS, nullptr},
    {"create", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_create), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"currentFrameSlot", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_currentFrameSlot), METH_NOARGS, nullptr},
    {"driverInfo", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_driverInfo), METH_NOARGS, nullptr},
    {"endFrame", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_endFrame), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"endOffscreenFrame", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_endOffscreenFrame), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"finish", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_finish), METH_NOARGS, nullptr},
    {"isClipDepthZeroToOne", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_isClipDepthZeroToOne), METH_NOARGS, nullptr},
    {"isDeviceLost", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_isDeviceLost), METH_NOARGS, nullptr},
    {"isFeatureSupported", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_isFeatureSupported), METH_O, nullptr},
    {"isRecordingFrame", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_isRecordingFrame), METH_NOARGS, nullptr},
    {"isTextureFormatSupported", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_isTextureFormatSupported), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isYUpInFramebuffer", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_isYUpInFramebuffer), METH_NOARGS, nullptr},
    {"isYUpInNDC", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_isYUpInNDC), METH_NOARGS, nullptr},
    {"makeThreadLocalNativeContextCurrent", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_makeThreadLocalNativeContextCurrent), METH_NOARGS, nullptr},
    {"mipLevelsForSize", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_mipLevelsForSize), METH_O|METH_STATIC, nullptr},
    {"nativeHandles", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_nativeHandles), METH_NOARGS, nullptr},
    {"newBuffer", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_newBuffer), METH_VARARGS, nullptr},
    {"newComputePipeline", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_newComputePipeline), METH_NOARGS, nullptr},
    {"newGraphicsPipeline", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_newGraphicsPipeline), METH_NOARGS, nullptr},
    {"newRenderBuffer", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_newRenderBuffer), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"newSampler", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_newSampler), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"newShaderResourceBindings", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_newShaderResourceBindings), METH_NOARGS, nullptr},
    {"newSwapChain", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_newSwapChain), METH_NOARGS, nullptr},
    {"newTexture", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_newTexture), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"newTextureArray", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_newTextureArray), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"newTextureRenderTarget", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_newTextureRenderTarget), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"nextResourceUpdateBatch", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_nextResourceUpdateBatch), METH_NOARGS, nullptr},
    {"pipelineCacheData", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_pipelineCacheData), METH_NOARGS, nullptr},
    {"probe", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_probe), METH_VARARGS|METH_STATIC, nullptr},
    {"releaseCachedResources", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_releaseCachedResources), METH_NOARGS, nullptr},
    {"removeCleanupCallback", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_removeCleanupCallback), METH_O, nullptr},
    {"resourceLimit", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_resourceLimit), METH_O, nullptr},
    {"runCleanup", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_runCleanup), METH_NOARGS, nullptr},
    {"setPipelineCacheData", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_setPipelineCacheData), METH_O, nullptr},
    {"sizeForMipLevel", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_sizeForMipLevel), METH_VARARGS|METH_STATIC, nullptr},
    {"statistics", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_statistics), METH_NOARGS, nullptr},
    {"supportedSampleCounts", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_supportedSampleCounts), METH_NOARGS, nullptr},
    {"thread", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_thread), METH_NOARGS, nullptr},
    {"ubufAligned", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_ubufAligned), METH_O, nullptr},
    {"ubufAlignment", reinterpret_cast<PyCFunction>(Sbk_QRhiFunc_ubufAlignment), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QRhi_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QRhiMethod_backendName = {
        Sbk_QRhiMethod_backendName.ml_name,
        Sbk_QRhiMethod_backendName.ml_meth,
        Sbk_QRhiMethod_backendName.ml_flags & (~METH_STATIC),
        Sbk_QRhiMethod_backendName.ml_doc,
    };
    if (Shiboken::String::compare(name, "backendName") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QRhiMethod_backendName, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

} // extern "C"

static int Sbk_QRhi_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhi_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhi_Type = nullptr;
static PyTypeObject *Sbk_QRhi_TypeF(void)
{
    return _Sbk_QRhi_Type;
}

static PyType_Slot Sbk_QRhi_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QRhi_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhi_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhi_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhi_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QRhi_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhi_spec = {
    "2:PySide6.QtGui.QRhi",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhi_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QRhi_Implementation_PythonToCpp_QRhi_Implementation(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhi::Implementation>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhi::Implementation *>(cppOut) = value;

}
static PythonToCppFunc is_QRhi_Implementation_PythonToCpp_QRhi_Implementation_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_Implementation_IDX])))
        return QRhi_Implementation_PythonToCpp_QRhi_Implementation;
    return {};
}
static PyObject *QRhi_Implementation_CppToPython_QRhi_Implementation(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhi::Implementation *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_Implementation_IDX]), castCppIn);

}

static void QRhi_Flag_PythonToCpp_QRhi_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhi::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhi::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_QRhi_Flag_PythonToCpp_QRhi_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_Flag_IDX])))
        return QRhi_Flag_PythonToCpp_QRhi_Flag;
    return {};
}
static PyObject *QRhi_Flag_CppToPython_QRhi_Flag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhi::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_Flag_IDX]), castCppIn);

}

static void QRhi_FrameOpResult_PythonToCpp_QRhi_FrameOpResult(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhi::FrameOpResult>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhi::FrameOpResult *>(cppOut) = value;

}
static PythonToCppFunc is_QRhi_FrameOpResult_PythonToCpp_QRhi_FrameOpResult_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_FrameOpResult_IDX])))
        return QRhi_FrameOpResult_PythonToCpp_QRhi_FrameOpResult;
    return {};
}
static PyObject *QRhi_FrameOpResult_CppToPython_QRhi_FrameOpResult(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhi::FrameOpResult *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_FrameOpResult_IDX]), castCppIn);

}

static void QRhi_Feature_PythonToCpp_QRhi_Feature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhi::Feature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhi::Feature *>(cppOut) = value;

}
static PythonToCppFunc is_QRhi_Feature_PythonToCpp_QRhi_Feature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_Feature_IDX])))
        return QRhi_Feature_PythonToCpp_QRhi_Feature;
    return {};
}
static PyObject *QRhi_Feature_CppToPython_QRhi_Feature(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhi::Feature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_Feature_IDX]), castCppIn);

}

static void QRhi_BeginFrameFlag_PythonToCpp_QRhi_BeginFrameFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhi::BeginFrameFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhi::BeginFrameFlag *>(cppOut) = value;

}
static PythonToCppFunc is_QRhi_BeginFrameFlag_PythonToCpp_QRhi_BeginFrameFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_BeginFrameFlag_IDX])))
        return QRhi_BeginFrameFlag_PythonToCpp_QRhi_BeginFrameFlag;
    return {};
}
static PyObject *QRhi_BeginFrameFlag_CppToPython_QRhi_BeginFrameFlag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhi::BeginFrameFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_BeginFrameFlag_IDX]), castCppIn);

}

static void QRhi_EndFrameFlag_PythonToCpp_QRhi_EndFrameFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhi::EndFrameFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhi::EndFrameFlag *>(cppOut) = value;

}
static PythonToCppFunc is_QRhi_EndFrameFlag_PythonToCpp_QRhi_EndFrameFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_EndFrameFlag_IDX])))
        return QRhi_EndFrameFlag_PythonToCpp_QRhi_EndFrameFlag;
    return {};
}
static PyObject *QRhi_EndFrameFlag_CppToPython_QRhi_EndFrameFlag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhi::EndFrameFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_EndFrameFlag_IDX]), castCppIn);

}

static void QRhi_ResourceLimit_PythonToCpp_QRhi_ResourceLimit(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhi::ResourceLimit>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhi::ResourceLimit *>(cppOut) = value;

}
static PythonToCppFunc is_QRhi_ResourceLimit_PythonToCpp_QRhi_ResourceLimit_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_ResourceLimit_IDX])))
        return QRhi_ResourceLimit_PythonToCpp_QRhi_ResourceLimit;
    return {};
}
static PyObject *QRhi_ResourceLimit_CppToPython_QRhi_ResourceLimit(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QRhi::ResourceLimit *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_ResourceLimit_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhi_PythonToCpp_QRhi_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhi_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhi_PythonToCpp_QRhi_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhi_TypeF()))
        return QRhi_PythonToCpp_QRhi_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhi_PTR_CppToPython_QRhi(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QRhi *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QRhi_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QRhi_SignatureStrings[] = {
    "PySide6.QtGui.QRhi(self)",
    "PySide6.QtGui.QRhi.backend(self)->PySide6.QtGui.QRhi.Implementation",
    "1:PySide6.QtGui.QRhi.backendName(self)->char*",
    "0:PySide6.QtGui.QRhi.backendName(impl:PySide6.QtGui.QRhi.Implementation)->char*",
    "PySide6.QtGui.QRhi.beginFrame(self,swapChain:PySide6.QtGui.QRhiSwapChain,flags:PySide6.QtGui.QRhi.BeginFrameFlag={})->PySide6.QtGui.QRhi.FrameOpResult",
    "PySide6.QtGui.QRhi.beginOffscreenFrame(self,cb:PySide6.QtGui.QRhiCommandBuffer,flags:PySide6.QtGui.QRhi.BeginFrameFlag={})->PySide6.QtGui.QRhi.FrameOpResult",
    "PySide6.QtGui.QRhi.clipSpaceCorrMatrix(self)->PySide6.QtGui.QMatrix4x4",
    "PySide6.QtGui.QRhi.create(impl:PySide6.QtGui.QRhi.Implementation,params:PySide6.QtGui.QRhiInitParams,flags:PySide6.QtGui.QRhi.Flag={},importDevice:PySide6.QtGui.QRhiNativeHandles=nullptr)->PySide6.QtGui.QRhi",
    "PySide6.QtGui.QRhi.currentFrameSlot(self)->int",
    "PySide6.QtGui.QRhi.driverInfo(self)->PySide6.QtGui.QRhiDriverInfo",
    "PySide6.QtGui.QRhi.endFrame(self,swapChain:PySide6.QtGui.QRhiSwapChain,flags:PySide6.QtGui.QRhi.EndFrameFlag={})->PySide6.QtGui.QRhi.FrameOpResult",
    "PySide6.QtGui.QRhi.endOffscreenFrame(self,flags:PySide6.QtGui.QRhi.EndFrameFlag={})->PySide6.QtGui.QRhi.FrameOpResult",
    "PySide6.QtGui.QRhi.finish(self)->PySide6.QtGui.QRhi.FrameOpResult",
    "PySide6.QtGui.QRhi.isClipDepthZeroToOne(self)->bool",
    "PySide6.QtGui.QRhi.isDeviceLost(self)->bool",
    "PySide6.QtGui.QRhi.isFeatureSupported(self,feature:PySide6.QtGui.QRhi.Feature)->bool",
    "PySide6.QtGui.QRhi.isRecordingFrame(self)->bool",
    "PySide6.QtGui.QRhi.isTextureFormatSupported(self,format:PySide6.QtGui.QRhiTexture.Format,flags:PySide6.QtGui.QRhiTexture.Flag={})->bool",
    "PySide6.QtGui.QRhi.isYUpInFramebuffer(self)->bool",
    "PySide6.QtGui.QRhi.isYUpInNDC(self)->bool",
    "PySide6.QtGui.QRhi.makeThreadLocalNativeContextCurrent(self)->bool",
    "PySide6.QtGui.QRhi.mipLevelsForSize(size:PySide6.QtCore.QSize)->int",
    "PySide6.QtGui.QRhi.nativeHandles(self)->PySide6.QtGui.QRhiNativeHandles",
    "PySide6.QtGui.QRhi.newBuffer(self,type:PySide6.QtGui.QRhiBuffer.Type,usage:PySide6.QtGui.QRhiBuffer.UsageFlag,size:quint32)->PySide6.QtGui.QRhiBuffer",
    "PySide6.QtGui.QRhi.newComputePipeline(self)->PySide6.QtGui.QRhiComputePipeline",
    "PySide6.QtGui.QRhi.newGraphicsPipeline(self)->PySide6.QtGui.QRhiGraphicsPipeline",
    "PySide6.QtGui.QRhi.newRenderBuffer(self,type:PySide6.QtGui.QRhiRenderBuffer.Type,pixelSize:PySide6.QtCore.QSize,sampleCount:int=1,flags:PySide6.QtGui.QRhiRenderBuffer.Flag={},backingFormatHint:PySide6.QtGui.QRhiTexture.Format=QRhiTexture.UnknownFormat)->PySide6.QtGui.QRhiRenderBuffer",
    "PySide6.QtGui.QRhi.newSampler(self,magFilter:PySide6.QtGui.QRhiSampler.Filter,minFilter:PySide6.QtGui.QRhiSampler.Filter,mipmapMode:PySide6.QtGui.QRhiSampler.Filter,addressU:PySide6.QtGui.QRhiSampler.AddressMode,addressV:PySide6.QtGui.QRhiSampler.AddressMode,addressW:PySide6.QtGui.QRhiSampler.AddressMode=QRhiSampler.Repeat)->PySide6.QtGui.QRhiSampler",
    "PySide6.QtGui.QRhi.newShaderResourceBindings(self)->PySide6.QtGui.QRhiShaderResourceBindings",
    "PySide6.QtGui.QRhi.newSwapChain(self)->PySide6.QtGui.QRhiSwapChain",
    "1:PySide6.QtGui.QRhi.newTexture(self,format:PySide6.QtGui.QRhiTexture.Format,pixelSize:PySide6.QtCore.QSize,sampleCount:int=1,flags:PySide6.QtGui.QRhiTexture.Flag={})->PySide6.QtGui.QRhiTexture",
    "0:PySide6.QtGui.QRhi.newTexture(self,format:PySide6.QtGui.QRhiTexture.Format,width:int,height:int,depth:int,sampleCount:int=1,flags:PySide6.QtGui.QRhiTexture.Flag={})->PySide6.QtGui.QRhiTexture",
    "PySide6.QtGui.QRhi.newTextureArray(self,format:PySide6.QtGui.QRhiTexture.Format,arraySize:int,pixelSize:PySide6.QtCore.QSize,sampleCount:int=1,flags:PySide6.QtGui.QRhiTexture.Flag={})->PySide6.QtGui.QRhiTexture",
    "PySide6.QtGui.QRhi.newTextureRenderTarget(self,desc:typing.Union[PySide6.QtGui.QRhiTextureRenderTargetDescription, PySide6.QtGui.QRhiColorAttachment],flags:PySide6.QtGui.QRhiTextureRenderTarget.Flag={})->PySide6.QtGui.QRhiTextureRenderTarget",
    "PySide6.QtGui.QRhi.nextResourceUpdateBatch(self)->PySide6.QtGui.QRhiResourceUpdateBatch",
    "PySide6.QtGui.QRhi.pipelineCacheData(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtGui.QRhi.probe(impl:PySide6.QtGui.QRhi.Implementation,params:PySide6.QtGui.QRhiInitParams)->bool",
    "PySide6.QtGui.QRhi.releaseCachedResources(self)",
    "PySide6.QtGui.QRhi.removeCleanupCallback(self,key:void)",
    "PySide6.QtGui.QRhi.resourceLimit(self,limit:PySide6.QtGui.QRhi.ResourceLimit)->int",
    "PySide6.QtGui.QRhi.runCleanup(self)",
    "PySide6.QtGui.QRhi.setPipelineCacheData(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtGui.QRhi.sizeForMipLevel(mipLevel:int,baseLevelSize:PySide6.QtCore.QSize)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QRhi.statistics(self)->PySide6.QtGui.QRhiStats",
    "PySide6.QtGui.QRhi.supportedSampleCounts(self)->QList[int]",
    "PySide6.QtGui.QRhi.thread(self)->PySide6.QtCore.QThread",
    "PySide6.QtGui.QRhi.ubufAligned(self,v:int)->int",
    "PySide6.QtGui.QRhi.ubufAlignment(self)->int",
    nullptr}; // Sentinel

PyTypeObject *init_QRhi(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhi_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QRhi_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhi",
        "QRhi*",
        &Sbk_QRhi_spec,
        &Shiboken::callCppDestructor< ::QRhi >,
        Sbk_QRhi_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRhi_TypeF(); // references _Sbk_QRhi_Type
    InitSignatureStrings(pyType, QRhi_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhi_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhi_PythonToCpp_QRhi_PTR,
        is_QRhi_PythonToCpp_QRhi_PTR_Convertible,
        QRhi_PTR_CppToPython_QRhi);

    Shiboken::Conversions::registerConverterName(converter, "QRhi");
    Shiboken::Conversions::registerConverterName(converter, "QRhi*");
    Shiboken::Conversions::registerConverterName(converter, "QRhi&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhi).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhi_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Implementation'.
    const char *Implementation_Initializer[] = {
        "Null",
        "Vulkan",
        "OpenGLES2",
        "D3D11",
        "Metal",
        "D3D12",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Implementation_InitializerValues[] = {
        uint8_t(QRhi::Implementation::Null),      //  0x00  0
        uint8_t(QRhi::Implementation::Vulkan),    //  0x01  1
        uint8_t(QRhi::Implementation::OpenGLES2), //  0x02  2
        uint8_t(QRhi::Implementation::D3D11),     //  0x03  3
        uint8_t(QRhi::Implementation::Metal),     //  0x04  4
        uint8_t(QRhi::Implementation::D3D12)      //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhi_TypeF(),
        "2:PySide6.QtGui.QRhi.Implementation",
        Implementation_Initializer, Implementation_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhi_Implementation_IDX].type = EType;
    // Register converter for enum 'QRhi::Implementation'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhi_Implementation_CppToPython_QRhi_Implementation);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRhi_Implementation_PythonToCpp_QRhi_Implementation,
            is_QRhi_Implementation_PythonToCpp_QRhi_Implementation_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhi::Implementation");
        Shiboken::Conversions::registerConverterName(converter, "Implementation");
    }
    // End of 'Implementation' enum.

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "EnableDebugMarkers",
        "PreferSoftwareRenderer",
        "EnablePipelineCacheDataSave",
        "EnableTimestamps",
        "SuppressSmokeTestWarnings",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Flag_InitializerValues[] = {
        uint8_t(QRhi::Flag::EnableDebugMarkers),          //  0x01  1
        uint8_t(QRhi::Flag::PreferSoftwareRenderer),      //  0x02  2
        uint8_t(QRhi::Flag::EnablePipelineCacheDataSave), //  0x04  4
        uint8_t(QRhi::Flag::EnableTimestamps),            //  0x08  8
        uint8_t(QRhi::Flag::SuppressSmokeTestWarnings)    //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhi_TypeF(),
        "2:PySide6.QtGui.QRhi.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhi_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhi_Flag_IDX].type =
        EType;
    // Register converter for enum 'QRhi::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhi_Flag_CppToPython_QRhi_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRhi_Flag_PythonToCpp_QRhi_Flag,
            is_QRhi_Flag_PythonToCpp_QRhi_Flag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhi::Flag");
        Shiboken::Conversions::registerConverterName(converter, "Flag");
        // Register converter for flag 'QFlags<QRhi::Flag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QRhi::Flag>");
        Shiboken::Conversions::registerConverterName(converter, "QRhi::Flags");
    }
    // End of 'Flag' enum/flags.

    // Initialization of enum 'FrameOpResult'.
    const char *FrameOpResult_Initializer[] = {
        "FrameOpSuccess",
        "FrameOpError",
        "FrameOpSwapChainOutOfDate",
        "FrameOpDeviceLost",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FrameOpResult_InitializerValues[] = {
        uint8_t(QRhi::FrameOpResult::FrameOpSuccess),            //  0x00  0
        uint8_t(QRhi::FrameOpResult::FrameOpError),              //  0x01  1
        uint8_t(QRhi::FrameOpResult::FrameOpSwapChainOutOfDate), //  0x02  2
        uint8_t(QRhi::FrameOpResult::FrameOpDeviceLost)          //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhi_TypeF(),
        "2:PySide6.QtGui.QRhi.FrameOpResult",
        FrameOpResult_Initializer, FrameOpResult_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhi_FrameOpResult_IDX].type = EType;
    // Register converter for enum 'QRhi::FrameOpResult'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhi_FrameOpResult_CppToPython_QRhi_FrameOpResult);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRhi_FrameOpResult_PythonToCpp_QRhi_FrameOpResult,
            is_QRhi_FrameOpResult_PythonToCpp_QRhi_FrameOpResult_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhi::FrameOpResult");
        Shiboken::Conversions::registerConverterName(converter, "FrameOpResult");
    }
    // End of 'FrameOpResult' enum.

    // Initialization of enum 'Feature'.
    const char *Feature_Initializer[] = {
        "MultisampleTexture",
        "MultisampleRenderBuffer",
        "DebugMarkers",
        "Timestamps",
        "Instancing",
        "CustomInstanceStepRate",
        "PrimitiveRestart",
        "NonDynamicUniformBuffers",
        "NonFourAlignedEffectiveIndexBufferOffset",
        "NPOTTextureRepeat",
        "RedOrAlpha8IsRed",
        "ElementIndexUint",
        "Compute",
        "WideLines",
        "VertexShaderPointSize",
        "BaseVertex",
        "BaseInstance",
        "TriangleFanTopology",
        "ReadBackNonUniformBuffer",
        "ReadBackNonBaseMipLevel",
        "TexelFetch",
        "RenderToNonBaseMipLevel",
        "IntAttributes",
        "ScreenSpaceDerivatives",
        "ReadBackAnyTextureFormat",
        "PipelineCacheDataLoadSave",
        "ImageDataStride",
        "RenderBufferImport",
        "ThreeDimensionalTextures",
        "RenderTo3DTextureSlice",
        "TextureArrays",
        "Tessellation",
        "GeometryShader",
        "TextureArrayRange",
        "NonFillPolygonMode",
        "OneDimensionalTextures",
        "OneDimensionalTextureMipmaps",
        "HalfAttributes",
        "RenderToOneDimensionalTexture",
        "ThreeDimensionalTextureMipmaps",
        "MultiView",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Feature_InitializerValues[] = {
        uint8_t(QRhi::Feature::MultisampleTexture),                       //  0x01  1
        uint8_t(QRhi::Feature::MultisampleRenderBuffer),                  //  0x02  2
        uint8_t(QRhi::Feature::DebugMarkers),                             //  0x03  3
        uint8_t(QRhi::Feature::Timestamps),                               //  0x04  4
        uint8_t(QRhi::Feature::Instancing),                               //  0x05  5
        uint8_t(QRhi::Feature::CustomInstanceStepRate),                   //  0x06  6
        uint8_t(QRhi::Feature::PrimitiveRestart),                         //  0x07  7
        uint8_t(QRhi::Feature::NonDynamicUniformBuffers),                 //  0x08  8
        uint8_t(QRhi::Feature::NonFourAlignedEffectiveIndexBufferOffset), //  0x09  9
        uint8_t(QRhi::Feature::NPOTTextureRepeat),                        //  0x0a  10
        uint8_t(QRhi::Feature::RedOrAlpha8IsRed),                         //  0x0b  11
        uint8_t(QRhi::Feature::ElementIndexUint),                         //  0x0c  12
        uint8_t(QRhi::Feature::Compute),                                  //  0x0d  13
        uint8_t(QRhi::Feature::WideLines),                                //  0x0e  14
        uint8_t(QRhi::Feature::VertexShaderPointSize),                    //  0x0f  15
        uint8_t(QRhi::Feature::BaseVertex),                               //  0x10  16
        uint8_t(QRhi::Feature::BaseInstance),                             //  0x11  17
        uint8_t(QRhi::Feature::TriangleFanTopology),                      //  0x12  18
        uint8_t(QRhi::Feature::ReadBackNonUniformBuffer),                 //  0x13  19
        uint8_t(QRhi::Feature::ReadBackNonBaseMipLevel),                  //  0x14  20
        uint8_t(QRhi::Feature::TexelFetch),                               //  0x15  21
        uint8_t(QRhi::Feature::RenderToNonBaseMipLevel),                  //  0x16  22
        uint8_t(QRhi::Feature::IntAttributes),                            //  0x17  23
        uint8_t(QRhi::Feature::ScreenSpaceDerivatives),                   //  0x18  24
        uint8_t(QRhi::Feature::ReadBackAnyTextureFormat),                 //  0x19  25
        uint8_t(QRhi::Feature::PipelineCacheDataLoadSave),                //  0x1a  26
        uint8_t(QRhi::Feature::ImageDataStride),                          //  0x1b  27
        uint8_t(QRhi::Feature::RenderBufferImport),                       //  0x1c  28
        uint8_t(QRhi::Feature::ThreeDimensionalTextures),                 //  0x1d  29
        uint8_t(QRhi::Feature::RenderTo3DTextureSlice),                   //  0x1e  30
        uint8_t(QRhi::Feature::TextureArrays),                            //  0x1f  31
        uint8_t(QRhi::Feature::Tessellation),                             //  0x20  32
        uint8_t(QRhi::Feature::GeometryShader),                           //  0x21  33
        uint8_t(QRhi::Feature::TextureArrayRange),                        //  0x22  34
        uint8_t(QRhi::Feature::NonFillPolygonMode),                       //  0x23  35
        uint8_t(QRhi::Feature::OneDimensionalTextures),                   //  0x24  36
        uint8_t(QRhi::Feature::OneDimensionalTextureMipmaps),             //  0x25  37
        uint8_t(QRhi::Feature::HalfAttributes),                           //  0x26  38
        uint8_t(QRhi::Feature::RenderToOneDimensionalTexture),            //  0x27  39
        uint8_t(QRhi::Feature::ThreeDimensionalTextureMipmaps),           //  0x28  40
        uint8_t(QRhi::Feature::MultiView)                                 //  0x29  41
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhi_TypeF(),
        "2:PySide6.QtGui.QRhi.Feature",
        Feature_Initializer, Feature_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhi_Feature_IDX].type = EType;
    // Register converter for enum 'QRhi::Feature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhi_Feature_CppToPython_QRhi_Feature);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRhi_Feature_PythonToCpp_QRhi_Feature,
            is_QRhi_Feature_PythonToCpp_QRhi_Feature_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhi::Feature");
        Shiboken::Conversions::registerConverterName(converter, "Feature");
    }
    // End of 'Feature' enum.

    // Initialization of enum 'BeginFrameFlag'.
    const char *BeginFrameFlag_Initializer[] = {
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    const uint8_t *BeginFrameFlag_InitializerValues{};
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhi_TypeF(),
        "2:PySide6.QtGui.QRhi.BeginFrameFlag",
        BeginFrameFlag_Initializer, BeginFrameFlag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhi_BeginFrameFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhi_BeginFrameFlag_IDX].type =
        EType;
    // Register converter for enum 'QRhi::BeginFrameFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhi_BeginFrameFlag_CppToPython_QRhi_BeginFrameFlag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRhi_BeginFrameFlag_PythonToCpp_QRhi_BeginFrameFlag,
            is_QRhi_BeginFrameFlag_PythonToCpp_QRhi_BeginFrameFlag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhi::BeginFrameFlag");
        Shiboken::Conversions::registerConverterName(converter, "BeginFrameFlag");
        // Register converter for flag 'QFlags<QRhi::BeginFrameFlag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QRhi::BeginFrameFlag>");
        Shiboken::Conversions::registerConverterName(converter, "QRhi::BeginFrameFlags");
    }
    // End of 'BeginFrameFlag' enum/flags.

    // Initialization of enum 'EndFrameFlag'.
    const char *EndFrameFlag_Initializer[] = {
        "SkipPresent",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t EndFrameFlag_InitializerValues[] = {
        uint8_t(QRhi::EndFrameFlag::SkipPresent) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhi_TypeF(),
        "2:PySide6.QtGui.QRhi.EndFrameFlag",
        EndFrameFlag_Initializer, EndFrameFlag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhi_EndFrameFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhi_EndFrameFlag_IDX].type =
        EType;
    // Register converter for enum 'QRhi::EndFrameFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhi_EndFrameFlag_CppToPython_QRhi_EndFrameFlag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRhi_EndFrameFlag_PythonToCpp_QRhi_EndFrameFlag,
            is_QRhi_EndFrameFlag_PythonToCpp_QRhi_EndFrameFlag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhi::EndFrameFlag");
        Shiboken::Conversions::registerConverterName(converter, "EndFrameFlag");
        // Register converter for flag 'QFlags<QRhi::EndFrameFlag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QRhi::EndFrameFlag>");
        Shiboken::Conversions::registerConverterName(converter, "QRhi::EndFrameFlags");
    }
    // End of 'EndFrameFlag' enum/flags.

    // Initialization of enum 'ResourceLimit'.
    const char *ResourceLimit_Initializer[] = {
        "TextureSizeMin",
        "TextureSizeMax",
        "MaxColorAttachments",
        "FramesInFlight",
        "MaxAsyncReadbackFrames",
        "MaxThreadGroupsPerDimension",
        "MaxThreadsPerThreadGroup",
        "MaxThreadGroupX",
        "MaxThreadGroupY",
        "MaxThreadGroupZ",
        "TextureArraySizeMax",
        "MaxUniformBufferRange",
        "MaxVertexInputs",
        "MaxVertexOutputs",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ResourceLimit_InitializerValues[] = {
        uint8_t(QRhi::ResourceLimit::TextureSizeMin),              //  0x01  1
        uint8_t(QRhi::ResourceLimit::TextureSizeMax),              //  0x02  2
        uint8_t(QRhi::ResourceLimit::MaxColorAttachments),         //  0x03  3
        uint8_t(QRhi::ResourceLimit::FramesInFlight),              //  0x04  4
        uint8_t(QRhi::ResourceLimit::MaxAsyncReadbackFrames),      //  0x05  5
        uint8_t(QRhi::ResourceLimit::MaxThreadGroupsPerDimension), //  0x06  6
        uint8_t(QRhi::ResourceLimit::MaxThreadsPerThreadGroup),    //  0x07  7
        uint8_t(QRhi::ResourceLimit::MaxThreadGroupX),             //  0x08  8
        uint8_t(QRhi::ResourceLimit::MaxThreadGroupY),             //  0x09  9
        uint8_t(QRhi::ResourceLimit::MaxThreadGroupZ),             //  0x0a  10
        uint8_t(QRhi::ResourceLimit::TextureArraySizeMax),         //  0x0b  11
        uint8_t(QRhi::ResourceLimit::MaxUniformBufferRange),       //  0x0c  12
        uint8_t(QRhi::ResourceLimit::MaxVertexInputs),             //  0x0d  13
        uint8_t(QRhi::ResourceLimit::MaxVertexOutputs)             //  0x0e  14
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhi_TypeF(),
        "2:PySide6.QtGui.QRhi.ResourceLimit",
        ResourceLimit_Initializer, ResourceLimit_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhi_ResourceLimit_IDX].type = EType;
    // Register converter for enum 'QRhi::ResourceLimit'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhi_ResourceLimit_CppToPython_QRhi_ResourceLimit);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QRhi_ResourceLimit_PythonToCpp_QRhi_ResourceLimit,
            is_QRhi_ResourceLimit_PythonToCpp_QRhi_ResourceLimit_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QRhi::ResourceLimit");
        Shiboken::Conversions::registerConverterName(converter, "ResourceLimit");
    }
    // End of 'ResourceLimit' enum.

    qRegisterMetaType< ::QRhi *>();
    qRegisterMetaType< ::QRhi::Implementation >("QRhi::Implementation");
    qRegisterMetaType< ::QRhi::Flag >("QRhi::Flag");
    qRegisterMetaType< ::QRhi::FrameOpResult >("QRhi::FrameOpResult");
    qRegisterMetaType< ::QRhi::Feature >("QRhi::Feature");
    qRegisterMetaType< ::QRhi::BeginFrameFlag >("QRhi::BeginFrameFlag");
    qRegisterMetaType< ::QRhi::EndFrameFlag >("QRhi::EndFrameFlag");
    qRegisterMetaType< ::QRhi::ResourceLimit >("QRhi::ResourceLimit");

    return pyType;
}

PyTypeObject *init_QRhiStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QRhi");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "MAX_MIP_LEVELS",
                         Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &QRhi::MAX_MIP_LEVELS));
    return type;
}
