// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"

// main header
#include "qshaderversion_wrapper.h"

// Argument includes
#include <rhi/qshader.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QShaderVersion_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QShaderVersion >()))
        return -1;

    ::QShaderVersion *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QShaderVersion.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:QShaderVersion", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QShaderVersion::QShaderVersion()
    // 1: QShaderVersion::QShaderVersion(QShaderVersion)
    // 2: QShaderVersion::QShaderVersion(int,QFlags<QShaderVersion::Flag>=)
    if (numArgs == 0) {
        overloadId = 0; // QShaderVersion()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QShaderVersion(int,QFlags<QShaderVersion::Flag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QShaderVersion_Flag_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 2; // QShaderVersion(int,QFlags<QShaderVersion::Flag>)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QShaderVersion(QShaderVersion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QShaderVersion()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QShaderVersion()
                cptr = new ::QShaderVersion();
            }
            break;
        }
        case 1: // QShaderVersion(const QShaderVersion & QShaderVersion)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QShaderVersion cppArg0_local;
            ::QShaderVersion *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QShaderVersion(QShaderVersion)
                cptr = new ::QShaderVersion(*cppArg0);
            }
            break;
        }
        case 2: // QShaderVersion(int v, QFlags<QShaderVersion::Flag> f)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_f = Shiboken::String::createStaticString("f");
                if (PyDict_Contains(kwds, key_f) != 0) {
                    value = PyDict_GetItem(kwds, key_f);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_f);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QShaderVersion_Flag_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_f);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QShaderVersion::Flag> cppArg1 = QShaderVersion::Flags();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QShaderVersion(int,QFlags<QShaderVersion::Flag>)
                cptr = new ::QShaderVersion(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QShaderVersion >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QShaderVersionFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QShaderVersion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QShaderVersion.flags";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // flags()const
            QFlags<QShaderVersion::Flag> cppResult = const_cast<const ::QShaderVersion *>(cppSelf)->flags();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QShaderVersion_Flag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QShaderVersionFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QShaderVersion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QShaderVersion.setFlags";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderVersion::setFlags(QFlags<QShaderVersion::Flag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QShaderVersion_Flag_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFlags(QFlags<QShaderVersion::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QShaderVersion::Flag> cppArg0 = QFlags<QShaderVersion::Flag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QShaderVersion::Flag>)
            cppSelf->setFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QShaderVersionFunc_setVersion(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QShaderVersion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QShaderVersion.setVersion";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QShaderVersion::setVersion(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setVersion(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVersion(int)
            cppSelf->setVersion(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QShaderVersionFunc_version(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QShaderVersion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QShaderVersion.version";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // version()const
            int cppResult = const_cast<const ::QShaderVersion *>(cppSelf)->version();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QShaderVersion__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QShaderVersion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QShaderVersion_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QShaderVersion_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QShaderVersion_methods[] = {
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QShaderVersionFunc_flags), METH_NOARGS, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QShaderVersionFunc_setFlags), METH_O, nullptr},
    {"setVersion", reinterpret_cast<PyCFunction>(Sbk_QShaderVersionFunc_setVersion), METH_O, nullptr},
    {"version", reinterpret_cast<PyCFunction>(Sbk_QShaderVersionFunc_version), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QShaderVersion__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QShaderVersion_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QShaderVersion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX]), (pyArg)))) {
                // operator!=(const QShaderVersion & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QShaderVersion cppArg0_local;
                ::QShaderVersion *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX]), (pyArg)))) {
                // operator<(const QShaderVersion & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QShaderVersion cppArg0_local;
                ::QShaderVersion *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX]), (pyArg)))) {
                // operator==(const QShaderVersion & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QShaderVersion cppArg0_local;
                ::QShaderVersion *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QShaderVersion_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QShaderVersion_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QShaderVersion__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QShaderVersion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QShaderVersion_Type = nullptr;
static PyTypeObject *Sbk_QShaderVersion_TypeF(void)
{
    return _Sbk_QShaderVersion_Type;
}

static PyType_Slot Sbk_QShaderVersion_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QShaderVersion__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QShaderVersion_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QShaderVersion_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QShaderVersion_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QShaderVersion_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QShaderVersion_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QShaderVersion_spec = {
    "2:PySide6.QtGui.QShaderVersion",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QShaderVersion_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QShaderVersion_Flag_PythonToCpp_QShaderVersion_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QShaderVersion::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QShaderVersion::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_QShaderVersion_Flag_PythonToCpp_QShaderVersion_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_Flag_IDX])))
        return QShaderVersion_Flag_PythonToCpp_QShaderVersion_Flag;
    return {};
}
static PyObject *QShaderVersion_Flag_CppToPython_QShaderVersion_Flag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QShaderVersion::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_Flag_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QShaderVersion_PythonToCpp_QShaderVersion_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QShaderVersion_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QShaderVersion_PythonToCpp_QShaderVersion_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QShaderVersion_TypeF()))
        return QShaderVersion_PythonToCpp_QShaderVersion_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QShaderVersion_PTR_CppToPython_QShaderVersion(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QShaderVersion *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QShaderVersion_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QShaderVersion_COPY_CppToPython_QShaderVersion(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QShaderVersion *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QShaderVersion_TypeF(), new ::QShaderVersion(*source), true, true);
}

// Python to C++ copy conversion.
static void QShaderVersion_PythonToCpp_QShaderVersion_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QShaderVersion *>(cppOut) = *reinterpret_cast< ::QShaderVersion *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QShaderVersion_PythonToCpp_QShaderVersion_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QShaderVersion_TypeF()))
        return QShaderVersion_PythonToCpp_QShaderVersion_COPY;
    return {};
}

// Implicit conversions.
static void int_PythonToCpp_QShaderVersion(PyObject *pyIn, void *cppOut)
{
    int cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn, &cppIn);
    *reinterpret_cast<::QShaderVersion *>(cppOut) = ::QShaderVersion(cppIn);
}
static PythonToCppFunc is_int_PythonToCpp_QShaderVersion_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return int_PythonToCpp_QShaderVersion;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QShaderVersion_SignatureStrings[] = {
    "2:PySide6.QtGui.QShaderVersion(self)",
    "1:PySide6.QtGui.QShaderVersion(self,QShaderVersion:typing.Union[PySide6.QtGui.QShaderVersion, int])",
    "0:PySide6.QtGui.QShaderVersion(self,v:int,f:PySide6.QtGui.QShaderVersion.Flag=QShaderVersion.Flags())",
    "PySide6.QtGui.QShaderVersion.flags(self)->PySide6.QtGui.QShaderVersion.Flag",
    "PySide6.QtGui.QShaderVersion.setFlags(self,f:PySide6.QtGui.QShaderVersion.Flag)",
    "PySide6.QtGui.QShaderVersion.setVersion(self,v:int)",
    "PySide6.QtGui.QShaderVersion.version(self)->int",
    "PySide6.QtGui.QShaderVersion.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QShaderVersion(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX].type;

    Shiboken::AutoDecRef Sbk_QShaderVersion_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QShaderVersion_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QShaderVersion",
        "QShaderVersion",
        &Sbk_QShaderVersion_spec,
        &Shiboken::callCppDestructor< ::QShaderVersion >,
        Sbk_QShaderVersion_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QShaderVersion_TypeF(); // references _Sbk_QShaderVersion_Type
    InitSignatureStrings(pyType, QShaderVersion_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QShaderVersion_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QShaderVersion_PythonToCpp_QShaderVersion_PTR,
        is_QShaderVersion_PythonToCpp_QShaderVersion_PTR_Convertible,
        QShaderVersion_PTR_CppToPython_QShaderVersion,
        QShaderVersion_COPY_CppToPython_QShaderVersion);

    Shiboken::Conversions::registerConverterName(converter, "QShaderVersion");
    Shiboken::Conversions::registerConverterName(converter, "QShaderVersion*");
    Shiboken::Conversions::registerConverterName(converter, "QShaderVersion&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QShaderVersion).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QShaderVersion_PythonToCpp_QShaderVersion_COPY,
        is_QShaderVersion_PythonToCpp_QShaderVersion_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        int_PythonToCpp_QShaderVersion,
        is_int_PythonToCpp_QShaderVersion_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QShaderVersion_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "GlslEs",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Flag_InitializerValues[] = {
        uint8_t(QShaderVersion::Flag::GlslEs) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QShaderVersion_TypeF(),
        "2:PySide6.QtGui.QShaderVersion.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QShaderVersion_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QShaderVersion_Flag_IDX].type =
        EType;
    // Register converter for enum 'QShaderVersion::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QShaderVersion_Flag_CppToPython_QShaderVersion_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QShaderVersion_Flag_PythonToCpp_QShaderVersion_Flag,
            is_QShaderVersion_Flag_PythonToCpp_QShaderVersion_Flag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QShaderVersion::Flag");
        Shiboken::Conversions::registerConverterName(converter, "Flag");
        // Register converter for flag 'QFlags<QShaderVersion::Flag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QShaderVersion::Flag>");
        Shiboken::Conversions::registerConverterName(converter, "QShaderVersion::Flags");
    }
    // End of 'Flag' enum/flags.

    qRegisterMetaType< ::QShaderVersion >("QShaderVersion");
    qRegisterMetaType< ::QShaderVersion::Flag >("QShaderVersion::Flag");

    return pyType;
}
