// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"

// main header
#include "qsurface_wrapper.h"

// Argument includes
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSurfaceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSurfaceWrapper::QSurfaceWrapper(::QSurface::SurfaceClass type) : QSurface(type)
{
    resetPyMethodCache();
    // ... middle
}

::QSurfaceFormat QSurfaceWrapper::format() const
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSurface.format");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "format";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSurface.format");
        return {};
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSurface", funcName, Shiboken::SbkType< QSurfaceFormat >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSurfaceFormat cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSize QSurfaceWrapper::size() const
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSurface.size");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "size";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSurface.size");
        return {};
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSurface", funcName, Shiboken::SbkType< QSize >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSize cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QPlatformSurface * QSurfaceWrapper::surfaceHandle() const
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSurface.surfaceHandle");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "surfaceHandle";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSurface.surfaceHandle");
        return nullptr;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<QPlatformSurface>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSurface", funcName, Shiboken::SbkType< QPlatformSurface >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPlatformSurface *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSurface::SurfaceType QSurfaceWrapper::surfaceType() const
{
    if (m_PyMethodCache[3]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSurface.surfaceType");
        return QSurface::RasterSurface;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QSurface::RasterSurface;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "surfaceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSurface.surfaceType");
        return QSurface::RasterSurface;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QSurface::RasterSurface;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_SurfaceType_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSurface", funcName, Shiboken::SbkType< QSurface::SurfaceType >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QSurface::RasterSurface;
    }
    ::QSurface::SurfaceType cppResult{QSurface::RasterSurface};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QSurfaceWrapper::~QSurfaceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSurface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QSurface");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSurface >()))
        return -1;

    QSurfaceWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QSurface.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSurface", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSurface::QSurface(QSurface::SurfaceClass)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_SurfaceClass_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QSurface(QSurface::SurfaceClass)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        ::QSurface::SurfaceClass cppArg0{QSurface::Window};
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSurface(QSurface::SurfaceClass)
            cptr = new QSurfaceWrapper(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSurface >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSurfaceFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurface.format";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // format()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSurface.format");
                return {};
            }
            QSurfaceFormat cppResult = const_cast<const ::QSurface *>(cppSelf)->format();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurface.size";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // size()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSurface.size");
                return {};
            }
            QSize cppResult = const_cast<const ::QSurface *>(cppSelf)->size();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFunc_supportsOpenGL(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurface.supportsOpenGL";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportsOpenGL()const
            bool cppResult = const_cast<const ::QSurface *>(cppSelf)->supportsOpenGL();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFunc_surfaceClass(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurface.surfaceClass";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // surfaceClass()const
            QSurface::SurfaceClass cppResult = const_cast<const ::QSurface *>(cppSelf)->surfaceClass();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_SurfaceClass_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFunc_surfaceHandle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurface.surfaceHandle";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // surfaceHandle()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSurface.surfaceHandle");
                return {};
            }
            QPlatformSurface * cppResult = const_cast<const ::QSurface *>(cppSelf)->surfaceHandle();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<QPlatformSurface>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSurfaceFunc_surfaceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QSurface.surfaceType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // surfaceType()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSurface.surfaceType");
                return {};
            }
            QSurface::SurfaceType cppResult = const_cast<const ::QSurface *>(cppSelf)->surfaceType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_SurfaceType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSurface_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSurface_EnumFlagInfo[] = {
    "SurfaceClass:Enum",
    "SurfaceType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSurface_methods[] = {
    {"format", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFunc_format), METH_NOARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFunc_size), METH_NOARGS, nullptr},
    {"supportsOpenGL", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFunc_supportsOpenGL), METH_NOARGS, nullptr},
    {"surfaceClass", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFunc_surfaceClass), METH_NOARGS, nullptr},
    {"surfaceHandle", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFunc_surfaceHandle), METH_NOARGS, nullptr},
    {"surfaceType", reinterpret_cast<PyCFunction>(Sbk_QSurfaceFunc_surfaceType), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSurface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSurface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSurfaceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QSurface_get_m_type(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSurface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QSurface::SurfaceClass cppOut_local = cppSelf->m_type;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_SurfaceClass_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QSurface_set_m_type(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSurface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_type");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_SurfaceClass_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_type", "SurfaceClass");
        return -1;
    }

    auto cppOut_local = cppSelf->m_type;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_type = cppOut_local;

    return 0;
}

// Getters and Setters for QSurface
static PyGetSetDef Sbk_QSurface_getsetlist[] = {
    {const_cast<char *>("m_type"), Sbk_QSurface_get_m_type, Sbk_QSurface_set_m_type, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSurface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSurface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSurface_Type = nullptr;
static PyTypeObject *Sbk_QSurface_TypeF(void)
{
    return _Sbk_QSurface_Type;
}

static PyType_Slot Sbk_QSurface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSurface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSurface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSurface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSurface_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QSurface_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSurface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSurface_spec = {
    "2:PySide6.QtGui.QSurface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSurface_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QSurface_SurfaceClass_PythonToCpp_QSurface_SurfaceClass(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSurface::SurfaceClass>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSurface::SurfaceClass *>(cppOut) = value;

}
static PythonToCppFunc is_QSurface_SurfaceClass_PythonToCpp_QSurface_SurfaceClass_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_SurfaceClass_IDX])))
        return QSurface_SurfaceClass_PythonToCpp_QSurface_SurfaceClass;
    return {};
}
static PyObject *QSurface_SurfaceClass_CppToPython_QSurface_SurfaceClass(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSurface::SurfaceClass *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_SurfaceClass_IDX]), castCppIn);

}

static void QSurface_SurfaceType_PythonToCpp_QSurface_SurfaceType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSurface::SurfaceType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSurface::SurfaceType *>(cppOut) = value;

}
static PythonToCppFunc is_QSurface_SurfaceType_PythonToCpp_QSurface_SurfaceType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_SurfaceType_IDX])))
        return QSurface_SurfaceType_PythonToCpp_QSurface_SurfaceType;
    return {};
}
static PyObject *QSurface_SurfaceType_CppToPython_QSurface_SurfaceType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSurface::SurfaceType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurface_SurfaceType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSurface_PythonToCpp_QSurface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSurface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSurface_PythonToCpp_QSurface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSurface_TypeF()))
        return QSurface_PythonToCpp_QSurface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSurface_PTR_CppToPython_QSurface(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QSurface *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QSurface_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QSurface_SignatureStrings[] = {
    "PySide6.QtGui.QSurface(self,type:PySide6.QtGui.QSurface.SurfaceClass)",
    "PySide6.QtGui.QSurface.format(self)->PySide6.QtGui.QSurfaceFormat",
    "PySide6.QtGui.QSurface.size(self)->PySide6.QtCore.QSize",
    "PySide6.QtGui.QSurface.supportsOpenGL(self)->bool",
    "PySide6.QtGui.QSurface.surfaceClass(self)->PySide6.QtGui.QSurface.SurfaceClass",
    "PySide6.QtGui.QSurface.surfaceHandle(self)->QPlatformSurface*",
    "PySide6.QtGui.QSurface.surfaceType(self)->PySide6.QtGui.QSurface.SurfaceType",
    nullptr}; // Sentinel

PyTypeObject *init_QSurface(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX].type;

    Shiboken::AutoDecRef Sbk_QSurface_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSurface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSurface",
        "QSurface*",
        &Sbk_QSurface_spec,
        &Shiboken::callCppDestructor< QSurface >,
        Sbk_QSurface_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSurface_TypeF(); // references _Sbk_QSurface_Type
    InitSignatureStrings(pyType, QSurface_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSurface_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QSurface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSurface_PythonToCpp_QSurface_PTR,
        is_QSurface_PythonToCpp_QSurface_PTR_Convertible,
        QSurface_PTR_CppToPython_QSurface);

    Shiboken::Conversions::registerConverterName(converter, "QSurface");
    Shiboken::Conversions::registerConverterName(converter, "QSurface*");
    Shiboken::Conversions::registerConverterName(converter, "QSurface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSurface).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSurfaceWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSurface_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SurfaceClass'.
    const char *SurfaceClass_Initializer[] = {
        "Window",
        "Offscreen",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SurfaceClass_InitializerValues[] = {
        uint8_t(QSurface::SurfaceClass::Window),   //  0x00  0
        uint8_t(QSurface::SurfaceClass::Offscreen) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSurface_TypeF(),
        "2:PySide6.QtGui.QSurface.SurfaceClass",
        SurfaceClass_Initializer, SurfaceClass_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QSurface_SurfaceClass_IDX].type = EType;
    // Register converter for enum 'QSurface::SurfaceClass'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSurface_SurfaceClass_CppToPython_QSurface_SurfaceClass);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSurface_SurfaceClass_PythonToCpp_QSurface_SurfaceClass,
            is_QSurface_SurfaceClass_PythonToCpp_QSurface_SurfaceClass_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSurface::SurfaceClass");
        Shiboken::Conversions::registerConverterName(converter, "SurfaceClass");
    }
    // End of 'SurfaceClass' enum.

    // Initialization of enum 'SurfaceType'.
    const char *SurfaceType_Initializer[] = {
        "RasterSurface",
        "OpenGLSurface",
        "RasterGLSurface",
        "OpenVGSurface",
        "VulkanSurface",
        "MetalSurface",
        "Direct3DSurface",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SurfaceType_InitializerValues[] = {
        uint8_t(QSurface::SurfaceType::RasterSurface),   //  0x00  0
        uint8_t(QSurface::SurfaceType::OpenGLSurface),   //  0x01  1
        uint8_t(QSurface::SurfaceType::RasterGLSurface), //  0x02  2
        uint8_t(QSurface::SurfaceType::OpenVGSurface),   //  0x03  3
        uint8_t(QSurface::SurfaceType::VulkanSurface),   //  0x04  4
        uint8_t(QSurface::SurfaceType::MetalSurface),    //  0x05  5
        uint8_t(QSurface::SurfaceType::Direct3DSurface)  //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSurface_TypeF(),
        "2:PySide6.QtGui.QSurface.SurfaceType",
        SurfaceType_Initializer, SurfaceType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QSurface_SurfaceType_IDX].type = EType;
    // Register converter for enum 'QSurface::SurfaceType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSurface_SurfaceType_CppToPython_QSurface_SurfaceType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSurface_SurfaceType_PythonToCpp_QSurface_SurfaceType,
            is_QSurface_SurfaceType_PythonToCpp_QSurface_SurfaceType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSurface::SurfaceType");
        Shiboken::Conversions::registerConverterName(converter, "SurfaceType");
    }
    // End of 'SurfaceType' enum.

    qRegisterMetaType< ::QSurface *>();
    qRegisterMetaType< ::QSurface::SurfaceClass >("QSurface::SurfaceClass");
    qRegisterMetaType< ::QSurface::SurfaceType >("QSurface::SurfaceType");

    return pyType;
}
