// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"

// main header
#include "qtextlength_wrapper.h"

// Argument includes
#include <QtGui/qtextformat.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextLength_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextLength >()))
        return -1;

    ::QTextLength *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextLength.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QTextLength", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextLength::QTextLength()
    // 1: QTextLength::QTextLength(QTextLength::Type,qreal)
    // 2: QTextLength::QTextLength(QTextLength)
    if (numArgs == 0) {
        overloadId = 0; // QTextLength()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QTextLength(QTextLength)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_Type_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // QTextLength(QTextLength::Type,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextLength()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextLength()
                cptr = new ::QTextLength();
            }
            break;
        }
        case 1: // QTextLength(QTextLength::Type type, qreal value)
        {
            ::QTextLength::Type cppArg0{QTextLength::VariableLength};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextLength(QTextLength::Type,qreal)
                cptr = new ::QTextLength(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QTextLength(const QTextLength & QTextLength)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextLength cppArg0_local;
            ::QTextLength *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextLength(QTextLength)
                cptr = new ::QTextLength(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextLength >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextLengthFunc_rawValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLength *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextLength.rawValue";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // rawValue()const
            qreal cppResult = const_cast<const ::QTextLength *>(cppSelf)->rawValue();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextLengthFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLength *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtGui.QTextLength.type";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // type()const
            QTextLength::Type cppResult = const_cast<const ::QTextLength *>(cppSelf)->type();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_Type_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextLengthFunc_value(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLength *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtGui.QTextLength.value";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextLength::value(qreal)const->qreal
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // value(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // value(qreal)const
            qreal cppResult = const_cast<const ::QTextLength *>(cppSelf)->value(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextLength__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextLength *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextLength_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTextLength_EnumFlagInfo[] = {
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextLength_methods[] = {
    {"rawValue", reinterpret_cast<PyCFunction>(Sbk_QTextLengthFunc_rawValue), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QTextLengthFunc_type), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QTextLengthFunc_value), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextLength__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QTextLength_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextLength *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), (pyArg)))) {
                // operator!=(const QTextLength & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextLength cppArg0_local;
                ::QTextLength *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), (pyArg)))) {
                // operator==(const QTextLength & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QTextLength cppArg0_local;
                ::QTextLength *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QTextLength_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextLength_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QTextLength__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextLength *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextLength_Type = nullptr;
static PyTypeObject *Sbk_QTextLength_TypeF(void)
{
    return _Sbk_QTextLength_Type;
}

static PyType_Slot Sbk_QTextLength_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QTextLength__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextLength_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextLength_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QTextLength_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextLength_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextLength_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextLength_spec = {
    "2:PySide6.QtGui.QTextLength",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextLength_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QTextLength_Type_PythonToCpp_QTextLength_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextLength::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextLength::Type *>(cppOut) = value;

}
static PythonToCppFunc is_QTextLength_Type_PythonToCpp_QTextLength_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_Type_IDX])))
        return QTextLength_Type_PythonToCpp_QTextLength_Type;
    return {};
}
static PyObject *QTextLength_Type_CppToPython_QTextLength_Type(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QTextLength::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_Type_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextLength_PythonToCpp_QTextLength_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextLength_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextLength_PythonToCpp_QTextLength_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextLength_TypeF()))
        return QTextLength_PythonToCpp_QTextLength_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextLength_PTR_CppToPython_QTextLength(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QTextLength *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QTextLength_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QTextLength_COPY_CppToPython_QTextLength(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextLength *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextLength_TypeF(), new ::QTextLength(*source), true, true);
}

// Python to C++ copy conversion.
static void QTextLength_PythonToCpp_QTextLength_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextLength *>(cppOut) = *reinterpret_cast< ::QTextLength *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QTextLength_PythonToCpp_QTextLength_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextLength_TypeF()))
        return QTextLength_PythonToCpp_QTextLength_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QTextLength_SignatureStrings[] = {
    "2:PySide6.QtGui.QTextLength(self)",
    "1:PySide6.QtGui.QTextLength(self,type:PySide6.QtGui.QTextLength.Type,value:qreal)",
    "0:PySide6.QtGui.QTextLength(self,QTextLength:PySide6.QtGui.QTextLength)",
    "PySide6.QtGui.QTextLength.rawValue(self)->qreal",
    "PySide6.QtGui.QTextLength.type(self)->PySide6.QtGui.QTextLength.Type",
    "PySide6.QtGui.QTextLength.value(self,maximumLength:qreal)->qreal",
    "PySide6.QtGui.QTextLength.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QTextLength(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextLength_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextLength_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextLength",
        "QTextLength",
        &Sbk_QTextLength_spec,
        &Shiboken::callCppDestructor< ::QTextLength >,
        Sbk_QTextLength_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextLength_TypeF(); // references _Sbk_QTextLength_Type
    InitSignatureStrings(pyType, QTextLength_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextLength_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextLength_PythonToCpp_QTextLength_PTR,
        is_QTextLength_PythonToCpp_QTextLength_PTR_Convertible,
        QTextLength_PTR_CppToPython_QTextLength,
        QTextLength_COPY_CppToPython_QTextLength);

    Shiboken::Conversions::registerConverterName(converter, "QTextLength");
    Shiboken::Conversions::registerConverterName(converter, "QTextLength*");
    Shiboken::Conversions::registerConverterName(converter, "QTextLength&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextLength).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QTextLength_PythonToCpp_QTextLength_COPY,
        is_QTextLength_PythonToCpp_QTextLength_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTextLength_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "VariableLength",
        "FixedLength",
        "PercentageLength",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QTextLength::Type::VariableLength),  //  0x00  0
        uint8_t(QTextLength::Type::FixedLength),     //  0x01  1
        uint8_t(QTextLength::Type::PercentageLength) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextLength_TypeF(),
        "2:PySide6.QtGui.QTextLength.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextLength_Type_IDX].type = EType;
    // Register converter for enum 'QTextLength::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextLength_Type_CppToPython_QTextLength_Type);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QTextLength_Type_PythonToCpp_QTextLength_Type,
            is_QTextLength_Type_PythonToCpp_QTextLength_Type_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QTextLength::Type");
        Shiboken::Conversions::registerConverterName(converter, "Type");
    }
    // End of 'Type' enum.

    qRegisterMetaType< ::QTextLength >("QTextLength");
    qRegisterMetaType< ::QTextLength::Type >("QTextLength::Type");

    return pyType;
}
