// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qthttpserver_python.h"

// main header
#include "qabstracthttpserver_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtHttpServer/qhttpserverrequest.h>
#include <QtHttpServer/qhttpserverresponder.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qlocalserver.h>
#include <QtNetwork/qssl.h>
#include <QtNetwork/qsslcertificate.h>
#include <QtNetwork/qsslconfiguration.h>
#include <QtNetwork/qsslkey.h>
#include <QtNetwork/qtcpserver.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractHttpServer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]);
    SBK_UNUSED(sbkSelf)
    SBK_UNUSED(type)
    SBK_UNUSED(myType)
    SBK_UNUSED(metaObject)
    Shiboken::Errors::setInstantiateAbstractClassDisabledWrapper("QAbstractHttpServer");
    return -1;
}

static PyObject *Sbk_QAbstractHttpServerFunc_bind(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QAbstractHttpServer.bind";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:bind", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractHttpServer::bind(QLocalServer*)
    // 1: QAbstractHttpServer::bind(QTcpServer*=)
    if (numArgs == 0) {
        overloadId = 1; // bind(QTcpServer*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QTcpServer_IDX]), (pyArgs[0])))) {
        overloadId = 1; // bind(QTcpServer*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QLocalServer_IDX]), (pyArgs[0])))) {
        overloadId = 0; // bind(QLocalServer*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // bind(QLocalServer * server)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLocalServer *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bind(QLocalServer*)
                cppSelf->bind(cppArg0);
            }
            break;
        }
        case 1: // bind(QTcpServer * server)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_server = Shiboken::String::createStaticString("server");
                if (PyDict_Contains(kwds, key_server) != 0) {
                    value = PyDict_GetItem(kwds, key_server);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_server);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QTcpServer_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_server);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTcpServer *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bind(QTcpServer*)
                cppSelf->bind(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractHttpServerFunc_listen(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QAbstractHttpServer.listen";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:listen", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractHttpServer::listen(const QHostAddress&=,quint16=)->quint16
    if (numArgs == 0) {
        overloadId = 0; // listen(QHostAddress,quint16)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // listen(QHostAddress,quint16)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
            overloadId = 0; // listen(QHostAddress,quint16)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_address = Shiboken::String::createStaticString("address");
            if (PyDict_Contains(kwds, key_address) != 0) {
                value = PyDict_GetItem(kwds, key_address);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_address);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_address);
            }
            static PyObject *const key_port = Shiboken::String::createStaticString("port");
            if (PyDict_Contains(kwds, key_port) != 0) {
                value = PyDict_GetItem(kwds, key_port);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_port);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_port);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QHostAddress cppArg0_local(QHostAddress::Any);
        ::QHostAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }
        quint16 cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // listen(QHostAddress,quint16)
            quint16 cppResult = cppSelf->listen(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractHttpServerFunc_localServers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtHttpServer.QAbstractHttpServer.localServers";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // localServers()const
            QList<QLocalServer*> cppResult = const_cast<const ::QAbstractHttpServer *>(cppSelf)->localServers();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtHttpServerTypeConverters[SBK_QtHttpServer_QList_QLocalServerPTR_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractHttpServerFunc_serverPorts(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtHttpServer.QAbstractHttpServer.serverPorts";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // serverPorts()
            QList<quint16> cppResult = cppSelf->serverPorts();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtHttpServerTypeConverters[SBK_QtHttpServer_QList_quint16_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractHttpServerFunc_servers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtHttpServer.QAbstractHttpServer.servers";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // servers()const
            QList<QTcpServer*> cppResult = const_cast<const ::QAbstractHttpServer *>(cppSelf)->servers();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtHttpServerTypeConverters[SBK_QtHttpServer_QList_QTcpServerPTR_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractHttpServerFunc_sslSetup(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractHttpServer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtHttpServer.QAbstractHttpServer.sslSetup";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:sslSetup", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractHttpServer::sslSetup(QSslCertificate,QSslKey,QSsl::SslProtocol=)
    // 1: QAbstractHttpServer::sslSetup(QSslConfiguration)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslConfiguration_IDX]), (pyArgs[0])))) {
        overloadId = 1; // sslSetup(QSslConfiguration)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslCertificate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSslKey_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // sslSetup(QSslCertificate,QSslKey,QSsl::SslProtocol)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_SslProtocol_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 0; // sslSetup(QSslCertificate,QSslKey,QSsl::SslProtocol)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // sslSetup(const QSslCertificate & certificate, const QSslKey & privateKey, QSsl::SslProtocol protocol)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_protocol = Shiboken::String::createStaticString("protocol");
                if (PyDict_Contains(kwds, key_protocol) != 0) {
                    value = PyDict_GetItem(kwds, key_protocol);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_protocol);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QSsl_SslProtocol_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_protocol);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSslCertificate cppArg0_local;
            ::QSslCertificate *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QSslKey cppArg1_local;
            ::QSslKey *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QSsl::SslProtocol cppArg2(QSsl::SecureProtocols);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sslSetup(QSslCertificate,QSslKey,QSsl::SslProtocol)
                cppSelf->sslSetup(*cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 1: // sslSetup(const QSslConfiguration & sslConfiguration)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSslConfiguration cppArg0_local;
            ::QSslConfiguration *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // sslSetup(QSslConfiguration)
                cppSelf->sslSetup(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QAbstractHttpServer_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractHttpServer_methods[] = {
    {"bind", reinterpret_cast<PyCFunction>(Sbk_QAbstractHttpServerFunc_bind), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"listen", reinterpret_cast<PyCFunction>(Sbk_QAbstractHttpServerFunc_listen), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"localServers", reinterpret_cast<PyCFunction>(Sbk_QAbstractHttpServerFunc_localServers), METH_NOARGS, nullptr},
    {"serverPorts", reinterpret_cast<PyCFunction>(Sbk_QAbstractHttpServerFunc_serverPorts), METH_NOARGS, nullptr},
    {"servers", reinterpret_cast<PyCFunction>(Sbk_QAbstractHttpServerFunc_servers), METH_NOARGS, nullptr},
    {"sslSetup", reinterpret_cast<PyCFunction>(Sbk_QAbstractHttpServerFunc_sslSetup), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractHttpServer_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractHttpServer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractHttpServer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractHttpServer_Type = nullptr;
static PyTypeObject *Sbk_QAbstractHttpServer_TypeF(void)
{
    return _Sbk_QAbstractHttpServer_Type;
}

static PyType_Slot Sbk_QAbstractHttpServer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractHttpServer_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractHttpServer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractHttpServer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractHttpServer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractHttpServer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractHttpServer_spec = {
    "2:PySide6.QtHttpServer.QAbstractHttpServer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractHttpServer_slots
};

} //extern "C"

static void *Sbk_QAbstractHttpServer_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAbstractHttpServer *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractHttpServer_PythonToCpp_QAbstractHttpServer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractHttpServer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractHttpServer_PythonToCpp_QAbstractHttpServer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractHttpServer_TypeF()))
        return QAbstractHttpServer_PythonToCpp_QAbstractHttpServer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractHttpServer_PTR_CppToPython_QAbstractHttpServer(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAbstractHttpServer *>(const_cast<void *>(cppIn)), Sbk_QAbstractHttpServer_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QAbstractHttpServer_SignatureStrings[] = {
    "PySide6.QtHttpServer.QAbstractHttpServer(self,parent:PySide6.QtCore.QObject=nullptr)",
    "1:PySide6.QtHttpServer.QAbstractHttpServer.bind(self,server:PySide6.QtNetwork.QLocalServer)",
    "0:PySide6.QtHttpServer.QAbstractHttpServer.bind(self,server:PySide6.QtNetwork.QTcpServer=nullptr)",
    "PySide6.QtHttpServer.QAbstractHttpServer.listen(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress]=QHostAddress.Any,port:quint16=0)->quint16",
    "PySide6.QtHttpServer.QAbstractHttpServer.localServers(self)->QList[PySide6.QtNetwork.QLocalServer]",
    "PySide6.QtHttpServer.QAbstractHttpServer.serverPorts(self)->QList[quint16]",
    "PySide6.QtHttpServer.QAbstractHttpServer.servers(self)->QList[PySide6.QtNetwork.QTcpServer]",
    "1:PySide6.QtHttpServer.QAbstractHttpServer.sslSetup(self,certificate:typing.Union[PySide6.QtNetwork.QSslCertificate, PySide6.QtCore.QIODevice],privateKey:typing.Union[PySide6.QtNetwork.QSslKey, Qt.HANDLE],protocol:PySide6.QtNetwork.QSsl.SslProtocol=QSsl.SecureProtocols)",
    "0:PySide6.QtHttpServer.QAbstractHttpServer.sslSetup(self,sslConfiguration:PySide6.QtNetwork.QSslConfiguration)",
    nullptr}; // Sentinel

PyTypeObject *init_QAbstractHttpServer(PyObject *module)
{
    if (SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX].type != nullptr)
        return SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractHttpServer_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QAbstractHttpServer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractHttpServer",
        "QAbstractHttpServer*",
        &Sbk_QAbstractHttpServer_spec,
        &Shiboken::callCppDestructor< ::QAbstractHttpServer >,
        Sbk_QAbstractHttpServer_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAbstractHttpServer_TypeF(); // references _Sbk_QAbstractHttpServer_Type
    InitSignatureStrings(pyType, QAbstractHttpServer_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractHttpServer_PropertyStrings);
    SbkPySide6_QtHttpServerTypeStructs[SBK_QAbstractHttpServer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractHttpServer_PythonToCpp_QAbstractHttpServer_PTR,
        is_QAbstractHttpServer_PythonToCpp_QAbstractHttpServer_PTR_Convertible,
        QAbstractHttpServer_PTR_CppToPython_QAbstractHttpServer);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractHttpServer");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractHttpServer*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractHttpServer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractHttpServer).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAbstractHttpServer_TypeF(), &Sbk_QAbstractHttpServer_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAbstractHttpServer::staticMetaObject, sizeof(::QAbstractHttpServer));

    return pyType;
}
