// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qgeoserviceprovider_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QMap>
#include <QString>
#include <QStringList>
#include <QtLocation/qgeocodingmanager.h>
#include <QtLocation/qgeoroutingmanager.h>
#include <QtLocation/qgeoserviceprovider.h>
#include <QtLocation/qplacemanager.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qlocale.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGeoServiceProviderWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGeoServiceProviderWrapper::QGeoServiceProviderWrapper(const ::QString & providerName, const ::QMap<QString,QVariant> & parameters, bool allowExperimental) : QGeoServiceProvider(providerName, parameters, allowExperimental)
{
    resetPyMethodCache();
    // ... middle
}

void QGeoServiceProviderWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QGeoServiceProviderWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QGeoServiceProviderWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QGeoServiceProviderWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QGeoServiceProviderWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGeoServiceProvider", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QGeoServiceProviderWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGeoServiceProvider", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGeoServiceProviderWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

const QMetaObject *QGeoServiceProviderWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QGeoServiceProvider::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QGeoServiceProviderWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QGeoServiceProvider::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QGeoServiceProviderWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QGeoServiceProviderWrapper *>(this));
    return QGeoServiceProvider::qt_metacast(_clname);
}

QGeoServiceProviderWrapper::~QGeoServiceProviderWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGeoServiceProvider_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGeoServiceProvider >()))
        return -1;

    QGeoServiceProviderWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOO:QGeoServiceProvider", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGeoServiceProvider::QGeoServiceProvider(QString,const QMap<QString,QVariant>&=,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QGeoServiceProvider(QString,QMap<QString,QVariant>,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // QGeoServiceProvider(QString,QMap<QString,QVariant>,bool)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2])))) {
                overloadId = 0; // QGeoServiceProvider(QString,QMap<QString,QVariant>,bool)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
            if (PyDict_Contains(kwds, key_parameters) != 0) {
                value = PyDict_GetItem(kwds, key_parameters);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parameters);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_parameters);
            }
            static PyObject *const key_allowExperimental = Shiboken::String::createStaticString("allowExperimental");
            if (PyDict_Contains(kwds, key_allowExperimental) != 0) {
                value = PyDict_GetItem(kwds, key_allowExperimental);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_allowExperimental);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_allowExperimental);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QMap<QString,QVariant> cppArg1 = QVariantMap();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        bool cppArg2 = false;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QGeoServiceProvider(QString,QMap<QString,QVariant>,bool)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QGeoServiceProviderWrapper(cppArg0, cppArg1, cppArg2);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QGeoServiceProviderWrapper(cppArg0, cppArg1, cppArg2);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QGeoServiceProvider >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    };


    return 1;
}

static PyObject *Sbk_QGeoServiceProviderFunc_availableServiceProviders(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.availableServiceProviders";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // availableServiceProviders()
            QStringList cppResult = ::QGeoServiceProvider::availableServiceProviders();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.error";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // error()const
            QGeoServiceProvider::Error cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->error();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.errorString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // errorString()const
            QString cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->errorString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_geocodingError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.geocodingError";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // geocodingError()const
            QGeoServiceProvider::Error cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->geocodingError();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_geocodingErrorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.geocodingErrorString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // geocodingErrorString()const
            QString cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->geocodingErrorString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_geocodingFeatures(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.geocodingFeatures";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // geocodingFeatures()const
            QFlags<QGeoServiceProvider::GeocodingFeature> cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->geocodingFeatures();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoServiceProvider_GeocodingFeature_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_geocodingManager(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.geocodingManager";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // geocodingManager()const
            QGeoCodingManager * cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->geocodingManager();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoCodingManager_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_mappingError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.mappingError";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mappingError()const
            QGeoServiceProvider::Error cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->mappingError();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_mappingErrorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.mappingErrorString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mappingErrorString()const
            QString cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->mappingErrorString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_mappingFeatures(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.mappingFeatures";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mappingFeatures()const
            QFlags<QGeoServiceProvider::MappingFeature> cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->mappingFeatures();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoServiceProvider_MappingFeature_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_navigationError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.navigationError";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // navigationError()const
            QGeoServiceProvider::Error cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->navigationError();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_navigationErrorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.navigationErrorString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // navigationErrorString()const
            QString cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->navigationErrorString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_navigationFeatures(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.navigationFeatures";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // navigationFeatures()const
            QFlags<QGeoServiceProvider::NavigationFeature> cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->navigationFeatures();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoServiceProvider_NavigationFeature_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_placeManager(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.placeManager";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // placeManager()const
            QPlaceManager * cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->placeManager();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceManager_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_placesError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.placesError";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // placesError()const
            QGeoServiceProvider::Error cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->placesError();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_placesErrorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.placesErrorString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // placesErrorString()const
            QString cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->placesErrorString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_placesFeatures(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.placesFeatures";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // placesFeatures()const
            QFlags<QGeoServiceProvider::PlacesFeature> cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->placesFeatures();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoServiceProvider_PlacesFeature_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_routingError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.routingError";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // routingError()const
            QGeoServiceProvider::Error cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->routingError();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_routingErrorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.routingErrorString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // routingErrorString()const
            QString cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->routingErrorString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_routingFeatures(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.routingFeatures";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // routingFeatures()const
            QFlags<QGeoServiceProvider::RoutingFeature> cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->routingFeatures();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoServiceProvider_RoutingFeature_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_routingManager(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.routingManager";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // routingManager()const
            QGeoRoutingManager * cppResult = const_cast<const ::QGeoServiceProvider *>(cppSelf)->routingManager();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoRoutingManager_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGeoServiceProviderFunc_setAllowExperimental(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.setAllowExperimental";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoServiceProvider::setAllowExperimental(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAllowExperimental(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAllowExperimental(bool)
            cppSelf->setAllowExperimental(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoServiceProviderFunc_setLocale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.setLocale";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoServiceProvider::setLocale(QLocale)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocale(QLocale)
            cppSelf->setLocale(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGeoServiceProviderFunc_setParameters(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QGeoServiceProvider.setParameters";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGeoServiceProvider::setParameters(QMap<QString,QVariant>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QMap_QString_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setParameters(QMap<QString,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QMap<QString,QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setParameters(QMap<QString,QVariant>)
            cppSelf->setParameters(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QGeoServiceProvider_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QGeoServiceProvider_EnumFlagInfo[] = {
    "Error:Enum",
    "GeocodingFeature:Flag:GeocodingFeatures",
    "MappingFeature:Flag:MappingFeatures",
    "NavigationFeature:Flag:NavigationFeatures",
    "PlacesFeature:Flag:PlacesFeatures",
    "RoutingFeature:Flag:RoutingFeatures",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGeoServiceProvider_methods[] = {
    {"availableServiceProviders", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_availableServiceProviders), METH_NOARGS|METH_STATIC, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_errorString), METH_NOARGS, nullptr},
    {"geocodingError", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_geocodingError), METH_NOARGS, nullptr},
    {"geocodingErrorString", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_geocodingErrorString), METH_NOARGS, nullptr},
    {"geocodingFeatures", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_geocodingFeatures), METH_NOARGS, nullptr},
    {"geocodingManager", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_geocodingManager), METH_NOARGS, nullptr},
    {"mappingError", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_mappingError), METH_NOARGS, nullptr},
    {"mappingErrorString", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_mappingErrorString), METH_NOARGS, nullptr},
    {"mappingFeatures", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_mappingFeatures), METH_NOARGS, nullptr},
    {"navigationError", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_navigationError), METH_NOARGS, nullptr},
    {"navigationErrorString", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_navigationErrorString), METH_NOARGS, nullptr},
    {"navigationFeatures", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_navigationFeatures), METH_NOARGS, nullptr},
    {"placeManager", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_placeManager), METH_NOARGS, nullptr},
    {"placesError", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_placesError), METH_NOARGS, nullptr},
    {"placesErrorString", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_placesErrorString), METH_NOARGS, nullptr},
    {"placesFeatures", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_placesFeatures), METH_NOARGS, nullptr},
    {"routingError", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_routingError), METH_NOARGS, nullptr},
    {"routingErrorString", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_routingErrorString), METH_NOARGS, nullptr},
    {"routingFeatures", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_routingFeatures), METH_NOARGS, nullptr},
    {"routingManager", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_routingManager), METH_NOARGS, nullptr},
    {"setAllowExperimental", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_setAllowExperimental), METH_O, nullptr},
    {"setLocale", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_setLocale), METH_O, nullptr},
    {"setParameters", reinterpret_cast<PyCFunction>(Sbk_QGeoServiceProviderFunc_setParameters), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGeoServiceProvider_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGeoServiceProvider *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGeoServiceProviderWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGeoServiceProvider_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGeoServiceProvider_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGeoServiceProvider_Type = nullptr;
static PyTypeObject *Sbk_QGeoServiceProvider_TypeF(void)
{
    return _Sbk_QGeoServiceProvider_Type;
}

static PyType_Slot Sbk_QGeoServiceProvider_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGeoServiceProvider_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGeoServiceProvider_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGeoServiceProvider_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGeoServiceProvider_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGeoServiceProvider_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGeoServiceProvider_spec = {
    "2:PySide6.QtLocation.QGeoServiceProvider",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGeoServiceProvider_slots
};

} //extern "C"

static void *Sbk_QGeoServiceProvider_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QGeoServiceProvider *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QGeoServiceProvider_Error_PythonToCpp_QGeoServiceProvider_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoServiceProvider::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoServiceProvider::Error *>(cppOut) = value;

}
static PythonToCppFunc is_QGeoServiceProvider_Error_PythonToCpp_QGeoServiceProvider_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX])))
        return QGeoServiceProvider_Error_PythonToCpp_QGeoServiceProvider_Error;
    return {};
}
static PyObject *QGeoServiceProvider_Error_CppToPython_QGeoServiceProvider_Error(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QGeoServiceProvider::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX]), castCppIn);

}

static void QGeoServiceProvider_RoutingFeature_PythonToCpp_QGeoServiceProvider_RoutingFeature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoServiceProvider::RoutingFeature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoServiceProvider::RoutingFeature *>(cppOut) = value;

}
static PythonToCppFunc is_QGeoServiceProvider_RoutingFeature_PythonToCpp_QGeoServiceProvider_RoutingFeature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_RoutingFeature_IDX])))
        return QGeoServiceProvider_RoutingFeature_PythonToCpp_QGeoServiceProvider_RoutingFeature;
    return {};
}
static PyObject *QGeoServiceProvider_RoutingFeature_CppToPython_QGeoServiceProvider_RoutingFeature(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QGeoServiceProvider::RoutingFeature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_RoutingFeature_IDX]), castCppIn);

}

static void QGeoServiceProvider_GeocodingFeature_PythonToCpp_QGeoServiceProvider_GeocodingFeature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoServiceProvider::GeocodingFeature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoServiceProvider::GeocodingFeature *>(cppOut) = value;

}
static PythonToCppFunc is_QGeoServiceProvider_GeocodingFeature_PythonToCpp_QGeoServiceProvider_GeocodingFeature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_GeocodingFeature_IDX])))
        return QGeoServiceProvider_GeocodingFeature_PythonToCpp_QGeoServiceProvider_GeocodingFeature;
    return {};
}
static PyObject *QGeoServiceProvider_GeocodingFeature_CppToPython_QGeoServiceProvider_GeocodingFeature(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QGeoServiceProvider::GeocodingFeature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_GeocodingFeature_IDX]), castCppIn);

}

static void QGeoServiceProvider_MappingFeature_PythonToCpp_QGeoServiceProvider_MappingFeature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoServiceProvider::MappingFeature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoServiceProvider::MappingFeature *>(cppOut) = value;

}
static PythonToCppFunc is_QGeoServiceProvider_MappingFeature_PythonToCpp_QGeoServiceProvider_MappingFeature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_MappingFeature_IDX])))
        return QGeoServiceProvider_MappingFeature_PythonToCpp_QGeoServiceProvider_MappingFeature;
    return {};
}
static PyObject *QGeoServiceProvider_MappingFeature_CppToPython_QGeoServiceProvider_MappingFeature(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QGeoServiceProvider::MappingFeature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_MappingFeature_IDX]), castCppIn);

}

static void QGeoServiceProvider_PlacesFeature_PythonToCpp_QGeoServiceProvider_PlacesFeature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoServiceProvider::PlacesFeature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoServiceProvider::PlacesFeature *>(cppOut) = value;

}
static PythonToCppFunc is_QGeoServiceProvider_PlacesFeature_PythonToCpp_QGeoServiceProvider_PlacesFeature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_PlacesFeature_IDX])))
        return QGeoServiceProvider_PlacesFeature_PythonToCpp_QGeoServiceProvider_PlacesFeature;
    return {};
}
static PyObject *QGeoServiceProvider_PlacesFeature_CppToPython_QGeoServiceProvider_PlacesFeature(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QGeoServiceProvider::PlacesFeature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_PlacesFeature_IDX]), castCppIn);

}

static void QGeoServiceProvider_NavigationFeature_PythonToCpp_QGeoServiceProvider_NavigationFeature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGeoServiceProvider::NavigationFeature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGeoServiceProvider::NavigationFeature *>(cppOut) = value;

}
static PythonToCppFunc is_QGeoServiceProvider_NavigationFeature_PythonToCpp_QGeoServiceProvider_NavigationFeature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_NavigationFeature_IDX])))
        return QGeoServiceProvider_NavigationFeature_PythonToCpp_QGeoServiceProvider_NavigationFeature;
    return {};
}
static PyObject *QGeoServiceProvider_NavigationFeature_CppToPython_QGeoServiceProvider_NavigationFeature(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QGeoServiceProvider::NavigationFeature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_NavigationFeature_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGeoServiceProvider_PythonToCpp_QGeoServiceProvider_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGeoServiceProvider_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGeoServiceProvider_PythonToCpp_QGeoServiceProvider_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGeoServiceProvider_TypeF()))
        return QGeoServiceProvider_PythonToCpp_QGeoServiceProvider_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGeoServiceProvider_PTR_CppToPython_QGeoServiceProvider(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QGeoServiceProvider *>(const_cast<void *>(cppIn)), Sbk_QGeoServiceProvider_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QGeoServiceProvider_SignatureStrings[] = {
    "PySide6.QtLocation.QGeoServiceProvider(self,providerName:QString,parameters:QMap[QString, QVariant]=QVariantMap(),allowExperimental:bool=false)",
    "PySide6.QtLocation.QGeoServiceProvider.availableServiceProviders()->QStringList",
    "PySide6.QtLocation.QGeoServiceProvider.error(self)->PySide6.QtLocation.QGeoServiceProvider.Error",
    "PySide6.QtLocation.QGeoServiceProvider.errorString(self)->QString",
    "PySide6.QtLocation.QGeoServiceProvider.geocodingError(self)->PySide6.QtLocation.QGeoServiceProvider.Error",
    "PySide6.QtLocation.QGeoServiceProvider.geocodingErrorString(self)->QString",
    "PySide6.QtLocation.QGeoServiceProvider.geocodingFeatures(self)->PySide6.QtLocation.QGeoServiceProvider.GeocodingFeature",
    "PySide6.QtLocation.QGeoServiceProvider.geocodingManager(self)->PySide6.QtLocation.QGeoCodingManager",
    "PySide6.QtLocation.QGeoServiceProvider.mappingError(self)->PySide6.QtLocation.QGeoServiceProvider.Error",
    "PySide6.QtLocation.QGeoServiceProvider.mappingErrorString(self)->QString",
    "PySide6.QtLocation.QGeoServiceProvider.mappingFeatures(self)->PySide6.QtLocation.QGeoServiceProvider.MappingFeature",
    "PySide6.QtLocation.QGeoServiceProvider.navigationError(self)->PySide6.QtLocation.QGeoServiceProvider.Error",
    "PySide6.QtLocation.QGeoServiceProvider.navigationErrorString(self)->QString",
    "PySide6.QtLocation.QGeoServiceProvider.navigationFeatures(self)->PySide6.QtLocation.QGeoServiceProvider.NavigationFeature",
    "PySide6.QtLocation.QGeoServiceProvider.placeManager(self)->PySide6.QtLocation.QPlaceManager",
    "PySide6.QtLocation.QGeoServiceProvider.placesError(self)->PySide6.QtLocation.QGeoServiceProvider.Error",
    "PySide6.QtLocation.QGeoServiceProvider.placesErrorString(self)->QString",
    "PySide6.QtLocation.QGeoServiceProvider.placesFeatures(self)->PySide6.QtLocation.QGeoServiceProvider.PlacesFeature",
    "PySide6.QtLocation.QGeoServiceProvider.routingError(self)->PySide6.QtLocation.QGeoServiceProvider.Error",
    "PySide6.QtLocation.QGeoServiceProvider.routingErrorString(self)->QString",
    "PySide6.QtLocation.QGeoServiceProvider.routingFeatures(self)->PySide6.QtLocation.QGeoServiceProvider.RoutingFeature",
    "PySide6.QtLocation.QGeoServiceProvider.routingManager(self)->PySide6.QtLocation.QGeoRoutingManager",
    "PySide6.QtLocation.QGeoServiceProvider.setAllowExperimental(self,allow:bool)",
    "PySide6.QtLocation.QGeoServiceProvider.setLocale(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])",
    "PySide6.QtLocation.QGeoServiceProvider.setParameters(self,parameters:QMap[QString, QVariant])",
    nullptr}; // Sentinel

PyTypeObject *init_QGeoServiceProvider(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX].type;

    Shiboken::AutoDecRef Sbk_QGeoServiceProvider_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QGeoServiceProvider_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGeoServiceProvider",
        "QGeoServiceProvider*",
        &Sbk_QGeoServiceProvider_spec,
        &Shiboken::callCppDestructor< QGeoServiceProvider >,
        Sbk_QGeoServiceProvider_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGeoServiceProvider_TypeF(); // references _Sbk_QGeoServiceProvider_Type
    InitSignatureStrings(pyType, QGeoServiceProvider_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGeoServiceProvider_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGeoServiceProvider_PythonToCpp_QGeoServiceProvider_PTR,
        is_QGeoServiceProvider_PythonToCpp_QGeoServiceProvider_PTR_Convertible,
        QGeoServiceProvider_PTR_CppToPython_QGeoServiceProvider);

    Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProvider");
    Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProvider*");
    Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProvider&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGeoServiceProvider).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGeoServiceProviderWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QGeoServiceProvider_TypeF(), &Sbk_QGeoServiceProvider_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QGeoServiceProvider_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "NotSupportedError",
        "UnknownParameterError",
        "MissingRequiredParameterError",
        "ConnectionError",
        "LoaderError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QGeoServiceProvider::Error::NoError),                       //  0x00  0
        uint8_t(QGeoServiceProvider::Error::NotSupportedError),             //  0x01  1
        uint8_t(QGeoServiceProvider::Error::UnknownParameterError),         //  0x02  2
        uint8_t(QGeoServiceProvider::Error::MissingRequiredParameterError), //  0x03  3
        uint8_t(QGeoServiceProvider::Error::ConnectionError),               //  0x04  4
        uint8_t(QGeoServiceProvider::Error::LoaderError)                    //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoServiceProvider_TypeF(),
        "2:PySide6.QtLocation.QGeoServiceProvider.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_Error_IDX].type = EType;
    // Register converter for enum 'QGeoServiceProvider::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoServiceProvider_Error_CppToPython_QGeoServiceProvider_Error);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QGeoServiceProvider_Error_PythonToCpp_QGeoServiceProvider_Error,
            is_QGeoServiceProvider_Error_PythonToCpp_QGeoServiceProvider_Error_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProvider::Error");
        Shiboken::Conversions::registerConverterName(converter, "Error");
    }
    // End of 'Error' enum.

    // Initialization of enum 'RoutingFeature'.
    const char *RoutingFeature_Initializer[] = {
        "NoRoutingFeatures",
        "OnlineRoutingFeature",
        "OfflineRoutingFeature",
        "LocalizedRoutingFeature",
        "RouteUpdatesFeature",
        "AlternativeRoutesFeature",
        "ExcludeAreasRoutingFeature",
        "AnyRoutingFeatures",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t RoutingFeature_InitializerValues[] = {
        int8_t(QGeoServiceProvider::RoutingFeature::NoRoutingFeatures),          //  0x00  0
        int8_t(QGeoServiceProvider::RoutingFeature::OnlineRoutingFeature),       //  0x01  1
        int8_t(QGeoServiceProvider::RoutingFeature::OfflineRoutingFeature),      //  0x02  2
        int8_t(QGeoServiceProvider::RoutingFeature::LocalizedRoutingFeature),    //  0x04  4
        int8_t(QGeoServiceProvider::RoutingFeature::RouteUpdatesFeature),        //  0x08  8
        int8_t(QGeoServiceProvider::RoutingFeature::AlternativeRoutesFeature),   //  0x10  16
        int8_t(QGeoServiceProvider::RoutingFeature::ExcludeAreasRoutingFeature), //  0x20  32
        int8_t(QGeoServiceProvider::RoutingFeature::AnyRoutingFeatures)          // -0x01 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoServiceProvider_TypeF(),
        "2:PySide6.QtLocation.QGeoServiceProvider.RoutingFeature",
        RoutingFeature_Initializer, RoutingFeature_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_RoutingFeature_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoServiceProvider_RoutingFeature_IDX].type =
        EType;
    // Register converter for enum 'QGeoServiceProvider::RoutingFeature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoServiceProvider_RoutingFeature_CppToPython_QGeoServiceProvider_RoutingFeature);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QGeoServiceProvider_RoutingFeature_PythonToCpp_QGeoServiceProvider_RoutingFeature,
            is_QGeoServiceProvider_RoutingFeature_PythonToCpp_QGeoServiceProvider_RoutingFeature_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProvider::RoutingFeature");
        Shiboken::Conversions::registerConverterName(converter, "RoutingFeature");
        // Register converter for flag 'QFlags<QGeoServiceProvider::RoutingFeature>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QGeoServiceProvider::RoutingFeature>");
        Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProvider::RoutingFeatures");
    }
    // End of 'RoutingFeature' enum/flags.

    // Initialization of enum 'GeocodingFeature'.
    const char *GeocodingFeature_Initializer[] = {
        "NoGeocodingFeatures",
        "OnlineGeocodingFeature",
        "OfflineGeocodingFeature",
        "ReverseGeocodingFeature",
        "LocalizedGeocodingFeature",
        "AnyGeocodingFeatures",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t GeocodingFeature_InitializerValues[] = {
        int8_t(QGeoServiceProvider::GeocodingFeature::NoGeocodingFeatures),       //  0x00  0
        int8_t(QGeoServiceProvider::GeocodingFeature::OnlineGeocodingFeature),    //  0x01  1
        int8_t(QGeoServiceProvider::GeocodingFeature::OfflineGeocodingFeature),   //  0x02  2
        int8_t(QGeoServiceProvider::GeocodingFeature::ReverseGeocodingFeature),   //  0x04  4
        int8_t(QGeoServiceProvider::GeocodingFeature::LocalizedGeocodingFeature), //  0x08  8
        int8_t(QGeoServiceProvider::GeocodingFeature::AnyGeocodingFeatures)       // -0x01 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoServiceProvider_TypeF(),
        "2:PySide6.QtLocation.QGeoServiceProvider.GeocodingFeature",
        GeocodingFeature_Initializer, GeocodingFeature_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_GeocodingFeature_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoServiceProvider_GeocodingFeature_IDX].type =
        EType;
    // Register converter for enum 'QGeoServiceProvider::GeocodingFeature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoServiceProvider_GeocodingFeature_CppToPython_QGeoServiceProvider_GeocodingFeature);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QGeoServiceProvider_GeocodingFeature_PythonToCpp_QGeoServiceProvider_GeocodingFeature,
            is_QGeoServiceProvider_GeocodingFeature_PythonToCpp_QGeoServiceProvider_GeocodingFeature_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProvider::GeocodingFeature");
        Shiboken::Conversions::registerConverterName(converter, "GeocodingFeature");
        // Register converter for flag 'QFlags<QGeoServiceProvider::GeocodingFeature>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QGeoServiceProvider::GeocodingFeature>");
        Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProvider::GeocodingFeatures");
    }
    // End of 'GeocodingFeature' enum/flags.

    // Initialization of enum 'MappingFeature'.
    const char *MappingFeature_Initializer[] = {
        "NoMappingFeatures",
        "OnlineMappingFeature",
        "OfflineMappingFeature",
        "LocalizedMappingFeature",
        "AnyMappingFeatures",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t MappingFeature_InitializerValues[] = {
        int8_t(QGeoServiceProvider::MappingFeature::NoMappingFeatures),       //  0x00  0
        int8_t(QGeoServiceProvider::MappingFeature::OnlineMappingFeature),    //  0x01  1
        int8_t(QGeoServiceProvider::MappingFeature::OfflineMappingFeature),   //  0x02  2
        int8_t(QGeoServiceProvider::MappingFeature::LocalizedMappingFeature), //  0x04  4
        int8_t(QGeoServiceProvider::MappingFeature::AnyMappingFeatures)       // -0x01 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoServiceProvider_TypeF(),
        "2:PySide6.QtLocation.QGeoServiceProvider.MappingFeature",
        MappingFeature_Initializer, MappingFeature_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_MappingFeature_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoServiceProvider_MappingFeature_IDX].type =
        EType;
    // Register converter for enum 'QGeoServiceProvider::MappingFeature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoServiceProvider_MappingFeature_CppToPython_QGeoServiceProvider_MappingFeature);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QGeoServiceProvider_MappingFeature_PythonToCpp_QGeoServiceProvider_MappingFeature,
            is_QGeoServiceProvider_MappingFeature_PythonToCpp_QGeoServiceProvider_MappingFeature_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProvider::MappingFeature");
        Shiboken::Conversions::registerConverterName(converter, "MappingFeature");
        // Register converter for flag 'QFlags<QGeoServiceProvider::MappingFeature>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QGeoServiceProvider::MappingFeature>");
        Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProvider::MappingFeatures");
    }
    // End of 'MappingFeature' enum/flags.

    // Initialization of enum 'PlacesFeature'.
    const char *PlacesFeature_Initializer[] = {
        "NoPlacesFeatures",
        "OnlinePlacesFeature",
        "OfflinePlacesFeature",
        "SavePlaceFeature",
        "RemovePlaceFeature",
        "SaveCategoryFeature",
        "RemoveCategoryFeature",
        "PlaceRecommendationsFeature",
        "SearchSuggestionsFeature",
        "LocalizedPlacesFeature",
        "NotificationsFeature",
        "PlaceMatchingFeature",
        "AnyPlacesFeatures",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t PlacesFeature_InitializerValues[] = {
        int16_t(QGeoServiceProvider::PlacesFeature::NoPlacesFeatures),            //  0x0000  0
        int16_t(QGeoServiceProvider::PlacesFeature::OnlinePlacesFeature),         //  0x0001  1
        int16_t(QGeoServiceProvider::PlacesFeature::OfflinePlacesFeature),        //  0x0002  2
        int16_t(QGeoServiceProvider::PlacesFeature::SavePlaceFeature),            //  0x0004  4
        int16_t(QGeoServiceProvider::PlacesFeature::RemovePlaceFeature),          //  0x0008  8
        int16_t(QGeoServiceProvider::PlacesFeature::SaveCategoryFeature),         //  0x0010  16
        int16_t(QGeoServiceProvider::PlacesFeature::RemoveCategoryFeature),       //  0x0020  32
        int16_t(QGeoServiceProvider::PlacesFeature::PlaceRecommendationsFeature), //  0x0040  64
        int16_t(QGeoServiceProvider::PlacesFeature::SearchSuggestionsFeature),    //  0x0080  128
        int16_t(QGeoServiceProvider::PlacesFeature::LocalizedPlacesFeature),      //  0x0100  256
        int16_t(QGeoServiceProvider::PlacesFeature::NotificationsFeature),        //  0x0200  512
        int16_t(QGeoServiceProvider::PlacesFeature::PlaceMatchingFeature),        //  0x0400  1024
        int16_t(QGeoServiceProvider::PlacesFeature::AnyPlacesFeatures)            // -0x0001 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoServiceProvider_TypeF(),
        "2:PySide6.QtLocation.QGeoServiceProvider.PlacesFeature",
        PlacesFeature_Initializer, PlacesFeature_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_PlacesFeature_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoServiceProvider_PlacesFeature_IDX].type =
        EType;
    // Register converter for enum 'QGeoServiceProvider::PlacesFeature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoServiceProvider_PlacesFeature_CppToPython_QGeoServiceProvider_PlacesFeature);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QGeoServiceProvider_PlacesFeature_PythonToCpp_QGeoServiceProvider_PlacesFeature,
            is_QGeoServiceProvider_PlacesFeature_PythonToCpp_QGeoServiceProvider_PlacesFeature_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProvider::PlacesFeature");
        Shiboken::Conversions::registerConverterName(converter, "PlacesFeature");
        // Register converter for flag 'QFlags<QGeoServiceProvider::PlacesFeature>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QGeoServiceProvider::PlacesFeature>");
        Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProvider::PlacesFeatures");
    }
    // End of 'PlacesFeature' enum/flags.

    // Initialization of enum 'NavigationFeature'.
    const char *NavigationFeature_Initializer[] = {
        "NoNavigationFeatures",
        "OnlineNavigationFeature",
        "OfflineNavigationFeature",
        "AnyNavigationFeatures",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t NavigationFeature_InitializerValues[] = {
        int8_t(QGeoServiceProvider::NavigationFeature::NoNavigationFeatures),     //  0x00  0
        int8_t(QGeoServiceProvider::NavigationFeature::OnlineNavigationFeature),  //  0x01  1
        int8_t(QGeoServiceProvider::NavigationFeature::OfflineNavigationFeature), //  0x02  2
        int8_t(QGeoServiceProvider::NavigationFeature::AnyNavigationFeatures)     // -0x01 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGeoServiceProvider_TypeF(),
        "2:PySide6.QtLocation.QGeoServiceProvider.NavigationFeature",
        NavigationFeature_Initializer, NavigationFeature_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_NavigationFeature_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoServiceProvider_NavigationFeature_IDX].type =
        EType;
    // Register converter for enum 'QGeoServiceProvider::NavigationFeature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGeoServiceProvider_NavigationFeature_CppToPython_QGeoServiceProvider_NavigationFeature);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QGeoServiceProvider_NavigationFeature_PythonToCpp_QGeoServiceProvider_NavigationFeature,
            is_QGeoServiceProvider_NavigationFeature_PythonToCpp_QGeoServiceProvider_NavigationFeature_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProvider::NavigationFeature");
        Shiboken::Conversions::registerConverterName(converter, "NavigationFeature");
        // Register converter for flag 'QFlags<QGeoServiceProvider::NavigationFeature>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QGeoServiceProvider::NavigationFeature>");
        Shiboken::Conversions::registerConverterName(converter, "QGeoServiceProvider::NavigationFeatures");
    }
    // End of 'NavigationFeature' enum/flags.

    qRegisterMetaType< ::QGeoServiceProvider::Error >("QGeoServiceProvider::Error");
    qRegisterMetaType< ::QGeoServiceProvider::RoutingFeature >("QGeoServiceProvider::RoutingFeature");
    qRegisterMetaType< ::QGeoServiceProvider::GeocodingFeature >("QGeoServiceProvider::GeocodingFeature");
    qRegisterMetaType< ::QGeoServiceProvider::MappingFeature >("QGeoServiceProvider::MappingFeature");
    qRegisterMetaType< ::QGeoServiceProvider::PlacesFeature >("QGeoServiceProvider::PlacesFeature");
    qRegisterMetaType< ::QGeoServiceProvider::NavigationFeature >("QGeoServiceProvider::NavigationFeature");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QGeoServiceProvider::staticMetaObject, sizeof(QGeoServiceProviderWrapper));

    return pyType;
}
