// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtlocation_python.h"

// main header
#include "qplacesearchrequest_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtLocation/qplacecategory.h>
#include <QtLocation/qplacesearchrequest.h>
#include <QtPositioning/qgeoshape.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPlaceSearchRequest_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPlaceSearchRequest >()))
        return -1;

    ::QPlaceSearchRequest *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPlaceSearchRequest", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPlaceSearchRequest::QPlaceSearchRequest()
    // 1: QPlaceSearchRequest::QPlaceSearchRequest(QPlaceSearchRequest)
    if (numArgs == 0) {
        overloadId = 0; // QPlaceSearchRequest()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPlaceSearchRequest(QPlaceSearchRequest)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPlaceSearchRequest()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPlaceSearchRequest()
                cptr = new ::QPlaceSearchRequest();
            }
            break;
        }
        case 1: // QPlaceSearchRequest(const QPlaceSearchRequest & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPlaceSearchRequest *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPlaceSearchRequest(QPlaceSearchRequest)
                cptr = new ::QPlaceSearchRequest(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPlaceSearchRequest >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_categories(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.categories";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // categories()const
            QList<QPlaceCategory> cppResult = const_cast<const ::QPlaceSearchRequest *>(cppSelf)->categories();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QPlaceCategory_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.clear";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clear()
            cppSelf->clear();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_limit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.limit";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // limit()const
            int cppResult = const_cast<const ::QPlaceSearchRequest *>(cppSelf)->limit();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_recommendationId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.recommendationId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // recommendationId()const
            QString cppResult = const_cast<const ::QPlaceSearchRequest *>(cppSelf)->recommendationId();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_relevanceHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.relevanceHint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // relevanceHint()const
            QPlaceSearchRequest::RelevanceHint cppResult = const_cast<const ::QPlaceSearchRequest *>(cppSelf)->relevanceHint();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_RelevanceHint_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_searchArea(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.searchArea";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // searchArea()const
            QGeoShape cppResult = const_cast<const ::QPlaceSearchRequest *>(cppSelf)->searchArea();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_searchContext(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.searchContext";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // searchContext()const
            QVariant cppResult = const_cast<const ::QPlaceSearchRequest *>(cppSelf)->searchContext();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_searchTerm(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.searchTerm";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // searchTerm()const
            QString cppResult = const_cast<const ::QPlaceSearchRequest *>(cppSelf)->searchTerm();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_setCategories(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.setCategories";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceSearchRequest::setCategories(QList<QPlaceCategory>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtLocationTypeConverters[SBK_QtLocation_QList_QPlaceCategory_IDX], (pyArg)))) {
        overloadId = 0; // setCategories(QList<QPlaceCategory>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QPlaceCategory> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCategories(QList<QPlaceCategory>)
            cppSelf->setCategories(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_setCategory(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.setCategory";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceSearchRequest::setCategory(QPlaceCategory)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceCategory_IDX]), (pyArg)))) {
        overloadId = 0; // setCategory(QPlaceCategory)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceCategory cppArg0_local;
        ::QPlaceCategory *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCategory(QPlaceCategory)
            cppSelf->setCategory(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_setLimit(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.setLimit";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceSearchRequest::setLimit(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLimit(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLimit(int)
            cppSelf->setLimit(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_setRecommendationId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.setRecommendationId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceSearchRequest::setRecommendationId(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setRecommendationId(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRecommendationId(QString)
            cppSelf->setRecommendationId(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_setRelevanceHint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.setRelevanceHint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceSearchRequest::setRelevanceHint(QPlaceSearchRequest::RelevanceHint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_RelevanceHint_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setRelevanceHint(QPlaceSearchRequest::RelevanceHint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QPlaceSearchRequest::RelevanceHint cppArg0{QPlaceSearchRequest::UnspecifiedHint};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRelevanceHint(QPlaceSearchRequest::RelevanceHint)
            cppSelf->setRelevanceHint(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_setSearchArea(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.setSearchArea";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceSearchRequest::setSearchArea(QGeoShape)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]), (pyArg)))) {
        overloadId = 0; // setSearchArea(QGeoShape)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGeoShape cppArg0_local;
        ::QGeoShape *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSearchArea(QGeoShape)
            cppSelf->setSearchArea(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_setSearchContext(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.setSearchContext";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceSearchRequest::setSearchContext(QVariant)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setSearchContext(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QVariant cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSearchContext(QVariant)
            cppSelf->setSearchContext(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_setSearchTerm(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.setSearchTerm";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceSearchRequest::setSearchTerm(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setSearchTerm(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSearchTerm(QString)
            cppSelf->setSearchTerm(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlaceSearchRequestFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtLocation.QPlaceSearchRequest.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlaceSearchRequest::swap(QPlaceSearchRequest&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QPlaceSearchRequest&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPlaceSearchRequest *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QPlaceSearchRequest&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QPlaceSearchRequest_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QPlaceSearchRequest_EnumFlagInfo[] = {
    "RelevanceHint:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPlaceSearchRequest_methods[] = {
    {"categories", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_categories), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_clear), METH_NOARGS, nullptr},
    {"limit", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_limit), METH_NOARGS, nullptr},
    {"recommendationId", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_recommendationId), METH_NOARGS, nullptr},
    {"relevanceHint", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_relevanceHint), METH_NOARGS, nullptr},
    {"searchArea", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_searchArea), METH_NOARGS, nullptr},
    {"searchContext", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_searchContext), METH_NOARGS, nullptr},
    {"searchTerm", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_searchTerm), METH_NOARGS, nullptr},
    {"setCategories", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_setCategories), METH_O, nullptr},
    {"setCategory", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_setCategory), METH_O, nullptr},
    {"setLimit", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_setLimit), METH_O, nullptr},
    {"setRecommendationId", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_setRecommendationId), METH_O, nullptr},
    {"setRelevanceHint", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_setRelevanceHint), METH_O, nullptr},
    {"setSearchArea", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_setSearchArea), METH_O, nullptr},
    {"setSearchContext", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_setSearchContext), METH_O, nullptr},
    {"setSearchTerm", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_setSearchTerm), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QPlaceSearchRequestFunc_swap), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QPlaceSearchRequest_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPlaceSearchRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), (pyArg)))) {
                // operator!=(const QPlaceSearchRequest & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPlaceSearchRequest *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX]), (pyArg)))) {
                // operator==(const QPlaceSearchRequest & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QPlaceSearchRequest *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QPlaceSearchRequest_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPlaceSearchRequest_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPlaceSearchRequest_Type = nullptr;
static PyTypeObject *Sbk_QPlaceSearchRequest_TypeF(void)
{
    return _Sbk_QPlaceSearchRequest_Type;
}

static PyType_Slot Sbk_QPlaceSearchRequest_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPlaceSearchRequest_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPlaceSearchRequest_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QPlaceSearchRequest_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPlaceSearchRequest_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPlaceSearchRequest_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPlaceSearchRequest_spec = {
    "2:PySide6.QtLocation.QPlaceSearchRequest",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPlaceSearchRequest_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QPlaceSearchRequest_RelevanceHint_PythonToCpp_QPlaceSearchRequest_RelevanceHint(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPlaceSearchRequest::RelevanceHint>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPlaceSearchRequest::RelevanceHint *>(cppOut) = value;

}
static PythonToCppFunc is_QPlaceSearchRequest_RelevanceHint_PythonToCpp_QPlaceSearchRequest_RelevanceHint_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_RelevanceHint_IDX])))
        return QPlaceSearchRequest_RelevanceHint_PythonToCpp_QPlaceSearchRequest_RelevanceHint;
    return {};
}
static PyObject *QPlaceSearchRequest_RelevanceHint_CppToPython_QPlaceSearchRequest_RelevanceHint(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QPlaceSearchRequest::RelevanceHint *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_RelevanceHint_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPlaceSearchRequest_PythonToCpp_QPlaceSearchRequest_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPlaceSearchRequest_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPlaceSearchRequest_PythonToCpp_QPlaceSearchRequest_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPlaceSearchRequest_TypeF()))
        return QPlaceSearchRequest_PythonToCpp_QPlaceSearchRequest_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPlaceSearchRequest_PTR_CppToPython_QPlaceSearchRequest(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QPlaceSearchRequest *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QPlaceSearchRequest_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QPlaceSearchRequest_SignatureStrings[] = {
    "1:PySide6.QtLocation.QPlaceSearchRequest(self)",
    "0:PySide6.QtLocation.QPlaceSearchRequest(self,other:PySide6.QtLocation.QPlaceSearchRequest)",
    "PySide6.QtLocation.QPlaceSearchRequest.categories(self)->QList[PySide6.QtLocation.QPlaceCategory]",
    "PySide6.QtLocation.QPlaceSearchRequest.clear(self)",
    "PySide6.QtLocation.QPlaceSearchRequest.limit(self)->int",
    "PySide6.QtLocation.QPlaceSearchRequest.recommendationId(self)->QString",
    "PySide6.QtLocation.QPlaceSearchRequest.relevanceHint(self)->PySide6.QtLocation.QPlaceSearchRequest.RelevanceHint",
    "PySide6.QtLocation.QPlaceSearchRequest.searchArea(self)->PySide6.QtPositioning.QGeoShape",
    "PySide6.QtLocation.QPlaceSearchRequest.searchContext(self)->QVariant",
    "PySide6.QtLocation.QPlaceSearchRequest.searchTerm(self)->QString",
    "PySide6.QtLocation.QPlaceSearchRequest.setCategories(self,categories:QList[PySide6.QtLocation.QPlaceCategory])",
    "PySide6.QtLocation.QPlaceSearchRequest.setCategory(self,category:PySide6.QtLocation.QPlaceCategory)",
    "PySide6.QtLocation.QPlaceSearchRequest.setLimit(self,limit:int)",
    "PySide6.QtLocation.QPlaceSearchRequest.setRecommendationId(self,recommendationId:QString)",
    "PySide6.QtLocation.QPlaceSearchRequest.setRelevanceHint(self,hint:PySide6.QtLocation.QPlaceSearchRequest.RelevanceHint)",
    "PySide6.QtLocation.QPlaceSearchRequest.setSearchArea(self,area:PySide6.QtPositioning.QGeoShape)",
    "PySide6.QtLocation.QPlaceSearchRequest.setSearchContext(self,context:QVariant)",
    "PySide6.QtLocation.QPlaceSearchRequest.setSearchTerm(self,term:QString)",
    "PySide6.QtLocation.QPlaceSearchRequest.swap(self,other:PySide6.QtLocation.QPlaceSearchRequest)",
    nullptr}; // Sentinel

PyTypeObject *init_QPlaceSearchRequest(PyObject *module)
{
    if (SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX].type != nullptr)
        return SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX].type;

    Shiboken::AutoDecRef Sbk_QPlaceSearchRequest_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPlaceSearchRequest_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPlaceSearchRequest",
        "QPlaceSearchRequest*",
        &Sbk_QPlaceSearchRequest_spec,
        &Shiboken::callCppDestructor< ::QPlaceSearchRequest >,
        Sbk_QPlaceSearchRequest_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPlaceSearchRequest_TypeF(); // references _Sbk_QPlaceSearchRequest_Type
    InitSignatureStrings(pyType, QPlaceSearchRequest_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPlaceSearchRequest_PropertyStrings);
    SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPlaceSearchRequest_PythonToCpp_QPlaceSearchRequest_PTR,
        is_QPlaceSearchRequest_PythonToCpp_QPlaceSearchRequest_PTR_Convertible,
        QPlaceSearchRequest_PTR_CppToPython_QPlaceSearchRequest);

    Shiboken::Conversions::registerConverterName(converter, "QPlaceSearchRequest");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceSearchRequest*");
    Shiboken::Conversions::registerConverterName(converter, "QPlaceSearchRequest&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlaceSearchRequest).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPlaceSearchRequest_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'RelevanceHint'.
    const char *RelevanceHint_Initializer[] = {
        "UnspecifiedHint",
        "DistanceHint",
        "LexicalPlaceNameHint",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RelevanceHint_InitializerValues[] = {
        uint8_t(QPlaceSearchRequest::RelevanceHint::UnspecifiedHint),     //  0x00  0
        uint8_t(QPlaceSearchRequest::RelevanceHint::DistanceHint),        //  0x01  1
        uint8_t(QPlaceSearchRequest::RelevanceHint::LexicalPlaceNameHint) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPlaceSearchRequest_TypeF(),
        "2:PySide6.QtLocation.QPlaceSearchRequest.RelevanceHint",
        RelevanceHint_Initializer, RelevanceHint_InitializerValues);
    SbkPySide6_QtLocationTypeStructs[SBK_QPlaceSearchRequest_RelevanceHint_IDX].type = EType;
    // Register converter for enum 'QPlaceSearchRequest::RelevanceHint'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPlaceSearchRequest_RelevanceHint_CppToPython_QPlaceSearchRequest_RelevanceHint);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QPlaceSearchRequest_RelevanceHint_PythonToCpp_QPlaceSearchRequest_RelevanceHint,
            is_QPlaceSearchRequest_RelevanceHint_PythonToCpp_QPlaceSearchRequest_RelevanceHint_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QPlaceSearchRequest::RelevanceHint");
        Shiboken::Conversions::registerConverterName(converter, "RelevanceHint");
    }
    // End of 'RelevanceHint' enum.

    qRegisterMetaType< ::QPlaceSearchRequest *>();
    qRegisterMetaType< ::QPlaceSearchRequest::RelevanceHint >("QPlaceSearchRequest::RelevanceHint");

    return pyType;
}
