// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qaudiobuffer_wrapper.h"

// Argument includes
#include <QtMultimedia/qaudiobuffer.h>
#include <QtMultimedia/qaudioformat.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAudioBuffer_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAudioBuffer >()))
        return -1;

    ::QAudioBuffer *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioBuffer.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:QAudioBuffer", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAudioBuffer::QAudioBuffer()
    // 1: QAudioBuffer::QAudioBuffer(QAudioBuffer)
    // 2: QAudioBuffer::QAudioBuffer(QByteArray,QAudioFormat,qint64=)
    // 3: QAudioBuffer::QAudioBuffer(int,QAudioFormat,qint64=)
    if (numArgs == 0) {
        overloadId = 0; // QAudioBuffer()
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 3; // QAudioBuffer(int,QAudioFormat,qint64)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[2])))) {
            overloadId = 3; // QAudioBuffer(int,QAudioFormat,qint64)
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // QAudioBuffer(QByteArray,QAudioFormat,qint64)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[2])))) {
            overloadId = 2; // QAudioBuffer(QByteArray,QAudioFormat,qint64)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QAudioBuffer(QAudioBuffer)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAudioBuffer()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAudioBuffer()
                cptr = new ::QAudioBuffer();
            }
            break;
        }
        case 1: // QAudioBuffer(const QAudioBuffer & other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAudioBuffer cppArg0_local;
            ::QAudioBuffer *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QAudioBuffer(QAudioBuffer)
                cptr = new ::QAudioBuffer(*cppArg0);
            }
            break;
        }
        case 2: // QAudioBuffer(const QByteArray & data, const QAudioFormat & format, qint64 startTime)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_startTime = Shiboken::String::createStaticString("startTime");
                if (PyDict_Contains(kwds, key_startTime) != 0) {
                    value = PyDict_GetItem(kwds, key_startTime);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_startTime);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_startTime);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local;
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QAudioFormat cppArg1_local;
            ::QAudioFormat *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            qint64 cppArg2 = -1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAudioBuffer(QByteArray,QAudioFormat,qint64)
                cptr = new ::QAudioBuffer(*cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 3: // QAudioBuffer(int numFrames, const QAudioFormat & format, qint64 startTime)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_startTime = Shiboken::String::createStaticString("startTime");
                if (PyDict_Contains(kwds, key_startTime) != 0) {
                    value = PyDict_GetItem(kwds, key_startTime);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_startTime);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_startTime);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QAudioFormat cppArg1_local;
            ::QAudioFormat *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            qint64 cppArg2 = -1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAudioBuffer(int,QAudioFormat,qint64)
                cptr = new ::QAudioBuffer(cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QAudioBuffer >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAudioBufferFunc_byteCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioBuffer.byteCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // byteCount()const
            qsizetype cppResult = const_cast<const ::QAudioBuffer *>(cppSelf)->byteCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioBufferFunc_constData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioBuffer.constData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // constData()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtmultimedia.cpp (qaudiobuffer-const-data)]
            const unsigned char *data = cppSelf->constData<unsigned char>();
            const auto size = cppSelf->byteCount();
            pyResult = Shiboken::Buffer::newObject(data, size);
            // END of custom code block [file: ../glue/qtmultimedia.cpp (qaudiobuffer-const-data)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioBufferFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioBuffer.data";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // data()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtmultimedia.cpp (qaudiobuffer-data)]
            unsigned char *data = cppSelf->data<unsigned char>();
            const auto size = cppSelf->byteCount();
            pyResult = Shiboken::Buffer::newObject(data, size, Shiboken::Buffer::ReadWrite);
            // END of custom code block [file: ../glue/qtmultimedia.cpp (qaudiobuffer-data)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioBufferFunc_duration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioBuffer.duration";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // duration()const
            qint64 cppResult = const_cast<const ::QAudioBuffer *>(cppSelf)->duration();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioBufferFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioBuffer.format";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // format()const
            QAudioFormat cppResult = const_cast<const ::QAudioBuffer *>(cppSelf)->format();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioBufferFunc_frameCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioBuffer.frameCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // frameCount()const
            qsizetype cppResult = const_cast<const ::QAudioBuffer *>(cppSelf)->frameCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioBufferFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioBuffer.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QAudioBuffer *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioBufferFunc_sampleCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioBuffer.sampleCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // sampleCount()const
            qsizetype cppResult = const_cast<const ::QAudioBuffer *>(cppSelf)->sampleCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioBufferFunc_startTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioBuffer.startTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // startTime()const
            qint64 cppResult = const_cast<const ::QAudioBuffer *>(cppSelf)->startTime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioBufferFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioBuffer.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioBuffer::swap(QAudioBuffer&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QAudioBuffer&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAudioBuffer cppArg0_local;
        ::QAudioBuffer *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QAudioBuffer&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioBuffer__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QAudioBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAudioBuffer_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAudioBuffer_methods[] = {
    {"byteCount", reinterpret_cast<PyCFunction>(Sbk_QAudioBufferFunc_byteCount), METH_NOARGS, nullptr},
    {"constData", reinterpret_cast<PyCFunction>(Sbk_QAudioBufferFunc_constData), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QAudioBufferFunc_data), METH_NOARGS, nullptr},
    {"duration", reinterpret_cast<PyCFunction>(Sbk_QAudioBufferFunc_duration), METH_NOARGS, nullptr},
    {"format", reinterpret_cast<PyCFunction>(Sbk_QAudioBufferFunc_format), METH_NOARGS, nullptr},
    {"frameCount", reinterpret_cast<PyCFunction>(Sbk_QAudioBufferFunc_frameCount), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QAudioBufferFunc_isValid), METH_NOARGS, nullptr},
    {"sampleCount", reinterpret_cast<PyCFunction>(Sbk_QAudioBufferFunc_sampleCount), METH_NOARGS, nullptr},
    {"startTime", reinterpret_cast<PyCFunction>(Sbk_QAudioBufferFunc_startTime), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QAudioBufferFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QAudioBuffer__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QAudioBuffer_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAudioBuffer_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAudioBuffer_Type = nullptr;
static PyTypeObject *Sbk_QAudioBuffer_TypeF(void)
{
    return _Sbk_QAudioBuffer_Type;
}

static PyType_Slot Sbk_QAudioBuffer_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAudioBuffer_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAudioBuffer_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAudioBuffer_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAudioBuffer_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAudioBuffer_spec = {
    "2:PySide6.QtMultimedia.QAudioBuffer",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAudioBuffer_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAudioBuffer_PythonToCpp_QAudioBuffer_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAudioBuffer_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAudioBuffer_PythonToCpp_QAudioBuffer_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAudioBuffer_TypeF()))
        return QAudioBuffer_PythonToCpp_QAudioBuffer_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAudioBuffer_PTR_CppToPython_QAudioBuffer(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QAudioBuffer *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QAudioBuffer_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QAudioBuffer_COPY_CppToPython_QAudioBuffer(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QAudioBuffer *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QAudioBuffer_TypeF(), new ::QAudioBuffer(*source), true, true);
}

// Python to C++ copy conversion.
static void QAudioBuffer_PythonToCpp_QAudioBuffer_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QAudioBuffer *>(cppOut) = *reinterpret_cast< ::QAudioBuffer *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QAudioBuffer_PythonToCpp_QAudioBuffer_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QAudioBuffer_TypeF()))
        return QAudioBuffer_PythonToCpp_QAudioBuffer_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QAudioBuffer_SignatureStrings[] = {
    "3:PySide6.QtMultimedia.QAudioBuffer(self)",
    "2:PySide6.QtMultimedia.QAudioBuffer(self,other:PySide6.QtMultimedia.QAudioBuffer)",
    "1:PySide6.QtMultimedia.QAudioBuffer(self,data:typing.Union[PySide6.QtCore.QByteArray, char*],format:PySide6.QtMultimedia.QAudioFormat,startTime:qint64=-1)",
    "0:PySide6.QtMultimedia.QAudioBuffer(self,numFrames:int,format:PySide6.QtMultimedia.QAudioFormat,startTime:qint64=-1)",
    "PySide6.QtMultimedia.QAudioBuffer.byteCount(self)->qsizetype",
    "PySide6.QtMultimedia.QAudioBuffer.constData(self)->PyBuffer",
    "PySide6.QtMultimedia.QAudioBuffer.data(self)->PyBuffer",
    "PySide6.QtMultimedia.QAudioBuffer.duration(self)->qint64",
    "PySide6.QtMultimedia.QAudioBuffer.format(self)->PySide6.QtMultimedia.QAudioFormat",
    "PySide6.QtMultimedia.QAudioBuffer.frameCount(self)->qsizetype",
    "PySide6.QtMultimedia.QAudioBuffer.isValid(self)->bool",
    "PySide6.QtMultimedia.QAudioBuffer.sampleCount(self)->qsizetype",
    "PySide6.QtMultimedia.QAudioBuffer.startTime(self)->qint64",
    "PySide6.QtMultimedia.QAudioBuffer.swap(self,other:PySide6.QtMultimedia.QAudioBuffer)",
    "PySide6.QtMultimedia.QAudioBuffer.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QAudioBuffer(PyObject *module)
{
    if (SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX].type != nullptr)
        return SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX].type;

    Shiboken::AutoDecRef Sbk_QAudioBuffer_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAudioBuffer_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAudioBuffer",
        "QAudioBuffer",
        &Sbk_QAudioBuffer_spec,
        &Shiboken::callCppDestructor< ::QAudioBuffer >,
        Sbk_QAudioBuffer_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QAudioBuffer_TypeF(); // references _Sbk_QAudioBuffer_Type
    InitSignatureStrings(pyType, QAudioBuffer_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAudioBuffer_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioBuffer_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAudioBuffer_PythonToCpp_QAudioBuffer_PTR,
        is_QAudioBuffer_PythonToCpp_QAudioBuffer_PTR_Convertible,
        QAudioBuffer_PTR_CppToPython_QAudioBuffer,
        QAudioBuffer_COPY_CppToPython_QAudioBuffer);

    Shiboken::Conversions::registerConverterName(converter, "QAudioBuffer");
    Shiboken::Conversions::registerConverterName(converter, "QAudioBuffer*");
    Shiboken::Conversions::registerConverterName(converter, "QAudioBuffer&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAudioBuffer).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QAudioBuffer_PythonToCpp_QAudioBuffer_COPY,
        is_QAudioBuffer_PythonToCpp_QAudioBuffer_COPY_Convertible);

    qRegisterMetaType< ::QAudioBuffer >("QAudioBuffer");

    return pyType;
}
