// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qaudiodevice_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtMultimedia/qaudiodevice.h>
#include <QtMultimedia/qaudioformat.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAudioDevice_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAudioDevice >()))
        return -1;

    ::QAudioDevice *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAudioDevice", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAudioDevice::QAudioDevice()
    // 1: QAudioDevice::QAudioDevice(QAudioDevice)
    if (numArgs == 0) {
        overloadId = 0; // QAudioDevice()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QAudioDevice(QAudioDevice)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QAudioDevice()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QAudioDevice()
                cptr = new ::QAudioDevice();
            }
            break;
        }
        case 1: // QAudioDevice(const QAudioDevice & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QAudioDevice cppArg0_local;
            ::QAudioDevice *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QAudioDevice(QAudioDevice)
                cptr = new ::QAudioDevice(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QAudioDevice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QAudioDeviceFunc_channelConfiguration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.channelConfiguration";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // channelConfiguration()const
            QAudioFormat::ChannelConfig cppResult = const_cast<const ::QAudioDevice *>(cppSelf)->channelConfiguration();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_ChannelConfig_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioDeviceFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.description";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // description()const
            QString cppResult = const_cast<const ::QAudioDevice *>(cppSelf)->description();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioDeviceFunc_id(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.id";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // id()const
            QByteArray cppResult = const_cast<const ::QAudioDevice *>(cppSelf)->id();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioDeviceFunc_isDefault(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.isDefault";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDefault()const
            bool cppResult = const_cast<const ::QAudioDevice *>(cppSelf)->isDefault();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioDeviceFunc_isFormatSupported(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.isFormatSupported";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioDevice::isFormatSupported(QAudioFormat)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), (pyArg)))) {
        overloadId = 0; // isFormatSupported(QAudioFormat)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAudioFormat cppArg0_local;
        ::QAudioFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isFormatSupported(QAudioFormat)const
            bool cppResult = const_cast<const ::QAudioDevice *>(cppSelf)->isFormatSupported(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioDeviceFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.isNull";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isNull()const
            bool cppResult = const_cast<const ::QAudioDevice *>(cppSelf)->isNull();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioDeviceFunc_maximumChannelCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.maximumChannelCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maximumChannelCount()const
            int cppResult = const_cast<const ::QAudioDevice *>(cppSelf)->maximumChannelCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioDeviceFunc_maximumSampleRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.maximumSampleRate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maximumSampleRate()const
            int cppResult = const_cast<const ::QAudioDevice *>(cppSelf)->maximumSampleRate();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioDeviceFunc_minimumChannelCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.minimumChannelCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minimumChannelCount()const
            int cppResult = const_cast<const ::QAudioDevice *>(cppSelf)->minimumChannelCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioDeviceFunc_minimumSampleRate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.minimumSampleRate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minimumSampleRate()const
            int cppResult = const_cast<const ::QAudioDevice *>(cppSelf)->minimumSampleRate();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioDeviceFunc_mode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.mode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mode()const
            QAudioDevice::Mode cppResult = const_cast<const ::QAudioDevice *>(cppSelf)->mode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_Mode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioDeviceFunc_preferredFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.preferredFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // preferredFormat()const
            QAudioFormat cppResult = const_cast<const ::QAudioDevice *>(cppSelf)->preferredFormat();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioDeviceFunc_supportedSampleFormats(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.supportedSampleFormats";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportedSampleFormats()const
            QList<QAudioFormat::SampleFormat> cppResult = const_cast<const ::QAudioDevice *>(cppSelf)->supportedSampleFormats();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtMultimediaTypeConverters[SBK_QtMultimedia_QList_QAudioFormat_SampleFormat_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioDeviceFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QAudioDevice.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioDevice::swap(QAudioDevice&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QAudioDevice&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAudioDevice cppArg0_local;
        ::QAudioDevice *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QAudioDevice&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioDevice__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAudioDevice_PropertyStrings[] = {
    "description:",
    "id:",
    "isDefault:",
    "mode:",
    nullptr // Sentinel
};

static const char *Sbk_QAudioDevice_EnumFlagInfo[] = {
    "Mode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAudioDevice_methods[] = {
    {"channelConfiguration", reinterpret_cast<PyCFunction>(Sbk_QAudioDeviceFunc_channelConfiguration), METH_NOARGS, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QAudioDeviceFunc_description), METH_NOARGS, nullptr},
    {"id", reinterpret_cast<PyCFunction>(Sbk_QAudioDeviceFunc_id), METH_NOARGS, nullptr},
    {"isDefault", reinterpret_cast<PyCFunction>(Sbk_QAudioDeviceFunc_isDefault), METH_NOARGS, nullptr},
    {"isFormatSupported", reinterpret_cast<PyCFunction>(Sbk_QAudioDeviceFunc_isFormatSupported), METH_O, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QAudioDeviceFunc_isNull), METH_NOARGS, nullptr},
    {"maximumChannelCount", reinterpret_cast<PyCFunction>(Sbk_QAudioDeviceFunc_maximumChannelCount), METH_NOARGS, nullptr},
    {"maximumSampleRate", reinterpret_cast<PyCFunction>(Sbk_QAudioDeviceFunc_maximumSampleRate), METH_NOARGS, nullptr},
    {"minimumChannelCount", reinterpret_cast<PyCFunction>(Sbk_QAudioDeviceFunc_minimumChannelCount), METH_NOARGS, nullptr},
    {"minimumSampleRate", reinterpret_cast<PyCFunction>(Sbk_QAudioDeviceFunc_minimumSampleRate), METH_NOARGS, nullptr},
    {"mode", reinterpret_cast<PyCFunction>(Sbk_QAudioDeviceFunc_mode), METH_NOARGS, nullptr},
    {"preferredFormat", reinterpret_cast<PyCFunction>(Sbk_QAudioDeviceFunc_preferredFormat), METH_NOARGS, nullptr},
    {"supportedSampleFormats", reinterpret_cast<PyCFunction>(Sbk_QAudioDeviceFunc_supportedSampleFormats), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QAudioDeviceFunc_swap), METH_O, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QAudioDevice__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAudioDevice___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

// Rich comparison
static PyObject * Sbk_QAudioDevice_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), (pyArg)))) {
                // operator!=(const QAudioDevice & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QAudioDevice cppArg0_local;
                ::QAudioDevice *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), (pyArg)))) {
                // operator==(const QAudioDevice & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QAudioDevice cppArg0_local;
                ::QAudioDevice *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QAudioDevice_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAudioDevice_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAudioDevice_Type = nullptr;
static PyTypeObject *Sbk_QAudioDevice_TypeF(void)
{
    return _Sbk_QAudioDevice_Type;
}

static PyType_Slot Sbk_QAudioDevice_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAudioDevice_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAudioDevice_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QAudioDevice_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAudioDevice_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAudioDevice_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QAudioDevice___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAudioDevice_spec = {
    "2:PySide6.QtMultimedia.QAudioDevice",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAudioDevice_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QAudioDevice_Mode_PythonToCpp_QAudioDevice_Mode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAudioDevice::Mode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAudioDevice::Mode *>(cppOut) = value;

}
static PythonToCppFunc is_QAudioDevice_Mode_PythonToCpp_QAudioDevice_Mode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_Mode_IDX])))
        return QAudioDevice_Mode_PythonToCpp_QAudioDevice_Mode;
    return {};
}
static PyObject *QAudioDevice_Mode_CppToPython_QAudioDevice_Mode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QAudioDevice::Mode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_Mode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAudioDevice_PythonToCpp_QAudioDevice_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAudioDevice_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAudioDevice_PythonToCpp_QAudioDevice_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAudioDevice_TypeF()))
        return QAudioDevice_PythonToCpp_QAudioDevice_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAudioDevice_PTR_CppToPython_QAudioDevice(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QAudioDevice *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QAudioDevice_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QAudioDevice_COPY_CppToPython_QAudioDevice(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QAudioDevice *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QAudioDevice_TypeF(), new ::QAudioDevice(*source), true, true);
}

// Python to C++ copy conversion.
static void QAudioDevice_PythonToCpp_QAudioDevice_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QAudioDevice *>(cppOut) = *reinterpret_cast< ::QAudioDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QAudioDevice_PythonToCpp_QAudioDevice_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QAudioDevice_TypeF()))
        return QAudioDevice_PythonToCpp_QAudioDevice_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QAudioDevice_SignatureStrings[] = {
    "1:PySide6.QtMultimedia.QAudioDevice(self)",
    "0:PySide6.QtMultimedia.QAudioDevice(self,other:PySide6.QtMultimedia.QAudioDevice)",
    "PySide6.QtMultimedia.QAudioDevice.channelConfiguration(self)->PySide6.QtMultimedia.QAudioFormat.ChannelConfig",
    "PySide6.QtMultimedia.QAudioDevice.description(self)->QString",
    "PySide6.QtMultimedia.QAudioDevice.id(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtMultimedia.QAudioDevice.isDefault(self)->bool",
    "PySide6.QtMultimedia.QAudioDevice.isFormatSupported(self,format:PySide6.QtMultimedia.QAudioFormat)->bool",
    "PySide6.QtMultimedia.QAudioDevice.isNull(self)->bool",
    "PySide6.QtMultimedia.QAudioDevice.maximumChannelCount(self)->int",
    "PySide6.QtMultimedia.QAudioDevice.maximumSampleRate(self)->int",
    "PySide6.QtMultimedia.QAudioDevice.minimumChannelCount(self)->int",
    "PySide6.QtMultimedia.QAudioDevice.minimumSampleRate(self)->int",
    "PySide6.QtMultimedia.QAudioDevice.mode(self)->PySide6.QtMultimedia.QAudioDevice.Mode",
    "PySide6.QtMultimedia.QAudioDevice.preferredFormat(self)->PySide6.QtMultimedia.QAudioFormat",
    "PySide6.QtMultimedia.QAudioDevice.supportedSampleFormats(self)->QList[PySide6.QtMultimedia.QAudioFormat.SampleFormat]",
    "PySide6.QtMultimedia.QAudioDevice.swap(self,other:PySide6.QtMultimedia.QAudioDevice)",
    "PySide6.QtMultimedia.QAudioDevice.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QAudioDevice(PyObject *module)
{
    if (SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX].type != nullptr)
        return SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX].type;

    Shiboken::AutoDecRef Sbk_QAudioDevice_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QAudioDevice_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAudioDevice",
        "QAudioDevice",
        &Sbk_QAudioDevice_spec,
        &Shiboken::callCppDestructor< ::QAudioDevice >,
        Sbk_QAudioDevice_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QAudioDevice_TypeF(); // references _Sbk_QAudioDevice_Type
    InitSignatureStrings(pyType, QAudioDevice_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAudioDevice_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAudioDevice_PythonToCpp_QAudioDevice_PTR,
        is_QAudioDevice_PythonToCpp_QAudioDevice_PTR_Convertible,
        QAudioDevice_PTR_CppToPython_QAudioDevice,
        QAudioDevice_COPY_CppToPython_QAudioDevice);

    Shiboken::Conversions::registerConverterName(converter, "QAudioDevice");
    Shiboken::Conversions::registerConverterName(converter, "QAudioDevice*");
    Shiboken::Conversions::registerConverterName(converter, "QAudioDevice&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAudioDevice).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QAudioDevice_PythonToCpp_QAudioDevice_COPY,
        is_QAudioDevice_PythonToCpp_QAudioDevice_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAudioDevice_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Mode'.
    const char *Mode_Initializer[] = {
        "Null",
        "Input",
        "Output",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Mode_InitializerValues[] = {
        uint8_t(QAudioDevice::Mode::Null),  //  0x00  0
        uint8_t(QAudioDevice::Mode::Input), //  0x01  1
        uint8_t(QAudioDevice::Mode::Output) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAudioDevice_TypeF(),
        "2:PySide6.QtMultimedia.QAudioDevice.Mode",
        Mode_Initializer, Mode_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QAudioDevice_Mode_IDX].type = EType;
    // Register converter for enum 'QAudioDevice::Mode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAudioDevice_Mode_CppToPython_QAudioDevice_Mode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QAudioDevice_Mode_PythonToCpp_QAudioDevice_Mode,
            is_QAudioDevice_Mode_PythonToCpp_QAudioDevice_Mode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QAudioDevice::Mode");
        Shiboken::Conversions::registerConverterName(converter, "Mode");
    }
    // End of 'Mode' enum.

    qRegisterMetaType< ::QAudioDevice >("QAudioDevice");
    qRegisterMetaType< ::QAudioDevice::Mode >("QAudioDevice::Mode");

    return pyType;
}
