// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qcamera_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtMultimedia/qcamera.h>
#include <QtMultimedia/qcameradevice.h>
#include <QtMultimedia/qmediacapturesession.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QCameraWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QCameraWrapper::QCameraWrapper(::QCameraDevice::Position position, ::QObject * parent) : QCamera(position, parent)
{
    resetPyMethodCache();
    // ... middle
}

QCameraWrapper::QCameraWrapper(::QObject * parent) : QCamera(parent)
{
    resetPyMethodCache();
    // ... middle
}

QCameraWrapper::QCameraWrapper(const ::QCameraDevice & cameraDevice, ::QObject * parent) : QCamera(cameraDevice, parent)
{
    resetPyMethodCache();
    // ... middle
}

void QCameraWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCameraWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCameraWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QCameraWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QCameraWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCamera", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QCameraWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QCamera", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QCameraWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

const QMetaObject *QCameraWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QCamera::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QCameraWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QCamera::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QCameraWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QCameraWrapper *>(this));
    return QCamera::qt_metacast(_clname);
}

QCameraWrapper::~QCameraWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCamera_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCamera >()))
        return -1;

    QCameraWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QCamera", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QCamera::QCamera(QCameraDevice::Position,QObject*=)
    // 1: QCamera::QCamera(QObject*=)
    // 2: QCamera::QCamera(QCameraDevice,QObject*=)
    if (numArgs == 0) {
        overloadId = 1; // QCamera(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QCamera(QCameraDevice,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QCamera(QCameraDevice,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QCamera(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_Position_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QCamera(QCameraDevice::Position,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QCamera(QCameraDevice::Position,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QCamera(QCameraDevice::Position position, QObject * parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::QCameraDevice::Position cppArg0{QCameraDevice::UnspecifiedPosition};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCamera(QCameraDevice::Position,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QCameraWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QCameraWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 1: // QCamera(QObject * parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCamera(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QCameraWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QCameraWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 2: // QCamera(const QCameraDevice & cameraDevice, QObject * parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCameraDevice cppArg0_local;
            ::QCameraDevice *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QCamera(QCameraDevice,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QCameraWrapper(*cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QCameraWrapper(*cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QCamera >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    };


    return 1;
}

static PyObject *Sbk_QCameraFunc_cameraDevice(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.cameraDevice";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cameraDevice()const
            QCameraDevice cppResult = const_cast<const ::QCamera *>(cppSelf)->cameraDevice();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_cameraFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.cameraFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // cameraFormat()const
            QCameraFormat cppResult = const_cast<const ::QCamera *>(cppSelf)->cameraFormat();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_captureSession(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.captureSession";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // captureSession()const
            QMediaCaptureSession * cppResult = const_cast<const ::QCamera *>(cppSelf)->captureSession();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QMediaCaptureSession_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_colorTemperature(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.colorTemperature";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // colorTemperature()const
            int cppResult = const_cast<const ::QCamera *>(cppSelf)->colorTemperature();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_customFocusPoint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.customFocusPoint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // customFocusPoint()const
            QPointF cppResult = const_cast<const ::QCamera *>(cppSelf)->customFocusPoint();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.error";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // error()const
            QCamera::Error cppResult = const_cast<const ::QCamera *>(cppSelf)->error();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_Error_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.errorString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // errorString()const
            QString cppResult = const_cast<const ::QCamera *>(cppSelf)->errorString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_exposureCompensation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.exposureCompensation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // exposureCompensation()const
            float cppResult = const_cast<const ::QCamera *>(cppSelf)->exposureCompensation();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_exposureMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.exposureMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // exposureMode()const
            QCamera::ExposureMode cppResult = const_cast<const ::QCamera *>(cppSelf)->exposureMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_ExposureMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_exposureTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.exposureTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // exposureTime()const
            float cppResult = const_cast<const ::QCamera *>(cppSelf)->exposureTime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_flashMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.flashMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // flashMode()const
            QCamera::FlashMode cppResult = const_cast<const ::QCamera *>(cppSelf)->flashMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_FlashMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_focusDistance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.focusDistance";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusDistance()const
            float cppResult = const_cast<const ::QCamera *>(cppSelf)->focusDistance();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_focusMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.focusMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusMode()const
            QCamera::FocusMode cppResult = const_cast<const ::QCamera *>(cppSelf)->focusMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_FocusMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_focusPoint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.focusPoint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusPoint()const
            QPointF cppResult = const_cast<const ::QCamera *>(cppSelf)->focusPoint();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_isActive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.isActive";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isActive()const
            bool cppResult = const_cast<const ::QCamera *>(cppSelf)->isActive();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_isAvailable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.isAvailable";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isAvailable()const
            bool cppResult = const_cast<const ::QCamera *>(cppSelf)->isAvailable();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_isExposureModeSupported(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.isExposureModeSupported";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::isExposureModeSupported(QCamera::ExposureMode)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_ExposureMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isExposureModeSupported(QCamera::ExposureMode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCamera::ExposureMode cppArg0{QCamera::ExposureAuto};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isExposureModeSupported(QCamera::ExposureMode)const
            bool cppResult = const_cast<const ::QCamera *>(cppSelf)->isExposureModeSupported(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_isFlashModeSupported(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.isFlashModeSupported";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::isFlashModeSupported(QCamera::FlashMode)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_FlashMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isFlashModeSupported(QCamera::FlashMode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCamera::FlashMode cppArg0{QCamera::FlashOff};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isFlashModeSupported(QCamera::FlashMode)const
            bool cppResult = const_cast<const ::QCamera *>(cppSelf)->isFlashModeSupported(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_isFlashReady(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.isFlashReady";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isFlashReady()const
            bool cppResult = const_cast<const ::QCamera *>(cppSelf)->isFlashReady();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_isFocusModeSupported(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.isFocusModeSupported";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::isFocusModeSupported(QCamera::FocusMode)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_FocusMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isFocusModeSupported(QCamera::FocusMode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCamera::FocusMode cppArg0{QCamera::FocusModeAuto};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isFocusModeSupported(QCamera::FocusMode)const
            bool cppResult = const_cast<const ::QCamera *>(cppSelf)->isFocusModeSupported(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_isTorchModeSupported(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.isTorchModeSupported";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::isTorchModeSupported(QCamera::TorchMode)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_TorchMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isTorchModeSupported(QCamera::TorchMode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCamera::TorchMode cppArg0{QCamera::TorchOff};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isTorchModeSupported(QCamera::TorchMode)const
            bool cppResult = const_cast<const ::QCamera *>(cppSelf)->isTorchModeSupported(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_isWhiteBalanceModeSupported(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.isWhiteBalanceModeSupported";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::isWhiteBalanceModeSupported(QCamera::WhiteBalanceMode)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_WhiteBalanceMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isWhiteBalanceModeSupported(QCamera::WhiteBalanceMode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCamera::WhiteBalanceMode cppArg0{QCamera::WhiteBalanceAuto};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isWhiteBalanceModeSupported(QCamera::WhiteBalanceMode)const
            bool cppResult = const_cast<const ::QCamera *>(cppSelf)->isWhiteBalanceModeSupported(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_isoSensitivity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.isoSensitivity";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isoSensitivity()const
            int cppResult = const_cast<const ::QCamera *>(cppSelf)->isoSensitivity();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_manualExposureTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.manualExposureTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // manualExposureTime()const
            float cppResult = const_cast<const ::QCamera *>(cppSelf)->manualExposureTime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_manualIsoSensitivity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.manualIsoSensitivity";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // manualIsoSensitivity()const
            int cppResult = const_cast<const ::QCamera *>(cppSelf)->manualIsoSensitivity();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_maximumExposureTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.maximumExposureTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maximumExposureTime()const
            float cppResult = const_cast<const ::QCamera *>(cppSelf)->maximumExposureTime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_maximumIsoSensitivity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.maximumIsoSensitivity";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maximumIsoSensitivity()const
            int cppResult = const_cast<const ::QCamera *>(cppSelf)->maximumIsoSensitivity();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_maximumZoomFactor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.maximumZoomFactor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maximumZoomFactor()const
            float cppResult = const_cast<const ::QCamera *>(cppSelf)->maximumZoomFactor();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_minimumExposureTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.minimumExposureTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minimumExposureTime()const
            float cppResult = const_cast<const ::QCamera *>(cppSelf)->minimumExposureTime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_minimumIsoSensitivity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.minimumIsoSensitivity";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minimumIsoSensitivity()const
            int cppResult = const_cast<const ::QCamera *>(cppSelf)->minimumIsoSensitivity();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_minimumZoomFactor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.minimumZoomFactor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minimumZoomFactor()const
            float cppResult = const_cast<const ::QCamera *>(cppSelf)->minimumZoomFactor();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_setActive(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setActive";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setActive(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setActive(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActive(bool)
            cppSelf->setActive(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setAutoExposureTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setAutoExposureTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoExposureTime()
            cppSelf->setAutoExposureTime();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setAutoIsoSensitivity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setAutoIsoSensitivity";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoIsoSensitivity()
            cppSelf->setAutoIsoSensitivity();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setCameraDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setCameraDevice";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setCameraDevice(QCameraDevice)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraDevice_IDX]), (pyArg)))) {
        overloadId = 0; // setCameraDevice(QCameraDevice)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCameraDevice cppArg0_local;
        ::QCameraDevice *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraDevice(QCameraDevice)
            cppSelf->setCameraDevice(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setCameraFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setCameraFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setCameraFormat(QCameraFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCameraFormat_IDX]), (pyArg)))) {
        overloadId = 0; // setCameraFormat(QCameraFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCameraFormat cppArg0_local;
        ::QCameraFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraFormat(QCameraFormat)
            cppSelf->setCameraFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setColorTemperature(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setColorTemperature";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setColorTemperature(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setColorTemperature(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColorTemperature(int)
            cppSelf->setColorTemperature(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setCustomFocusPoint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setCustomFocusPoint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setCustomFocusPoint(QPointF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // setCustomFocusPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCustomFocusPoint(QPointF)
            cppSelf->setCustomFocusPoint(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setExposureCompensation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setExposureCompensation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setExposureCompensation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setExposureCompensation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExposureCompensation(float)
            cppSelf->setExposureCompensation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setExposureMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setExposureMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setExposureMode(QCamera::ExposureMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_ExposureMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setExposureMode(QCamera::ExposureMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCamera::ExposureMode cppArg0{QCamera::ExposureAuto};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExposureMode(QCamera::ExposureMode)
            cppSelf->setExposureMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setFlashMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setFlashMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setFlashMode(QCamera::FlashMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_FlashMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFlashMode(QCamera::FlashMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCamera::FlashMode cppArg0{QCamera::FlashOff};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlashMode(QCamera::FlashMode)
            cppSelf->setFlashMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setFocusDistance(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setFocusDistance";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setFocusDistance(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setFocusDistance(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFocusDistance(float)
            cppSelf->setFocusDistance(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setFocusMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setFocusMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setFocusMode(QCamera::FocusMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_FocusMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFocusMode(QCamera::FocusMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCamera::FocusMode cppArg0{QCamera::FocusModeAuto};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFocusMode(QCamera::FocusMode)
            cppSelf->setFocusMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setManualExposureTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setManualExposureTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setManualExposureTime(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setManualExposureTime(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setManualExposureTime(float)
            cppSelf->setManualExposureTime(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setManualIsoSensitivity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setManualIsoSensitivity";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setManualIsoSensitivity(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setManualIsoSensitivity(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setManualIsoSensitivity(int)
            cppSelf->setManualIsoSensitivity(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setTorchMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setTorchMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setTorchMode(QCamera::TorchMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_TorchMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTorchMode(QCamera::TorchMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCamera::TorchMode cppArg0{QCamera::TorchOff};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTorchMode(QCamera::TorchMode)
            cppSelf->setTorchMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setWhiteBalanceMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setWhiteBalanceMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setWhiteBalanceMode(QCamera::WhiteBalanceMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_WhiteBalanceMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setWhiteBalanceMode(QCamera::WhiteBalanceMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QCamera::WhiteBalanceMode cppArg0{QCamera::WhiteBalanceAuto};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWhiteBalanceMode(QCamera::WhiteBalanceMode)
            cppSelf->setWhiteBalanceMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_setZoomFactor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.setZoomFactor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCamera::setZoomFactor(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setZoomFactor(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZoomFactor(float)
            cppSelf->setZoomFactor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_start(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.start";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // start()
            cppSelf->start();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_stop(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.stop";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // stop()
            cppSelf->stop();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QCameraFunc_supportedFeatures(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.supportedFeatures";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportedFeatures()const
            QFlags<QCamera::Feature> cppResult = const_cast<const ::QCamera *>(cppSelf)->supportedFeatures();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QFlags_QCamera_Feature_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_torchMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.torchMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // torchMode()const
            QCamera::TorchMode cppResult = const_cast<const ::QCamera *>(cppSelf)->torchMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_TorchMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_whiteBalanceMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.whiteBalanceMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // whiteBalanceMode()const
            QCamera::WhiteBalanceMode cppResult = const_cast<const ::QCamera *>(cppSelf)->whiteBalanceMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_WhiteBalanceMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_zoomFactor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.zoomFactor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // zoomFactor()const
            float cppResult = const_cast<const ::QCamera *>(cppSelf)->zoomFactor();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCameraFunc_zoomTo(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QCamera.zoomTo";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "zoomTo", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QCamera::zoomTo(float,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // zoomTo(float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // zoomTo(float,float)
            cppSelf->zoomTo(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QCamera_PropertyStrings[] = {
    "active:isActive:",
    "cameraDevice::",
    "cameraFormat::",
    "colorTemperature::",
    "customFocusPoint::",
    "error:",
    "errorString:",
    "exposureCompensation::",
    "exposureMode::",
    "exposureTime:",
    "flashMode::",
    "flashReady:isFlashReady",
    "focusDistance::",
    "focusMode::",
    "focusPoint:",
    "isoSensitivity:",
    "manualExposureTime::",
    "manualIsoSensitivity::",
    "maximumZoomFactor:",
    "minimumZoomFactor:",
    "supportedFeatures:",
    "torchMode::",
    "whiteBalanceMode::",
    "zoomFactor::",
    nullptr // Sentinel
};

static const char *Sbk_QCamera_EnumFlagInfo[] = {
    "Error:Enum",
    "ExposureMode:Enum",
    "Feature:Flag:Features",
    "FlashMode:Enum",
    "FocusMode:Enum",
    "TorchMode:Enum",
    "WhiteBalanceMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCamera_methods[] = {
    {"cameraDevice", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_cameraDevice), METH_NOARGS, nullptr},
    {"cameraFormat", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_cameraFormat), METH_NOARGS, nullptr},
    {"captureSession", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_captureSession), METH_NOARGS, nullptr},
    {"colorTemperature", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_colorTemperature), METH_NOARGS, nullptr},
    {"customFocusPoint", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_customFocusPoint), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_errorString), METH_NOARGS, nullptr},
    {"exposureCompensation", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_exposureCompensation), METH_NOARGS, nullptr},
    {"exposureMode", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_exposureMode), METH_NOARGS, nullptr},
    {"exposureTime", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_exposureTime), METH_NOARGS, nullptr},
    {"flashMode", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_flashMode), METH_NOARGS, nullptr},
    {"focusDistance", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_focusDistance), METH_NOARGS, nullptr},
    {"focusMode", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_focusMode), METH_NOARGS, nullptr},
    {"focusPoint", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_focusPoint), METH_NOARGS, nullptr},
    {"isActive", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_isActive), METH_NOARGS, nullptr},
    {"isAvailable", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_isAvailable), METH_NOARGS, nullptr},
    {"isExposureModeSupported", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_isExposureModeSupported), METH_O, nullptr},
    {"isFlashModeSupported", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_isFlashModeSupported), METH_O, nullptr},
    {"isFlashReady", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_isFlashReady), METH_NOARGS, nullptr},
    {"isFocusModeSupported", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_isFocusModeSupported), METH_O, nullptr},
    {"isTorchModeSupported", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_isTorchModeSupported), METH_O, nullptr},
    {"isWhiteBalanceModeSupported", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_isWhiteBalanceModeSupported), METH_O, nullptr},
    {"isoSensitivity", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_isoSensitivity), METH_NOARGS, nullptr},
    {"manualExposureTime", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_manualExposureTime), METH_NOARGS, nullptr},
    {"manualIsoSensitivity", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_manualIsoSensitivity), METH_NOARGS, nullptr},
    {"maximumExposureTime", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_maximumExposureTime), METH_NOARGS, nullptr},
    {"maximumIsoSensitivity", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_maximumIsoSensitivity), METH_NOARGS, nullptr},
    {"maximumZoomFactor", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_maximumZoomFactor), METH_NOARGS, nullptr},
    {"minimumExposureTime", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_minimumExposureTime), METH_NOARGS, nullptr},
    {"minimumIsoSensitivity", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_minimumIsoSensitivity), METH_NOARGS, nullptr},
    {"minimumZoomFactor", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_minimumZoomFactor), METH_NOARGS, nullptr},
    {"setActive", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setActive), METH_O, nullptr},
    {"setAutoExposureTime", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setAutoExposureTime), METH_NOARGS, nullptr},
    {"setAutoIsoSensitivity", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setAutoIsoSensitivity), METH_NOARGS, nullptr},
    {"setCameraDevice", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setCameraDevice), METH_O, nullptr},
    {"setCameraFormat", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setCameraFormat), METH_O, nullptr},
    {"setColorTemperature", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setColorTemperature), METH_O, nullptr},
    {"setCustomFocusPoint", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setCustomFocusPoint), METH_O, nullptr},
    {"setExposureCompensation", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setExposureCompensation), METH_O, nullptr},
    {"setExposureMode", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setExposureMode), METH_O, nullptr},
    {"setFlashMode", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setFlashMode), METH_O, nullptr},
    {"setFocusDistance", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setFocusDistance), METH_O, nullptr},
    {"setFocusMode", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setFocusMode), METH_O, nullptr},
    {"setManualExposureTime", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setManualExposureTime), METH_O, nullptr},
    {"setManualIsoSensitivity", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setManualIsoSensitivity), METH_O, nullptr},
    {"setTorchMode", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setTorchMode), METH_O, nullptr},
    {"setWhiteBalanceMode", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setWhiteBalanceMode), METH_O, nullptr},
    {"setZoomFactor", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_setZoomFactor), METH_O, nullptr},
    {"start", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_start), METH_NOARGS, nullptr},
    {"stop", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_stop), METH_NOARGS, nullptr},
    {"supportedFeatures", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_supportedFeatures), METH_NOARGS, nullptr},
    {"torchMode", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_torchMode), METH_NOARGS, nullptr},
    {"whiteBalanceMode", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_whiteBalanceMode), METH_NOARGS, nullptr},
    {"zoomFactor", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_zoomFactor), METH_NOARGS, nullptr},
    {"zoomTo", reinterpret_cast<PyCFunction>(Sbk_QCameraFunc_zoomTo), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QCamera_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QCamera *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QCameraWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QCamera_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCamera_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCamera_Type = nullptr;
static PyTypeObject *Sbk_QCamera_TypeF(void)
{
    return _Sbk_QCamera_Type;
}

static PyType_Slot Sbk_QCamera_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QCamera_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCamera_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCamera_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCamera_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCamera_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCamera_spec = {
    "2:PySide6.QtMultimedia.QCamera",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCamera_slots
};

} //extern "C"

static void *Sbk_QCamera_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QCamera *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QCamera_Error_PythonToCpp_QCamera_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCamera::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCamera::Error *>(cppOut) = value;

}
static PythonToCppFunc is_QCamera_Error_PythonToCpp_QCamera_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_Error_IDX])))
        return QCamera_Error_PythonToCpp_QCamera_Error;
    return {};
}
static PyObject *QCamera_Error_CppToPython_QCamera_Error(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCamera::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_Error_IDX]), castCppIn);

}

static void QCamera_FocusMode_PythonToCpp_QCamera_FocusMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCamera::FocusMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCamera::FocusMode *>(cppOut) = value;

}
static PythonToCppFunc is_QCamera_FocusMode_PythonToCpp_QCamera_FocusMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_FocusMode_IDX])))
        return QCamera_FocusMode_PythonToCpp_QCamera_FocusMode;
    return {};
}
static PyObject *QCamera_FocusMode_CppToPython_QCamera_FocusMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCamera::FocusMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_FocusMode_IDX]), castCppIn);

}

static void QCamera_FlashMode_PythonToCpp_QCamera_FlashMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCamera::FlashMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCamera::FlashMode *>(cppOut) = value;

}
static PythonToCppFunc is_QCamera_FlashMode_PythonToCpp_QCamera_FlashMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_FlashMode_IDX])))
        return QCamera_FlashMode_PythonToCpp_QCamera_FlashMode;
    return {};
}
static PyObject *QCamera_FlashMode_CppToPython_QCamera_FlashMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCamera::FlashMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_FlashMode_IDX]), castCppIn);

}

static void QCamera_TorchMode_PythonToCpp_QCamera_TorchMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCamera::TorchMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCamera::TorchMode *>(cppOut) = value;

}
static PythonToCppFunc is_QCamera_TorchMode_PythonToCpp_QCamera_TorchMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_TorchMode_IDX])))
        return QCamera_TorchMode_PythonToCpp_QCamera_TorchMode;
    return {};
}
static PyObject *QCamera_TorchMode_CppToPython_QCamera_TorchMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCamera::TorchMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_TorchMode_IDX]), castCppIn);

}

static void QCamera_ExposureMode_PythonToCpp_QCamera_ExposureMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCamera::ExposureMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCamera::ExposureMode *>(cppOut) = value;

}
static PythonToCppFunc is_QCamera_ExposureMode_PythonToCpp_QCamera_ExposureMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_ExposureMode_IDX])))
        return QCamera_ExposureMode_PythonToCpp_QCamera_ExposureMode;
    return {};
}
static PyObject *QCamera_ExposureMode_CppToPython_QCamera_ExposureMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCamera::ExposureMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_ExposureMode_IDX]), castCppIn);

}

static void QCamera_WhiteBalanceMode_PythonToCpp_QCamera_WhiteBalanceMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCamera::WhiteBalanceMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCamera::WhiteBalanceMode *>(cppOut) = value;

}
static PythonToCppFunc is_QCamera_WhiteBalanceMode_PythonToCpp_QCamera_WhiteBalanceMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_WhiteBalanceMode_IDX])))
        return QCamera_WhiteBalanceMode_PythonToCpp_QCamera_WhiteBalanceMode;
    return {};
}
static PyObject *QCamera_WhiteBalanceMode_CppToPython_QCamera_WhiteBalanceMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCamera::WhiteBalanceMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_WhiteBalanceMode_IDX]), castCppIn);

}

static void QCamera_Feature_PythonToCpp_QCamera_Feature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCamera::Feature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCamera::Feature *>(cppOut) = value;

}
static PythonToCppFunc is_QCamera_Feature_PythonToCpp_QCamera_Feature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_Feature_IDX])))
        return QCamera_Feature_PythonToCpp_QCamera_Feature;
    return {};
}
static PyObject *QCamera_Feature_CppToPython_QCamera_Feature(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCamera::Feature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_Feature_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCamera_PythonToCpp_QCamera_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCamera_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCamera_PythonToCpp_QCamera_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCamera_TypeF()))
        return QCamera_PythonToCpp_QCamera_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCamera_PTR_CppToPython_QCamera(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QCamera *>(const_cast<void *>(cppIn)), Sbk_QCamera_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QCamera_SignatureStrings[] = {
    "2:PySide6.QtMultimedia.QCamera(self,position:PySide6.QtMultimedia.QCameraDevice.Position,parent:PySide6.QtCore.QObject=nullptr)",
    "1:PySide6.QtMultimedia.QCamera(self,parent:PySide6.QtCore.QObject=nullptr)",
    "0:PySide6.QtMultimedia.QCamera(self,cameraDevice:PySide6.QtMultimedia.QCameraDevice,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtMultimedia.QCamera.cameraDevice(self)->PySide6.QtMultimedia.QCameraDevice",
    "PySide6.QtMultimedia.QCamera.cameraFormat(self)->PySide6.QtMultimedia.QCameraFormat",
    "PySide6.QtMultimedia.QCamera.captureSession(self)->PySide6.QtMultimedia.QMediaCaptureSession",
    "PySide6.QtMultimedia.QCamera.colorTemperature(self)->int",
    "PySide6.QtMultimedia.QCamera.customFocusPoint(self)->PySide6.QtCore.QPointF",
    "PySide6.QtMultimedia.QCamera.error(self)->PySide6.QtMultimedia.QCamera.Error",
    "PySide6.QtMultimedia.QCamera.errorString(self)->QString",
    "PySide6.QtMultimedia.QCamera.exposureCompensation(self)->float",
    "PySide6.QtMultimedia.QCamera.exposureMode(self)->PySide6.QtMultimedia.QCamera.ExposureMode",
    "PySide6.QtMultimedia.QCamera.exposureTime(self)->float",
    "PySide6.QtMultimedia.QCamera.flashMode(self)->PySide6.QtMultimedia.QCamera.FlashMode",
    "PySide6.QtMultimedia.QCamera.focusDistance(self)->float",
    "PySide6.QtMultimedia.QCamera.focusMode(self)->PySide6.QtMultimedia.QCamera.FocusMode",
    "PySide6.QtMultimedia.QCamera.focusPoint(self)->PySide6.QtCore.QPointF",
    "PySide6.QtMultimedia.QCamera.isActive(self)->bool",
    "PySide6.QtMultimedia.QCamera.isAvailable(self)->bool",
    "PySide6.QtMultimedia.QCamera.isExposureModeSupported(self,mode:PySide6.QtMultimedia.QCamera.ExposureMode)->bool",
    "PySide6.QtMultimedia.QCamera.isFlashModeSupported(self,mode:PySide6.QtMultimedia.QCamera.FlashMode)->bool",
    "PySide6.QtMultimedia.QCamera.isFlashReady(self)->bool",
    "PySide6.QtMultimedia.QCamera.isFocusModeSupported(self,mode:PySide6.QtMultimedia.QCamera.FocusMode)->bool",
    "PySide6.QtMultimedia.QCamera.isTorchModeSupported(self,mode:PySide6.QtMultimedia.QCamera.TorchMode)->bool",
    "PySide6.QtMultimedia.QCamera.isWhiteBalanceModeSupported(self,mode:PySide6.QtMultimedia.QCamera.WhiteBalanceMode)->bool",
    "PySide6.QtMultimedia.QCamera.isoSensitivity(self)->int",
    "PySide6.QtMultimedia.QCamera.manualExposureTime(self)->float",
    "PySide6.QtMultimedia.QCamera.manualIsoSensitivity(self)->int",
    "PySide6.QtMultimedia.QCamera.maximumExposureTime(self)->float",
    "PySide6.QtMultimedia.QCamera.maximumIsoSensitivity(self)->int",
    "PySide6.QtMultimedia.QCamera.maximumZoomFactor(self)->float",
    "PySide6.QtMultimedia.QCamera.minimumExposureTime(self)->float",
    "PySide6.QtMultimedia.QCamera.minimumIsoSensitivity(self)->int",
    "PySide6.QtMultimedia.QCamera.minimumZoomFactor(self)->float",
    "PySide6.QtMultimedia.QCamera.setActive(self,active:bool)",
    "PySide6.QtMultimedia.QCamera.setAutoExposureTime(self)",
    "PySide6.QtMultimedia.QCamera.setAutoIsoSensitivity(self)",
    "PySide6.QtMultimedia.QCamera.setCameraDevice(self,cameraDevice:PySide6.QtMultimedia.QCameraDevice)",
    "PySide6.QtMultimedia.QCamera.setCameraFormat(self,format:PySide6.QtMultimedia.QCameraFormat)",
    "PySide6.QtMultimedia.QCamera.setColorTemperature(self,colorTemperature:int)",
    "PySide6.QtMultimedia.QCamera.setCustomFocusPoint(self,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "PySide6.QtMultimedia.QCamera.setExposureCompensation(self,ev:float)",
    "PySide6.QtMultimedia.QCamera.setExposureMode(self,mode:PySide6.QtMultimedia.QCamera.ExposureMode)",
    "PySide6.QtMultimedia.QCamera.setFlashMode(self,mode:PySide6.QtMultimedia.QCamera.FlashMode)",
    "PySide6.QtMultimedia.QCamera.setFocusDistance(self,d:float)",
    "PySide6.QtMultimedia.QCamera.setFocusMode(self,mode:PySide6.QtMultimedia.QCamera.FocusMode)",
    "PySide6.QtMultimedia.QCamera.setManualExposureTime(self,seconds:float)",
    "PySide6.QtMultimedia.QCamera.setManualIsoSensitivity(self,iso:int)",
    "PySide6.QtMultimedia.QCamera.setTorchMode(self,mode:PySide6.QtMultimedia.QCamera.TorchMode)",
    "PySide6.QtMultimedia.QCamera.setWhiteBalanceMode(self,mode:PySide6.QtMultimedia.QCamera.WhiteBalanceMode)",
    "PySide6.QtMultimedia.QCamera.setZoomFactor(self,factor:float)",
    "PySide6.QtMultimedia.QCamera.start(self)",
    "PySide6.QtMultimedia.QCamera.stop(self)",
    "PySide6.QtMultimedia.QCamera.supportedFeatures(self)->PySide6.QtMultimedia.QCamera.Feature",
    "PySide6.QtMultimedia.QCamera.torchMode(self)->PySide6.QtMultimedia.QCamera.TorchMode",
    "PySide6.QtMultimedia.QCamera.whiteBalanceMode(self)->PySide6.QtMultimedia.QCamera.WhiteBalanceMode",
    "PySide6.QtMultimedia.QCamera.zoomFactor(self)->float",
    "PySide6.QtMultimedia.QCamera.zoomTo(self,zoom:float,rate:float)",
    nullptr}; // Sentinel

PyTypeObject *init_QCamera(PyObject *module)
{
    if (SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX].type != nullptr)
        return SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX].type;

    Shiboken::AutoDecRef Sbk_QCamera_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QCamera_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCamera",
        "QCamera*",
        &Sbk_QCamera_spec,
        &Shiboken::callCppDestructor< QCamera >,
        Sbk_QCamera_Type_bases.object(),
        0);
    auto *pyType = Sbk_QCamera_TypeF(); // references _Sbk_QCamera_Type
    InitSignatureStrings(pyType, QCamera_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCamera_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCamera_PythonToCpp_QCamera_PTR,
        is_QCamera_PythonToCpp_QCamera_PTR_Convertible,
        QCamera_PTR_CppToPython_QCamera);

    Shiboken::Conversions::registerConverterName(converter, "QCamera");
    Shiboken::Conversions::registerConverterName(converter, "QCamera*");
    Shiboken::Conversions::registerConverterName(converter, "QCamera&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCamera).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QCameraWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QCamera_TypeF(), &Sbk_QCamera_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCamera_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "CameraError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QCamera::Error::NoError),    //  0x00  0
        uint8_t(QCamera::Error::CameraError) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCamera_TypeF(),
        "2:PySide6.QtMultimedia.QCamera.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_Error_IDX].type = EType;
    // Register converter for enum 'QCamera::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCamera_Error_CppToPython_QCamera_Error);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCamera_Error_PythonToCpp_QCamera_Error,
            is_QCamera_Error_PythonToCpp_QCamera_Error_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCamera::Error");
        Shiboken::Conversions::registerConverterName(converter, "Error");
    }
    // End of 'Error' enum.

    // Initialization of enum 'FocusMode'.
    const char *FocusMode_Initializer[] = {
        "FocusModeAuto",
        "FocusModeAutoNear",
        "FocusModeAutoFar",
        "FocusModeHyperfocal",
        "FocusModeInfinity",
        "FocusModeManual",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FocusMode_InitializerValues[] = {
        uint8_t(QCamera::FocusMode::FocusModeAuto),       //  0x00  0
        uint8_t(QCamera::FocusMode::FocusModeAutoNear),   //  0x01  1
        uint8_t(QCamera::FocusMode::FocusModeAutoFar),    //  0x02  2
        uint8_t(QCamera::FocusMode::FocusModeHyperfocal), //  0x03  3
        uint8_t(QCamera::FocusMode::FocusModeInfinity),   //  0x04  4
        uint8_t(QCamera::FocusMode::FocusModeManual)      //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCamera_TypeF(),
        "2:PySide6.QtMultimedia.QCamera.FocusMode",
        FocusMode_Initializer, FocusMode_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_FocusMode_IDX].type = EType;
    // Register converter for enum 'QCamera::FocusMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCamera_FocusMode_CppToPython_QCamera_FocusMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCamera_FocusMode_PythonToCpp_QCamera_FocusMode,
            is_QCamera_FocusMode_PythonToCpp_QCamera_FocusMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCamera::FocusMode");
        Shiboken::Conversions::registerConverterName(converter, "FocusMode");
    }
    // End of 'FocusMode' enum.

    // Initialization of enum 'FlashMode'.
    const char *FlashMode_Initializer[] = {
        "FlashOff",
        "FlashOn",
        "FlashAuto",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FlashMode_InitializerValues[] = {
        uint8_t(QCamera::FlashMode::FlashOff), //  0x00  0
        uint8_t(QCamera::FlashMode::FlashOn),  //  0x01  1
        uint8_t(QCamera::FlashMode::FlashAuto) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCamera_TypeF(),
        "2:PySide6.QtMultimedia.QCamera.FlashMode",
        FlashMode_Initializer, FlashMode_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_FlashMode_IDX].type = EType;
    // Register converter for enum 'QCamera::FlashMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCamera_FlashMode_CppToPython_QCamera_FlashMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCamera_FlashMode_PythonToCpp_QCamera_FlashMode,
            is_QCamera_FlashMode_PythonToCpp_QCamera_FlashMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCamera::FlashMode");
        Shiboken::Conversions::registerConverterName(converter, "FlashMode");
    }
    // End of 'FlashMode' enum.

    // Initialization of enum 'TorchMode'.
    const char *TorchMode_Initializer[] = {
        "TorchOff",
        "TorchOn",
        "TorchAuto",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TorchMode_InitializerValues[] = {
        uint8_t(QCamera::TorchMode::TorchOff), //  0x00  0
        uint8_t(QCamera::TorchMode::TorchOn),  //  0x01  1
        uint8_t(QCamera::TorchMode::TorchAuto) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCamera_TypeF(),
        "2:PySide6.QtMultimedia.QCamera.TorchMode",
        TorchMode_Initializer, TorchMode_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_TorchMode_IDX].type = EType;
    // Register converter for enum 'QCamera::TorchMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCamera_TorchMode_CppToPython_QCamera_TorchMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCamera_TorchMode_PythonToCpp_QCamera_TorchMode,
            is_QCamera_TorchMode_PythonToCpp_QCamera_TorchMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCamera::TorchMode");
        Shiboken::Conversions::registerConverterName(converter, "TorchMode");
    }
    // End of 'TorchMode' enum.

    // Initialization of enum 'ExposureMode'.
    const char *ExposureMode_Initializer[] = {
        "ExposureAuto",
        "ExposureManual",
        "ExposurePortrait",
        "ExposureNight",
        "ExposureSports",
        "ExposureSnow",
        "ExposureBeach",
        "ExposureAction",
        "ExposureLandscape",
        "ExposureNightPortrait",
        "ExposureTheatre",
        "ExposureSunset",
        "ExposureSteadyPhoto",
        "ExposureFireworks",
        "ExposureParty",
        "ExposureCandlelight",
        "ExposureBarcode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ExposureMode_InitializerValues[] = {
        uint8_t(QCamera::ExposureMode::ExposureAuto),          //  0x00  0
        uint8_t(QCamera::ExposureMode::ExposureManual),        //  0x01  1
        uint8_t(QCamera::ExposureMode::ExposurePortrait),      //  0x02  2
        uint8_t(QCamera::ExposureMode::ExposureNight),         //  0x03  3
        uint8_t(QCamera::ExposureMode::ExposureSports),        //  0x04  4
        uint8_t(QCamera::ExposureMode::ExposureSnow),          //  0x05  5
        uint8_t(QCamera::ExposureMode::ExposureBeach),         //  0x06  6
        uint8_t(QCamera::ExposureMode::ExposureAction),        //  0x07  7
        uint8_t(QCamera::ExposureMode::ExposureLandscape),     //  0x08  8
        uint8_t(QCamera::ExposureMode::ExposureNightPortrait), //  0x09  9
        uint8_t(QCamera::ExposureMode::ExposureTheatre),       //  0x0a  10
        uint8_t(QCamera::ExposureMode::ExposureSunset),        //  0x0b  11
        uint8_t(QCamera::ExposureMode::ExposureSteadyPhoto),   //  0x0c  12
        uint8_t(QCamera::ExposureMode::ExposureFireworks),     //  0x0d  13
        uint8_t(QCamera::ExposureMode::ExposureParty),         //  0x0e  14
        uint8_t(QCamera::ExposureMode::ExposureCandlelight),   //  0x0f  15
        uint8_t(QCamera::ExposureMode::ExposureBarcode)        //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCamera_TypeF(),
        "2:PySide6.QtMultimedia.QCamera.ExposureMode",
        ExposureMode_Initializer, ExposureMode_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_ExposureMode_IDX].type = EType;
    // Register converter for enum 'QCamera::ExposureMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCamera_ExposureMode_CppToPython_QCamera_ExposureMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCamera_ExposureMode_PythonToCpp_QCamera_ExposureMode,
            is_QCamera_ExposureMode_PythonToCpp_QCamera_ExposureMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCamera::ExposureMode");
        Shiboken::Conversions::registerConverterName(converter, "ExposureMode");
    }
    // End of 'ExposureMode' enum.

    // Initialization of enum 'WhiteBalanceMode'.
    const char *WhiteBalanceMode_Initializer[] = {
        "WhiteBalanceAuto",
        "WhiteBalanceManual",
        "WhiteBalanceSunlight",
        "WhiteBalanceCloudy",
        "WhiteBalanceShade",
        "WhiteBalanceTungsten",
        "WhiteBalanceFluorescent",
        "WhiteBalanceFlash",
        "WhiteBalanceSunset",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t WhiteBalanceMode_InitializerValues[] = {
        uint8_t(QCamera::WhiteBalanceMode::WhiteBalanceAuto),        //  0x00  0
        uint8_t(QCamera::WhiteBalanceMode::WhiteBalanceManual),      //  0x01  1
        uint8_t(QCamera::WhiteBalanceMode::WhiteBalanceSunlight),    //  0x02  2
        uint8_t(QCamera::WhiteBalanceMode::WhiteBalanceCloudy),      //  0x03  3
        uint8_t(QCamera::WhiteBalanceMode::WhiteBalanceShade),       //  0x04  4
        uint8_t(QCamera::WhiteBalanceMode::WhiteBalanceTungsten),    //  0x05  5
        uint8_t(QCamera::WhiteBalanceMode::WhiteBalanceFluorescent), //  0x06  6
        uint8_t(QCamera::WhiteBalanceMode::WhiteBalanceFlash),       //  0x07  7
        uint8_t(QCamera::WhiteBalanceMode::WhiteBalanceSunset)       //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCamera_TypeF(),
        "2:PySide6.QtMultimedia.QCamera.WhiteBalanceMode",
        WhiteBalanceMode_Initializer, WhiteBalanceMode_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_WhiteBalanceMode_IDX].type = EType;
    // Register converter for enum 'QCamera::WhiteBalanceMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCamera_WhiteBalanceMode_CppToPython_QCamera_WhiteBalanceMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCamera_WhiteBalanceMode_PythonToCpp_QCamera_WhiteBalanceMode,
            is_QCamera_WhiteBalanceMode_PythonToCpp_QCamera_WhiteBalanceMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCamera::WhiteBalanceMode");
        Shiboken::Conversions::registerConverterName(converter, "WhiteBalanceMode");
    }
    // End of 'WhiteBalanceMode' enum.

    // Initialization of enum 'Feature'.
    const char *Feature_Initializer[] = {
        "ColorTemperature",
        "ExposureCompensation",
        "IsoSensitivity",
        "ManualExposureTime",
        "CustomFocusPoint",
        "FocusDistance",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Feature_InitializerValues[] = {
        int8_t(QCamera::Feature::ColorTemperature),     //  0x01  1
        int8_t(QCamera::Feature::ExposureCompensation), //  0x02  2
        int8_t(QCamera::Feature::IsoSensitivity),       //  0x04  4
        int8_t(QCamera::Feature::ManualExposureTime),   //  0x08  8
        int8_t(QCamera::Feature::CustomFocusPoint),     //  0x10  16
        int8_t(QCamera::Feature::FocusDistance)         //  0x20  32
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCamera_TypeF(),
        "2:PySide6.QtMultimedia.QCamera.Feature",
        Feature_Initializer, Feature_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QCamera_Feature_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtMultimediaTypeStructs[SBK_QFlags_QCamera_Feature_IDX].type =
        EType;
    // Register converter for enum 'QCamera::Feature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCamera_Feature_CppToPython_QCamera_Feature);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCamera_Feature_PythonToCpp_QCamera_Feature,
            is_QCamera_Feature_PythonToCpp_QCamera_Feature_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCamera::Feature");
        Shiboken::Conversions::registerConverterName(converter, "Feature");
        // Register converter for flag 'QFlags<QCamera::Feature>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QCamera::Feature>");
        Shiboken::Conversions::registerConverterName(converter, "QCamera::Features");
    }
    // End of 'Feature' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QCamera::staticMetaObject);
    qRegisterMetaType< ::QCamera::Error >("QCamera::Error");
    qRegisterMetaType< ::QCamera::FocusMode >("QCamera::FocusMode");
    qRegisterMetaType< ::QCamera::FlashMode >("QCamera::FlashMode");
    qRegisterMetaType< ::QCamera::TorchMode >("QCamera::TorchMode");
    qRegisterMetaType< ::QCamera::ExposureMode >("QCamera::ExposureMode");
    qRegisterMetaType< ::QCamera::WhiteBalanceMode >("QCamera::WhiteBalanceMode");
    qRegisterMetaType< ::QCamera::Feature >("QCamera::Feature");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QCamera::staticMetaObject, sizeof(QCameraWrapper));

    return pyType;
}
