// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtmultimedia_python.h"

// main header
#include "qvideoframe_wrapper.h"

// inner classes
#include "qvideoframe_paintoptions_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qimage.h>
#include <QtGui/qpainter.h>
#include <QtMultimedia/qtvideo.h>
#include <QtMultimedia/qvideoframe.h>
#include <QtMultimedia/qvideoframeformat.h>
#include <qrect.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QVideoFrame_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QVideoFrame >()))
        return -1;

    ::QVideoFrame *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QVideoFrame", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QVideoFrame::QVideoFrame()
    // 1: QVideoFrame::QVideoFrame(QVideoFrame)
    // 2: QVideoFrame::QVideoFrame(QVideoFrameFormat)
    if (numArgs == 0) {
        overloadId = 0; // QVideoFrame()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrameFormat_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QVideoFrame(QVideoFrameFormat)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QVideoFrame(QVideoFrame)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QVideoFrame()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QVideoFrame()
                cptr = new ::QVideoFrame();
            }
            break;
        }
        case 1: // QVideoFrame(const QVideoFrame & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVideoFrame cppArg0_local;
            ::QVideoFrame *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QVideoFrame(QVideoFrame)
                cptr = new ::QVideoFrame(*cppArg0);
            }
            break;
        }
        case 2: // QVideoFrame(const QVideoFrameFormat & format)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QVideoFrameFormat cppArg0_local;
            ::QVideoFrameFormat *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QVideoFrame(QVideoFrameFormat)
                cptr = new ::QVideoFrame(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QVideoFrame >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QVideoFrameFunc_bits(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.bits";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVideoFrame::bits(int)->uchar*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // bits(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // bits(int)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtmultimedia.cpp (qvideoframe-bits)]
#include "object.h"
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            uchar * cppResult = cppSelf->bits(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            const auto size = cppSelf->mappedBytes(cppArg0);
            pyResult = Shiboken::Buffer::newObject(cppResult, size, Shiboken::Buffer::ReadWrite);
            // END of custom code block [file: ../glue/qtmultimedia.cpp (qvideoframe-bits)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_bytesPerLine(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.bytesPerLine";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVideoFrame::bytesPerLine(int)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // bytesPerLine(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // bytesPerLine(int)const
            int cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->bytesPerLine(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_endTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.endTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // endTime()const
            qint64 cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->endTime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_handleType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.handleType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // handleType()const
            QVideoFrame::HandleType cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->handleType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_HandleType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_height(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.height";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // height()const
            int cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->height();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_isMapped(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.isMapped";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isMapped()const
            bool cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->isMapped();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_isReadable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.isReadable";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isReadable()const
            bool cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->isReadable();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_isWritable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.isWritable";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isWritable()const
            bool cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->isWritable();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_map(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.map";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVideoFrame::map(QVideoFrame::MapMode)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_MapMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // map(QVideoFrame::MapMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QVideoFrame::MapMode cppArg0{QVideoFrame::NotMapped};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // map(QVideoFrame::MapMode)
            bool cppResult = cppSelf->map(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_mapMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.mapMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mapMode()const
            QVideoFrame::MapMode cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->mapMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_MapMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_mappedBytes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.mappedBytes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVideoFrame::mappedBytes(int)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // mappedBytes(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mappedBytes(int)const
            int cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->mappedBytes(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_mirrored(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.mirrored";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mirrored()const
            bool cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->mirrored();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_paint(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.paint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "paint", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QVideoFrame::paint(QPainter*,QRectF,QVideoFrame::PaintOptions)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_PaintOptions_IDX]), (pyArgs[2])))) {
        overloadId = 0; // paint(QPainter*,QRectF,QVideoFrame::PaintOptions)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRectF cppArg1_local;
        ::QRectF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QVideoFrame::PaintOptions cppArg2_local;
        ::QVideoFrame::PaintOptions *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);


        if (Shiboken::Errors::occurred() == nullptr) {
            // paint(QPainter*,QRectF,QVideoFrame::PaintOptions)
            cppSelf->paint(cppArg0, *cppArg1, *cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVideoFrameFunc_pixelFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.pixelFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // pixelFormat()const
            QVideoFrameFormat::PixelFormat cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->pixelFormat();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrameFormat_PixelFormat_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_planeCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.planeCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // planeCount()const
            int cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->planeCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_rotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.rotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // rotation()const
            QtVideo::Rotation cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->rotation();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QtVideo_Rotation_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_rotationAngle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.rotationAngle";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QVideoFrame", "rotationAngle() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        if (Shiboken::Errors::occurred() == nullptr) {
            // rotationAngle()const
            QVideoFrame::RotationAngle cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->rotationAngle();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_RotationAngle_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_setEndTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.setEndTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVideoFrame::setEndTime(qint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // setEndTime(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEndTime(qint64)
            cppSelf->setEndTime(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVideoFrameFunc_setMirrored(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.setMirrored";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVideoFrame::setMirrored(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setMirrored(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMirrored(bool)
            cppSelf->setMirrored(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVideoFrameFunc_setRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.setRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVideoFrame::setRotation(QtVideo::Rotation)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QtVideo_Rotation_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setRotation(QtVideo::Rotation)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QtVideo::Rotation cppArg0{QtVideo::Rotation::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotation(QtVideo::Rotation)
            cppSelf->setRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVideoFrameFunc_setRotationAngle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.setRotationAngle";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVideoFrame::setRotationAngle(QVideoFrame::RotationAngle)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_RotationAngle_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setRotationAngle(QVideoFrame::RotationAngle)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QVideoFrame", "setRotationAngle(QVideoFrame.RotationAngle angle)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        ::QVideoFrame::RotationAngle cppArg0{QVideoFrame::Rotation0};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotationAngle(QVideoFrame::RotationAngle)
            cppSelf->setRotationAngle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVideoFrameFunc_setStartTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.setStartTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVideoFrame::setStartTime(qint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // setStartTime(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStartTime(qint64)
            cppSelf->setStartTime(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVideoFrameFunc_setSubtitleText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.setSubtitleText";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVideoFrame::setSubtitleText(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setSubtitleText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSubtitleText(QString)
            cppSelf->setSubtitleText(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVideoFrameFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.size";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // size()const
            QSize cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->size();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_startTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.startTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // startTime()const
            qint64 cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->startTime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_subtitleText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.subtitleText";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // subtitleText()const
            QString cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->subtitleText();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_surfaceFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.surfaceFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // surfaceFormat()const
            QVideoFrameFormat cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->surfaceFormat();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrameFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QVideoFrame::swap(QVideoFrame&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QVideoFrame&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVideoFrame cppArg0_local;
        ::QVideoFrame *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QVideoFrame&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVideoFrameFunc_toImage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.toImage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toImage()const
            QImage cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->toImage();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrameFunc_unmap(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.unmap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // unmap()
            cppSelf->unmap();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QVideoFrameFunc_width(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtMultimedia.QVideoFrame.width";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // width()const
            int cppResult = const_cast<const ::QVideoFrame *>(cppSelf)->width();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QVideoFrame__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QVideoFrame_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QVideoFrame_EnumFlagInfo[] = {
    "HandleType:Enum",
    "MapMode:Enum",
    "RotationAngle:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QVideoFrame_methods[] = {
    {"bits", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_bits), METH_O, nullptr},
    {"bytesPerLine", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_bytesPerLine), METH_O, nullptr},
    {"endTime", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_endTime), METH_NOARGS, nullptr},
    {"handleType", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_handleType), METH_NOARGS, nullptr},
    {"height", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_height), METH_NOARGS, nullptr},
    {"isMapped", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_isMapped), METH_NOARGS, nullptr},
    {"isReadable", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_isReadable), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_isValid), METH_NOARGS, nullptr},
    {"isWritable", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_isWritable), METH_NOARGS, nullptr},
    {"map", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_map), METH_O, nullptr},
    {"mapMode", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_mapMode), METH_NOARGS, nullptr},
    {"mappedBytes", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_mappedBytes), METH_O, nullptr},
    {"mirrored", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_mirrored), METH_NOARGS, nullptr},
    {"paint", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_paint), METH_VARARGS, nullptr},
    {"pixelFormat", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_pixelFormat), METH_NOARGS, nullptr},
    {"planeCount", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_planeCount), METH_NOARGS, nullptr},
    {"rotation", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_rotation), METH_NOARGS, nullptr},
    {"rotationAngle", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_rotationAngle), METH_NOARGS, nullptr},
    {"setEndTime", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_setEndTime), METH_O, nullptr},
    {"setMirrored", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_setMirrored), METH_O, nullptr},
    {"setRotation", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_setRotation), METH_O, nullptr},
    {"setRotationAngle", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_setRotationAngle), METH_O, nullptr},
    {"setStartTime", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_setStartTime), METH_O, nullptr},
    {"setSubtitleText", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_setSubtitleText), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_size), METH_NOARGS, nullptr},
    {"startTime", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_startTime), METH_NOARGS, nullptr},
    {"subtitleText", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_subtitleText), METH_NOARGS, nullptr},
    {"surfaceFormat", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_surfaceFormat), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_swap), METH_O, nullptr},
    {"toImage", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_toImage), METH_NOARGS, nullptr},
    {"unmap", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_unmap), METH_NOARGS, nullptr},
    {"width", reinterpret_cast<PyCFunction>(Sbk_QVideoFrameFunc_width), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QVideoFrame__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QVideoFrame_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), (pyArg)))) {
                // operator!=(const QVideoFrame & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QVideoFrame cppArg0_local;
                ::QVideoFrame *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), (pyArg)))) {
                // operator==(const QVideoFrame & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QVideoFrame cppArg0_local;
                ::QVideoFrame *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QVideoFrame_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QVideoFrame_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QVideoFrame__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QVideoFrame_Type = nullptr;
static PyTypeObject *Sbk_QVideoFrame_TypeF(void)
{
    return _Sbk_QVideoFrame_Type;
}

static PyType_Slot Sbk_QVideoFrame_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QVideoFrame__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QVideoFrame_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QVideoFrame_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QVideoFrame_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QVideoFrame_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QVideoFrame_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QVideoFrame_spec = {
    "2:PySide6.QtMultimedia.QVideoFrame",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QVideoFrame_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QVideoFrame_HandleType_PythonToCpp_QVideoFrame_HandleType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QVideoFrame::HandleType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QVideoFrame::HandleType *>(cppOut) = value;

}
static PythonToCppFunc is_QVideoFrame_HandleType_PythonToCpp_QVideoFrame_HandleType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_HandleType_IDX])))
        return QVideoFrame_HandleType_PythonToCpp_QVideoFrame_HandleType;
    return {};
}
static PyObject *QVideoFrame_HandleType_CppToPython_QVideoFrame_HandleType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QVideoFrame::HandleType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_HandleType_IDX]), castCppIn);

}

static void QVideoFrame_MapMode_PythonToCpp_QVideoFrame_MapMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QVideoFrame::MapMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QVideoFrame::MapMode *>(cppOut) = value;

}
static PythonToCppFunc is_QVideoFrame_MapMode_PythonToCpp_QVideoFrame_MapMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_MapMode_IDX])))
        return QVideoFrame_MapMode_PythonToCpp_QVideoFrame_MapMode;
    return {};
}
static PyObject *QVideoFrame_MapMode_CppToPython_QVideoFrame_MapMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QVideoFrame::MapMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_MapMode_IDX]), castCppIn);

}

static void QVideoFrame_RotationAngle_PythonToCpp_QVideoFrame_RotationAngle(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QVideoFrame::RotationAngle>(Shiboken::Enum::getValue(pyIn));
    switch (value) {
    case QVideoFrame::RotationAngle::Rotation0:
        Shiboken::Warnings::warnDeprecatedEnumValue("QVideoFrame::RotationAngle", "Rotation0");
        break;
    case QVideoFrame::RotationAngle::Rotation90:
        Shiboken::Warnings::warnDeprecatedEnumValue("QVideoFrame::RotationAngle", "Rotation90");
        break;
    case QVideoFrame::RotationAngle::Rotation180:
        Shiboken::Warnings::warnDeprecatedEnumValue("QVideoFrame::RotationAngle", "Rotation180");
        break;
    case QVideoFrame::RotationAngle::Rotation270:
        Shiboken::Warnings::warnDeprecatedEnumValue("QVideoFrame::RotationAngle", "Rotation270");
        break;
    }
    *reinterpret_cast<::QVideoFrame::RotationAngle *>(cppOut) = value;

}
static PythonToCppFunc is_QVideoFrame_RotationAngle_PythonToCpp_QVideoFrame_RotationAngle_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_RotationAngle_IDX])))
        return QVideoFrame_RotationAngle_PythonToCpp_QVideoFrame_RotationAngle;
    return {};
}
static PyObject *QVideoFrame_RotationAngle_CppToPython_QVideoFrame_RotationAngle(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QVideoFrame::RotationAngle *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_RotationAngle_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QVideoFrame_PythonToCpp_QVideoFrame_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QVideoFrame_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QVideoFrame_PythonToCpp_QVideoFrame_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QVideoFrame_TypeF()))
        return QVideoFrame_PythonToCpp_QVideoFrame_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QVideoFrame_PTR_CppToPython_QVideoFrame(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QVideoFrame *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QVideoFrame_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QVideoFrame_COPY_CppToPython_QVideoFrame(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QVideoFrame *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QVideoFrame_TypeF(), new ::QVideoFrame(*source), true, true);
}

// Python to C++ copy conversion.
static void QVideoFrame_PythonToCpp_QVideoFrame_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QVideoFrame *>(cppOut) = *reinterpret_cast< ::QVideoFrame *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QVideoFrame_PythonToCpp_QVideoFrame_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QVideoFrame_TypeF()))
        return QVideoFrame_PythonToCpp_QVideoFrame_COPY;
    return {};
}

// Implicit conversions.
static void constQVideoFrameFormatREF_PythonToCpp_QVideoFrame(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QVideoFrame *>(cppOut) = ::QVideoFrame( *reinterpret_cast< ::QVideoFrameFormat *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrameFormat_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_constQVideoFrameFormatREF_PythonToCpp_QVideoFrame_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrameFormat_IDX]), pyIn))
        return constQVideoFrameFormatREF_PythonToCpp_QVideoFrame;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QVideoFrame_SignatureStrings[] = {
    "2:PySide6.QtMultimedia.QVideoFrame(self)",
    "1:PySide6.QtMultimedia.QVideoFrame(self,other:typing.Union[PySide6.QtMultimedia.QVideoFrame, PySide6.QtMultimedia.QVideoFrameFormat])",
    "0:PySide6.QtMultimedia.QVideoFrame(self,format:PySide6.QtMultimedia.QVideoFrameFormat)",
    "PySide6.QtMultimedia.QVideoFrame.bits(self,plane:int)->uchar*",
    "PySide6.QtMultimedia.QVideoFrame.bytesPerLine(self,plane:int)->int",
    "PySide6.QtMultimedia.QVideoFrame.endTime(self)->qint64",
    "PySide6.QtMultimedia.QVideoFrame.handleType(self)->PySide6.QtMultimedia.QVideoFrame.HandleType",
    "PySide6.QtMultimedia.QVideoFrame.height(self)->int",
    "PySide6.QtMultimedia.QVideoFrame.isMapped(self)->bool",
    "PySide6.QtMultimedia.QVideoFrame.isReadable(self)->bool",
    "PySide6.QtMultimedia.QVideoFrame.isValid(self)->bool",
    "PySide6.QtMultimedia.QVideoFrame.isWritable(self)->bool",
    "PySide6.QtMultimedia.QVideoFrame.map(self,mode:PySide6.QtMultimedia.QVideoFrame.MapMode)->bool",
    "PySide6.QtMultimedia.QVideoFrame.mapMode(self)->PySide6.QtMultimedia.QVideoFrame.MapMode",
    "PySide6.QtMultimedia.QVideoFrame.mappedBytes(self,plane:int)->int",
    "PySide6.QtMultimedia.QVideoFrame.mirrored(self)->bool",
    "PySide6.QtMultimedia.QVideoFrame.paint(self,painter:PySide6.QtGui.QPainter,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],options:PySide6.QtMultimedia.QVideoFrame.PaintOptions)",
    "PySide6.QtMultimedia.QVideoFrame.pixelFormat(self)->PySide6.QtMultimedia.QVideoFrameFormat.PixelFormat",
    "PySide6.QtMultimedia.QVideoFrame.planeCount(self)->int",
    "PySide6.QtMultimedia.QVideoFrame.rotation(self)->PySide6.QtMultimedia.QtVideo.Rotation",
    "PySide6.QtMultimedia.QVideoFrame.rotationAngle(self)->PySide6.QtMultimedia.QVideoFrame.RotationAngle",
    "PySide6.QtMultimedia.QVideoFrame.setEndTime(self,time:qint64)",
    "PySide6.QtMultimedia.QVideoFrame.setMirrored(self,arg__1:bool)",
    "PySide6.QtMultimedia.QVideoFrame.setRotation(self,angle:PySide6.QtMultimedia.QtVideo.Rotation)",
    "PySide6.QtMultimedia.QVideoFrame.setRotationAngle(self,angle:PySide6.QtMultimedia.QVideoFrame.RotationAngle)",
    "PySide6.QtMultimedia.QVideoFrame.setStartTime(self,time:qint64)",
    "PySide6.QtMultimedia.QVideoFrame.setSubtitleText(self,text:QString)",
    "PySide6.QtMultimedia.QVideoFrame.size(self)->PySide6.QtCore.QSize",
    "PySide6.QtMultimedia.QVideoFrame.startTime(self)->qint64",
    "PySide6.QtMultimedia.QVideoFrame.subtitleText(self)->QString",
    "PySide6.QtMultimedia.QVideoFrame.surfaceFormat(self)->PySide6.QtMultimedia.QVideoFrameFormat",
    "PySide6.QtMultimedia.QVideoFrame.swap(self,other:typing.Union[PySide6.QtMultimedia.QVideoFrame, PySide6.QtMultimedia.QVideoFrameFormat])",
    "PySide6.QtMultimedia.QVideoFrame.toImage(self)->PySide6.QtGui.QImage",
    "PySide6.QtMultimedia.QVideoFrame.unmap(self)",
    "PySide6.QtMultimedia.QVideoFrame.width(self)->int",
    "PySide6.QtMultimedia.QVideoFrame.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QVideoFrame(PyObject *module)
{
    if (SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX].type != nullptr)
        return SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX].type;

    Shiboken::AutoDecRef Sbk_QVideoFrame_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QVideoFrame_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QVideoFrame",
        "QVideoFrame",
        &Sbk_QVideoFrame_spec,
        &Shiboken::callCppDestructor< ::QVideoFrame >,
        Sbk_QVideoFrame_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QVideoFrame_TypeF(); // references _Sbk_QVideoFrame_Type
    InitSignatureStrings(pyType, QVideoFrame_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QVideoFrame_PropertyStrings);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QVideoFrame_PythonToCpp_QVideoFrame_PTR,
        is_QVideoFrame_PythonToCpp_QVideoFrame_PTR_Convertible,
        QVideoFrame_PTR_CppToPython_QVideoFrame,
        QVideoFrame_COPY_CppToPython_QVideoFrame);

    Shiboken::Conversions::registerConverterName(converter, "QVideoFrame");
    Shiboken::Conversions::registerConverterName(converter, "QVideoFrame*");
    Shiboken::Conversions::registerConverterName(converter, "QVideoFrame&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QVideoFrame).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QVideoFrame_PythonToCpp_QVideoFrame_COPY,
        is_QVideoFrame_PythonToCpp_QVideoFrame_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQVideoFrameFormatREF_PythonToCpp_QVideoFrame,
        is_constQVideoFrameFormatREF_PythonToCpp_QVideoFrame_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QVideoFrame_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'HandleType'.
    const char *HandleType_Initializer[] = {
        "NoHandle",
        "RhiTextureHandle",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t HandleType_InitializerValues[] = {
        uint8_t(QVideoFrame::HandleType::NoHandle),        //  0x00  0
        uint8_t(QVideoFrame::HandleType::RhiTextureHandle) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QVideoFrame_TypeF(),
        "2:PySide6.QtMultimedia.QVideoFrame.HandleType",
        HandleType_Initializer, HandleType_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_HandleType_IDX].type = EType;
    // Register converter for enum 'QVideoFrame::HandleType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QVideoFrame_HandleType_CppToPython_QVideoFrame_HandleType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QVideoFrame_HandleType_PythonToCpp_QVideoFrame_HandleType,
            is_QVideoFrame_HandleType_PythonToCpp_QVideoFrame_HandleType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QVideoFrame::HandleType");
        Shiboken::Conversions::registerConverterName(converter, "HandleType");
    }
    // End of 'HandleType' enum.

    // Initialization of enum 'MapMode'.
    const char *MapMode_Initializer[] = {
        "NotMapped",
        "ReadOnly",
        "WriteOnly",
        "ReadWrite",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MapMode_InitializerValues[] = {
        uint8_t(QVideoFrame::MapMode::NotMapped), //  0x00  0
        uint8_t(QVideoFrame::MapMode::ReadOnly),  //  0x01  1
        uint8_t(QVideoFrame::MapMode::WriteOnly), //  0x02  2
        uint8_t(QVideoFrame::MapMode::ReadWrite)  //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QVideoFrame_TypeF(),
        "2:PySide6.QtMultimedia.QVideoFrame.MapMode",
        MapMode_Initializer, MapMode_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_MapMode_IDX].type = EType;
    // Register converter for enum 'QVideoFrame::MapMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QVideoFrame_MapMode_CppToPython_QVideoFrame_MapMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QVideoFrame_MapMode_PythonToCpp_QVideoFrame_MapMode,
            is_QVideoFrame_MapMode_PythonToCpp_QVideoFrame_MapMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QVideoFrame::MapMode");
        Shiboken::Conversions::registerConverterName(converter, "MapMode");
    }
    // End of 'MapMode' enum.

    // Initialization of enum 'RotationAngle'.
    const char *RotationAngle_Initializer[] = {
        "Rotation0",
        "Rotation90",
        "Rotation180",
        "Rotation270",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t RotationAngle_InitializerValues[] = {
        uint16_t(QVideoFrame::RotationAngle::Rotation0),   //  0x0000  0
        uint16_t(QVideoFrame::RotationAngle::Rotation90),  //  0x005a  90
        uint16_t(QVideoFrame::RotationAngle::Rotation180), //  0x00b4  180
        uint16_t(QVideoFrame::RotationAngle::Rotation270)  //  0x010e  270
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QVideoFrame_TypeF(),
        "2:PySide6.QtMultimedia.QVideoFrame.RotationAngle",
        RotationAngle_Initializer, RotationAngle_InitializerValues);
    SbkPySide6_QtMultimediaTypeStructs[SBK_QVideoFrame_RotationAngle_IDX].type = EType;
    // Register converter for enum 'QVideoFrame::RotationAngle'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QVideoFrame_RotationAngle_CppToPython_QVideoFrame_RotationAngle);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QVideoFrame_RotationAngle_PythonToCpp_QVideoFrame_RotationAngle,
            is_QVideoFrame_RotationAngle_PythonToCpp_QVideoFrame_RotationAngle_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QVideoFrame::RotationAngle");
        Shiboken::Conversions::registerConverterName(converter, "RotationAngle");
    }
    // End of 'RotationAngle' enum.

    qRegisterMetaType< ::QVideoFrame >("QVideoFrame");
    qRegisterMetaType< ::QVideoFrame::HandleType >("QVideoFrame::HandleType");
    qRegisterMetaType< ::QVideoFrame::MapMode >("QVideoFrame::MapMode");
    qRegisterMetaType< ::QVideoFrame::RotationAngle >("QVideoFrame::RotationAngle");

    return pyType;
}
