// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qnetworkcookie_wrapper.h"

// Extra includes
#include <QDateTime>

// Argument includes
#include <QList>
#include <QString>
#include <QtNetwork/qnetworkcookie.h>
#include <qbytearray.h>
#include <qbytearrayview.h>
#include <qdatetime.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkCookie_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNetworkCookie >()))
        return -1;

    ::QNetworkCookie *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:QNetworkCookie", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNetworkCookie::QNetworkCookie(const QByteArray&=,const QByteArray&=)
    // 1: QNetworkCookie::QNetworkCookie(QNetworkCookie)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkCookie(QByteArray,QByteArray)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QNetworkCookie(QNetworkCookie)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // QNetworkCookie(QByteArray,QByteArray)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            overloadId = 0; // QNetworkCookie(QByteArray,QByteArray)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QNetworkCookie(const QByteArray & name, const QByteArray & value)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_name = Shiboken::String::createStaticString("name");
                if (PyDict_Contains(kwds, key_name) != 0) {
                    value = PyDict_GetItem(kwds, key_name);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_name);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_name);
                }
                static PyObject *const key_value = Shiboken::String::createStaticString("value");
                if (PyDict_Contains(kwds, key_value) != 0) {
                    value = PyDict_GetItem(kwds, key_value);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_value);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_value);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QByteArray cppArg0_local = QByteArray();
            ::QByteArray *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0]) {
                if (pythonToCpp[0].isValue())
                    pythonToCpp[0](pyArgs[0], &cppArg0_local);
                else
                    pythonToCpp[0](pyArgs[0], &cppArg0);
                }
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QByteArray cppArg1_local = QByteArray();
            ::QByteArray *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkCookie(QByteArray,QByteArray)
                cptr = new ::QNetworkCookie(*cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // QNetworkCookie(const QNetworkCookie & other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNetworkCookie cppArg0_local;
            ::QNetworkCookie *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkCookie(QNetworkCookie)
                cptr = new ::QNetworkCookie(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QNetworkCookie >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNetworkCookieFunc_domain(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.domain";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // domain()const
            QString cppResult = const_cast<const ::QNetworkCookie *>(cppSelf)->domain();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCookieFunc_expirationDate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.expirationDate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // expirationDate()const
            QDateTime cppResult = const_cast<const ::QNetworkCookie *>(cppSelf)->expirationDate();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCookieFunc_hasSameIdentifier(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.hasSameIdentifier";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCookie::hasSameIdentifier(QNetworkCookie)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), (pyArg)))) {
        overloadId = 0; // hasSameIdentifier(QNetworkCookie)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkCookie cppArg0_local;
        ::QNetworkCookie *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // hasSameIdentifier(QNetworkCookie)const
            bool cppResult = const_cast<const ::QNetworkCookie *>(cppSelf)->hasSameIdentifier(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCookieFunc_isHttpOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.isHttpOnly";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isHttpOnly()const
            bool cppResult = const_cast<const ::QNetworkCookie *>(cppSelf)->isHttpOnly();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCookieFunc_isSecure(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.isSecure";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isSecure()const
            bool cppResult = const_cast<const ::QNetworkCookie *>(cppSelf)->isSecure();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCookieFunc_isSessionCookie(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.isSessionCookie";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isSessionCookie()const
            bool cppResult = const_cast<const ::QNetworkCookie *>(cppSelf)->isSessionCookie();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCookieFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.name";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // name()const
            QByteArray cppResult = const_cast<const ::QNetworkCookie *>(cppSelf)->name();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCookieFunc_normalize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.normalize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCookie::normalize(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // normalize(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // normalize(QUrl)
            cppSelf->normalize(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCookieFunc_parseCookies(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.parseCookies";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkCookie::parseCookies(QByteArrayView)->QList< QNetworkCookie>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // parseCookies(QByteArrayView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // parseCookies(QByteArrayView)
            QList<QNetworkCookie> cppResult = ::QNetworkCookie::parseCookies(QByteArrayView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkCookie_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCookieFunc_path(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.path";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // path()const
            QString cppResult = const_cast<const ::QNetworkCookie *>(cppSelf)->path();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCookieFunc_sameSitePolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.sameSitePolicy";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // sameSitePolicy()const
            QNetworkCookie::SameSite cppResult = const_cast<const ::QNetworkCookie *>(cppSelf)->sameSitePolicy();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_SameSite_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCookieFunc_setDomain(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.setDomain";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCookie::setDomain(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDomain(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDomain(QString)
            cppSelf->setDomain(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCookieFunc_setExpirationDate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.setExpirationDate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCookie::setExpirationDate(QDateTime)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // setExpirationDate(QDateTime)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setExpirationDate(QDateTime)
            cppSelf->setExpirationDate(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCookieFunc_setHttpOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.setHttpOnly";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCookie::setHttpOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setHttpOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttpOnly(bool)
            cppSelf->setHttpOnly(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCookieFunc_setName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.setName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCookie::setName(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setName(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setName(QByteArray)
            cppSelf->setName(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCookieFunc_setPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.setPath";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCookie::setPath(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPath(QString)
            cppSelf->setPath(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCookieFunc_setSameSitePolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.setSameSitePolicy";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCookie::setSameSitePolicy(QNetworkCookie::SameSite)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_SameSite_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSameSitePolicy(QNetworkCookie::SameSite)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QNetworkCookie::SameSite cppArg0{QNetworkCookie::SameSite::Default};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSameSitePolicy(QNetworkCookie::SameSite)
            cppSelf->setSameSitePolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCookieFunc_setSecure(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.setSecure";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCookie::setSecure(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSecure(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSecure(bool)
            cppSelf->setSecure(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCookieFunc_setValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.setValue";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCookie::setValue(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setValue(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setValue(QByteArray)
            cppSelf->setValue(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCookieFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkCookie::swap(QNetworkCookie&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QNetworkCookie&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkCookie cppArg0_local;
        ::QNetworkCookie *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QNetworkCookie&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkCookieFunc_toRawForm(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.toRawForm";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:toRawForm", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNetworkCookie::toRawForm(QNetworkCookie::RawForm=)const->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // toRawForm(QNetworkCookie::RawForm)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_RawForm_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // toRawForm(QNetworkCookie::RawForm)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_form = Shiboken::String::createStaticString("form");
            if (PyDict_Contains(kwds, key_form) != 0) {
                value = PyDict_GetItem(kwds, key_form);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_form);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_RawForm_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_form);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QNetworkCookie::RawForm cppArg0(QNetworkCookie::RawForm::Full);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toRawForm(QNetworkCookie::RawForm)const
            QByteArray cppResult = const_cast<const ::QNetworkCookie *>(cppSelf)->toRawForm(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCookieFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkCookie.value";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // value()const
            QByteArray cppResult = const_cast<const ::QNetworkCookie *>(cppSelf)->value();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkCookie__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNetworkCookie_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QNetworkCookie_EnumFlagInfo[] = {
    "RawForm:Enum",
    "SameSite:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNetworkCookie_methods[] = {
    {"domain", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_domain), METH_NOARGS, nullptr},
    {"expirationDate", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_expirationDate), METH_NOARGS, nullptr},
    {"hasSameIdentifier", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_hasSameIdentifier), METH_O, nullptr},
    {"isHttpOnly", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_isHttpOnly), METH_NOARGS, nullptr},
    {"isSecure", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_isSecure), METH_NOARGS, nullptr},
    {"isSessionCookie", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_isSessionCookie), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_name), METH_NOARGS, nullptr},
    {"normalize", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_normalize), METH_O, nullptr},
    {"parseCookies", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_parseCookies), METH_O|METH_STATIC, nullptr},
    {"path", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_path), METH_NOARGS, nullptr},
    {"sameSitePolicy", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_sameSitePolicy), METH_NOARGS, nullptr},
    {"setDomain", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_setDomain), METH_O, nullptr},
    {"setExpirationDate", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_setExpirationDate), METH_O, nullptr},
    {"setHttpOnly", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_setHttpOnly), METH_O, nullptr},
    {"setName", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_setName), METH_O, nullptr},
    {"setPath", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_setPath), METH_O, nullptr},
    {"setSameSitePolicy", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_setSameSitePolicy), METH_O, nullptr},
    {"setSecure", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_setSecure), METH_O, nullptr},
    {"setValue", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_setValue), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_swap), METH_O, nullptr},
    {"toRawForm", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_toRawForm), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookieFunc_value), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QNetworkCookie__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QNetworkCookie_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), (pyArg)))) {
                // operator!=(const QNetworkCookie & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNetworkCookie cppArg0_local;
                ::QNetworkCookie *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), (pyArg)))) {
                // operator==(const QNetworkCookie & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNetworkCookie cppArg0_local;
                ::QNetworkCookie *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QNetworkCookie_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNetworkCookie_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QNetworkCookie__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNetworkCookie_Type = nullptr;
static PyTypeObject *Sbk_QNetworkCookie_TypeF(void)
{
    return _Sbk_QNetworkCookie_Type;
}

static PyType_Slot Sbk_QNetworkCookie_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QNetworkCookie__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNetworkCookie_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNetworkCookie_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QNetworkCookie_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNetworkCookie_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNetworkCookie_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNetworkCookie_spec = {
    "2:PySide6.QtNetwork.QNetworkCookie",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNetworkCookie_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QNetworkCookie_RawForm_PythonToCpp_QNetworkCookie_RawForm(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkCookie::RawForm>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkCookie::RawForm *>(cppOut) = value;

}
static PythonToCppFunc is_QNetworkCookie_RawForm_PythonToCpp_QNetworkCookie_RawForm_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_RawForm_IDX])))
        return QNetworkCookie_RawForm_PythonToCpp_QNetworkCookie_RawForm;
    return {};
}
static PyObject *QNetworkCookie_RawForm_CppToPython_QNetworkCookie_RawForm(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QNetworkCookie::RawForm *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_RawForm_IDX]), castCppIn);

}

static void QNetworkCookie_SameSite_PythonToCpp_QNetworkCookie_SameSite(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkCookie::SameSite>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkCookie::SameSite *>(cppOut) = value;

}
static PythonToCppFunc is_QNetworkCookie_SameSite_PythonToCpp_QNetworkCookie_SameSite_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_SameSite_IDX])))
        return QNetworkCookie_SameSite_PythonToCpp_QNetworkCookie_SameSite;
    return {};
}
static PyObject *QNetworkCookie_SameSite_CppToPython_QNetworkCookie_SameSite(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QNetworkCookie::SameSite *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_SameSite_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNetworkCookie_PythonToCpp_QNetworkCookie_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNetworkCookie_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNetworkCookie_PythonToCpp_QNetworkCookie_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkCookie_TypeF()))
        return QNetworkCookie_PythonToCpp_QNetworkCookie_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNetworkCookie_PTR_CppToPython_QNetworkCookie(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QNetworkCookie *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QNetworkCookie_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QNetworkCookie_COPY_CppToPython_QNetworkCookie(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QNetworkCookie *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QNetworkCookie_TypeF(), new ::QNetworkCookie(*source), true, true);
}

// Python to C++ copy conversion.
static void QNetworkCookie_PythonToCpp_QNetworkCookie_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNetworkCookie *>(cppOut) = *reinterpret_cast< ::QNetworkCookie *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QNetworkCookie_PythonToCpp_QNetworkCookie_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkCookie_TypeF()))
        return QNetworkCookie_PythonToCpp_QNetworkCookie_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QNetworkCookie_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QNetworkCookie(self,name:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray(),value:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray())",
    "0:PySide6.QtNetwork.QNetworkCookie(self,other:PySide6.QtNetwork.QNetworkCookie)",
    "PySide6.QtNetwork.QNetworkCookie.domain(self)->QString",
    "PySide6.QtNetwork.QNetworkCookie.expirationDate(self)->PySide6.QtCore.QDateTime",
    "PySide6.QtNetwork.QNetworkCookie.hasSameIdentifier(self,other:PySide6.QtNetwork.QNetworkCookie)->bool",
    "PySide6.QtNetwork.QNetworkCookie.isHttpOnly(self)->bool",
    "PySide6.QtNetwork.QNetworkCookie.isSecure(self)->bool",
    "PySide6.QtNetwork.QNetworkCookie.isSessionCookie(self)->bool",
    "PySide6.QtNetwork.QNetworkCookie.name(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetwork.QNetworkCookie.normalize(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtNetwork.QNetworkCookie.parseCookies(cookieString:typing.Union[PySide6.QtCore.QByteArray, char*])->QList[PySide6.QtNetwork.QNetworkCookie]",
    "PySide6.QtNetwork.QNetworkCookie.path(self)->QString",
    "PySide6.QtNetwork.QNetworkCookie.sameSitePolicy(self)->PySide6.QtNetwork.QNetworkCookie.SameSite",
    "PySide6.QtNetwork.QNetworkCookie.setDomain(self,domain:QString)",
    "PySide6.QtNetwork.QNetworkCookie.setExpirationDate(self,date:PySide6.QtCore.QDateTime)",
    "PySide6.QtNetwork.QNetworkCookie.setHttpOnly(self,enable:bool)",
    "PySide6.QtNetwork.QNetworkCookie.setName(self,cookieName:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtNetwork.QNetworkCookie.setPath(self,path:QString)",
    "PySide6.QtNetwork.QNetworkCookie.setSameSitePolicy(self,sameSite:PySide6.QtNetwork.QNetworkCookie.SameSite)",
    "PySide6.QtNetwork.QNetworkCookie.setSecure(self,enable:bool)",
    "PySide6.QtNetwork.QNetworkCookie.setValue(self,value:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtNetwork.QNetworkCookie.swap(self,other:PySide6.QtNetwork.QNetworkCookie)",
    "PySide6.QtNetwork.QNetworkCookie.toRawForm(self,form:PySide6.QtNetwork.QNetworkCookie.RawForm=QNetworkCookie.RawForm.Full)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetwork.QNetworkCookie.value(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetwork.QNetworkCookie.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QNetworkCookie(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX].type;

    Shiboken::AutoDecRef Sbk_QNetworkCookie_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QNetworkCookie_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNetworkCookie",
        "QNetworkCookie",
        &Sbk_QNetworkCookie_spec,
        &Shiboken::callCppDestructor< ::QNetworkCookie >,
        Sbk_QNetworkCookie_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QNetworkCookie_TypeF(); // references _Sbk_QNetworkCookie_Type
    InitSignatureStrings(pyType, QNetworkCookie_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNetworkCookie_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNetworkCookie_PythonToCpp_QNetworkCookie_PTR,
        is_QNetworkCookie_PythonToCpp_QNetworkCookie_PTR_Convertible,
        QNetworkCookie_PTR_CppToPython_QNetworkCookie,
        QNetworkCookie_COPY_CppToPython_QNetworkCookie);

    Shiboken::Conversions::registerConverterName(converter, "QNetworkCookie");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkCookie*");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkCookie&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNetworkCookie).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QNetworkCookie_PythonToCpp_QNetworkCookie_COPY,
        is_QNetworkCookie_PythonToCpp_QNetworkCookie_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QNetworkCookie_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'RawForm'.
    const char *RawForm_Initializer[] = {
        "NameAndValueOnly",
        "Full",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RawForm_InitializerValues[] = {
        uint8_t(QNetworkCookie::RawForm::NameAndValueOnly), //  0x00  0
        uint8_t(QNetworkCookie::RawForm::Full)              //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkCookie_TypeF(),
        "2:PySide6.QtNetwork.QNetworkCookie.RawForm",
        RawForm_Initializer, RawForm_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_RawForm_IDX].type = EType;
    // Register converter for enum 'QNetworkCookie::RawForm'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkCookie_RawForm_CppToPython_QNetworkCookie_RawForm);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QNetworkCookie_RawForm_PythonToCpp_QNetworkCookie_RawForm,
            is_QNetworkCookie_RawForm_PythonToCpp_QNetworkCookie_RawForm_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkCookie::RawForm");
        Shiboken::Conversions::registerConverterName(converter, "RawForm");
    }
    // End of 'RawForm' enum.

    // Initialization of enum 'SameSite'.
    const char *SameSite_Initializer[] = {
        "Default",
        "None_",
        "Lax",
        "Strict",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t SameSite_InitializerValues[] = {
        int8_t(QNetworkCookie::SameSite::Default), //  0x00  0
        int8_t(QNetworkCookie::SameSite::None),    //  0x01  1
        int8_t(QNetworkCookie::SameSite::Lax),     //  0x02  2
        int8_t(QNetworkCookie::SameSite::Strict)   //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkCookie_TypeF(),
        "2:PySide6.QtNetwork.QNetworkCookie.SameSite",
        SameSite_Initializer, SameSite_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkCookie_SameSite_IDX].type = EType;
    // Register converter for enum 'QNetworkCookie::SameSite'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkCookie_SameSite_CppToPython_QNetworkCookie_SameSite);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QNetworkCookie_SameSite_PythonToCpp_QNetworkCookie_SameSite,
            is_QNetworkCookie_SameSite_PythonToCpp_QNetworkCookie_SameSite_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkCookie::SameSite");
        Shiboken::Conversions::registerConverterName(converter, "SameSite");
    }
    // End of 'SameSite' enum.

    qRegisterMetaType< ::QNetworkCookie >("QNetworkCookie");
    qRegisterMetaType< ::QNetworkCookie::RawForm >("QNetworkCookie::RawForm");
    qRegisterMetaType< ::QNetworkCookie::SameSite >("QNetworkCookie::SameSite");

    return pyType;
}
