// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qnetworkinformation_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <QtNetwork/qnetworkinformation.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QNetworkInformationFunc_availableBackends(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInformation.availableBackends";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // availableBackends()
            QStringList cppResult = ::QNetworkInformation::availableBackends();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_backendName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInformation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInformation.backendName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // backendName()const
            QString cppResult = const_cast<const ::QNetworkInformation *>(cppSelf)->backendName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_instance(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInformation.instance";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // instance()
            QNetworkInformation * cppResult = ::QNetworkInformation::instance();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_isBehindCaptivePortal(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInformation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInformation.isBehindCaptivePortal";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isBehindCaptivePortal()const
            bool cppResult = const_cast<const ::QNetworkInformation *>(cppSelf)->isBehindCaptivePortal();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_isMetered(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInformation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInformation.isMetered";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isMetered()const
            bool cppResult = const_cast<const ::QNetworkInformation *>(cppSelf)->isMetered();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_load(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInformation.load";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkInformation::load(QFlags<QNetworkInformation::Feature>)->bool
    // 1: static QNetworkInformation::load(QStringView)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // load(QStringView)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInformation_Feature_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // load(QFlags<QNetworkInformation::Feature>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // load(QFlags<QNetworkInformation::Feature> features)
        {
            Shiboken::Warnings::warnDeprecated("QNetworkInformation", "load(QFlags<QNetworkInformation.Feature> features)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            ::QFlags<QNetworkInformation::Feature> cppArg0 = QFlags<QNetworkInformation::Feature>(0);
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QFlags<QNetworkInformation::Feature>)
                bool cppResult = ::QNetworkInformation::load(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // load(QStringView backend)
        {
            Shiboken::Warnings::warnDeprecated("QNetworkInformation", "load(QStringView backend)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QStringView)
                bool cppResult = ::QNetworkInformation::load(QStringView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_loadBackendByFeatures(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInformation.loadBackendByFeatures";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkInformation::loadBackendByFeatures(QFlags<QNetworkInformation::Feature>)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInformation_Feature_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // loadBackendByFeatures(QFlags<QNetworkInformation::Feature>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QNetworkInformation::Feature> cppArg0 = QFlags<QNetworkInformation::Feature>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // loadBackendByFeatures(QFlags<QNetworkInformation::Feature>)
            bool cppResult = ::QNetworkInformation::loadBackendByFeatures(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_loadBackendByName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInformation.loadBackendByName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkInformation::loadBackendByName(QStringView)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // loadBackendByName(QStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // loadBackendByName(QStringView)
            bool cppResult = ::QNetworkInformation::loadBackendByName(QStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_loadDefaultBackend(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInformation.loadDefaultBackend";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // loadDefaultBackend()
            bool cppResult = ::QNetworkInformation::loadDefaultBackend();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_reachability(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInformation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInformation.reachability";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // reachability()const
            QNetworkInformation::Reachability cppResult = const_cast<const ::QNetworkInformation *>(cppSelf)->reachability();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Reachability_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_supportedFeatures(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInformation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInformation.supportedFeatures";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportedFeatures()const
            QFlags<QNetworkInformation::Feature> cppResult = const_cast<const ::QNetworkInformation *>(cppSelf)->supportedFeatures();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInformation_Feature_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_supports(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInformation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInformation.supports";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkInformation::supports(QFlags<QNetworkInformation::Feature>)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInformation_Feature_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // supports(QFlags<QNetworkInformation::Feature>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QNetworkInformation::Feature> cppArg0 = QFlags<QNetworkInformation::Feature>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // supports(QFlags<QNetworkInformation::Feature>)const
            bool cppResult = const_cast<const ::QNetworkInformation *>(cppSelf)->supports(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInformationFunc_transportMedium(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInformation *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInformation.transportMedium";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // transportMedium()const
            QNetworkInformation::TransportMedium cppResult = const_cast<const ::QNetworkInformation *>(cppSelf)->transportMedium();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_TransportMedium_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNetworkInformation_PropertyStrings[] = {
    "isBehindCaptivePortal:",
    "isMetered:",
    "reachability:",
    "transportMedium:",
    nullptr // Sentinel
};

static const char *Sbk_QNetworkInformation_EnumFlagInfo[] = {
    "Feature:Flag:Features",
    "Reachability:Enum",
    "TransportMedium:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNetworkInformation_methods[] = {
    {"availableBackends", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_availableBackends), METH_NOARGS|METH_STATIC, nullptr},
    {"backendName", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_backendName), METH_NOARGS, nullptr},
    {"instance", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_instance), METH_NOARGS|METH_STATIC, nullptr},
    {"isBehindCaptivePortal", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_isBehindCaptivePortal), METH_NOARGS, nullptr},
    {"isMetered", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_isMetered), METH_NOARGS, nullptr},
    {"load", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_load), METH_O|METH_STATIC, nullptr},
    {"loadBackendByFeatures", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_loadBackendByFeatures), METH_O|METH_STATIC, nullptr},
    {"loadBackendByName", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_loadBackendByName), METH_O|METH_STATIC, nullptr},
    {"loadDefaultBackend", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_loadDefaultBackend), METH_NOARGS|METH_STATIC, nullptr},
    {"reachability", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_reachability), METH_NOARGS, nullptr},
    {"supportedFeatures", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_supportedFeatures), METH_NOARGS, nullptr},
    {"supports", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_supports), METH_O, nullptr},
    {"transportMedium", reinterpret_cast<PyCFunction>(Sbk_QNetworkInformationFunc_transportMedium), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QNetworkInformation_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QNetworkInformation_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNetworkInformation_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNetworkInformation_Type = nullptr;
static PyTypeObject *Sbk_QNetworkInformation_TypeF(void)
{
    return _Sbk_QNetworkInformation_Type;
}

static PyType_Slot Sbk_QNetworkInformation_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(SbkDeallocWrapperWithPrivateDtor)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QNetworkInformation_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNetworkInformation_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNetworkInformation_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNetworkInformation_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNetworkInformation_spec = {
    "2:PySide6.QtNetwork.QNetworkInformation",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNetworkInformation_slots
};

} //extern "C"

static void *Sbk_QNetworkInformation_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QNetworkInformation *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QNetworkInformation_Reachability_PythonToCpp_QNetworkInformation_Reachability(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkInformation::Reachability>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkInformation::Reachability *>(cppOut) = value;

}
static PythonToCppFunc is_QNetworkInformation_Reachability_PythonToCpp_QNetworkInformation_Reachability_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Reachability_IDX])))
        return QNetworkInformation_Reachability_PythonToCpp_QNetworkInformation_Reachability;
    return {};
}
static PyObject *QNetworkInformation_Reachability_CppToPython_QNetworkInformation_Reachability(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QNetworkInformation::Reachability *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Reachability_IDX]), castCppIn);

}

static void QNetworkInformation_TransportMedium_PythonToCpp_QNetworkInformation_TransportMedium(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkInformation::TransportMedium>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkInformation::TransportMedium *>(cppOut) = value;

}
static PythonToCppFunc is_QNetworkInformation_TransportMedium_PythonToCpp_QNetworkInformation_TransportMedium_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_TransportMedium_IDX])))
        return QNetworkInformation_TransportMedium_PythonToCpp_QNetworkInformation_TransportMedium;
    return {};
}
static PyObject *QNetworkInformation_TransportMedium_CppToPython_QNetworkInformation_TransportMedium(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QNetworkInformation::TransportMedium *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_TransportMedium_IDX]), castCppIn);

}

static void QNetworkInformation_Feature_PythonToCpp_QNetworkInformation_Feature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkInformation::Feature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkInformation::Feature *>(cppOut) = value;

}
static PythonToCppFunc is_QNetworkInformation_Feature_PythonToCpp_QNetworkInformation_Feature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Feature_IDX])))
        return QNetworkInformation_Feature_PythonToCpp_QNetworkInformation_Feature;
    return {};
}
static PyObject *QNetworkInformation_Feature_CppToPython_QNetworkInformation_Feature(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QNetworkInformation::Feature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Feature_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNetworkInformation_PythonToCpp_QNetworkInformation_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNetworkInformation_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNetworkInformation_PythonToCpp_QNetworkInformation_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkInformation_TypeF()))
        return QNetworkInformation_PythonToCpp_QNetworkInformation_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNetworkInformation_PTR_CppToPython_QNetworkInformation(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QNetworkInformation *>(const_cast<void *>(cppIn)), Sbk_QNetworkInformation_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QNetworkInformation_SignatureStrings[] = {
    "PySide6.QtNetwork.QNetworkInformation.availableBackends()->QStringList",
    "PySide6.QtNetwork.QNetworkInformation.backendName(self)->QString",
    "PySide6.QtNetwork.QNetworkInformation.instance()->PySide6.QtNetwork.QNetworkInformation",
    "PySide6.QtNetwork.QNetworkInformation.isBehindCaptivePortal(self)->bool",
    "PySide6.QtNetwork.QNetworkInformation.isMetered(self)->bool",
    "1:PySide6.QtNetwork.QNetworkInformation.load(features:PySide6.QtNetwork.QNetworkInformation.Feature)->bool",
    "0:PySide6.QtNetwork.QNetworkInformation.load(backend:QString)->bool",
    "PySide6.QtNetwork.QNetworkInformation.loadBackendByFeatures(features:PySide6.QtNetwork.QNetworkInformation.Feature)->bool",
    "PySide6.QtNetwork.QNetworkInformation.loadBackendByName(backend:QString)->bool",
    "PySide6.QtNetwork.QNetworkInformation.loadDefaultBackend()->bool",
    "PySide6.QtNetwork.QNetworkInformation.reachability(self)->PySide6.QtNetwork.QNetworkInformation.Reachability",
    "PySide6.QtNetwork.QNetworkInformation.supportedFeatures(self)->PySide6.QtNetwork.QNetworkInformation.Feature",
    "PySide6.QtNetwork.QNetworkInformation.supports(self,features:PySide6.QtNetwork.QNetworkInformation.Feature)->bool",
    "PySide6.QtNetwork.QNetworkInformation.transportMedium(self)->PySide6.QtNetwork.QNetworkInformation.TransportMedium",
    nullptr}; // Sentinel

PyTypeObject *init_QNetworkInformation(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX].type;

    Shiboken::AutoDecRef Sbk_QNetworkInformation_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QNetworkInformation_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNetworkInformation",
        "QNetworkInformation*",
        &Sbk_QNetworkInformation_spec,
        nullptr,
        Sbk_QNetworkInformation_Type_bases.object(),
        0);
    auto *pyType = Sbk_QNetworkInformation_TypeF(); // references _Sbk_QNetworkInformation_Type
    InitSignatureStrings(pyType, QNetworkInformation_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNetworkInformation_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNetworkInformation_PythonToCpp_QNetworkInformation_PTR,
        is_QNetworkInformation_PythonToCpp_QNetworkInformation_PTR_Convertible,
        QNetworkInformation_PTR_CppToPython_QNetworkInformation);

    Shiboken::Conversions::registerConverterName(converter, "QNetworkInformation");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkInformation*");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkInformation&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNetworkInformation).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QNetworkInformation_TypeF(), &Sbk_QNetworkInformation_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QNetworkInformation_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Reachability'.
    const char *Reachability_Initializer[] = {
        "Unknown",
        "Disconnected",
        "Local",
        "Site",
        "Online",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Reachability_InitializerValues[] = {
        int8_t(QNetworkInformation::Reachability::Unknown),      //  0x00  0
        int8_t(QNetworkInformation::Reachability::Disconnected), //  0x01  1
        int8_t(QNetworkInformation::Reachability::Local),        //  0x02  2
        int8_t(QNetworkInformation::Reachability::Site),         //  0x03  3
        int8_t(QNetworkInformation::Reachability::Online)        //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkInformation_TypeF(),
        "2:PySide6.QtNetwork.QNetworkInformation.Reachability",
        Reachability_Initializer, Reachability_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Reachability_IDX].type = EType;
    // Register converter for enum 'QNetworkInformation::Reachability'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkInformation_Reachability_CppToPython_QNetworkInformation_Reachability);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QNetworkInformation_Reachability_PythonToCpp_QNetworkInformation_Reachability,
            is_QNetworkInformation_Reachability_PythonToCpp_QNetworkInformation_Reachability_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkInformation::Reachability");
        Shiboken::Conversions::registerConverterName(converter, "Reachability");
    }
    // End of 'Reachability' enum.

    // Initialization of enum 'TransportMedium'.
    const char *TransportMedium_Initializer[] = {
        "Unknown",
        "Ethernet",
        "Cellular",
        "WiFi",
        "Bluetooth",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t TransportMedium_InitializerValues[] = {
        int8_t(QNetworkInformation::TransportMedium::Unknown),  //  0x00  0
        int8_t(QNetworkInformation::TransportMedium::Ethernet), //  0x01  1
        int8_t(QNetworkInformation::TransportMedium::Cellular), //  0x02  2
        int8_t(QNetworkInformation::TransportMedium::WiFi),     //  0x03  3
        int8_t(QNetworkInformation::TransportMedium::Bluetooth) //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkInformation_TypeF(),
        "2:PySide6.QtNetwork.QNetworkInformation.TransportMedium",
        TransportMedium_Initializer, TransportMedium_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_TransportMedium_IDX].type = EType;
    // Register converter for enum 'QNetworkInformation::TransportMedium'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkInformation_TransportMedium_CppToPython_QNetworkInformation_TransportMedium);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QNetworkInformation_TransportMedium_PythonToCpp_QNetworkInformation_TransportMedium,
            is_QNetworkInformation_TransportMedium_PythonToCpp_QNetworkInformation_TransportMedium_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkInformation::TransportMedium");
        Shiboken::Conversions::registerConverterName(converter, "TransportMedium");
    }
    // End of 'TransportMedium' enum.

    // Initialization of enum 'Feature'.
    const char *Feature_Initializer[] = {
        "Reachability",
        "CaptivePortal",
        "TransportMedium",
        "Metered",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t Feature_InitializerValues[] = {
        int8_t(QNetworkInformation::Feature::Reachability),    //  0x01  1
        int8_t(QNetworkInformation::Feature::CaptivePortal),   //  0x02  2
        int8_t(QNetworkInformation::Feature::TransportMedium), //  0x04  4
        int8_t(QNetworkInformation::Feature::Metered)          //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkInformation_TypeF(),
        "2:PySide6.QtNetwork.QNetworkInformation.Feature",
        Feature_Initializer, Feature_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Feature_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInformation_Feature_IDX].type =
        EType;
    // Register converter for enum 'QNetworkInformation::Feature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkInformation_Feature_CppToPython_QNetworkInformation_Feature);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QNetworkInformation_Feature_PythonToCpp_QNetworkInformation_Feature,
            is_QNetworkInformation_Feature_PythonToCpp_QNetworkInformation_Feature_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkInformation::Feature");
        Shiboken::Conversions::registerConverterName(converter, "Feature");
        // Register converter for flag 'QFlags<QNetworkInformation::Feature>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QNetworkInformation::Feature>");
        Shiboken::Conversions::registerConverterName(converter, "QNetworkInformation::Features");
    }
    // End of 'Feature' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QNetworkInformation::staticMetaObject);
    qRegisterMetaType< ::QNetworkInformation::Reachability >("QNetworkInformation::Reachability");
    qRegisterMetaType< ::QNetworkInformation::TransportMedium >("QNetworkInformation::TransportMedium");
    qRegisterMetaType< ::QNetworkInformation::Feature >("QNetworkInformation::Feature");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QNetworkInformation::staticMetaObject, sizeof(::QNetworkInformation));

    return pyType;
}
