// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qnetworkinterface_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkinterface.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNetworkInterface >()))
        return -1;

    ::QNetworkInterface *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QNetworkInterface", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNetworkInterface::QNetworkInterface()
    // 1: QNetworkInterface::QNetworkInterface(QNetworkInterface)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkInterface()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QNetworkInterface(QNetworkInterface)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QNetworkInterface()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkInterface()
                cptr = new ::QNetworkInterface();
            }
            break;
        }
        case 1: // QNetworkInterface(const QNetworkInterface & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNetworkInterface cppArg0_local;
            ::QNetworkInterface *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkInterface(QNetworkInterface)
                cptr = new ::QNetworkInterface(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QNetworkInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNetworkInterfaceFunc_addressEntries(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.addressEntries";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // addressEntries()const
            QList<QNetworkAddressEntry> cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->addressEntries();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkAddressEntry_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_allAddresses(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.allAddresses";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // allAddresses()
            QList<QHostAddress> cppResult = ::QNetworkInterface::allAddresses();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QHostAddress_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_allInterfaces(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.allInterfaces";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // allInterfaces()
            QList<QNetworkInterface> cppResult = ::QNetworkInterface::allInterfaces();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkInterface_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.flags";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // flags()const
            QFlags<QNetworkInterface::InterfaceFlag> cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->flags();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInterface_InterfaceFlag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_hardwareAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.hardwareAddress";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hardwareAddress()const
            QString cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->hardwareAddress();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_humanReadableName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.humanReadableName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // humanReadableName()const
            QString cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->humanReadableName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_index(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.index";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // index()const
            int cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->index();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_interfaceFromIndex(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.interfaceFromIndex";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkInterface::interfaceFromIndex(int)->QNetworkInterface
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // interfaceFromIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // interfaceFromIndex(int)
            QNetworkInterface cppResult = ::QNetworkInterface::interfaceFromIndex(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_interfaceFromName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.interfaceFromName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkInterface::interfaceFromName(QString)->QNetworkInterface
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // interfaceFromName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // interfaceFromName(QString)
            QNetworkInterface cppResult = ::QNetworkInterface::interfaceFromName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_interfaceIndexFromName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.interfaceIndexFromName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkInterface::interfaceIndexFromName(QString)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // interfaceIndexFromName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // interfaceIndexFromName(QString)
            int cppResult = ::QNetworkInterface::interfaceIndexFromName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_interfaceNameFromIndex(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.interfaceNameFromIndex";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkInterface::interfaceNameFromIndex(int)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // interfaceNameFromIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // interfaceNameFromIndex(int)
            QString cppResult = ::QNetworkInterface::interfaceNameFromIndex(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_maximumTransmissionUnit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.maximumTransmissionUnit";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maximumTransmissionUnit()const
            int cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->maximumTransmissionUnit();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_name(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.name";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // name()const
            QString cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->name();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterfaceFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkInterface::swap(QNetworkInterface&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QNetworkInterface&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkInterface cppArg0_local;
        ::QNetworkInterface *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QNetworkInterface&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkInterfaceFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkInterface.type";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // type()const
            QNetworkInterface::InterfaceType cppResult = const_cast<const ::QNetworkInterface *>(cppSelf)->type();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterface__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNetworkInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QNetworkInterface_EnumFlagInfo[] = {
    "InterfaceFlag:Flag:InterfaceFlags",
    "InterfaceType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNetworkInterface_methods[] = {
    {"addressEntries", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_addressEntries), METH_NOARGS, nullptr},
    {"allAddresses", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_allAddresses), METH_NOARGS|METH_STATIC, nullptr},
    {"allInterfaces", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_allInterfaces), METH_NOARGS|METH_STATIC, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_flags), METH_NOARGS, nullptr},
    {"hardwareAddress", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_hardwareAddress), METH_NOARGS, nullptr},
    {"humanReadableName", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_humanReadableName), METH_NOARGS, nullptr},
    {"index", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_index), METH_NOARGS, nullptr},
    {"interfaceFromIndex", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_interfaceFromIndex), METH_O|METH_STATIC, nullptr},
    {"interfaceFromName", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_interfaceFromName), METH_O|METH_STATIC, nullptr},
    {"interfaceIndexFromName", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_interfaceIndexFromName), METH_O|METH_STATIC, nullptr},
    {"interfaceNameFromIndex", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_interfaceNameFromIndex), METH_O|METH_STATIC, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_isValid), METH_NOARGS, nullptr},
    {"maximumTransmissionUnit", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_maximumTransmissionUnit), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_name), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_swap), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterfaceFunc_type), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QNetworkInterface__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QNetworkInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNetworkInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QNetworkInterface__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNetworkInterface_Type = nullptr;
static PyTypeObject *Sbk_QNetworkInterface_TypeF(void)
{
    return _Sbk_QNetworkInterface_Type;
}

static PyType_Slot Sbk_QNetworkInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QNetworkInterface__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNetworkInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNetworkInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNetworkInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNetworkInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNetworkInterface_spec = {
    "2:PySide6.QtNetwork.QNetworkInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNetworkInterface_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QNetworkInterface_InterfaceFlag_PythonToCpp_QNetworkInterface_InterfaceFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkInterface::InterfaceFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkInterface::InterfaceFlag *>(cppOut) = value;

}
static PythonToCppFunc is_QNetworkInterface_InterfaceFlag_PythonToCpp_QNetworkInterface_InterfaceFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceFlag_IDX])))
        return QNetworkInterface_InterfaceFlag_PythonToCpp_QNetworkInterface_InterfaceFlag;
    return {};
}
static PyObject *QNetworkInterface_InterfaceFlag_CppToPython_QNetworkInterface_InterfaceFlag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QNetworkInterface::InterfaceFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceFlag_IDX]), castCppIn);

}

static void QNetworkInterface_InterfaceType_PythonToCpp_QNetworkInterface_InterfaceType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkInterface::InterfaceType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkInterface::InterfaceType *>(cppOut) = value;

}
static PythonToCppFunc is_QNetworkInterface_InterfaceType_PythonToCpp_QNetworkInterface_InterfaceType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceType_IDX])))
        return QNetworkInterface_InterfaceType_PythonToCpp_QNetworkInterface_InterfaceType;
    return {};
}
static PyObject *QNetworkInterface_InterfaceType_CppToPython_QNetworkInterface_InterfaceType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QNetworkInterface::InterfaceType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNetworkInterface_PythonToCpp_QNetworkInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNetworkInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNetworkInterface_PythonToCpp_QNetworkInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkInterface_TypeF()))
        return QNetworkInterface_PythonToCpp_QNetworkInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNetworkInterface_PTR_CppToPython_QNetworkInterface(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QNetworkInterface *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QNetworkInterface_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QNetworkInterface_COPY_CppToPython_QNetworkInterface(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QNetworkInterface *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QNetworkInterface_TypeF(), new ::QNetworkInterface(*source), true, true);
}

// Python to C++ copy conversion.
static void QNetworkInterface_PythonToCpp_QNetworkInterface_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNetworkInterface *>(cppOut) = *reinterpret_cast< ::QNetworkInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QNetworkInterface_PythonToCpp_QNetworkInterface_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkInterface_TypeF()))
        return QNetworkInterface_PythonToCpp_QNetworkInterface_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QNetworkInterface_SignatureStrings[] = {
    "1:PySide6.QtNetwork.QNetworkInterface(self)",
    "0:PySide6.QtNetwork.QNetworkInterface(self,other:PySide6.QtNetwork.QNetworkInterface)",
    "PySide6.QtNetwork.QNetworkInterface.addressEntries(self)->QList[PySide6.QtNetwork.QNetworkAddressEntry]",
    "PySide6.QtNetwork.QNetworkInterface.allAddresses()->QList[PySide6.QtNetwork.QHostAddress]",
    "PySide6.QtNetwork.QNetworkInterface.allInterfaces()->QList[PySide6.QtNetwork.QNetworkInterface]",
    "PySide6.QtNetwork.QNetworkInterface.flags(self)->PySide6.QtNetwork.QNetworkInterface.InterfaceFlag",
    "PySide6.QtNetwork.QNetworkInterface.hardwareAddress(self)->QString",
    "PySide6.QtNetwork.QNetworkInterface.humanReadableName(self)->QString",
    "PySide6.QtNetwork.QNetworkInterface.index(self)->int",
    "PySide6.QtNetwork.QNetworkInterface.interfaceFromIndex(index:int)->PySide6.QtNetwork.QNetworkInterface",
    "PySide6.QtNetwork.QNetworkInterface.interfaceFromName(name:QString)->PySide6.QtNetwork.QNetworkInterface",
    "PySide6.QtNetwork.QNetworkInterface.interfaceIndexFromName(name:QString)->int",
    "PySide6.QtNetwork.QNetworkInterface.interfaceNameFromIndex(index:int)->QString",
    "PySide6.QtNetwork.QNetworkInterface.isValid(self)->bool",
    "PySide6.QtNetwork.QNetworkInterface.maximumTransmissionUnit(self)->int",
    "PySide6.QtNetwork.QNetworkInterface.name(self)->QString",
    "PySide6.QtNetwork.QNetworkInterface.swap(self,other:PySide6.QtNetwork.QNetworkInterface)",
    "PySide6.QtNetwork.QNetworkInterface.type(self)->PySide6.QtNetwork.QNetworkInterface.InterfaceType",
    "PySide6.QtNetwork.QNetworkInterface.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QNetworkInterface(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QNetworkInterface_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QNetworkInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNetworkInterface",
        "QNetworkInterface",
        &Sbk_QNetworkInterface_spec,
        &Shiboken::callCppDestructor< ::QNetworkInterface >,
        Sbk_QNetworkInterface_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QNetworkInterface_TypeF(); // references _Sbk_QNetworkInterface_Type
    InitSignatureStrings(pyType, QNetworkInterface_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNetworkInterface_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNetworkInterface_PythonToCpp_QNetworkInterface_PTR,
        is_QNetworkInterface_PythonToCpp_QNetworkInterface_PTR_Convertible,
        QNetworkInterface_PTR_CppToPython_QNetworkInterface,
        QNetworkInterface_COPY_CppToPython_QNetworkInterface);

    Shiboken::Conversions::registerConverterName(converter, "QNetworkInterface");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNetworkInterface).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QNetworkInterface_PythonToCpp_QNetworkInterface_COPY,
        is_QNetworkInterface_PythonToCpp_QNetworkInterface_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QNetworkInterface_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'InterfaceFlag'.
    const char *InterfaceFlag_Initializer[] = {
        "IsUp",
        "IsRunning",
        "CanBroadcast",
        "IsLoopBack",
        "IsPointToPoint",
        "CanMulticast",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t InterfaceFlag_InitializerValues[] = {
        uint8_t(QNetworkInterface::InterfaceFlag::IsUp),           //  0x01  1
        uint8_t(QNetworkInterface::InterfaceFlag::IsRunning),      //  0x02  2
        uint8_t(QNetworkInterface::InterfaceFlag::CanBroadcast),   //  0x04  4
        uint8_t(QNetworkInterface::InterfaceFlag::IsLoopBack),     //  0x08  8
        uint8_t(QNetworkInterface::InterfaceFlag::IsPointToPoint), //  0x10  16
        uint8_t(QNetworkInterface::InterfaceFlag::CanMulticast)    //  0x20  32
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkInterface_TypeF(),
        "2:PySide6.QtNetwork.QNetworkInterface.InterfaceFlag",
        InterfaceFlag_Initializer, InterfaceFlag_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInterface_InterfaceFlag_IDX].type =
        EType;
    // Register converter for enum 'QNetworkInterface::InterfaceFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkInterface_InterfaceFlag_CppToPython_QNetworkInterface_InterfaceFlag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QNetworkInterface_InterfaceFlag_PythonToCpp_QNetworkInterface_InterfaceFlag,
            is_QNetworkInterface_InterfaceFlag_PythonToCpp_QNetworkInterface_InterfaceFlag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkInterface::InterfaceFlag");
        Shiboken::Conversions::registerConverterName(converter, "InterfaceFlag");
        // Register converter for flag 'QFlags<QNetworkInterface::InterfaceFlag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QNetworkInterface::InterfaceFlag>");
        Shiboken::Conversions::registerConverterName(converter, "QNetworkInterface::InterfaceFlags");
    }
    // End of 'InterfaceFlag' enum/flags.

    // Initialization of enum 'InterfaceType'.
    const char *InterfaceType_Initializer[] = {
        "Loopback",
        "Virtual",
        "Ethernet",
        "Slip",
        "CanBus",
        "Ppp",
        "Fddi",
        "Wifi",
        "Ieee80211",
        "Phonet",
        "Ieee802154",
        "SixLoWPAN",
        "Ieee80216",
        "Ieee1394",
        "Unknown",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t InterfaceType_InitializerValues[] = {
        uint8_t(QNetworkInterface::InterfaceType::Loopback),   //  0x01  1
        uint8_t(QNetworkInterface::InterfaceType::Virtual),    //  0x02  2
        uint8_t(QNetworkInterface::InterfaceType::Ethernet),   //  0x03  3
        uint8_t(QNetworkInterface::InterfaceType::Slip),       //  0x04  4
        uint8_t(QNetworkInterface::InterfaceType::CanBus),     //  0x05  5
        uint8_t(QNetworkInterface::InterfaceType::Ppp),        //  0x06  6
        uint8_t(QNetworkInterface::InterfaceType::Fddi),       //  0x07  7
        uint8_t(QNetworkInterface::InterfaceType::Wifi),       //  0x08  8
        uint8_t(QNetworkInterface::InterfaceType::Ieee80211),  //  0x08  8
        uint8_t(QNetworkInterface::InterfaceType::Phonet),     //  0x09  9
        uint8_t(QNetworkInterface::InterfaceType::Ieee802154), //  0x0a  10
        uint8_t(QNetworkInterface::InterfaceType::SixLoWPAN),  //  0x0b  11
        uint8_t(QNetworkInterface::InterfaceType::Ieee80216),  //  0x0c  12
        uint8_t(QNetworkInterface::InterfaceType::Ieee1394),   //  0x0d  13
        uint8_t(QNetworkInterface::InterfaceType::Unknown)     //  0x00  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkInterface_TypeF(),
        "2:PySide6.QtNetwork.QNetworkInterface.InterfaceType",
        InterfaceType_Initializer, InterfaceType_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceType_IDX].type = EType;
    // Register converter for enum 'QNetworkInterface::InterfaceType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkInterface_InterfaceType_CppToPython_QNetworkInterface_InterfaceType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QNetworkInterface_InterfaceType_PythonToCpp_QNetworkInterface_InterfaceType,
            is_QNetworkInterface_InterfaceType_PythonToCpp_QNetworkInterface_InterfaceType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkInterface::InterfaceType");
        Shiboken::Conversions::registerConverterName(converter, "InterfaceType");
    }
    // End of 'InterfaceType' enum.

    qRegisterMetaType< ::QNetworkInterface >("QNetworkInterface");
    qRegisterMetaType< ::QNetworkInterface::InterfaceFlag >("QNetworkInterface::InterfaceFlag");
    qRegisterMetaType< ::QNetworkInterface::InterfaceType >("QNetworkInterface::InterfaceType");

    return pyType;
}
