// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qnetworkproxyfactory_wrapper.h"

// Argument includes
#include <QList>
#include <QtNetwork/qnetworkproxy.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QNetworkProxyFactoryWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QNetworkProxyFactoryWrapper::QNetworkProxyFactoryWrapper() : QNetworkProxyFactory()
{
    resetPyMethodCache();
    // ... middle
}

::QList<QNetworkProxy> QNetworkProxyFactoryWrapper::queryProxy(const ::QNetworkProxyQuery & query)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QNetworkProxyFactory.queryProxy");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "queryProxy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QNetworkProxyFactory.queryProxy");
        return {};
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), &query)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), &query)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkProxy_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNetworkProxyFactory", funcName, "list", Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QList<QNetworkProxy> cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QNetworkProxyFactoryWrapper::~QNetworkProxyFactoryWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkProxyFactory_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyFactory_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QNetworkProxyFactory");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNetworkProxyFactory >()))
        return -1;

    QNetworkProxyFactoryWrapper *cptr{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyFactory.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QNetworkProxyFactory()
            cptr = new QNetworkProxyFactoryWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QNetworkProxyFactory >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNetworkProxyFactoryFunc_proxyForQuery(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyFactory.proxyForQuery";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkProxyFactory::proxyForQuery(QNetworkProxyQuery)->QList< QNetworkProxy>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), (pyArg)))) {
        overloadId = 0; // proxyForQuery(QNetworkProxyQuery)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkProxyQuery cppArg0_local;
        ::QNetworkProxyQuery *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // proxyForQuery(QNetworkProxyQuery)
            QList<QNetworkProxy> cppResult = ::QNetworkProxyFactory::proxyForQuery(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkProxy_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkProxyFactoryFunc_queryProxy(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyFactory.queryProxy";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:queryProxy", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNetworkProxyFactory::queryProxy(const QNetworkProxyQuery&=)->QList< QNetworkProxy>
    if (numArgs == 0) {
        overloadId = 0; // queryProxy(QNetworkProxyQuery)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), (pyArgs[0])))) {
        overloadId = 0; // queryProxy(QNetworkProxyQuery)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_query = Shiboken::String::createStaticString("query");
            if (PyDict_Contains(kwds, key_query) != 0) {
                value = PyDict_GetItem(kwds, key_query);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_query);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_query);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QNetworkProxyQuery cppArg0_local = QNetworkProxyQuery();
        ::QNetworkProxyQuery *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // queryProxy(QNetworkProxyQuery)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QNetworkProxyFactory.queryProxy");
                return {};
            }
            QList<QNetworkProxy> cppResult = cppSelf->queryProxy(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkProxy_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkProxyFactoryFunc_setApplicationProxyFactory(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyFactory.setApplicationProxyFactory";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkProxyFactory::setApplicationProxyFactory(QNetworkProxyFactory*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyFactory_IDX]), (pyArg)))) {
        overloadId = 0; // setApplicationProxyFactory(QNetworkProxyFactory*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkProxyFactory *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setApplicationProxyFactory(QNetworkProxyFactory*)
            ::QNetworkProxyFactory::setApplicationProxyFactory(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkProxyFactoryFunc_setUseSystemConfiguration(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyFactory.setUseSystemConfiguration";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QNetworkProxyFactory::setUseSystemConfiguration(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setUseSystemConfiguration(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUseSystemConfiguration(bool)
            ::QNetworkProxyFactory::setUseSystemConfiguration(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkProxyFactoryFunc_systemProxyForQuery(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyFactory.systemProxyForQuery";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:systemProxyForQuery", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QNetworkProxyFactory::systemProxyForQuery(const QNetworkProxyQuery&=)->QList< QNetworkProxy>
    if (numArgs == 0) {
        overloadId = 0; // systemProxyForQuery(QNetworkProxyQuery)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), (pyArgs[0])))) {
        overloadId = 0; // systemProxyForQuery(QNetworkProxyQuery)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_query = Shiboken::String::createStaticString("query");
            if (PyDict_Contains(kwds, key_query) != 0) {
                value = PyDict_GetItem(kwds, key_query);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_query);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_query);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QNetworkProxyQuery cppArg0_local = QNetworkProxyQuery();
        ::QNetworkProxyQuery *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // systemProxyForQuery(QNetworkProxyQuery)
            QList<QNetworkProxy> cppResult = ::QNetworkProxyFactory::systemProxyForQuery(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkTypeConverters[SBK_QtNetwork_QList_QNetworkProxy_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkProxyFactoryFunc_usesSystemConfiguration(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyFactory.usesSystemConfiguration";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // usesSystemConfiguration()
            bool cppResult = ::QNetworkProxyFactory::usesSystemConfiguration();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNetworkProxyFactory_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNetworkProxyFactory_methods[] = {
    {"proxyForQuery", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyFactoryFunc_proxyForQuery), METH_O|METH_STATIC, nullptr},
    {"queryProxy", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyFactoryFunc_queryProxy), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setApplicationProxyFactory", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyFactoryFunc_setApplicationProxyFactory), METH_O|METH_STATIC, nullptr},
    {"setUseSystemConfiguration", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyFactoryFunc_setUseSystemConfiguration), METH_O|METH_STATIC, nullptr},
    {"systemProxyForQuery", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyFactoryFunc_systemProxyForQuery), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"usesSystemConfiguration", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyFactoryFunc_usesSystemConfiguration), METH_NOARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QNetworkProxyFactory_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QNetworkProxyFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QNetworkProxyFactoryWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QNetworkProxyFactory_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNetworkProxyFactory_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNetworkProxyFactory_Type = nullptr;
static PyTypeObject *Sbk_QNetworkProxyFactory_TypeF(void)
{
    return _Sbk_QNetworkProxyFactory_Type;
}

static PyType_Slot Sbk_QNetworkProxyFactory_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QNetworkProxyFactory_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNetworkProxyFactory_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNetworkProxyFactory_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNetworkProxyFactory_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNetworkProxyFactory_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNetworkProxyFactory_spec = {
    "2:PySide6.QtNetwork.QNetworkProxyFactory",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNetworkProxyFactory_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNetworkProxyFactory_PythonToCpp_QNetworkProxyFactory_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNetworkProxyFactory_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNetworkProxyFactory_PythonToCpp_QNetworkProxyFactory_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkProxyFactory_TypeF()))
        return QNetworkProxyFactory_PythonToCpp_QNetworkProxyFactory_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNetworkProxyFactory_PTR_CppToPython_QNetworkProxyFactory(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QNetworkProxyFactory *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QNetworkProxyFactory_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QNetworkProxyFactory_SignatureStrings[] = {
    "PySide6.QtNetwork.QNetworkProxyFactory(self)",
    "PySide6.QtNetwork.QNetworkProxyFactory.proxyForQuery(query:typing.Union[PySide6.QtNetwork.QNetworkProxyQuery, PySide6.QtCore.QUrl, quint16])->QList[PySide6.QtNetwork.QNetworkProxy]",
    "PySide6.QtNetwork.QNetworkProxyFactory.queryProxy(self,query:typing.Union[PySide6.QtNetwork.QNetworkProxyQuery, PySide6.QtCore.QUrl, quint16]=QNetworkProxyQuery())->QList[PySide6.QtNetwork.QNetworkProxy]",
    "PySide6.QtNetwork.QNetworkProxyFactory.setApplicationProxyFactory(factory:PySide6.QtNetwork.QNetworkProxyFactory)",
    "PySide6.QtNetwork.QNetworkProxyFactory.setUseSystemConfiguration(enable:bool)",
    "PySide6.QtNetwork.QNetworkProxyFactory.systemProxyForQuery(query:typing.Union[PySide6.QtNetwork.QNetworkProxyQuery, PySide6.QtCore.QUrl, quint16]=QNetworkProxyQuery())->QList[PySide6.QtNetwork.QNetworkProxy]",
    "PySide6.QtNetwork.QNetworkProxyFactory.usesSystemConfiguration()->bool",
    nullptr}; // Sentinel

PyTypeObject *init_QNetworkProxyFactory(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyFactory_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyFactory_IDX].type;

    Shiboken::AutoDecRef Sbk_QNetworkProxyFactory_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QNetworkProxyFactory_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNetworkProxyFactory",
        "QNetworkProxyFactory*",
        &Sbk_QNetworkProxyFactory_spec,
        &Shiboken::callCppDestructor< QNetworkProxyFactory >,
        Sbk_QNetworkProxyFactory_Type_bases.object(),
        0);
    auto *pyType = Sbk_QNetworkProxyFactory_TypeF(); // references _Sbk_QNetworkProxyFactory_Type
    InitSignatureStrings(pyType, QNetworkProxyFactory_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNetworkProxyFactory_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyFactory_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNetworkProxyFactory_PythonToCpp_QNetworkProxyFactory_PTR,
        is_QNetworkProxyFactory_PythonToCpp_QNetworkProxyFactory_PTR_Convertible,
        QNetworkProxyFactory_PTR_CppToPython_QNetworkProxyFactory);

    Shiboken::Conversions::registerConverterName(converter, "QNetworkProxyFactory");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkProxyFactory*");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkProxyFactory&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNetworkProxyFactory).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QNetworkProxyFactoryWrapper).name());

    qRegisterMetaType< ::QNetworkProxyFactory *>();

    return pyType;
}
