// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qnetworkproxyquery_wrapper.h"

// Argument includes
#include <QString>
#include <QtNetwork/qnetworkproxy.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkProxyQuery_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNetworkProxyQuery >()))
        return -1;

    ::QNetworkProxyQuery *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyQuery.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:QNetworkProxyQuery", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNetworkProxyQuery::QNetworkProxyQuery()
    // 1: QNetworkProxyQuery::QNetworkProxyQuery(QNetworkProxyQuery)
    // 2: QNetworkProxyQuery::QNetworkProxyQuery(QString,int,const QString&=,QNetworkProxyQuery::QueryType=)
    // 3: QNetworkProxyQuery::QNetworkProxyQuery(QUrl,QNetworkProxyQuery::QueryType=)
    // 4: QNetworkProxyQuery::QNetworkProxyQuery(quint16,const QString&=,QNetworkProxyQuery::QueryType=)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkProxyQuery()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 4; // QNetworkProxyQuery(quint16,QString,QNetworkProxyQuery::QueryType)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 4; // QNetworkProxyQuery(quint16,QString,QNetworkProxyQuery::QueryType)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_QueryType_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 4; // QNetworkProxyQuery(quint16,QString,QNetworkProxyQuery::QueryType)
            }
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // QNetworkProxyQuery(QString,int,QString,QNetworkProxyQuery::QueryType)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 2; // QNetworkProxyQuery(QString,int,QString,QNetworkProxyQuery::QueryType)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_QueryType_IDX])))->converter, (pyArgs[3])))) {
                overloadId = 2; // QNetworkProxyQuery(QString,int,QString,QNetworkProxyQuery::QueryType)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // QNetworkProxyQuery(QUrl,QNetworkProxyQuery::QueryType)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_QueryType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 3; // QNetworkProxyQuery(QUrl,QNetworkProxyQuery::QueryType)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QNetworkProxyQuery(QNetworkProxyQuery)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QNetworkProxyQuery()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkProxyQuery()
                cptr = new ::QNetworkProxyQuery();
            }
            break;
        }
        case 1: // QNetworkProxyQuery(const QNetworkProxyQuery & other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QNetworkProxyQuery cppArg0_local;
            ::QNetworkProxyQuery *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkProxyQuery(QNetworkProxyQuery)
                cptr = new ::QNetworkProxyQuery(*cppArg0);
            }
            break;
        }
        case 2: // QNetworkProxyQuery(const QString & hostname, int port, const QString & protocolTag, QNetworkProxyQuery::QueryType queryType)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_protocolTag = Shiboken::String::createStaticString("protocolTag");
                if (PyDict_Contains(kwds, key_protocolTag) != 0) {
                    value = PyDict_GetItem(kwds, key_protocolTag);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_protocolTag);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_protocolTag);
                }
                static PyObject *const key_queryType = Shiboken::String::createStaticString("queryType");
                if (PyDict_Contains(kwds, key_queryType) != 0) {
                    value = PyDict_GetItem(kwds, key_queryType);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_queryType);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_QueryType_IDX])))->converter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_queryType);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2 = QString();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QNetworkProxyQuery::QueryType cppArg3(QNetworkProxyQuery::QueryType::TcpSocket);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkProxyQuery(QString,int,QString,QNetworkProxyQuery::QueryType)
                cptr = new ::QNetworkProxyQuery(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 3: // QNetworkProxyQuery(const QUrl & requestUrl, QNetworkProxyQuery::QueryType queryType)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_queryType = Shiboken::String::createStaticString("queryType");
                if (PyDict_Contains(kwds, key_queryType) != 0) {
                    value = PyDict_GetItem(kwds, key_queryType);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_queryType);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_QueryType_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_queryType);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QNetworkProxyQuery::QueryType cppArg1(QNetworkProxyQuery::QueryType::UrlRequest);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkProxyQuery(QUrl,QNetworkProxyQuery::QueryType)
                cptr = new ::QNetworkProxyQuery(*cppArg0, cppArg1);
            }
            break;
        }
        case 4: // QNetworkProxyQuery(quint16 bindPort, const QString & protocolTag, QNetworkProxyQuery::QueryType queryType)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_protocolTag = Shiboken::String::createStaticString("protocolTag");
                if (PyDict_Contains(kwds, key_protocolTag) != 0) {
                    value = PyDict_GetItem(kwds, key_protocolTag);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_protocolTag);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_protocolTag);
                }
                static PyObject *const key_queryType = Shiboken::String::createStaticString("queryType");
                if (PyDict_Contains(kwds, key_queryType) != 0) {
                    value = PyDict_GetItem(kwds, key_queryType);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_queryType);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_QueryType_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_queryType);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            quint16 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QNetworkProxyQuery::QueryType cppArg2(QNetworkProxyQuery::QueryType::TcpServer);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QNetworkProxyQuery(quint16,QString,QNetworkProxyQuery::QueryType)
                cptr = new ::QNetworkProxyQuery(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QNetworkProxyQuery >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QNetworkProxyQueryFunc_localPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyQuery.localPort";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // localPort()const
            int cppResult = const_cast<const ::QNetworkProxyQuery *>(cppSelf)->localPort();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkProxyQueryFunc_peerHostName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyQuery.peerHostName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // peerHostName()const
            QString cppResult = const_cast<const ::QNetworkProxyQuery *>(cppSelf)->peerHostName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkProxyQueryFunc_peerPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyQuery.peerPort";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // peerPort()const
            int cppResult = const_cast<const ::QNetworkProxyQuery *>(cppSelf)->peerPort();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkProxyQueryFunc_protocolTag(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyQuery.protocolTag";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // protocolTag()const
            QString cppResult = const_cast<const ::QNetworkProxyQuery *>(cppSelf)->protocolTag();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkProxyQueryFunc_queryType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyQuery.queryType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // queryType()const
            QNetworkProxyQuery::QueryType cppResult = const_cast<const ::QNetworkProxyQuery *>(cppSelf)->queryType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_QueryType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkProxyQueryFunc_setLocalPort(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyQuery.setLocalPort";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkProxyQuery::setLocalPort(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLocalPort(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocalPort(int)
            cppSelf->setLocalPort(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkProxyQueryFunc_setPeerHostName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyQuery.setPeerHostName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkProxyQuery::setPeerHostName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPeerHostName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPeerHostName(QString)
            cppSelf->setPeerHostName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkProxyQueryFunc_setPeerPort(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyQuery.setPeerPort";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkProxyQuery::setPeerPort(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setPeerPort(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPeerPort(int)
            cppSelf->setPeerPort(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkProxyQueryFunc_setProtocolTag(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyQuery.setProtocolTag";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkProxyQuery::setProtocolTag(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setProtocolTag(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProtocolTag(QString)
            cppSelf->setProtocolTag(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkProxyQueryFunc_setQueryType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyQuery.setQueryType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkProxyQuery::setQueryType(QNetworkProxyQuery::QueryType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_QueryType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setQueryType(QNetworkProxyQuery::QueryType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QNetworkProxyQuery::QueryType cppArg0{QNetworkProxyQuery::TcpSocket};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setQueryType(QNetworkProxyQuery::QueryType)
            cppSelf->setQueryType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkProxyQueryFunc_setUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyQuery.setUrl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkProxyQuery::setUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUrl(QUrl)
            cppSelf->setUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkProxyQueryFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyQuery.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNetworkProxyQuery::swap(QNetworkProxyQuery&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QNetworkProxyQuery&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkProxyQuery cppArg0_local;
        ::QNetworkProxyQuery *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QNetworkProxyQuery&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QNetworkProxyQueryFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetwork.QNetworkProxyQuery.url";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // url()const
            QUrl cppResult = const_cast<const ::QNetworkProxyQuery *>(cppSelf)->url();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkProxyQuery__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNetworkProxyQuery_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QNetworkProxyQuery_EnumFlagInfo[] = {
    "QueryType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNetworkProxyQuery_methods[] = {
    {"localPort", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyQueryFunc_localPort), METH_NOARGS, nullptr},
    {"peerHostName", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyQueryFunc_peerHostName), METH_NOARGS, nullptr},
    {"peerPort", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyQueryFunc_peerPort), METH_NOARGS, nullptr},
    {"protocolTag", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyQueryFunc_protocolTag), METH_NOARGS, nullptr},
    {"queryType", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyQueryFunc_queryType), METH_NOARGS, nullptr},
    {"setLocalPort", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyQueryFunc_setLocalPort), METH_O, nullptr},
    {"setPeerHostName", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyQueryFunc_setPeerHostName), METH_O, nullptr},
    {"setPeerPort", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyQueryFunc_setPeerPort), METH_O, nullptr},
    {"setProtocolTag", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyQueryFunc_setProtocolTag), METH_O, nullptr},
    {"setQueryType", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyQueryFunc_setQueryType), METH_O, nullptr},
    {"setUrl", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyQueryFunc_setUrl), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyQueryFunc_swap), METH_O, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyQueryFunc_url), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QNetworkProxyQuery__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QNetworkProxyQuery_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), (pyArg)))) {
                // operator!=(const QNetworkProxyQuery & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNetworkProxyQuery cppArg0_local;
                ::QNetworkProxyQuery *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), (pyArg)))) {
                // operator==(const QNetworkProxyQuery & other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QNetworkProxyQuery cppArg0_local;
                ::QNetworkProxyQuery *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QNetworkProxyQuery_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNetworkProxyQuery_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QNetworkProxyQuery__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNetworkProxyQuery_Type = nullptr;
static PyTypeObject *Sbk_QNetworkProxyQuery_TypeF(void)
{
    return _Sbk_QNetworkProxyQuery_Type;
}

static PyType_Slot Sbk_QNetworkProxyQuery_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QNetworkProxyQuery__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNetworkProxyQuery_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNetworkProxyQuery_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QNetworkProxyQuery_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNetworkProxyQuery_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNetworkProxyQuery_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNetworkProxyQuery_spec = {
    "2:PySide6.QtNetwork.QNetworkProxyQuery",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNetworkProxyQuery_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QNetworkProxyQuery_QueryType_PythonToCpp_QNetworkProxyQuery_QueryType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNetworkProxyQuery::QueryType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNetworkProxyQuery::QueryType *>(cppOut) = value;

}
static PythonToCppFunc is_QNetworkProxyQuery_QueryType_PythonToCpp_QNetworkProxyQuery_QueryType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_QueryType_IDX])))
        return QNetworkProxyQuery_QueryType_PythonToCpp_QNetworkProxyQuery_QueryType;
    return {};
}
static PyObject *QNetworkProxyQuery_QueryType_CppToPython_QNetworkProxyQuery_QueryType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QNetworkProxyQuery::QueryType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_QueryType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNetworkProxyQuery_PythonToCpp_QNetworkProxyQuery_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNetworkProxyQuery_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNetworkProxyQuery_PythonToCpp_QNetworkProxyQuery_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkProxyQuery_TypeF()))
        return QNetworkProxyQuery_PythonToCpp_QNetworkProxyQuery_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNetworkProxyQuery_PTR_CppToPython_QNetworkProxyQuery(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QNetworkProxyQuery *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QNetworkProxyQuery_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QNetworkProxyQuery_COPY_CppToPython_QNetworkProxyQuery(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QNetworkProxyQuery *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QNetworkProxyQuery_TypeF(), new ::QNetworkProxyQuery(*source), true, true);
}

// Python to C++ copy conversion.
static void QNetworkProxyQuery_PythonToCpp_QNetworkProxyQuery_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNetworkProxyQuery *>(cppOut) = *reinterpret_cast< ::QNetworkProxyQuery *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QNetworkProxyQuery_PythonToCpp_QNetworkProxyQuery_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QNetworkProxyQuery_TypeF()))
        return QNetworkProxyQuery_PythonToCpp_QNetworkProxyQuery_COPY;
    return {};
}

// Implicit conversions.
static void PySide6_QtCore_constQUrlREF_PythonToCpp_QNetworkProxyQuery(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QNetworkProxyQuery *>(cppOut) = ::QNetworkProxyQuery( *reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_PySide6_QtCore_constQUrlREF_PythonToCpp_QNetworkProxyQuery_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), pyIn))
        return PySide6_QtCore_constQUrlREF_PythonToCpp_QNetworkProxyQuery;
    return {};
}

static void PySide6_QtCore_quint16_PythonToCpp_QNetworkProxyQuery(PyObject *pyIn, void *cppOut)
{
    quint16 cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), pyIn, &cppIn);
    *reinterpret_cast<::QNetworkProxyQuery *>(cppOut) = ::QNetworkProxyQuery(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_quint16_PythonToCpp_QNetworkProxyQuery_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return PySide6_QtCore_quint16_PythonToCpp_QNetworkProxyQuery;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QNetworkProxyQuery_SignatureStrings[] = {
    "4:PySide6.QtNetwork.QNetworkProxyQuery(self)",
    "3:PySide6.QtNetwork.QNetworkProxyQuery(self,other:typing.Union[PySide6.QtNetwork.QNetworkProxyQuery, PySide6.QtCore.QUrl, quint16])",
    "2:PySide6.QtNetwork.QNetworkProxyQuery(self,hostname:QString,port:int,protocolTag:QString=QString(),queryType:PySide6.QtNetwork.QNetworkProxyQuery.QueryType=QNetworkProxyQuery.QueryType.TcpSocket)",
    "1:PySide6.QtNetwork.QNetworkProxyQuery(self,requestUrl:typing.Union[PySide6.QtCore.QUrl, QString],queryType:PySide6.QtNetwork.QNetworkProxyQuery.QueryType=QNetworkProxyQuery.QueryType.UrlRequest)",
    "0:PySide6.QtNetwork.QNetworkProxyQuery(self,bindPort:quint16,protocolTag:QString=QString(),queryType:PySide6.QtNetwork.QNetworkProxyQuery.QueryType=QNetworkProxyQuery.QueryType.TcpServer)",
    "PySide6.QtNetwork.QNetworkProxyQuery.localPort(self)->int",
    "PySide6.QtNetwork.QNetworkProxyQuery.peerHostName(self)->QString",
    "PySide6.QtNetwork.QNetworkProxyQuery.peerPort(self)->int",
    "PySide6.QtNetwork.QNetworkProxyQuery.protocolTag(self)->QString",
    "PySide6.QtNetwork.QNetworkProxyQuery.queryType(self)->PySide6.QtNetwork.QNetworkProxyQuery.QueryType",
    "PySide6.QtNetwork.QNetworkProxyQuery.setLocalPort(self,port:int)",
    "PySide6.QtNetwork.QNetworkProxyQuery.setPeerHostName(self,hostname:QString)",
    "PySide6.QtNetwork.QNetworkProxyQuery.setPeerPort(self,port:int)",
    "PySide6.QtNetwork.QNetworkProxyQuery.setProtocolTag(self,protocolTag:QString)",
    "PySide6.QtNetwork.QNetworkProxyQuery.setQueryType(self,type:PySide6.QtNetwork.QNetworkProxyQuery.QueryType)",
    "PySide6.QtNetwork.QNetworkProxyQuery.setUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtNetwork.QNetworkProxyQuery.swap(self,other:typing.Union[PySide6.QtNetwork.QNetworkProxyQuery, PySide6.QtCore.QUrl, quint16])",
    "PySide6.QtNetwork.QNetworkProxyQuery.url(self)->PySide6.QtCore.QUrl",
    "PySide6.QtNetwork.QNetworkProxyQuery.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QNetworkProxyQuery(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX].type;

    Shiboken::AutoDecRef Sbk_QNetworkProxyQuery_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QNetworkProxyQuery_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNetworkProxyQuery",
        "QNetworkProxyQuery",
        &Sbk_QNetworkProxyQuery_spec,
        &Shiboken::callCppDestructor< ::QNetworkProxyQuery >,
        Sbk_QNetworkProxyQuery_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QNetworkProxyQuery_TypeF(); // references _Sbk_QNetworkProxyQuery_Type
    InitSignatureStrings(pyType, QNetworkProxyQuery_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNetworkProxyQuery_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNetworkProxyQuery_PythonToCpp_QNetworkProxyQuery_PTR,
        is_QNetworkProxyQuery_PythonToCpp_QNetworkProxyQuery_PTR_Convertible,
        QNetworkProxyQuery_PTR_CppToPython_QNetworkProxyQuery,
        QNetworkProxyQuery_COPY_CppToPython_QNetworkProxyQuery);

    Shiboken::Conversions::registerConverterName(converter, "QNetworkProxyQuery");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkProxyQuery*");
    Shiboken::Conversions::registerConverterName(converter, "QNetworkProxyQuery&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNetworkProxyQuery).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QNetworkProxyQuery_PythonToCpp_QNetworkProxyQuery_COPY,
        is_QNetworkProxyQuery_PythonToCpp_QNetworkProxyQuery_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_constQUrlREF_PythonToCpp_QNetworkProxyQuery,
        is_PySide6_QtCore_constQUrlREF_PythonToCpp_QNetworkProxyQuery_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_quint16_PythonToCpp_QNetworkProxyQuery,
        is_PySide6_QtCore_quint16_PythonToCpp_QNetworkProxyQuery_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QNetworkProxyQuery_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'QueryType'.
    const char *QueryType_Initializer[] = {
        "TcpSocket",
        "UdpSocket",
        "SctpSocket",
        "TcpServer",
        "UrlRequest",
        "SctpServer",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t QueryType_InitializerValues[] = {
        uint8_t(QNetworkProxyQuery::QueryType::TcpSocket),  //  0x00  0
        uint8_t(QNetworkProxyQuery::QueryType::UdpSocket),  //  0x01  1
        uint8_t(QNetworkProxyQuery::QueryType::SctpSocket), //  0x02  2
        uint8_t(QNetworkProxyQuery::QueryType::TcpServer),  //  0x64  100
        uint8_t(QNetworkProxyQuery::QueryType::UrlRequest), //  0x65  101
        uint8_t(QNetworkProxyQuery::QueryType::SctpServer)  //  0x66  102
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNetworkProxyQuery_TypeF(),
        "2:PySide6.QtNetwork.QNetworkProxyQuery.QueryType",
        QueryType_Initializer, QueryType_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxyQuery_QueryType_IDX].type = EType;
    // Register converter for enum 'QNetworkProxyQuery::QueryType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNetworkProxyQuery_QueryType_CppToPython_QNetworkProxyQuery_QueryType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QNetworkProxyQuery_QueryType_PythonToCpp_QNetworkProxyQuery_QueryType,
            is_QNetworkProxyQuery_QueryType_PythonToCpp_QNetworkProxyQuery_QueryType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QNetworkProxyQuery::QueryType");
        Shiboken::Conversions::registerConverterName(converter, "QueryType");
    }
    // End of 'QueryType' enum.

    qRegisterMetaType< ::QNetworkProxyQuery >("QNetworkProxyQuery");
    qRegisterMetaType< ::QNetworkProxyQuery::QueryType >("QNetworkProxyQuery::QueryType");

    return pyType;
}
