// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetworkauth_python.h"

// main header
#include "qoauth1signature_wrapper.h"

// Argument includes
#include <QList>
#include <QMultiMap>
#include <QString>
#include <QtNetworkAuth/qoauth1signature.h>
#include <qbytearray.h>
#include <qurl.h>
#include <qurlquery.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOAuth1Signature_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOAuth1Signature >()))
        return -1;

    ::QOAuth1Signature *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOO:QOAuth1Signature", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOAuth1Signature::QOAuth1Signature(QOAuth1Signature)
    // 1: QOAuth1Signature::QOAuth1Signature(const QUrl&=,QOAuth1Signature::HttpRequestMethod=,const QMultiMap<QString,QVariant>&=)
    // 2: QOAuth1Signature::QOAuth1Signature(QUrl,QString,QString,QOAuth1Signature::HttpRequestMethod=,const QMultiMap<QString,QVariant>&=)
    if (numArgs == 0) {
        overloadId = 1; // QOAuth1Signature(QUrl,QOAuth1Signature::HttpRequestMethod,QMultiMap<QString,QVariant>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QOAuth1Signature(QUrl,QOAuth1Signature::HttpRequestMethod,QMultiMap<QString,QVariant>)
        } else if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 2; // QOAuth1Signature(QUrl,QString,QString,QOAuth1Signature::HttpRequestMethod,QMultiMap<QString,QVariant>)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_HttpRequestMethod_IDX])))->converter, (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 2; // QOAuth1Signature(QUrl,QString,QString,QOAuth1Signature::HttpRequestMethod,QMultiMap<QString,QVariant>)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], (pyArgs[4])))) {
                    overloadId = 2; // QOAuth1Signature(QUrl,QString,QString,QOAuth1Signature::HttpRequestMethod,QMultiMap<QString,QVariant>)
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_HttpRequestMethod_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // QOAuth1Signature(QUrl,QOAuth1Signature::HttpRequestMethod,QMultiMap<QString,QVariant>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], (pyArgs[2])))) {
                overloadId = 1; // QOAuth1Signature(QUrl,QOAuth1Signature::HttpRequestMethod,QMultiMap<QString,QVariant>)
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QOAuth1Signature(QOAuth1Signature)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOAuth1Signature(const QOAuth1Signature & other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QOAuth1Signature cppArg0_local;
            ::QOAuth1Signature *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuth1Signature(QOAuth1Signature)
                cptr = new ::QOAuth1Signature(*cppArg0);
            }
            break;
        }
        case 1: // QOAuth1Signature(const QUrl & url, QOAuth1Signature::HttpRequestMethod method, const QMultiMap<QString,QVariant> & parameters)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_url = Shiboken::String::createStaticString("url");
                if (PyDict_Contains(kwds, key_url) != 0) {
                    value = PyDict_GetItem(kwds, key_url);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_url);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_url);
                }
                static PyObject *const key_method = Shiboken::String::createStaticString("method");
                if (PyDict_Contains(kwds, key_method) != 0) {
                    value = PyDict_GetItem(kwds, key_method);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_method);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_HttpRequestMethod_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_method);
                }
                static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
                if (PyDict_Contains(kwds, key_parameters) != 0) {
                    value = PyDict_GetItem(kwds, key_parameters);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_parameters);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_parameters);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0_local = QUrl();
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0]) {
                if (pythonToCpp[0].isValue())
                    pythonToCpp[0](pyArgs[0], &cppArg0_local);
                else
                    pythonToCpp[0](pyArgs[0], &cppArg0);
                }
            ::QOAuth1Signature::HttpRequestMethod cppArg1(QOAuth1Signature::HttpRequestMethod::Post);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QMultiMap<QString,QVariant> cppArg2{};
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuth1Signature(QUrl,QOAuth1Signature::HttpRequestMethod,QMultiMap<QString,QVariant>)
                cptr = new ::QOAuth1Signature(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 2: // QOAuth1Signature(const QUrl & url, const QString & clientSharedKey, const QString & tokenSecret, QOAuth1Signature::HttpRequestMethod method, const QMultiMap<QString,QVariant> & parameters)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_method = Shiboken::String::createStaticString("method");
                if (PyDict_Contains(kwds, key_method) != 0) {
                    value = PyDict_GetItem(kwds, key_method);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_method);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_HttpRequestMethod_IDX])))->converter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_method);
                }
                static PyObject *const key_parameters = Shiboken::String::createStaticString("parameters");
                if (PyDict_Contains(kwds, key_parameters) != 0) {
                    value = PyDict_GetItem(kwds, key_parameters);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_parameters);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], (pyArgs[4]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_parameters);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QOAuth1Signature::HttpRequestMethod cppArg3(QOAuth1Signature::HttpRequestMethod::Post);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QMultiMap<QString,QVariant> cppArg4{};
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOAuth1Signature(QUrl,QString,QString,QOAuth1Signature::HttpRequestMethod,QMultiMap<QString,QVariant>)
                cptr = new ::QOAuth1Signature(*cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOAuth1Signature >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOAuth1SignatureFunc_addRequestBody(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.addRequestBody";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1Signature::addRequestBody(QUrlQuery)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), (pyArg)))) {
        overloadId = 0; // addRequestBody(QUrlQuery)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrlQuery cppArg0_local;
        ::QUrlQuery *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // addRequestBody(QUrlQuery)
            cppSelf->addRequestBody(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1SignatureFunc_clientSharedKey(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.clientSharedKey";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clientSharedKey()const
            QString cppResult = const_cast<const ::QOAuth1Signature *>(cppSelf)->clientSharedKey();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1SignatureFunc_customMethodString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.customMethodString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // customMethodString()const
            QByteArray cppResult = const_cast<const ::QOAuth1Signature *>(cppSelf)->customMethodString();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1SignatureFunc_hmacSha1(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.hmacSha1";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hmacSha1()const
            QByteArray cppResult = const_cast<const ::QOAuth1Signature *>(cppSelf)->hmacSha1();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1SignatureFunc_httpRequestMethod(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.httpRequestMethod";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // httpRequestMethod()const
            QOAuth1Signature::HttpRequestMethod cppResult = const_cast<const ::QOAuth1Signature *>(cppSelf)->httpRequestMethod();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_HttpRequestMethod_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1SignatureFunc_insert(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.insert";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insert", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOAuth1Signature::insert(QString,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // insert(QString,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insert(QString,QVariant)
            cppSelf->insert(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1SignatureFunc_keys(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.keys";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // keys()const
            QList<QString> cppResult = const_cast<const ::QOAuth1Signature *>(cppSelf)->keys();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QList_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1SignatureFunc_parameters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.parameters";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // parameters()const
            QMultiMap<QString,QVariant> cppResult = const_cast<const ::QOAuth1Signature *>(cppSelf)->parameters();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1SignatureFunc_plainText(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    if (!Shiboken::Object::isValid(self))
        return {};
    ::QOAuth1Signature *cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (self)
        cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.plainText";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "plainText", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOAuth1Signature::plainText()const->QByteArray
    // 1: static QOAuth1Signature::plainText(QString,QString)->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // plainText()const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 1; // plainText(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // plainText() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // plainText()const
                QByteArray cppResult = const_cast<const ::QOAuth1Signature *>(cppSelf)->plainText();
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
        case 1: // plainText(const QString & clientSharedSecret, const QString & tokenSecret)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // plainText(QString,QString)
                QByteArray cppResult = ::QOAuth1Signature::plainText(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1SignatureFunc_rsaSha1(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.rsaSha1";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // rsaSha1()const
            QByteArray cppResult = const_cast<const ::QOAuth1Signature *>(cppSelf)->rsaSha1();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1SignatureFunc_setClientSharedKey(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.setClientSharedKey";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1Signature::setClientSharedKey(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setClientSharedKey(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setClientSharedKey(QString)
            cppSelf->setClientSharedKey(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1SignatureFunc_setCustomMethodString(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.setCustomMethodString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1Signature::setCustomMethodString(QByteArray)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // setCustomMethodString(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCustomMethodString(QByteArray)
            cppSelf->setCustomMethodString(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1SignatureFunc_setHttpRequestMethod(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.setHttpRequestMethod";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1Signature::setHttpRequestMethod(QOAuth1Signature::HttpRequestMethod)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_HttpRequestMethod_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setHttpRequestMethod(QOAuth1Signature::HttpRequestMethod)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QOAuth1Signature::HttpRequestMethod cppArg0{QOAuth1Signature::HttpRequestMethod::Unknown};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttpRequestMethod(QOAuth1Signature::HttpRequestMethod)
            cppSelf->setHttpRequestMethod(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1SignatureFunc_setParameters(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.setParameters";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1Signature::setParameters(QMultiMap<QString,QVariant>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNetworkAuthTypeConverters[SBK_QtNetworkAuth_QMultiMap_QString_QVariant_IDX], (pyArg)))) {
        overloadId = 0; // setParameters(QMultiMap<QString,QVariant>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QMultiMap<QString,QVariant> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setParameters(QMultiMap<QString,QVariant>)
            cppSelf->setParameters(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1SignatureFunc_setTokenSecret(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.setTokenSecret";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1Signature::setTokenSecret(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setTokenSecret(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTokenSecret(QString)
            cppSelf->setTokenSecret(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1SignatureFunc_setUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.setUrl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1Signature::setUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUrl(QUrl)
            cppSelf->setUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1SignatureFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1Signature::swap(QOAuth1Signature&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QOAuth1Signature&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QOAuth1Signature cppArg0_local;
        ::QOAuth1Signature *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QOAuth1Signature&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOAuth1SignatureFunc_take(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.take";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOAuth1Signature::take(QString)->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // take(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // take(QString)
            QVariant cppResult = cppSelf->take(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1SignatureFunc_tokenSecret(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.tokenSecret";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // tokenSecret()const
            QString cppResult = const_cast<const ::QOAuth1Signature *>(cppSelf)->tokenSecret();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1SignatureFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.url";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // url()const
            QUrl cppResult = const_cast<const ::QOAuth1Signature *>(cppSelf)->url();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1SignatureFunc_value(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNetworkAuth.QOAuth1Signature.value";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:value", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOAuth1Signature::value(QString,const QVariant&=)const->QVariant
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // value(QString,QVariant)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 0; // value(QString,QVariant)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultValue = Shiboken::String::createStaticString("defaultValue");
            if (PyDict_Contains(kwds, key_defaultValue) != 0) {
                value = PyDict_GetItem(kwds, key_defaultValue);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_defaultValue);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_defaultValue);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1 = QVariant();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // value(QString,QVariant)const
            QVariant cppResult = const_cast<const ::QOAuth1Signature *>(cppSelf)->value(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOAuth1Signature__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyMethodDef Sbk_QOAuth1SignatureMethod_plainText = {"plainText", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_plainText), METH_VARARGS|METH_STATIC, nullptr};


static const char *Sbk_QOAuth1Signature_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QOAuth1Signature_EnumFlagInfo[] = {
    "HttpRequestMethod:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOAuth1Signature_methods[] = {
    {"addRequestBody", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_addRequestBody), METH_O, nullptr},
    {"clientSharedKey", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_clientSharedKey), METH_NOARGS, nullptr},
    {"customMethodString", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_customMethodString), METH_NOARGS, nullptr},
    {"hmacSha1", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_hmacSha1), METH_NOARGS, nullptr},
    {"httpRequestMethod", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_httpRequestMethod), METH_NOARGS, nullptr},
    {"insert", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_insert), METH_VARARGS, nullptr},
    {"keys", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_keys), METH_NOARGS, nullptr},
    {"parameters", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_parameters), METH_NOARGS, nullptr},
    {"plainText", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_plainText), METH_VARARGS|METH_STATIC, nullptr},
    {"rsaSha1", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_rsaSha1), METH_NOARGS, nullptr},
    {"setClientSharedKey", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_setClientSharedKey), METH_O, nullptr},
    {"setCustomMethodString", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_setCustomMethodString), METH_O, nullptr},
    {"setHttpRequestMethod", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_setHttpRequestMethod), METH_O, nullptr},
    {"setParameters", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_setParameters), METH_O, nullptr},
    {"setTokenSecret", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_setTokenSecret), METH_O, nullptr},
    {"setUrl", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_setUrl), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_swap), METH_O, nullptr},
    {"take", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_take), METH_O, nullptr},
    {"tokenSecret", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_tokenSecret), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_url), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QOAuth1SignatureFunc_value), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QOAuth1Signature__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QOAuth1Signature_getattro(PyObject *self, PyObject *name)
{
    PySide::Feature::Select(self);
    // Search the method in the instance dict
    auto *ob_dict = SbkObject_GetDict_NoRef(self);
    if (auto *meth = PyDict_GetItem(ob_dict, name)) {
        Py_INCREF(meth);
        return meth;
    }
    // Search the method in the type dict
    if (Shiboken::Object::isUserType(self)) {
        Shiboken::AutoDecRef tmp(_Pep_PrivateMangle(self, name));
        Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
        if (auto *meth = PyDict_GetItem(tpDict.object(), tmp)) {
            if (std::strcmp(Py_TYPE(meth)->tp_name, "compiled_function") == 0) {
                auto descrGetFunc = reinterpret_cast<descrgetfunc>(PepType_GetSlot(Py_TYPE(meth), Py_tp_descr_get));
                ;
                return descrGetFunc(meth, self, nullptr);
            }
            return PyFunction_Check(meth) ? PyMethod_New(meth, self)
                                          : PyObject_GenericGetAttr(self, name);
        }
    }
    static PyMethodDef non_static_Sbk_QOAuth1SignatureMethod_plainText = {
        Sbk_QOAuth1SignatureMethod_plainText.ml_name,
        Sbk_QOAuth1SignatureMethod_plainText.ml_meth,
        Sbk_QOAuth1SignatureMethod_plainText.ml_flags & (~METH_STATIC),
        Sbk_QOAuth1SignatureMethod_plainText.ml_doc,
    };
    if (Shiboken::String::compare(name, "plainText") == 0)
        return PyCFunction_NewEx(&non_static_Sbk_QOAuth1SignatureMethod_plainText, self, 0);
    return PyObject_GenericGetAttr(self, name);
}

} // extern "C"

static int Sbk_QOAuth1Signature_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOAuth1Signature_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOAuth1Signature_Type = nullptr;
static PyTypeObject *Sbk_QOAuth1Signature_TypeF(void)
{
    return _Sbk_QOAuth1Signature_Type;
}

static PyType_Slot Sbk_QOAuth1Signature_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_getattro,    reinterpret_cast<void *>(Sbk_QOAuth1Signature_getattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOAuth1Signature_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOAuth1Signature_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOAuth1Signature_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOAuth1Signature_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOAuth1Signature_spec = {
    "2:PySide6.QtNetworkAuth.QOAuth1Signature",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOAuth1Signature_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QOAuth1Signature_HttpRequestMethod_PythonToCpp_QOAuth1Signature_HttpRequestMethod(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOAuth1Signature::HttpRequestMethod>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOAuth1Signature::HttpRequestMethod *>(cppOut) = value;

}
static PythonToCppFunc is_QOAuth1Signature_HttpRequestMethod_PythonToCpp_QOAuth1Signature_HttpRequestMethod_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_HttpRequestMethod_IDX])))
        return QOAuth1Signature_HttpRequestMethod_PythonToCpp_QOAuth1Signature_HttpRequestMethod;
    return {};
}
static PyObject *QOAuth1Signature_HttpRequestMethod_CppToPython_QOAuth1Signature_HttpRequestMethod(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOAuth1Signature::HttpRequestMethod *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_HttpRequestMethod_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOAuth1Signature_PythonToCpp_QOAuth1Signature_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOAuth1Signature_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOAuth1Signature_PythonToCpp_QOAuth1Signature_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOAuth1Signature_TypeF()))
        return QOAuth1Signature_PythonToCpp_QOAuth1Signature_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOAuth1Signature_PTR_CppToPython_QOAuth1Signature(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QOAuth1Signature *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QOAuth1Signature_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QOAuth1Signature_COPY_CppToPython_QOAuth1Signature(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QOAuth1Signature *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QOAuth1Signature_TypeF(), new ::QOAuth1Signature(*source), true, true);
}

// Python to C++ copy conversion.
static void QOAuth1Signature_PythonToCpp_QOAuth1Signature_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QOAuth1Signature *>(cppOut) = *reinterpret_cast< ::QOAuth1Signature *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QOAuth1Signature_PythonToCpp_QOAuth1Signature_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QOAuth1Signature_TypeF()))
        return QOAuth1Signature_PythonToCpp_QOAuth1Signature_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QOAuth1Signature_SignatureStrings[] = {
    "2:PySide6.QtNetworkAuth.QOAuth1Signature(self,other:PySide6.QtNetworkAuth.QOAuth1Signature)",
    "1:PySide6.QtNetworkAuth.QOAuth1Signature(self,url:typing.Union[PySide6.QtCore.QUrl, QString]=QUrl(),method:PySide6.QtNetworkAuth.QOAuth1Signature.HttpRequestMethod=QOAuth1Signature.HttpRequestMethod.Post,parameters:QMultiMap[QString, QVariant]={})",
    "0:PySide6.QtNetworkAuth.QOAuth1Signature(self,url:typing.Union[PySide6.QtCore.QUrl, QString],clientSharedKey:QString,tokenSecret:QString,method:PySide6.QtNetworkAuth.QOAuth1Signature.HttpRequestMethod=QOAuth1Signature.HttpRequestMethod.Post,parameters:QMultiMap[QString, QVariant]={})",
    "PySide6.QtNetworkAuth.QOAuth1Signature.addRequestBody(self,body:PySide6.QtCore.QUrlQuery)",
    "PySide6.QtNetworkAuth.QOAuth1Signature.clientSharedKey(self)->QString",
    "PySide6.QtNetworkAuth.QOAuth1Signature.customMethodString(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetworkAuth.QOAuth1Signature.hmacSha1(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetworkAuth.QOAuth1Signature.httpRequestMethod(self)->PySide6.QtNetworkAuth.QOAuth1Signature.HttpRequestMethod",
    "PySide6.QtNetworkAuth.QOAuth1Signature.insert(self,key:QString,value:QVariant)",
    "PySide6.QtNetworkAuth.QOAuth1Signature.keys(self)->QList[QString]",
    "PySide6.QtNetworkAuth.QOAuth1Signature.parameters(self)->QMultiMap[QString, QVariant]",
    "1:PySide6.QtNetworkAuth.QOAuth1Signature.plainText(self)->PySide6.QtCore.QByteArray",
    "0:PySide6.QtNetworkAuth.QOAuth1Signature.plainText(clientSharedSecret:QString,tokenSecret:QString)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetworkAuth.QOAuth1Signature.rsaSha1(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNetworkAuth.QOAuth1Signature.setClientSharedKey(self,secret:QString)",
    "PySide6.QtNetworkAuth.QOAuth1Signature.setCustomMethodString(self,verb:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "PySide6.QtNetworkAuth.QOAuth1Signature.setHttpRequestMethod(self,method:PySide6.QtNetworkAuth.QOAuth1Signature.HttpRequestMethod)",
    "PySide6.QtNetworkAuth.QOAuth1Signature.setParameters(self,parameters:QMultiMap[QString, QVariant])",
    "PySide6.QtNetworkAuth.QOAuth1Signature.setTokenSecret(self,secret:QString)",
    "PySide6.QtNetworkAuth.QOAuth1Signature.setUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtNetworkAuth.QOAuth1Signature.swap(self,other:PySide6.QtNetworkAuth.QOAuth1Signature)",
    "PySide6.QtNetworkAuth.QOAuth1Signature.take(self,key:QString)->QVariant",
    "PySide6.QtNetworkAuth.QOAuth1Signature.tokenSecret(self)->QString",
    "PySide6.QtNetworkAuth.QOAuth1Signature.url(self)->PySide6.QtCore.QUrl",
    "PySide6.QtNetworkAuth.QOAuth1Signature.value(self,key:QString,defaultValue:QVariant=QVariant())->QVariant",
    "PySide6.QtNetworkAuth.QOAuth1Signature.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QOAuth1Signature(PyObject *module)
{
    if (SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX].type != nullptr)
        return SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX].type;

    Shiboken::AutoDecRef Sbk_QOAuth1Signature_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QOAuth1Signature_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOAuth1Signature",
        "QOAuth1Signature",
        &Sbk_QOAuth1Signature_spec,
        &Shiboken::callCppDestructor< ::QOAuth1Signature >,
        Sbk_QOAuth1Signature_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QOAuth1Signature_TypeF(); // references _Sbk_QOAuth1Signature_Type
    InitSignatureStrings(pyType, QOAuth1Signature_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOAuth1Signature_PropertyStrings);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOAuth1Signature_PythonToCpp_QOAuth1Signature_PTR,
        is_QOAuth1Signature_PythonToCpp_QOAuth1Signature_PTR_Convertible,
        QOAuth1Signature_PTR_CppToPython_QOAuth1Signature,
        QOAuth1Signature_COPY_CppToPython_QOAuth1Signature);

    Shiboken::Conversions::registerConverterName(converter, "QOAuth1Signature");
    Shiboken::Conversions::registerConverterName(converter, "QOAuth1Signature*");
    Shiboken::Conversions::registerConverterName(converter, "QOAuth1Signature&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOAuth1Signature).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QOAuth1Signature_PythonToCpp_QOAuth1Signature_COPY,
        is_QOAuth1Signature_PythonToCpp_QOAuth1Signature_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QOAuth1Signature_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'HttpRequestMethod'.
    const char *HttpRequestMethod_Initializer[] = {
        "Head",
        "Get",
        "Put",
        "Post",
        "Delete",
        "Custom",
        "Unknown",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t HttpRequestMethod_InitializerValues[] = {
        int8_t(QOAuth1Signature::HttpRequestMethod::Head),   //  0x01  1
        int8_t(QOAuth1Signature::HttpRequestMethod::Get),    //  0x02  2
        int8_t(QOAuth1Signature::HttpRequestMethod::Put),    //  0x03  3
        int8_t(QOAuth1Signature::HttpRequestMethod::Post),   //  0x04  4
        int8_t(QOAuth1Signature::HttpRequestMethod::Delete), //  0x05  5
        int8_t(QOAuth1Signature::HttpRequestMethod::Custom), //  0x06  6
        int8_t(QOAuth1Signature::HttpRequestMethod::Unknown) //  0x00  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOAuth1Signature_TypeF(),
        "2:PySide6.QtNetworkAuth.QOAuth1Signature.HttpRequestMethod",
        HttpRequestMethod_Initializer, HttpRequestMethod_InitializerValues);
    SbkPySide6_QtNetworkAuthTypeStructs[SBK_QOAuth1Signature_HttpRequestMethod_IDX].type = EType;
    // Register converter for enum 'QOAuth1Signature::HttpRequestMethod'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOAuth1Signature_HttpRequestMethod_CppToPython_QOAuth1Signature_HttpRequestMethod);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOAuth1Signature_HttpRequestMethod_PythonToCpp_QOAuth1Signature_HttpRequestMethod,
            is_QOAuth1Signature_HttpRequestMethod_PythonToCpp_QOAuth1Signature_HttpRequestMethod_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOAuth1Signature::HttpRequestMethod");
        Shiboken::Conversions::registerConverterName(converter, "HttpRequestMethod");
    }
    // End of 'HttpRequestMethod' enum.

    qRegisterMetaType< ::QOAuth1Signature >("QOAuth1Signature");
    qRegisterMetaType< ::QOAuth1Signature::HttpRequestMethod >("QOAuth1Signature::HttpRequestMethod");

    return pyType;
}
