// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnfc_python.h"

// main header
#include "qnearfieldtarget_wrapper.h"

// inner classes
#include "qnearfieldtarget_requestid_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtNfc/qndefmessage.h>
#include <QtNfc/qnearfieldtarget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QNearFieldTargetWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QNearFieldTargetWrapper::QNearFieldTargetWrapper(::QObject * parent) : QNearFieldTarget(parent)
{
    resetPyMethodCache();
    // ... middle
}

void QNearFieldTargetWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QNearFieldTargetWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QNearFieldTargetWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QNearFieldTargetWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QNearFieldTargetWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNearFieldTarget", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QNearFieldTargetWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QNearFieldTarget", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QNearFieldTargetWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

const QMetaObject *QNearFieldTargetWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QNearFieldTarget::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QNearFieldTargetWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QNearFieldTarget::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QNearFieldTargetWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QNearFieldTargetWrapper *>(this));
    return QNearFieldTarget::qt_metacast(_clname);
}

QNearFieldTargetWrapper::~QNearFieldTargetWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNearFieldTarget_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QNearFieldTarget >()))
        return -1;

    QNearFieldTargetWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNearFieldTarget.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QNearFieldTarget", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QNearFieldTarget::QNearFieldTarget(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QNearFieldTarget(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QNearFieldTarget(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QNearFieldTarget(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QNearFieldTargetWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QNearFieldTargetWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QNearFieldTarget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    };


    return 1;
}

static PyObject *Sbk_QNearFieldTargetFunc_accessMethods(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNearFieldTarget.accessMethods";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // accessMethods()const
            QFlags<QNearFieldTarget::AccessMethod> cppResult = const_cast<const ::QNearFieldTarget *>(cppSelf)->accessMethods();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QFlags_QNearFieldTarget_AccessMethod_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNearFieldTargetFunc_disconnect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNearFieldTarget.disconnect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // disconnect()
            bool cppResult = cppSelf->disconnect();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNearFieldTargetFunc_hasNdefMessage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNearFieldTarget.hasNdefMessage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasNdefMessage()
            bool cppResult = cppSelf->hasNdefMessage();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNearFieldTargetFunc_maxCommandLength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNearFieldTarget.maxCommandLength";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maxCommandLength()const
            int cppResult = const_cast<const ::QNearFieldTarget *>(cppSelf)->maxCommandLength();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNearFieldTargetFunc_readNdefMessages(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNearFieldTarget.readNdefMessages";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // readNdefMessages()
            QNearFieldTarget::RequestId cppResult = cppSelf->readNdefMessages();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_RequestId_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNearFieldTargetFunc_requestResponse(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNearFieldTarget.requestResponse";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNearFieldTarget::requestResponse(QNearFieldTarget::RequestId)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_RequestId_IDX]), (pyArg)))) {
        overloadId = 0; // requestResponse(QNearFieldTarget::RequestId)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNearFieldTarget::RequestId cppArg0_local;
        ::QNearFieldTarget::RequestId *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // requestResponse(QNearFieldTarget::RequestId)const
            QVariant cppResult = const_cast<const ::QNearFieldTarget *>(cppSelf)->requestResponse(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNearFieldTargetFunc_sendCommand(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNearFieldTarget.sendCommand";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNearFieldTarget::sendCommand(QByteArray)->QNearFieldTarget::RequestId
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // sendCommand(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // sendCommand(QByteArray)
            QNearFieldTarget::RequestId cppResult = cppSelf->sendCommand(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_RequestId_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNearFieldTargetFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNearFieldTarget.type";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // type()const
            QNearFieldTarget::Type cppResult = const_cast<const ::QNearFieldTarget *>(cppSelf)->type();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_Type_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNearFieldTargetFunc_uid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtNfc.QNearFieldTarget.uid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // uid()const
            QByteArray cppResult = const_cast<const ::QNearFieldTarget *>(cppSelf)->uid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNearFieldTargetFunc_waitForRequestCompleted(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNearFieldTarget.waitForRequestCompleted";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:waitForRequestCompleted", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QNearFieldTarget::waitForRequestCompleted(QNearFieldTarget::RequestId,int=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_RequestId_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // waitForRequestCompleted(QNearFieldTarget::RequestId,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // waitForRequestCompleted(QNearFieldTarget::RequestId,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_msecs = Shiboken::String::createStaticString("msecs");
            if (PyDict_Contains(kwds, key_msecs) != 0) {
                value = PyDict_GetItem(kwds, key_msecs);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_msecs);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_msecs);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QNearFieldTarget::RequestId cppArg0_local;
        ::QNearFieldTarget::RequestId *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1 = 5000;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForRequestCompleted(QNearFieldTarget::RequestId,int)
            bool cppResult = cppSelf->waitForRequestCompleted(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QNearFieldTargetFunc_writeNdefMessages(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QNearFieldTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtNfc.QNearFieldTarget.writeNdefMessages";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QNearFieldTarget::writeNdefMessages(QList<QNdefMessage>)->QNearFieldTarget::RequestId
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtNfcTypeConverters[SBK_QtNfc_QList_QNdefMessage_IDX], (pyArg)))) {
        overloadId = 0; // writeNdefMessages(QList<QNdefMessage>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QNdefMessage> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeNdefMessages(QList<QNdefMessage>)
            QNearFieldTarget::RequestId cppResult = cppSelf->writeNdefMessages(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_RequestId_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QNearFieldTarget_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QNearFieldTarget_EnumFlagInfo[] = {
    "AccessMethod:Flag:AccessMethods",
    "Error:Enum",
    "Type:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QNearFieldTarget_methods[] = {
    {"accessMethods", reinterpret_cast<PyCFunction>(Sbk_QNearFieldTargetFunc_accessMethods), METH_NOARGS, nullptr},
    {"disconnect", reinterpret_cast<PyCFunction>(Sbk_QNearFieldTargetFunc_disconnect), METH_NOARGS, nullptr},
    {"hasNdefMessage", reinterpret_cast<PyCFunction>(Sbk_QNearFieldTargetFunc_hasNdefMessage), METH_NOARGS, nullptr},
    {"maxCommandLength", reinterpret_cast<PyCFunction>(Sbk_QNearFieldTargetFunc_maxCommandLength), METH_NOARGS, nullptr},
    {"readNdefMessages", reinterpret_cast<PyCFunction>(Sbk_QNearFieldTargetFunc_readNdefMessages), METH_NOARGS, nullptr},
    {"requestResponse", reinterpret_cast<PyCFunction>(Sbk_QNearFieldTargetFunc_requestResponse), METH_O, nullptr},
    {"sendCommand", reinterpret_cast<PyCFunction>(Sbk_QNearFieldTargetFunc_sendCommand), METH_O, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QNearFieldTargetFunc_type), METH_NOARGS, nullptr},
    {"uid", reinterpret_cast<PyCFunction>(Sbk_QNearFieldTargetFunc_uid), METH_NOARGS, nullptr},
    {"waitForRequestCompleted", reinterpret_cast<PyCFunction>(Sbk_QNearFieldTargetFunc_waitForRequestCompleted), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"writeNdefMessages", reinterpret_cast<PyCFunction>(Sbk_QNearFieldTargetFunc_writeNdefMessages), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QNearFieldTarget_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QNearFieldTarget *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QNearFieldTargetWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QNearFieldTarget_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QNearFieldTarget_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QNearFieldTarget_Type = nullptr;
static PyTypeObject *Sbk_QNearFieldTarget_TypeF(void)
{
    return _Sbk_QNearFieldTarget_Type;
}

static PyType_Slot Sbk_QNearFieldTarget_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QNearFieldTarget_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QNearFieldTarget_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QNearFieldTarget_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QNearFieldTarget_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QNearFieldTarget_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QNearFieldTarget_spec = {
    "2:PySide6.QtNfc.QNearFieldTarget",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QNearFieldTarget_slots
};

} //extern "C"

static void *Sbk_QNearFieldTarget_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QNearFieldTarget *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QNearFieldTarget_Type_PythonToCpp_QNearFieldTarget_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNearFieldTarget::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNearFieldTarget::Type *>(cppOut) = value;

}
static PythonToCppFunc is_QNearFieldTarget_Type_PythonToCpp_QNearFieldTarget_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_Type_IDX])))
        return QNearFieldTarget_Type_PythonToCpp_QNearFieldTarget_Type;
    return {};
}
static PyObject *QNearFieldTarget_Type_CppToPython_QNearFieldTarget_Type(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QNearFieldTarget::Type *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_Type_IDX]), castCppIn);

}

static void QNearFieldTarget_AccessMethod_PythonToCpp_QNearFieldTarget_AccessMethod(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNearFieldTarget::AccessMethod>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNearFieldTarget::AccessMethod *>(cppOut) = value;

}
static PythonToCppFunc is_QNearFieldTarget_AccessMethod_PythonToCpp_QNearFieldTarget_AccessMethod_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_AccessMethod_IDX])))
        return QNearFieldTarget_AccessMethod_PythonToCpp_QNearFieldTarget_AccessMethod;
    return {};
}
static PyObject *QNearFieldTarget_AccessMethod_CppToPython_QNearFieldTarget_AccessMethod(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QNearFieldTarget::AccessMethod *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_AccessMethod_IDX]), castCppIn);

}

static void QNearFieldTarget_Error_PythonToCpp_QNearFieldTarget_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QNearFieldTarget::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QNearFieldTarget::Error *>(cppOut) = value;

}
static PythonToCppFunc is_QNearFieldTarget_Error_PythonToCpp_QNearFieldTarget_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_Error_IDX])))
        return QNearFieldTarget_Error_PythonToCpp_QNearFieldTarget_Error;
    return {};
}
static PyObject *QNearFieldTarget_Error_CppToPython_QNearFieldTarget_Error(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QNearFieldTarget::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_Error_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QNearFieldTarget_PythonToCpp_QNearFieldTarget_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QNearFieldTarget_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QNearFieldTarget_PythonToCpp_QNearFieldTarget_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QNearFieldTarget_TypeF()))
        return QNearFieldTarget_PythonToCpp_QNearFieldTarget_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QNearFieldTarget_PTR_CppToPython_QNearFieldTarget(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QNearFieldTarget *>(const_cast<void *>(cppIn)), Sbk_QNearFieldTarget_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QNearFieldTarget_SignatureStrings[] = {
    "PySide6.QtNfc.QNearFieldTarget(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtNfc.QNearFieldTarget.accessMethods(self)->PySide6.QtNfc.QNearFieldTarget.AccessMethod",
    "PySide6.QtNfc.QNearFieldTarget.disconnect(self)->bool",
    "PySide6.QtNfc.QNearFieldTarget.hasNdefMessage(self)->bool",
    "PySide6.QtNfc.QNearFieldTarget.maxCommandLength(self)->int",
    "PySide6.QtNfc.QNearFieldTarget.readNdefMessages(self)->PySide6.QtNfc.QNearFieldTarget.RequestId",
    "PySide6.QtNfc.QNearFieldTarget.requestResponse(self,id:PySide6.QtNfc.QNearFieldTarget.RequestId)->QVariant",
    "PySide6.QtNfc.QNearFieldTarget.sendCommand(self,command:typing.Union[PySide6.QtCore.QByteArray, char*])->PySide6.QtNfc.QNearFieldTarget.RequestId",
    "PySide6.QtNfc.QNearFieldTarget.type(self)->PySide6.QtNfc.QNearFieldTarget.Type",
    "PySide6.QtNfc.QNearFieldTarget.uid(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtNfc.QNearFieldTarget.waitForRequestCompleted(self,id:PySide6.QtNfc.QNearFieldTarget.RequestId,msecs:int=5000)->bool",
    "PySide6.QtNfc.QNearFieldTarget.writeNdefMessages(self,messages:QList[PySide6.QtNfc.QNdefMessage])->PySide6.QtNfc.QNearFieldTarget.RequestId",
    nullptr}; // Sentinel

PyTypeObject *init_QNearFieldTarget(PyObject *module)
{
    if (SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX].type != nullptr)
        return SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX].type;

    Shiboken::AutoDecRef Sbk_QNearFieldTarget_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QNearFieldTarget_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QNearFieldTarget",
        "QNearFieldTarget*",
        &Sbk_QNearFieldTarget_spec,
        &Shiboken::callCppDestructor< QNearFieldTarget >,
        Sbk_QNearFieldTarget_Type_bases.object(),
        0);
    auto *pyType = Sbk_QNearFieldTarget_TypeF(); // references _Sbk_QNearFieldTarget_Type
    InitSignatureStrings(pyType, QNearFieldTarget_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QNearFieldTarget_PropertyStrings);
    SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QNearFieldTarget_PythonToCpp_QNearFieldTarget_PTR,
        is_QNearFieldTarget_PythonToCpp_QNearFieldTarget_PTR_Convertible,
        QNearFieldTarget_PTR_CppToPython_QNearFieldTarget);

    Shiboken::Conversions::registerConverterName(converter, "QNearFieldTarget");
    Shiboken::Conversions::registerConverterName(converter, "QNearFieldTarget*");
    Shiboken::Conversions::registerConverterName(converter, "QNearFieldTarget&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QNearFieldTarget).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QNearFieldTargetWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QNearFieldTarget_TypeF(), &Sbk_QNearFieldTarget_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QNearFieldTarget_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "ProprietaryTag",
        "NfcTagType1",
        "NfcTagType2",
        "NfcTagType3",
        "NfcTagType4",
        "NfcTagType4A",
        "NfcTagType4B",
        "MifareTag",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(QNearFieldTarget::Type::ProprietaryTag), //  0x00  0
        uint8_t(QNearFieldTarget::Type::NfcTagType1),    //  0x01  1
        uint8_t(QNearFieldTarget::Type::NfcTagType2),    //  0x02  2
        uint8_t(QNearFieldTarget::Type::NfcTagType3),    //  0x03  3
        uint8_t(QNearFieldTarget::Type::NfcTagType4),    //  0x04  4
        uint8_t(QNearFieldTarget::Type::NfcTagType4A),   //  0x05  5
        uint8_t(QNearFieldTarget::Type::NfcTagType4B),   //  0x06  6
        uint8_t(QNearFieldTarget::Type::MifareTag)       //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNearFieldTarget_TypeF(),
        "2:PySide6.QtNfc.QNearFieldTarget.Type",
        Type_Initializer, Type_InitializerValues);
    SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_Type_IDX].type = EType;
    // Register converter for enum 'QNearFieldTarget::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNearFieldTarget_Type_CppToPython_QNearFieldTarget_Type);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QNearFieldTarget_Type_PythonToCpp_QNearFieldTarget_Type,
            is_QNearFieldTarget_Type_PythonToCpp_QNearFieldTarget_Type_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QNearFieldTarget::Type");
        Shiboken::Conversions::registerConverterName(converter, "Type");
    }
    // End of 'Type' enum.

    // Initialization of enum 'AccessMethod'.
    const char *AccessMethod_Initializer[] = {
        "UnknownAccess",
        "NdefAccess",
        "TagTypeSpecificAccess",
        "AnyAccess",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AccessMethod_InitializerValues[] = {
        uint8_t(QNearFieldTarget::AccessMethod::UnknownAccess),         //  0x00  0
        uint8_t(QNearFieldTarget::AccessMethod::NdefAccess),            //  0x01  1
        uint8_t(QNearFieldTarget::AccessMethod::TagTypeSpecificAccess), //  0x02  2
        uint8_t(QNearFieldTarget::AccessMethod::AnyAccess)              //  0xff  255
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNearFieldTarget_TypeF(),
        "2:PySide6.QtNfc.QNearFieldTarget.AccessMethod",
        AccessMethod_Initializer, AccessMethod_InitializerValues);
    SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_AccessMethod_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtNfcTypeStructs[SBK_QFlags_QNearFieldTarget_AccessMethod_IDX].type =
        EType;
    // Register converter for enum 'QNearFieldTarget::AccessMethod'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNearFieldTarget_AccessMethod_CppToPython_QNearFieldTarget_AccessMethod);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QNearFieldTarget_AccessMethod_PythonToCpp_QNearFieldTarget_AccessMethod,
            is_QNearFieldTarget_AccessMethod_PythonToCpp_QNearFieldTarget_AccessMethod_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QNearFieldTarget::AccessMethod");
        Shiboken::Conversions::registerConverterName(converter, "AccessMethod");
        // Register converter for flag 'QFlags<QNearFieldTarget::AccessMethod>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QNearFieldTarget::AccessMethod>");
        Shiboken::Conversions::registerConverterName(converter, "QNearFieldTarget::AccessMethods");
    }
    // End of 'AccessMethod' enum/flags.

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "NoError",
        "UnknownError",
        "UnsupportedError",
        "TargetOutOfRangeError",
        "NoResponseError",
        "ChecksumMismatchError",
        "InvalidParametersError",
        "ConnectionError",
        "NdefReadError",
        "NdefWriteError",
        "CommandError",
        "TimeoutError",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QNearFieldTarget::Error::NoError),                //  0x00  0
        uint8_t(QNearFieldTarget::Error::UnknownError),           //  0x01  1
        uint8_t(QNearFieldTarget::Error::UnsupportedError),       //  0x02  2
        uint8_t(QNearFieldTarget::Error::TargetOutOfRangeError),  //  0x03  3
        uint8_t(QNearFieldTarget::Error::NoResponseError),        //  0x04  4
        uint8_t(QNearFieldTarget::Error::ChecksumMismatchError),  //  0x05  5
        uint8_t(QNearFieldTarget::Error::InvalidParametersError), //  0x06  6
        uint8_t(QNearFieldTarget::Error::ConnectionError),        //  0x07  7
        uint8_t(QNearFieldTarget::Error::NdefReadError),          //  0x08  8
        uint8_t(QNearFieldTarget::Error::NdefWriteError),         //  0x09  9
        uint8_t(QNearFieldTarget::Error::CommandError),           //  0x0a  10
        uint8_t(QNearFieldTarget::Error::TimeoutError)            //  0x0b  11
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QNearFieldTarget_TypeF(),
        "2:PySide6.QtNfc.QNearFieldTarget.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtNfcTypeStructs[SBK_QNearFieldTarget_Error_IDX].type = EType;
    // Register converter for enum 'QNearFieldTarget::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QNearFieldTarget_Error_CppToPython_QNearFieldTarget_Error);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QNearFieldTarget_Error_PythonToCpp_QNearFieldTarget_Error,
            is_QNearFieldTarget_Error_PythonToCpp_QNearFieldTarget_Error_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QNearFieldTarget::Error");
        Shiboken::Conversions::registerConverterName(converter, "Error");
    }
    // End of 'Error' enum.

    PySide::Signal::registerSignals(pyType, &::QNearFieldTarget::staticMetaObject);
    qRegisterMetaType< ::QNearFieldTarget::Type >("QNearFieldTarget::Type");
    qRegisterMetaType< ::QNearFieldTarget::AccessMethod >("QNearFieldTarget::AccessMethod");
    qRegisterMetaType< ::QNearFieldTarget::Error >("QNearFieldTarget::Error");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QNearFieldTarget::staticMetaObject, sizeof(QNearFieldTargetWrapper));

    return pyType;
}
