// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qopengltextureblitter_wrapper.h"

// Argument includes
#include <QtGui/qgenericmatrix.h>
#include <QtGui/qmatrix4x4.h>
#include <QtOpenGL/qopengltextureblitter.h>
#include <qrect.h>
#include <qsize.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOpenGLTextureBlitter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOpenGLTextureBlitter >()))
        return -1;

    ::QOpenGLTextureBlitter *cptr{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTextureBlitter.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QOpenGLTextureBlitter()
            cptr = new ::QOpenGLTextureBlitter();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOpenGLTextureBlitter >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_bind(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTextureBlitter.bind";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:bind", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTextureBlitter::bind(uint=)
    if (numArgs == 0) {
        overloadId = 0; // bind(uint)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))) {
        overloadId = 0; // bind(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_target = Shiboken::String::createStaticString("target");
            if (PyDict_Contains(kwds, key_target) != 0) {
                value = PyDict_GetItem(kwds, key_target);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_target);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_target);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        unsigned int cppArg0 = GL_TEXTURE_2D;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // bind(uint)
            cppSelf->bind(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_blit(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTextureBlitter.blit";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "blit", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTextureBlitter::blit(uint,QMatrix4x4,QOpenGLTextureBlitter::Origin)
    // 1: QOpenGLTextureBlitter::blit(uint,QMatrix4x4,QMatrix3x3)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), (pyArgs[1])))) {
        if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x3_IDX]), (pyArgs[2])))) {
            overloadId = 1; // blit(uint,QMatrix4x4,QMatrix3x3)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_Origin_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 0; // blit(uint,QMatrix4x4,QOpenGLTextureBlitter::Origin)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // blit(unsigned int texture, const QMatrix4x4 & targetTransform, QOpenGLTextureBlitter::Origin sourceOrigin)
        {
            unsigned int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix4x4 cppArg1_local;
            ::QMatrix4x4 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QOpenGLTextureBlitter::Origin cppArg2{QOpenGLTextureBlitter::OriginBottomLeft};
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // blit(uint,QMatrix4x4,QOpenGLTextureBlitter::Origin)
                cppSelf->blit(cppArg0, *cppArg1, cppArg2);
            }
            break;
        }
        case 1: // blit(unsigned int texture, const QMatrix4x4 & targetTransform, const QMatrix3x3 & sourceTransform)
        {
            unsigned int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMatrix4x4 cppArg1_local;
            ::QMatrix4x4 *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QMatrix3x3 cppArg2_local;
            ::QMatrix3x3 *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // blit(uint,QMatrix4x4,QMatrix3x3)
                cppSelf->blit(cppArg0, *cppArg1, *cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTextureBlitter.create";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // create()
            bool cppResult = cppSelf->create();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_destroy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTextureBlitter.destroy";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // destroy()
            cppSelf->destroy();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_isCreated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTextureBlitter.isCreated";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isCreated()const
            bool cppResult = const_cast<const ::QOpenGLTextureBlitter *>(cppSelf)->isCreated();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_release(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTextureBlitter.release";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // release()
            cppSelf->release();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_setOpacity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTextureBlitter.setOpacity";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTextureBlitter::setOpacity(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setOpacity(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOpacity(float)
            cppSelf->setOpacity(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_setRedBlueSwizzle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTextureBlitter.setRedBlueSwizzle";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTextureBlitter::setRedBlueSwizzle(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setRedBlueSwizzle(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRedBlueSwizzle(bool)
            cppSelf->setRedBlueSwizzle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_sourceTransform(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTextureBlitter.sourceTransform";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sourceTransform", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QOpenGLTextureBlitter::sourceTransform(QRectF,QSize,QOpenGLTextureBlitter::Origin)->QMatrix3x3
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_Origin_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 0; // sourceTransform(QRectF,QSize,QOpenGLTextureBlitter::Origin)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSize cppArg1_local;
        ::QSize *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        ::QOpenGLTextureBlitter::Origin cppArg2{QOpenGLTextureBlitter::OriginBottomLeft};
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sourceTransform(QRectF,QSize,QOpenGLTextureBlitter::Origin)
            QMatrix3x3 cppResult = ::QOpenGLTextureBlitter::sourceTransform(*cppArg0, *cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix3x3_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_supportsExternalOESTarget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTextureBlitter.supportsExternalOESTarget";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportsExternalOESTarget()const
            bool cppResult = const_cast<const ::QOpenGLTextureBlitter *>(cppSelf)->supportsExternalOESTarget();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_supportsRectangleTarget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTextureBlitter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTextureBlitter.supportsRectangleTarget";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportsRectangleTarget()const
            bool cppResult = const_cast<const ::QOpenGLTextureBlitter *>(cppSelf)->supportsRectangleTarget();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureBlitterFunc_targetTransform(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTextureBlitter.targetTransform";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "targetTransform", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QOpenGLTextureBlitter::targetTransform(QRectF,QRect)->QMatrix4x4
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))) {
        overloadId = 0; // targetTransform(QRectF,QRect)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRect cppArg1_local;
        ::QRect *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // targetTransform(QRectF,QRect)
            QMatrix4x4 cppResult = ::QOpenGLTextureBlitter::targetTransform(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMatrix4x4_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QOpenGLTextureBlitter_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QOpenGLTextureBlitter_EnumFlagInfo[] = {
    "Origin:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLTextureBlitter_methods[] = {
    {"bind", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_bind), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"blit", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_blit), METH_VARARGS, nullptr},
    {"create", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_create), METH_NOARGS, nullptr},
    {"destroy", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_destroy), METH_NOARGS, nullptr},
    {"isCreated", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_isCreated), METH_NOARGS, nullptr},
    {"release", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_release), METH_NOARGS, nullptr},
    {"setOpacity", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_setOpacity), METH_O, nullptr},
    {"setRedBlueSwizzle", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_setRedBlueSwizzle), METH_O, nullptr},
    {"sourceTransform", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_sourceTransform), METH_VARARGS|METH_STATIC, nullptr},
    {"supportsExternalOESTarget", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_supportsExternalOESTarget), METH_NOARGS, nullptr},
    {"supportsRectangleTarget", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_supportsRectangleTarget), METH_NOARGS, nullptr},
    {"targetTransform", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureBlitterFunc_targetTransform), METH_VARARGS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QOpenGLTextureBlitter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOpenGLTextureBlitter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOpenGLTextureBlitter_Type = nullptr;
static PyTypeObject *Sbk_QOpenGLTextureBlitter_TypeF(void)
{
    return _Sbk_QOpenGLTextureBlitter_Type;
}

static PyType_Slot Sbk_QOpenGLTextureBlitter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLTextureBlitter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLTextureBlitter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLTextureBlitter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLTextureBlitter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLTextureBlitter_spec = {
    "2:PySide6.QtOpenGL.QOpenGLTextureBlitter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLTextureBlitter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QOpenGLTextureBlitter_Origin_PythonToCpp_QOpenGLTextureBlitter_Origin(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTextureBlitter::Origin>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTextureBlitter::Origin *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTextureBlitter_Origin_PythonToCpp_QOpenGLTextureBlitter_Origin_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_Origin_IDX])))
        return QOpenGLTextureBlitter_Origin_PythonToCpp_QOpenGLTextureBlitter_Origin;
    return {};
}
static PyObject *QOpenGLTextureBlitter_Origin_CppToPython_QOpenGLTextureBlitter_Origin(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTextureBlitter::Origin *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_Origin_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOpenGLTextureBlitter_PythonToCpp_QOpenGLTextureBlitter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLTextureBlitter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOpenGLTextureBlitter_PythonToCpp_QOpenGLTextureBlitter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLTextureBlitter_TypeF()))
        return QOpenGLTextureBlitter_PythonToCpp_QOpenGLTextureBlitter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOpenGLTextureBlitter_PTR_CppToPython_QOpenGLTextureBlitter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QOpenGLTextureBlitter *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QOpenGLTextureBlitter_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QOpenGLTextureBlitter_SignatureStrings[] = {
    "PySide6.QtOpenGL.QOpenGLTextureBlitter(self)",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.bind(self,target:unsigned int=GL_TEXTURE_2D)",
    "1:PySide6.QtOpenGL.QOpenGLTextureBlitter.blit(self,texture:unsigned int,targetTransform:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform],sourceOrigin:PySide6.QtOpenGL.QOpenGLTextureBlitter.Origin)",
    "0:PySide6.QtOpenGL.QOpenGLTextureBlitter.blit(self,texture:unsigned int,targetTransform:typing.Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform],sourceTransform:PySide6.QtGui.QMatrix3x3)",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.create(self)->bool",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.destroy(self)",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.isCreated(self)->bool",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.release(self)",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.setOpacity(self,opacity:float)",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.setRedBlueSwizzle(self,swizzle:bool)",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.sourceTransform(subTexture:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],textureSize:PySide6.QtCore.QSize,origin:PySide6.QtOpenGL.QOpenGLTextureBlitter.Origin)->PySide6.QtGui.QMatrix3x3",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.supportsExternalOESTarget(self)->bool",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.supportsRectangleTarget(self)->bool",
    "PySide6.QtOpenGL.QOpenGLTextureBlitter.targetTransform(target:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],viewport:PySide6.QtCore.QRect)->PySide6.QtGui.QMatrix4x4",
    nullptr}; // Sentinel

PyTypeObject *init_QOpenGLTextureBlitter(PyObject *module)
{
    if (SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX].type != nullptr)
        return SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX].type;

    Shiboken::AutoDecRef Sbk_QOpenGLTextureBlitter_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QOpenGLTextureBlitter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOpenGLTextureBlitter",
        "QOpenGLTextureBlitter*",
        &Sbk_QOpenGLTextureBlitter_spec,
        &Shiboken::callCppDestructor< ::QOpenGLTextureBlitter >,
        Sbk_QOpenGLTextureBlitter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOpenGLTextureBlitter_TypeF(); // references _Sbk_QOpenGLTextureBlitter_Type
    InitSignatureStrings(pyType, QOpenGLTextureBlitter_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOpenGLTextureBlitter_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOpenGLTextureBlitter_PythonToCpp_QOpenGLTextureBlitter_PTR,
        is_QOpenGLTextureBlitter_PythonToCpp_QOpenGLTextureBlitter_PTR_Convertible,
        QOpenGLTextureBlitter_PTR_CppToPython_QOpenGLTextureBlitter);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLTextureBlitter");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLTextureBlitter*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLTextureBlitter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLTextureBlitter).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QOpenGLTextureBlitter_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Origin'.
    const char *Origin_Initializer[] = {
        "OriginBottomLeft",
        "OriginTopLeft",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Origin_InitializerValues[] = {
        uint8_t(QOpenGLTextureBlitter::Origin::OriginBottomLeft), //  0x00  0
        uint8_t(QOpenGLTextureBlitter::Origin::OriginTopLeft)     //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTextureBlitter_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTextureBlitter.Origin",
        Origin_Initializer, Origin_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTextureBlitter_Origin_IDX].type = EType;
    // Register converter for enum 'QOpenGLTextureBlitter::Origin'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTextureBlitter_Origin_CppToPython_QOpenGLTextureBlitter_Origin);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTextureBlitter_Origin_PythonToCpp_QOpenGLTextureBlitter_Origin,
            is_QOpenGLTextureBlitter_Origin_PythonToCpp_QOpenGLTextureBlitter_Origin_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTextureBlitter::Origin");
        Shiboken::Conversions::registerConverterName(converter, "Origin");
    }
    // End of 'Origin' enum.

    qRegisterMetaType< ::QOpenGLTextureBlitter *>();
    qRegisterMetaType< ::QOpenGLTextureBlitter::Origin >("QOpenGLTextureBlitter::Origin");

    return pyType;
}
