// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtpdf_python.h"

// main header
#include "qpdfselection_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtGui/qclipboard.h>
#include <QtGui/qpolygon.h>
#include <QtPdf/qpdfselection.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPdfSelection_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPdfSelection >()))
        return -1;

    ::QPdfSelection *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPdf.QPdfSelection.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPdfSelection", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPdfSelection::QPdfSelection(QPdfSelection)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QPdfSelection(QPdfSelection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QPdfSelection *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QPdfSelection(QPdfSelection)
            cptr = new ::QPdfSelection(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPdfSelection >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPdfSelectionFunc_boundingRectangle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPdf.QPdfSelection.boundingRectangle";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // boundingRectangle()const
            QRectF cppResult = const_cast<const ::QPdfSelection *>(cppSelf)->boundingRectangle();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfSelectionFunc_bounds(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPdf.QPdfSelection.bounds";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // bounds()const
            QList<QPolygonF> cppResult = const_cast<const ::QPdfSelection *>(cppSelf)->bounds();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPdfTypeConverters[SBK_QtPdf_QList_QPolygonF_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfSelectionFunc_copyToClipboard(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPdf.QPdfSelection.copyToClipboard";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:copyToClipboard", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPdfSelection::copyToClipboard(QClipboard::Mode=)const
    if (numArgs == 0) {
        overloadId = 0; // copyToClipboard(QClipboard::Mode)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // copyToClipboard(QClipboard::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QClipboard_Mode_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QClipboard::Mode cppArg0(QClipboard::Clipboard);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // copyToClipboard(QClipboard::Mode)const
            const_cast<const ::QPdfSelection *>(cppSelf)->copyToClipboard(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPdfSelectionFunc_endIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPdf.QPdfSelection.endIndex";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // endIndex()const
            int cppResult = const_cast<const ::QPdfSelection *>(cppSelf)->endIndex();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfSelectionFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPdf.QPdfSelection.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QPdfSelection *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfSelectionFunc_startIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPdf.QPdfSelection.startIndex";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // startIndex()const
            int cppResult = const_cast<const ::QPdfSelection *>(cppSelf)->startIndex();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPdfSelectionFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPdf.QPdfSelection.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfSelection::swap(QPdfSelection&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QPdfSelection&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPdfSelection *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QPdfSelection&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPdfSelectionFunc_text(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPdf.QPdfSelection.text";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // text()const
            QString cppResult = const_cast<const ::QPdfSelection *>(cppSelf)->text();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPdfSelection_PropertyStrings[] = {
    "boundingRectangle:",
    "bounds:",
    "endIndex:",
    "startIndex:",
    "text:",
    "valid:isValid",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPdfSelection_methods[] = {
    {"boundingRectangle", reinterpret_cast<PyCFunction>(Sbk_QPdfSelectionFunc_boundingRectangle), METH_NOARGS, nullptr},
    {"bounds", reinterpret_cast<PyCFunction>(Sbk_QPdfSelectionFunc_bounds), METH_NOARGS, nullptr},
    {"copyToClipboard", reinterpret_cast<PyCFunction>(Sbk_QPdfSelectionFunc_copyToClipboard), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"endIndex", reinterpret_cast<PyCFunction>(Sbk_QPdfSelectionFunc_endIndex), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QPdfSelectionFunc_isValid), METH_NOARGS, nullptr},
    {"startIndex", reinterpret_cast<PyCFunction>(Sbk_QPdfSelectionFunc_startIndex), METH_NOARGS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QPdfSelectionFunc_swap), METH_O, nullptr},
    {"text", reinterpret_cast<PyCFunction>(Sbk_QPdfSelectionFunc_text), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QPdfSelection_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPdfSelection_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPdfSelection_Type = nullptr;
static PyTypeObject *Sbk_QPdfSelection_TypeF(void)
{
    return _Sbk_QPdfSelection_Type;
}

static PyType_Slot Sbk_QPdfSelection_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPdfSelection_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPdfSelection_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPdfSelection_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPdfSelection_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPdfSelection_spec = {
    "2:PySide6.QtPdf.QPdfSelection",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPdfSelection_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPdfSelection_PythonToCpp_QPdfSelection_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPdfSelection_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPdfSelection_PythonToCpp_QPdfSelection_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPdfSelection_TypeF()))
        return QPdfSelection_PythonToCpp_QPdfSelection_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPdfSelection_PTR_CppToPython_QPdfSelection(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QPdfSelection *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QPdfSelection_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QPdfSelection_SignatureStrings[] = {
    "PySide6.QtPdf.QPdfSelection(self,other:PySide6.QtPdf.QPdfSelection)",
    "PySide6.QtPdf.QPdfSelection.boundingRectangle(self)->PySide6.QtCore.QRectF",
    "PySide6.QtPdf.QPdfSelection.bounds(self)->QList[PySide6.QtGui.QPolygonF]",
    "PySide6.QtPdf.QPdfSelection.copyToClipboard(self,mode:PySide6.QtGui.QClipboard.Mode=QClipboard.Clipboard)",
    "PySide6.QtPdf.QPdfSelection.endIndex(self)->int",
    "PySide6.QtPdf.QPdfSelection.isValid(self)->bool",
    "PySide6.QtPdf.QPdfSelection.startIndex(self)->int",
    "PySide6.QtPdf.QPdfSelection.swap(self,other:PySide6.QtPdf.QPdfSelection)",
    "PySide6.QtPdf.QPdfSelection.text(self)->QString",
    nullptr}; // Sentinel

PyTypeObject *init_QPdfSelection(PyObject *module)
{
    if (SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX].type != nullptr)
        return SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX].type;

    Shiboken::AutoDecRef Sbk_QPdfSelection_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPdfSelection_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPdfSelection",
        "QPdfSelection*",
        &Sbk_QPdfSelection_spec,
        &Shiboken::callCppDestructor< ::QPdfSelection >,
        Sbk_QPdfSelection_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPdfSelection_TypeF(); // references _Sbk_QPdfSelection_Type
    InitSignatureStrings(pyType, QPdfSelection_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPdfSelection_PropertyStrings);
    SbkPySide6_QtPdfTypeStructs[SBK_QPdfSelection_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPdfSelection_PythonToCpp_QPdfSelection_PTR,
        is_QPdfSelection_PythonToCpp_QPdfSelection_PTR_Convertible,
        QPdfSelection_PTR_CppToPython_QPdfSelection);

    Shiboken::Conversions::registerConverterName(converter, "QPdfSelection");
    Shiboken::Conversions::registerConverterName(converter, "QPdfSelection*");
    Shiboken::Conversions::registerConverterName(converter, "QPdfSelection&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPdfSelection).name());

    qRegisterMetaType< ::QPdfSelection *>();

    return pyType;
}
