// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtprintsupport_python.h"

// main header
#include "qprinterinfo_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGui/qpagesize.h>
#include <QtPrintSupport/qprinter.h>
#include <QtPrintSupport/qprinterinfo.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPrinterInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPrinterInfo >()))
        return -1;

    ::QPrinterInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPrinterInfo", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPrinterInfo::QPrinterInfo()
    // 1: QPrinterInfo::QPrinterInfo(QPrinter)
    // 2: QPrinterInfo::QPrinterInfo(QPrinterInfo)
    if (numArgs == 0) {
        overloadId = 0; // QPrinterInfo()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QPrinterInfo(QPrinterInfo)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPrinterInfo(QPrinter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPrinterInfo()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPrinterInfo()
                cptr = new ::QPrinterInfo();
            }
            break;
        }
        case 1: // QPrinterInfo(const QPrinter & printer)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPrinter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPrinterInfo(QPrinter)
                cptr = new ::QPrinterInfo(*cppArg0);
            }
            break;
        }
        case 2: // QPrinterInfo(const QPrinterInfo & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPrinterInfo cppArg0_local;
            ::QPrinterInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QPrinterInfo(QPrinterInfo)
                cptr = new ::QPrinterInfo(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPrinterInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPrinterInfoFunc_availablePrinterNames(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.availablePrinterNames";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // availablePrinterNames()
            QStringList cppResult = ::QPrinterInfo::availablePrinterNames();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_availablePrinters(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.availablePrinters";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // availablePrinters()
            QList<QPrinterInfo> cppResult = ::QPrinterInfo::availablePrinters();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPrintSupportTypeConverters[SBK_QtPrintSupport_QList_QPrinterInfo_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_defaultColorMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.defaultColorMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultColorMode()const
            QPrinter::ColorMode cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->defaultColorMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_ColorMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_defaultDuplexMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.defaultDuplexMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultDuplexMode()const
            QPrinter::DuplexMode cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->defaultDuplexMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_DuplexMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_defaultPageSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.defaultPageSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultPageSize()const
            QPageSize cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->defaultPageSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_defaultPrinter(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.defaultPrinter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultPrinter()
            QPrinterInfo cppResult = ::QPrinterInfo::defaultPrinter();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_defaultPrinterName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.defaultPrinterName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // defaultPrinterName()
            QString cppResult = ::QPrinterInfo::defaultPrinterName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.description";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // description()const
            QString cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->description();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_isDefault(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.isDefault";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDefault()const
            bool cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->isDefault();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.isNull";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isNull()const
            bool cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->isNull();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_isRemote(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.isRemote";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isRemote()const
            bool cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->isRemote();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_location(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.location";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // location()const
            QString cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->location();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_makeAndModel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.makeAndModel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // makeAndModel()const
            QString cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->makeAndModel();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_maximumPhysicalPageSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.maximumPhysicalPageSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maximumPhysicalPageSize()const
            QPageSize cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->maximumPhysicalPageSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_minimumPhysicalPageSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.minimumPhysicalPageSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minimumPhysicalPageSize()const
            QPageSize cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->minimumPhysicalPageSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageSize_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_printerInfo(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.printerInfo";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QPrinterInfo::printerInfo(QString)->QPrinterInfo
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // printerInfo(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // printerInfo(QString)
            QPrinterInfo cppResult = ::QPrinterInfo::printerInfo(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_printerName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.printerName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // printerName()const
            QString cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->printerName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.state";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // state()const
            QPrinter::PrinterState cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->state();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinter_PrinterState_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_supportedColorModes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.supportedColorModes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportedColorModes()const
            QList<QPrinter::ColorMode> cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->supportedColorModes();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPrintSupportTypeConverters[SBK_QtPrintSupport_QList_QPrinter_ColorMode_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_supportedDuplexModes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.supportedDuplexModes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportedDuplexModes()const
            QList<QPrinter::DuplexMode> cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->supportedDuplexModes();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPrintSupportTypeConverters[SBK_QtPrintSupport_QList_QPrinter_DuplexMode_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_supportedPageSizes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.supportedPageSizes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportedPageSizes()const
            QList<QPageSize> cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->supportedPageSizes();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPrintSupportTypeConverters[SBK_QtPrintSupport_QList_QPageSize_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_supportedResolutions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.supportedResolutions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportedResolutions()const
            QList<int> cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->supportedResolutions();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPrintSupportTypeConverters[SBK_QtPrintSupport_QList_int_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfoFunc_supportsCustomPageSizes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtPrintSupport.QPrinterInfo.supportsCustomPageSizes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // supportsCustomPageSizes()const
            bool cppResult = const_cast<const ::QPrinterInfo *>(cppSelf)->supportsCustomPageSizes();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPrinterInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPrinterInfo_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPrinterInfo_methods[] = {
    {"availablePrinterNames", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_availablePrinterNames), METH_NOARGS|METH_STATIC, nullptr},
    {"availablePrinters", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_availablePrinters), METH_NOARGS|METH_STATIC, nullptr},
    {"defaultColorMode", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_defaultColorMode), METH_NOARGS, nullptr},
    {"defaultDuplexMode", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_defaultDuplexMode), METH_NOARGS, nullptr},
    {"defaultPageSize", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_defaultPageSize), METH_NOARGS, nullptr},
    {"defaultPrinter", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_defaultPrinter), METH_NOARGS|METH_STATIC, nullptr},
    {"defaultPrinterName", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_defaultPrinterName), METH_NOARGS|METH_STATIC, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_description), METH_NOARGS, nullptr},
    {"isDefault", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_isDefault), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_isNull), METH_NOARGS, nullptr},
    {"isRemote", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_isRemote), METH_NOARGS, nullptr},
    {"location", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_location), METH_NOARGS, nullptr},
    {"makeAndModel", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_makeAndModel), METH_NOARGS, nullptr},
    {"maximumPhysicalPageSize", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_maximumPhysicalPageSize), METH_NOARGS, nullptr},
    {"minimumPhysicalPageSize", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_minimumPhysicalPageSize), METH_NOARGS, nullptr},
    {"printerInfo", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_printerInfo), METH_O|METH_STATIC, nullptr},
    {"printerName", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_printerName), METH_NOARGS, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_state), METH_NOARGS, nullptr},
    {"supportedColorModes", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_supportedColorModes), METH_NOARGS, nullptr},
    {"supportedDuplexModes", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_supportedDuplexModes), METH_NOARGS, nullptr},
    {"supportedPageSizes", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_supportedPageSizes), METH_NOARGS, nullptr},
    {"supportedResolutions", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_supportedResolutions), METH_NOARGS, nullptr},
    {"supportsCustomPageSizes", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfoFunc_supportsCustomPageSizes), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QPrinterInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPrinterInfo___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QPrinterInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPrinterInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPrinterInfo_Type = nullptr;
static PyTypeObject *Sbk_QPrinterInfo_TypeF(void)
{
    return _Sbk_QPrinterInfo_Type;
}

static PyType_Slot Sbk_QPrinterInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPrinterInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPrinterInfo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPrinterInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPrinterInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QPrinterInfo___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPrinterInfo_spec = {
    "2:PySide6.QtPrintSupport.QPrinterInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPrinterInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPrinterInfo_PythonToCpp_QPrinterInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPrinterInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPrinterInfo_PythonToCpp_QPrinterInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPrinterInfo_TypeF()))
        return QPrinterInfo_PythonToCpp_QPrinterInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPrinterInfo_PTR_CppToPython_QPrinterInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QPrinterInfo *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QPrinterInfo_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QPrinterInfo_COPY_CppToPython_QPrinterInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QPrinterInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QPrinterInfo_TypeF(), new ::QPrinterInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QPrinterInfo_PythonToCpp_QPrinterInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QPrinterInfo *>(cppOut) = *reinterpret_cast< ::QPrinterInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QPrinterInfo_PythonToCpp_QPrinterInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QPrinterInfo_TypeF()))
        return QPrinterInfo_PythonToCpp_QPrinterInfo_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QPrinterInfo_SignatureStrings[] = {
    "2:PySide6.QtPrintSupport.QPrinterInfo(self)",
    "1:PySide6.QtPrintSupport.QPrinterInfo(self,printer:PySide6.QtPrintSupport.QPrinter)",
    "0:PySide6.QtPrintSupport.QPrinterInfo(self,other:PySide6.QtPrintSupport.QPrinterInfo)",
    "PySide6.QtPrintSupport.QPrinterInfo.availablePrinterNames()->QStringList",
    "PySide6.QtPrintSupport.QPrinterInfo.availablePrinters()->QList[PySide6.QtPrintSupport.QPrinterInfo]",
    "PySide6.QtPrintSupport.QPrinterInfo.defaultColorMode(self)->PySide6.QtPrintSupport.QPrinter.ColorMode",
    "PySide6.QtPrintSupport.QPrinterInfo.defaultDuplexMode(self)->PySide6.QtPrintSupport.QPrinter.DuplexMode",
    "PySide6.QtPrintSupport.QPrinterInfo.defaultPageSize(self)->PySide6.QtGui.QPageSize",
    "PySide6.QtPrintSupport.QPrinterInfo.defaultPrinter()->PySide6.QtPrintSupport.QPrinterInfo",
    "PySide6.QtPrintSupport.QPrinterInfo.defaultPrinterName()->QString",
    "PySide6.QtPrintSupport.QPrinterInfo.description(self)->QString",
    "PySide6.QtPrintSupport.QPrinterInfo.isDefault(self)->bool",
    "PySide6.QtPrintSupport.QPrinterInfo.isNull(self)->bool",
    "PySide6.QtPrintSupport.QPrinterInfo.isRemote(self)->bool",
    "PySide6.QtPrintSupport.QPrinterInfo.location(self)->QString",
    "PySide6.QtPrintSupport.QPrinterInfo.makeAndModel(self)->QString",
    "PySide6.QtPrintSupport.QPrinterInfo.maximumPhysicalPageSize(self)->PySide6.QtGui.QPageSize",
    "PySide6.QtPrintSupport.QPrinterInfo.minimumPhysicalPageSize(self)->PySide6.QtGui.QPageSize",
    "PySide6.QtPrintSupport.QPrinterInfo.printerInfo(printerName:QString)->PySide6.QtPrintSupport.QPrinterInfo",
    "PySide6.QtPrintSupport.QPrinterInfo.printerName(self)->QString",
    "PySide6.QtPrintSupport.QPrinterInfo.state(self)->PySide6.QtPrintSupport.QPrinter.PrinterState",
    "PySide6.QtPrintSupport.QPrinterInfo.supportedColorModes(self)->QList[PySide6.QtPrintSupport.QPrinter.ColorMode]",
    "PySide6.QtPrintSupport.QPrinterInfo.supportedDuplexModes(self)->QList[PySide6.QtPrintSupport.QPrinter.DuplexMode]",
    "PySide6.QtPrintSupport.QPrinterInfo.supportedPageSizes(self)->QList[PySide6.QtGui.QPageSize]",
    "PySide6.QtPrintSupport.QPrinterInfo.supportedResolutions(self)->QList[int]",
    "PySide6.QtPrintSupport.QPrinterInfo.supportsCustomPageSizes(self)->bool",
    "PySide6.QtPrintSupport.QPrinterInfo.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QPrinterInfo(PyObject *module)
{
    if (SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX].type != nullptr)
        return SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QPrinterInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPrinterInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPrinterInfo",
        "QPrinterInfo",
        &Sbk_QPrinterInfo_spec,
        &Shiboken::callCppDestructor< ::QPrinterInfo >,
        Sbk_QPrinterInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QPrinterInfo_TypeF(); // references _Sbk_QPrinterInfo_Type
    InitSignatureStrings(pyType, QPrinterInfo_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPrinterInfo_PropertyStrings);
    SbkPySide6_QtPrintSupportTypeStructs[SBK_QPrinterInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPrinterInfo_PythonToCpp_QPrinterInfo_PTR,
        is_QPrinterInfo_PythonToCpp_QPrinterInfo_PTR_Convertible,
        QPrinterInfo_PTR_CppToPython_QPrinterInfo,
        QPrinterInfo_COPY_CppToPython_QPrinterInfo);

    Shiboken::Conversions::registerConverterName(converter, "QPrinterInfo");
    Shiboken::Conversions::registerConverterName(converter, "QPrinterInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QPrinterInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPrinterInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QPrinterInfo_PythonToCpp_QPrinterInfo_COPY,
        is_QPrinterInfo_PythonToCpp_QPrinterInfo_COPY_Convertible);


    return pyType;
}
