// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qqmlerror_wrapper.h"

// Argument includes
#include <QString>
#include <QtQml/qqmlerror.h>
#include <qlogging.h>
#include <qobject.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQmlError_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQmlError >()))
        return -1;

    ::QQmlError *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QQmlError", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQmlError::QQmlError()
    // 1: QQmlError::QQmlError(QQmlError)
    if (numArgs == 0) {
        overloadId = 0; // QQmlError()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QQmlError(QQmlError)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QQmlError()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QQmlError()
                cptr = new ::QQmlError();
            }
            break;
        }
        case 1: // QQmlError(const QQmlError & arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QQmlError cppArg0_local;
            ::QQmlError *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QQmlError(QQmlError)
                cptr = new ::QQmlError(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QQmlError >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQmlErrorFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.__repr__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __repr__()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtqml.cpp (qmlerrror-repr)]
            const QByteArray message = cppSelf->toString().toUtf8();
            pyResult = Shiboken::String::fromCString(message.constData());
            // END of custom code block [file: ../glue/qtqml.cpp (qmlerrror-repr)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_column(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.column";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // column()const
            int cppResult = const_cast<const ::QQmlError *>(cppSelf)->column();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.description";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // description()const
            QString cppResult = const_cast<const ::QQmlError *>(cppSelf)->description();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QQmlError *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_line(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.line";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // line()const
            int cppResult = const_cast<const ::QQmlError *>(cppSelf)->line();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_messageType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.messageType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // messageType()const
            QtMsgType cppResult = const_cast<const ::QQmlError *>(cppSelf)->messageType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtMsgType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_object(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.object";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // object()const
            QObject * cppResult = const_cast<const ::QQmlError *>(cppSelf)->object();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_setColumn(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.setColumn";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlError::setColumn(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setColumn(int)
            cppSelf->setColumn(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlErrorFunc_setDescription(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.setDescription";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlError::setDescription(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDescription(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDescription(QString)
            cppSelf->setDescription(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlErrorFunc_setLine(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.setLine";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlError::setLine(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLine(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLine(int)
            cppSelf->setLine(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlErrorFunc_setMessageType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.setMessageType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlError::setMessageType(QtMsgType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtMsgType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMessageType(QtMsgType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QtMsgType cppArg0{QtDebugMsg};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMessageType(QtMsgType)
            cppSelf->setMessageType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlErrorFunc_setObject(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.setObject";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlError::setObject(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // setObject(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setObject(QObject*)
            cppSelf->setObject(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlErrorFunc_setUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.setUrl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlError::setUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUrl(QUrl)
            cppSelf->setUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlErrorFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlError::swap(QQmlError&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QQmlError&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQmlError cppArg0_local;
        ::QQmlError *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QQmlError&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQmlErrorFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.toString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toString()const
            QString cppResult = const_cast<const ::QQmlError *>(cppSelf)->toString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlErrorFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQml.QQmlError.url";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // url()const
            QUrl cppResult = const_cast<const ::QQmlError *>(cppSelf)->url();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQmlError__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQmlError_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQmlError_methods[] = {
    {"column", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_column), METH_NOARGS, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_description), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_isValid), METH_NOARGS, nullptr},
    {"line", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_line), METH_NOARGS, nullptr},
    {"messageType", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_messageType), METH_NOARGS, nullptr},
    {"object", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_object), METH_NOARGS, nullptr},
    {"setColumn", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_setColumn), METH_O, nullptr},
    {"setDescription", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_setDescription), METH_O, nullptr},
    {"setLine", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_setLine), METH_O, nullptr},
    {"setMessageType", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_setMessageType), METH_O, nullptr},
    {"setObject", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_setObject), METH_O, nullptr},
    {"setUrl", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_setUrl), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_swap), METH_O, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_toString), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QQmlErrorFunc_url), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QQmlError__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QQmlError_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQmlError_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQmlError_Type = nullptr;
static PyTypeObject *Sbk_QQmlError_TypeF(void)
{
    return _Sbk_QQmlError_Type;
}

static PyType_Slot Sbk_QQmlError_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QQmlErrorFunc___repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQmlError_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQmlError_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQmlError_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQmlError_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQmlError_spec = {
    "2:PySide6.QtQml.QQmlError",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQmlError_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQmlError_PythonToCpp_QQmlError_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQmlError_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQmlError_PythonToCpp_QQmlError_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlError_TypeF()))
        return QQmlError_PythonToCpp_QQmlError_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQmlError_PTR_CppToPython_QQmlError(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QQmlError *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QQmlError_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QQmlError_COPY_CppToPython_QQmlError(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QQmlError *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QQmlError_TypeF(), new ::QQmlError(*source), true, true);
}

// Python to C++ copy conversion.
static void QQmlError_PythonToCpp_QQmlError_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QQmlError *>(cppOut) = *reinterpret_cast< ::QQmlError *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QQmlError_PythonToCpp_QQmlError_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlError_TypeF()))
        return QQmlError_PythonToCpp_QQmlError_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QQmlError_SignatureStrings[] = {
    "1:PySide6.QtQml.QQmlError(self)",
    "0:PySide6.QtQml.QQmlError(self,arg__1:PySide6.QtQml.QQmlError)",
    "PySide6.QtQml.QQmlError.__repr__(self)->PyObject",
    "PySide6.QtQml.QQmlError.column(self)->int",
    "PySide6.QtQml.QQmlError.description(self)->QString",
    "PySide6.QtQml.QQmlError.isValid(self)->bool",
    "PySide6.QtQml.QQmlError.line(self)->int",
    "PySide6.QtQml.QQmlError.messageType(self)->PySide6.QtCore.QtMsgType",
    "PySide6.QtQml.QQmlError.object(self)->PySide6.QtCore.QObject",
    "PySide6.QtQml.QQmlError.setColumn(self,arg__1:int)",
    "PySide6.QtQml.QQmlError.setDescription(self,arg__1:QString)",
    "PySide6.QtQml.QQmlError.setLine(self,arg__1:int)",
    "PySide6.QtQml.QQmlError.setMessageType(self,messageType:PySide6.QtCore.QtMsgType)",
    "PySide6.QtQml.QQmlError.setObject(self,arg__1:PySide6.QtCore.QObject)",
    "PySide6.QtQml.QQmlError.setUrl(self,arg__1:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtQml.QQmlError.swap(self,other:PySide6.QtQml.QQmlError)",
    "PySide6.QtQml.QQmlError.toString(self)->QString",
    "PySide6.QtQml.QQmlError.url(self)->PySide6.QtCore.QUrl",
    "PySide6.QtQml.QQmlError.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QQmlError(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX].type;

    Shiboken::AutoDecRef Sbk_QQmlError_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQmlError_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQmlError",
        "QQmlError",
        &Sbk_QQmlError_spec,
        &Shiboken::callCppDestructor< ::QQmlError >,
        Sbk_QQmlError_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QQmlError_TypeF(); // references _Sbk_QQmlError_Type
    InitSignatureStrings(pyType, QQmlError_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQmlError_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QQmlError_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQmlError_PythonToCpp_QQmlError_PTR,
        is_QQmlError_PythonToCpp_QQmlError_PTR_Convertible,
        QQmlError_PTR_CppToPython_QQmlError,
        QQmlError_COPY_CppToPython_QQmlError);

    Shiboken::Conversions::registerConverterName(converter, "QQmlError");
    Shiboken::Conversions::registerConverterName(converter, "QQmlError*");
    Shiboken::Conversions::registerConverterName(converter, "QQmlError&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQmlError).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QQmlError_PythonToCpp_QQmlError_COPY,
        is_QQmlError_PythonToCpp_QQmlError_COPY_Convertible);

    qRegisterMetaType< ::QQmlError >("QQmlError");

    return pyType;
}
