// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtqml_python.h"

// main header
#include "qqmlnetworkaccessmanagerfactory_wrapper.h"

// Argument includes
#include <QtNetwork/qnetworkaccessmanager.h>
#include <qobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQmlNetworkAccessManagerFactoryWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQmlNetworkAccessManagerFactoryWrapper::QQmlNetworkAccessManagerFactoryWrapper() : QQmlNetworkAccessManagerFactory()
{
    resetPyMethodCache();
    // ... middle
}

::QNetworkAccessManager * QQmlNetworkAccessManagerFactoryWrapper::create(::QObject * parent)
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QQmlNetworkAccessManagerFactory.create");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "create";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QQmlNetworkAccessManagerFactory.create");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), parent)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), parent)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQmlNetworkAccessManagerFactory", funcName, Shiboken::SbkType< QNetworkAccessManager >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QNetworkAccessManager *cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (Shiboken::Object::checkType(pyResult))
        Shiboken::Object::releaseOwnership(pyResult);
    return cppResult;
}

QQmlNetworkAccessManagerFactoryWrapper::~QQmlNetworkAccessManagerFactoryWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQmlNetworkAccessManagerFactory_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlNetworkAccessManagerFactory_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QQmlNetworkAccessManagerFactory");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQmlNetworkAccessManagerFactory >()))
        return -1;

    QQmlNetworkAccessManagerFactoryWrapper *cptr{};
    static const char fullName[] = "PySide6.QtQml.QQmlNetworkAccessManagerFactory.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QQmlNetworkAccessManagerFactory()
            cptr = new QQmlNetworkAccessManagerFactoryWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQmlNetworkAccessManagerFactory >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQmlNetworkAccessManagerFactoryFunc_create(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQmlNetworkAccessManagerFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlNetworkAccessManagerFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQml.QQmlNetworkAccessManagerFactory.create";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQmlNetworkAccessManagerFactory::create(QObject*)->QNetworkAccessManager*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // create(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // create(QObject*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QQmlNetworkAccessManagerFactory.create");
                return {};
            }
            QNetworkAccessManager * cppResult = cppSelf->create(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQmlNetworkAccessManagerFactory_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQmlNetworkAccessManagerFactory_methods[] = {
    {"create", reinterpret_cast<PyCFunction>(Sbk_QQmlNetworkAccessManagerFactoryFunc_create), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQmlNetworkAccessManagerFactory_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQmlNetworkAccessManagerFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlNetworkAccessManagerFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQmlNetworkAccessManagerFactoryWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQmlNetworkAccessManagerFactory_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQmlNetworkAccessManagerFactory_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQmlNetworkAccessManagerFactory_Type = nullptr;
static PyTypeObject *Sbk_QQmlNetworkAccessManagerFactory_TypeF(void)
{
    return _Sbk_QQmlNetworkAccessManagerFactory_Type;
}

static PyType_Slot Sbk_QQmlNetworkAccessManagerFactory_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQmlNetworkAccessManagerFactory_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQmlNetworkAccessManagerFactory_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQmlNetworkAccessManagerFactory_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQmlNetworkAccessManagerFactory_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQmlNetworkAccessManagerFactory_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQmlNetworkAccessManagerFactory_spec = {
    "2:PySide6.QtQml.QQmlNetworkAccessManagerFactory",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQmlNetworkAccessManagerFactory_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQmlNetworkAccessManagerFactory_PythonToCpp_QQmlNetworkAccessManagerFactory_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQmlNetworkAccessManagerFactory_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQmlNetworkAccessManagerFactory_PythonToCpp_QQmlNetworkAccessManagerFactory_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQmlNetworkAccessManagerFactory_TypeF()))
        return QQmlNetworkAccessManagerFactory_PythonToCpp_QQmlNetworkAccessManagerFactory_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQmlNetworkAccessManagerFactory_PTR_CppToPython_QQmlNetworkAccessManagerFactory(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QQmlNetworkAccessManagerFactory *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QQmlNetworkAccessManagerFactory_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QQmlNetworkAccessManagerFactory_SignatureStrings[] = {
    "PySide6.QtQml.QQmlNetworkAccessManagerFactory(self)",
    "PySide6.QtQml.QQmlNetworkAccessManagerFactory.create(self,parent:PySide6.QtCore.QObject)->PySide6.QtNetwork.QNetworkAccessManager",
    nullptr}; // Sentinel

PyTypeObject *init_QQmlNetworkAccessManagerFactory(PyObject *module)
{
    if (SbkPySide6_QtQmlTypeStructs[SBK_QQmlNetworkAccessManagerFactory_IDX].type != nullptr)
        return SbkPySide6_QtQmlTypeStructs[SBK_QQmlNetworkAccessManagerFactory_IDX].type;

    Shiboken::AutoDecRef Sbk_QQmlNetworkAccessManagerFactory_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQmlNetworkAccessManagerFactory_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQmlNetworkAccessManagerFactory",
        "QQmlNetworkAccessManagerFactory*",
        &Sbk_QQmlNetworkAccessManagerFactory_spec,
        &Shiboken::callCppDestructor< QQmlNetworkAccessManagerFactory >,
        Sbk_QQmlNetworkAccessManagerFactory_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQmlNetworkAccessManagerFactory_TypeF(); // references _Sbk_QQmlNetworkAccessManagerFactory_Type
    InitSignatureStrings(pyType, QQmlNetworkAccessManagerFactory_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQmlNetworkAccessManagerFactory_PropertyStrings);
    SbkPySide6_QtQmlTypeStructs[SBK_QQmlNetworkAccessManagerFactory_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQmlNetworkAccessManagerFactory_PythonToCpp_QQmlNetworkAccessManagerFactory_PTR,
        is_QQmlNetworkAccessManagerFactory_PythonToCpp_QQmlNetworkAccessManagerFactory_PTR_Convertible,
        QQmlNetworkAccessManagerFactory_PTR_CppToPython_QQmlNetworkAccessManagerFactory);

    Shiboken::Conversions::registerConverterName(converter, "QQmlNetworkAccessManagerFactory");
    Shiboken::Conversions::registerConverterName(converter, "QQmlNetworkAccessManagerFactory*");
    Shiboken::Conversions::registerConverterName(converter, "QQmlNetworkAccessManagerFactory&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQmlNetworkAccessManagerFactory).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQmlNetworkAccessManagerFactoryWrapper).name());

    qRegisterMetaType< ::QQmlNetworkAccessManagerFactory *>();

    return pyType;
}
