// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qquickgraphicsconfiguration_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QtQuick/qquickgraphicsconfiguration.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuickGraphicsConfiguration_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuickGraphicsConfiguration >()))
        return -1;

    ::QQuickGraphicsConfiguration *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QQuickGraphicsConfiguration", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQuickGraphicsConfiguration::QQuickGraphicsConfiguration()
    // 1: QQuickGraphicsConfiguration::QQuickGraphicsConfiguration(QQuickGraphicsConfiguration)
    if (numArgs == 0) {
        overloadId = 0; // QQuickGraphicsConfiguration()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QQuickGraphicsConfiguration(QQuickGraphicsConfiguration)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QQuickGraphicsConfiguration()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QQuickGraphicsConfiguration()
                cptr = new ::QQuickGraphicsConfiguration();
            }
            break;
        }
        case 1: // QQuickGraphicsConfiguration(const QQuickGraphicsConfiguration & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QQuickGraphicsConfiguration cppArg0_local;
            ::QQuickGraphicsConfiguration *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QQuickGraphicsConfiguration(QQuickGraphicsConfiguration)
                cptr = new ::QQuickGraphicsConfiguration(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QQuickGraphicsConfiguration >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_deviceExtensions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.deviceExtensions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // deviceExtensions()const
            QList<QByteArray> cppResult = const_cast<const ::QQuickGraphicsConfiguration *>(cppSelf)->deviceExtensions();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtQuickTypeConverters[SBK_QtQuick_QList_QByteArray_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_isAutomaticPipelineCacheEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.isAutomaticPipelineCacheEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isAutomaticPipelineCacheEnabled()const
            bool cppResult = const_cast<const ::QQuickGraphicsConfiguration *>(cppSelf)->isAutomaticPipelineCacheEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_isDebugLayerEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.isDebugLayerEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDebugLayerEnabled()const
            bool cppResult = const_cast<const ::QQuickGraphicsConfiguration *>(cppSelf)->isDebugLayerEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_isDebugMarkersEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.isDebugMarkersEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDebugMarkersEnabled()const
            bool cppResult = const_cast<const ::QQuickGraphicsConfiguration *>(cppSelf)->isDebugMarkersEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_isDepthBufferEnabledFor2D(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.isDepthBufferEnabledFor2D";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isDepthBufferEnabledFor2D()const
            bool cppResult = const_cast<const ::QQuickGraphicsConfiguration *>(cppSelf)->isDepthBufferEnabledFor2D();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_pipelineCacheLoadFile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.pipelineCacheLoadFile";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // pipelineCacheLoadFile()const
            QString cppResult = const_cast<const ::QQuickGraphicsConfiguration *>(cppSelf)->pipelineCacheLoadFile();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_pipelineCacheSaveFile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.pipelineCacheSaveFile";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // pipelineCacheSaveFile()const
            QString cppResult = const_cast<const ::QQuickGraphicsConfiguration *>(cppSelf)->pipelineCacheSaveFile();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_preferredInstanceExtensions(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.preferredInstanceExtensions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // preferredInstanceExtensions()
            QList<QByteArray> cppResult = ::QQuickGraphicsConfiguration::preferredInstanceExtensions();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtQuickTypeConverters[SBK_QtQuick_QList_QByteArray_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_prefersSoftwareDevice(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.prefersSoftwareDevice";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // prefersSoftwareDevice()const
            bool cppResult = const_cast<const ::QQuickGraphicsConfiguration *>(cppSelf)->prefersSoftwareDevice();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_setAutomaticPipelineCache(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.setAutomaticPipelineCache";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickGraphicsConfiguration::setAutomaticPipelineCache(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutomaticPipelineCache(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutomaticPipelineCache(bool)
            cppSelf->setAutomaticPipelineCache(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_setDebugLayer(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.setDebugLayer";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickGraphicsConfiguration::setDebugLayer(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDebugLayer(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDebugLayer(bool)
            cppSelf->setDebugLayer(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_setDebugMarkers(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.setDebugMarkers";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickGraphicsConfiguration::setDebugMarkers(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDebugMarkers(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDebugMarkers(bool)
            cppSelf->setDebugMarkers(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_setDepthBufferFor2D(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.setDepthBufferFor2D";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickGraphicsConfiguration::setDepthBufferFor2D(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDepthBufferFor2D(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthBufferFor2D(bool)
            cppSelf->setDepthBufferFor2D(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_setDeviceExtensions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.setDeviceExtensions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickGraphicsConfiguration::setDeviceExtensions(QList<QByteArray>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtQuickTypeConverters[SBK_QtQuick_QList_QByteArray_IDX], (pyArg)))) {
        overloadId = 0; // setDeviceExtensions(QList<QByteArray>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QList<QByteArray> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDeviceExtensions(QList<QByteArray>)
            cppSelf->setDeviceExtensions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_setPipelineCacheLoadFile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.setPipelineCacheLoadFile";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickGraphicsConfiguration::setPipelineCacheLoadFile(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPipelineCacheLoadFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPipelineCacheLoadFile(QString)
            cppSelf->setPipelineCacheLoadFile(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_setPipelineCacheSaveFile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.setPipelineCacheSaveFile";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickGraphicsConfiguration::setPipelineCacheSaveFile(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPipelineCacheSaveFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPipelineCacheSaveFile(QString)
            cppSelf->setPipelineCacheSaveFile(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_setPreferSoftwareDevice(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.setPreferSoftwareDevice";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickGraphicsConfiguration::setPreferSoftwareDevice(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPreferSoftwareDevice(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPreferSoftwareDevice(bool)
            cppSelf->setPreferSoftwareDevice(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_setTimestamps(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.setTimestamps";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickGraphicsConfiguration::setTimestamps(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setTimestamps(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTimestamps(bool)
            cppSelf->setTimestamps(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickGraphicsConfigurationFunc_timestampsEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsConfiguration.timestampsEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // timestampsEnabled()const
            bool cppResult = const_cast<const ::QQuickGraphicsConfiguration *>(cppSelf)->timestampsEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickGraphicsConfiguration__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQuickGraphicsConfiguration_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuickGraphicsConfiguration_methods[] = {
    {"deviceExtensions", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_deviceExtensions), METH_NOARGS, nullptr},
    {"isAutomaticPipelineCacheEnabled", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_isAutomaticPipelineCacheEnabled), METH_NOARGS, nullptr},
    {"isDebugLayerEnabled", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_isDebugLayerEnabled), METH_NOARGS, nullptr},
    {"isDebugMarkersEnabled", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_isDebugMarkersEnabled), METH_NOARGS, nullptr},
    {"isDepthBufferEnabledFor2D", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_isDepthBufferEnabledFor2D), METH_NOARGS, nullptr},
    {"pipelineCacheLoadFile", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_pipelineCacheLoadFile), METH_NOARGS, nullptr},
    {"pipelineCacheSaveFile", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_pipelineCacheSaveFile), METH_NOARGS, nullptr},
    {"preferredInstanceExtensions", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_preferredInstanceExtensions), METH_NOARGS|METH_STATIC, nullptr},
    {"prefersSoftwareDevice", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_prefersSoftwareDevice), METH_NOARGS, nullptr},
    {"setAutomaticPipelineCache", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_setAutomaticPipelineCache), METH_O, nullptr},
    {"setDebugLayer", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_setDebugLayer), METH_O, nullptr},
    {"setDebugMarkers", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_setDebugMarkers), METH_O, nullptr},
    {"setDepthBufferFor2D", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_setDepthBufferFor2D), METH_O, nullptr},
    {"setDeviceExtensions", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_setDeviceExtensions), METH_O, nullptr},
    {"setPipelineCacheLoadFile", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_setPipelineCacheLoadFile), METH_O, nullptr},
    {"setPipelineCacheSaveFile", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_setPipelineCacheSaveFile), METH_O, nullptr},
    {"setPreferSoftwareDevice", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_setPreferSoftwareDevice), METH_O, nullptr},
    {"setTimestamps", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_setTimestamps), METH_O, nullptr},
    {"timestampsEnabled", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfigurationFunc_timestampsEnabled), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsConfiguration__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QQuickGraphicsConfiguration_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuickGraphicsConfiguration_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuickGraphicsConfiguration_Type = nullptr;
static PyTypeObject *Sbk_QQuickGraphicsConfiguration_TypeF(void)
{
    return _Sbk_QQuickGraphicsConfiguration_Type;
}

static PyType_Slot Sbk_QQuickGraphicsConfiguration_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuickGraphicsConfiguration_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuickGraphicsConfiguration_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuickGraphicsConfiguration_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuickGraphicsConfiguration_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuickGraphicsConfiguration_spec = {
    "2:PySide6.QtQuick.QQuickGraphicsConfiguration",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuickGraphicsConfiguration_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuickGraphicsConfiguration_PythonToCpp_QQuickGraphicsConfiguration_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuickGraphicsConfiguration_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuickGraphicsConfiguration_PythonToCpp_QQuickGraphicsConfiguration_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickGraphicsConfiguration_TypeF()))
        return QQuickGraphicsConfiguration_PythonToCpp_QQuickGraphicsConfiguration_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuickGraphicsConfiguration_PTR_CppToPython_QQuickGraphicsConfiguration(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QQuickGraphicsConfiguration *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QQuickGraphicsConfiguration_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QQuickGraphicsConfiguration_COPY_CppToPython_QQuickGraphicsConfiguration(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QQuickGraphicsConfiguration *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QQuickGraphicsConfiguration_TypeF(), new ::QQuickGraphicsConfiguration(*source), true, true);
}

// Python to C++ copy conversion.
static void QQuickGraphicsConfiguration_PythonToCpp_QQuickGraphicsConfiguration_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QQuickGraphicsConfiguration *>(cppOut) = *reinterpret_cast< ::QQuickGraphicsConfiguration *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QQuickGraphicsConfiguration_PythonToCpp_QQuickGraphicsConfiguration_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickGraphicsConfiguration_TypeF()))
        return QQuickGraphicsConfiguration_PythonToCpp_QQuickGraphicsConfiguration_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QQuickGraphicsConfiguration_SignatureStrings[] = {
    "1:PySide6.QtQuick.QQuickGraphicsConfiguration(self)",
    "0:PySide6.QtQuick.QQuickGraphicsConfiguration(self,other:PySide6.QtQuick.QQuickGraphicsConfiguration)",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.deviceExtensions(self)->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.isAutomaticPipelineCacheEnabled(self)->bool",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.isDebugLayerEnabled(self)->bool",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.isDebugMarkersEnabled(self)->bool",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.isDepthBufferEnabledFor2D(self)->bool",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.pipelineCacheLoadFile(self)->QString",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.pipelineCacheSaveFile(self)->QString",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.preferredInstanceExtensions()->QList[PySide6.QtCore.QByteArray]",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.prefersSoftwareDevice(self)->bool",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.setAutomaticPipelineCache(self,enable:bool)",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.setDebugLayer(self,enable:bool)",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.setDebugMarkers(self,enable:bool)",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.setDepthBufferFor2D(self,enable:bool)",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.setDeviceExtensions(self,extensions:QList[PySide6.QtCore.QByteArray])",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.setPipelineCacheLoadFile(self,filename:QString)",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.setPipelineCacheSaveFile(self,filename:QString)",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.setPreferSoftwareDevice(self,enable:bool)",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.setTimestamps(self,enable:bool)",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.timestampsEnabled(self)->bool",
    "PySide6.QtQuick.QQuickGraphicsConfiguration.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QQuickGraphicsConfiguration(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuickGraphicsConfiguration_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQuickGraphicsConfiguration_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuickGraphicsConfiguration",
        "QQuickGraphicsConfiguration",
        &Sbk_QQuickGraphicsConfiguration_spec,
        &Shiboken::callCppDestructor< ::QQuickGraphicsConfiguration >,
        Sbk_QQuickGraphicsConfiguration_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QQuickGraphicsConfiguration_TypeF(); // references _Sbk_QQuickGraphicsConfiguration_Type
    InitSignatureStrings(pyType, QQuickGraphicsConfiguration_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuickGraphicsConfiguration_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsConfiguration_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuickGraphicsConfiguration_PythonToCpp_QQuickGraphicsConfiguration_PTR,
        is_QQuickGraphicsConfiguration_PythonToCpp_QQuickGraphicsConfiguration_PTR_Convertible,
        QQuickGraphicsConfiguration_PTR_CppToPython_QQuickGraphicsConfiguration,
        QQuickGraphicsConfiguration_COPY_CppToPython_QQuickGraphicsConfiguration);

    Shiboken::Conversions::registerConverterName(converter, "QQuickGraphicsConfiguration");
    Shiboken::Conversions::registerConverterName(converter, "QQuickGraphicsConfiguration*");
    Shiboken::Conversions::registerConverterName(converter, "QQuickGraphicsConfiguration&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuickGraphicsConfiguration).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QQuickGraphicsConfiguration_PythonToCpp_QQuickGraphicsConfiguration_COPY,
        is_QQuickGraphicsConfiguration_PythonToCpp_QQuickGraphicsConfiguration_COPY_Convertible);

    qRegisterMetaType< ::QQuickGraphicsConfiguration >("QQuickGraphicsConfiguration");

    return pyType;
}
