// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qquickgraphicsdevice_wrapper.h"

// Argument includes
#include <QtGui/qopenglcontext.h>
#include <QtQuick/qquickgraphicsdevice.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuickGraphicsDevice_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuickGraphicsDevice >()))
        return -1;

    ::QQuickGraphicsDevice *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsDevice.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QQuickGraphicsDevice", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQuickGraphicsDevice::QQuickGraphicsDevice()
    // 1: QQuickGraphicsDevice::QQuickGraphicsDevice(QQuickGraphicsDevice)
    if (numArgs == 0) {
        overloadId = 0; // QQuickGraphicsDevice()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsDevice_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QQuickGraphicsDevice(QQuickGraphicsDevice)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QQuickGraphicsDevice()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QQuickGraphicsDevice()
                cptr = new ::QQuickGraphicsDevice();
            }
            break;
        }
        case 1: // QQuickGraphicsDevice(const QQuickGraphicsDevice & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QQuickGraphicsDevice cppArg0_local;
            ::QQuickGraphicsDevice *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QQuickGraphicsDevice(QQuickGraphicsDevice)
                cptr = new ::QQuickGraphicsDevice(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QQuickGraphicsDevice >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQuickGraphicsDeviceFunc_fromOpenGLContext(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsDevice.fromOpenGLContext";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QQuickGraphicsDevice::fromOpenGLContext(QOpenGLContext*)->QQuickGraphicsDevice
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QOpenGLContext_IDX]), (pyArg)))) {
        overloadId = 0; // fromOpenGLContext(QOpenGLContext*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QOpenGLContext *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromOpenGLContext(QOpenGLContext*)
            QQuickGraphicsDevice cppResult = ::QQuickGraphicsDevice::fromOpenGLContext(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsDevice_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickGraphicsDeviceFunc_fromRhi(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsDevice.fromRhi";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QQuickGraphicsDevice::fromRhi(QRhi*)->QQuickGraphicsDevice
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhi_IDX]), (pyArg)))) {
        overloadId = 0; // fromRhi(QRhi*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhi *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromRhi(QRhi*)
            QQuickGraphicsDevice cppResult = ::QQuickGraphicsDevice::fromRhi(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsDevice_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickGraphicsDeviceFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QQuickGraphicsDevice.isNull";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isNull()const
            bool cppResult = const_cast<const ::QQuickGraphicsDevice *>(cppSelf)->isNull();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickGraphicsDevice__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QQuickGraphicsDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsDevice_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQuickGraphicsDevice_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuickGraphicsDevice_methods[] = {
    {"fromOpenGLContext", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsDeviceFunc_fromOpenGLContext), METH_O|METH_STATIC, nullptr},
    {"fromRhi", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsDeviceFunc_fromRhi), METH_O|METH_STATIC, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsDeviceFunc_isNull), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QQuickGraphicsDevice__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQuickGraphicsDevice___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QQuickGraphicsDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsDevice_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QQuickGraphicsDevice_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuickGraphicsDevice_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuickGraphicsDevice_Type = nullptr;
static PyTypeObject *Sbk_QQuickGraphicsDevice_TypeF(void)
{
    return _Sbk_QQuickGraphicsDevice_Type;
}

static PyType_Slot Sbk_QQuickGraphicsDevice_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuickGraphicsDevice_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuickGraphicsDevice_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuickGraphicsDevice_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuickGraphicsDevice_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QQuickGraphicsDevice___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuickGraphicsDevice_spec = {
    "2:PySide6.QtQuick.QQuickGraphicsDevice",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuickGraphicsDevice_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuickGraphicsDevice_PythonToCpp_QQuickGraphicsDevice_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuickGraphicsDevice_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuickGraphicsDevice_PythonToCpp_QQuickGraphicsDevice_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickGraphicsDevice_TypeF()))
        return QQuickGraphicsDevice_PythonToCpp_QQuickGraphicsDevice_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuickGraphicsDevice_PTR_CppToPython_QQuickGraphicsDevice(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QQuickGraphicsDevice *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QQuickGraphicsDevice_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QQuickGraphicsDevice_COPY_CppToPython_QQuickGraphicsDevice(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QQuickGraphicsDevice *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QQuickGraphicsDevice_TypeF(), new ::QQuickGraphicsDevice(*source), true, true);
}

// Python to C++ copy conversion.
static void QQuickGraphicsDevice_PythonToCpp_QQuickGraphicsDevice_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QQuickGraphicsDevice *>(cppOut) = *reinterpret_cast< ::QQuickGraphicsDevice *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsDevice_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QQuickGraphicsDevice_PythonToCpp_QQuickGraphicsDevice_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickGraphicsDevice_TypeF()))
        return QQuickGraphicsDevice_PythonToCpp_QQuickGraphicsDevice_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QQuickGraphicsDevice_SignatureStrings[] = {
    "1:PySide6.QtQuick.QQuickGraphicsDevice(self)",
    "0:PySide6.QtQuick.QQuickGraphicsDevice(self,other:PySide6.QtQuick.QQuickGraphicsDevice)",
    "PySide6.QtQuick.QQuickGraphicsDevice.fromOpenGLContext(context:PySide6.QtGui.QOpenGLContext)->PySide6.QtQuick.QQuickGraphicsDevice",
    "PySide6.QtQuick.QQuickGraphicsDevice.fromRhi(rhi:PySide6.QtGui.QRhi)->PySide6.QtQuick.QQuickGraphicsDevice",
    "PySide6.QtQuick.QQuickGraphicsDevice.isNull(self)->bool",
    "PySide6.QtQuick.QQuickGraphicsDevice.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QQuickGraphicsDevice(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsDevice_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsDevice_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuickGraphicsDevice_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQuickGraphicsDevice_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuickGraphicsDevice",
        "QQuickGraphicsDevice",
        &Sbk_QQuickGraphicsDevice_spec,
        &Shiboken::callCppDestructor< ::QQuickGraphicsDevice >,
        Sbk_QQuickGraphicsDevice_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QQuickGraphicsDevice_TypeF(); // references _Sbk_QQuickGraphicsDevice_Type
    InitSignatureStrings(pyType, QQuickGraphicsDevice_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuickGraphicsDevice_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickGraphicsDevice_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuickGraphicsDevice_PythonToCpp_QQuickGraphicsDevice_PTR,
        is_QQuickGraphicsDevice_PythonToCpp_QQuickGraphicsDevice_PTR_Convertible,
        QQuickGraphicsDevice_PTR_CppToPython_QQuickGraphicsDevice,
        QQuickGraphicsDevice_COPY_CppToPython_QQuickGraphicsDevice);

    Shiboken::Conversions::registerConverterName(converter, "QQuickGraphicsDevice");
    Shiboken::Conversions::registerConverterName(converter, "QQuickGraphicsDevice*");
    Shiboken::Conversions::registerConverterName(converter, "QQuickGraphicsDevice&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuickGraphicsDevice).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QQuickGraphicsDevice_PythonToCpp_QQuickGraphicsDevice_COPY,
        is_QQuickGraphicsDevice_PythonToCpp_QQuickGraphicsDevice_COPY_Convertible);

    qRegisterMetaType< ::QQuickGraphicsDevice >("QQuickGraphicsDevice");

    return pyType;
}
