// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgnode_wrapper.h"

// Argument includes
#include <QtQuick/qsgnode.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGNodeWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGNodeWrapper::QSGNodeWrapper() : QSGNode()
{
    resetPyMethodCache();
    // ... middle
}

QSGNodeWrapper::QSGNodeWrapper(::QSGNode::NodeType type) : QSGNode(type)
{
    resetPyMethodCache();
    // ... middle
}

bool QSGNodeWrapper::isSubtreeBlocked() const
{
    if (m_PyMethodCache[0])
        return this->::QSGNode::isSubtreeBlocked();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isSubtreeBlocked";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGNode::isSubtreeBlocked();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGNode", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QSGNodeWrapper::preprocess()
{
    if (m_PyMethodCache[1]) {
        return this->::QSGNode::preprocess();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "preprocess";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSGNode::preprocess();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

QSGNodeWrapper::~QSGNodeWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGNode_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGNode >()))
        return -1;

    QSGNodeWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QSGNode", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QSGNode::QSGNode()
    // 1: QSGNode::QSGNode(QSGNode::NodeType)
    if (numArgs == 0) {
        overloadId = 0; // QSGNode()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_NodeType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // QSGNode(QSGNode::NodeType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QSGNode()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSGNode()
                cptr = new QSGNodeWrapper();
            }
            break;
        }
        case 1: // QSGNode(QSGNode::NodeType type)
        {
            ::QSGNode::NodeType cppArg0{QSGNode::BasicNodeType};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QSGNode(QSGNode::NodeType)
                cptr = new QSGNodeWrapper(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGNode >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGNodeFunc_appendChildNode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.appendChildNode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNode::appendChildNode(QSGNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), (pyArg)))) {
        overloadId = 0; // appendChildNode(QSGNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // appendChildNode(QSGNode*)
            cppSelf->appendChildNode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeFunc_childAtIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.childAtIndex";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNode::childAtIndex(int)const->QSGNode*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // childAtIndex(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // childAtIndex(int)const
            QSGNode * cppResult = const_cast<const ::QSGNode *>(cppSelf)->childAtIndex(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGNodeFunc_childCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.childCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // childCount()const
            int cppResult = const_cast<const ::QSGNode *>(cppSelf)->childCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGNodeFunc_clearDirty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtQuick.QSGNode.clearDirty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QSGNode", "clearDirty()");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        if (Shiboken::Errors::occurred() == nullptr) {
            // clearDirty()
            cppSelf->clearDirty();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeFunc_dirtyState(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.dirtyState";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QSGNode", "dirtyState() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        if (Shiboken::Errors::occurred() == nullptr) {
            // dirtyState()const
            QFlags<QSGNode::DirtyStateBit> cppResult = const_cast<const ::QSGNode *>(cppSelf)->dirtyState();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGNode_DirtyStateBit_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGNodeFunc_firstChild(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.firstChild";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // firstChild()const
            QSGNode * cppResult = const_cast<const ::QSGNode *>(cppSelf)->firstChild();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGNodeFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.flags";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // flags()const
            QFlags<QSGNode::Flag> cppResult = const_cast<const ::QSGNode *>(cppSelf)->flags();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGNode_Flag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGNodeFunc_insertChildNodeAfter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.insertChildNodeAfter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertChildNodeAfter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGNode::insertChildNodeAfter(QSGNode*,QSGNode*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insertChildNodeAfter(QSGNode*,QSGNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSGNode *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSGNode *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertChildNodeAfter(QSGNode*,QSGNode*)
            cppSelf->insertChildNodeAfter(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeFunc_insertChildNodeBefore(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.insertChildNodeBefore";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertChildNodeBefore", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGNode::insertChildNodeBefore(QSGNode*,QSGNode*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insertChildNodeBefore(QSGNode*,QSGNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSGNode *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QSGNode *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertChildNodeBefore(QSGNode*,QSGNode*)
            cppSelf->insertChildNodeBefore(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeFunc_isSubtreeBlocked(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.isSubtreeBlocked";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isSubtreeBlocked()const
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSGNode *>(cppSelf)->::QSGNode::isSubtreeBlocked()
                : const_cast<const ::QSGNode *>(cppSelf)->isSubtreeBlocked();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGNodeFunc_lastChild(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.lastChild";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // lastChild()const
            QSGNode * cppResult = const_cast<const ::QSGNode *>(cppSelf)->lastChild();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGNodeFunc_markDirty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.markDirty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNode::markDirty(QFlags<QSGNode::DirtyStateBit>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGNode_DirtyStateBit_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // markDirty(QFlags<QSGNode::DirtyStateBit>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QSGNode::DirtyStateBit> cppArg0 = QFlags<QSGNode::DirtyStateBit>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // markDirty(QFlags<QSGNode::DirtyStateBit>)
            cppSelf->markDirty(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeFunc_nextSibling(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.nextSibling";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // nextSibling()const
            QSGNode * cppResult = const_cast<const ::QSGNode *>(cppSelf)->nextSibling();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGNodeFunc_parent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.parent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // parent()const
            QSGNode * cppResult = const_cast<const ::QSGNode *>(cppSelf)->parent();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGNodeFunc_prependChildNode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.prependChildNode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNode::prependChildNode(QSGNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), (pyArg)))) {
        overloadId = 0; // prependChildNode(QSGNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // prependChildNode(QSGNode*)
            cppSelf->prependChildNode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeFunc_preprocess(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtQuick.QSGNode.preprocess";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // preprocess()
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QSGNode::preprocess()
                : cppSelf->preprocess();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeFunc_previousSibling(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.previousSibling";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // previousSibling()const
            QSGNode * cppResult = const_cast<const ::QSGNode *>(cppSelf)->previousSibling();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGNodeFunc_removeAllChildNodes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtQuick.QSGNode.removeAllChildNodes";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeAllChildNodes()
            cppSelf->removeAllChildNodes();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeFunc_removeChildNode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.removeChildNode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNode::removeChildNode(QSGNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), (pyArg)))) {
        overloadId = 0; // removeChildNode(QSGNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeChildNode(QSGNode*)
            cppSelf->removeChildNode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeFunc_reparentChildNodesTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.reparentChildNodesTo";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGNode::reparentChildNodesTo(QSGNode*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), (pyArg)))) {
        overloadId = 0; // reparentChildNodesTo(QSGNode*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGNode *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // reparentChildNodesTo(QSGNode*)
            cppSelf->reparentChildNodesTo(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeFunc_setFlag(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.setFlag";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:setFlag", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGNode::setFlag(QSGNode::Flag,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_Flag_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setFlag(QSGNode::Flag,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setFlag(QSGNode::Flag,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_arg__2 = Shiboken::String::createStaticString("arg__2");
            if (PyDict_Contains(kwds, key_arg__2) != 0) {
                value = PyDict_GetItem(kwds, key_arg__2);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_arg__2);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_arg__2);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QSGNode::Flag cppArg0 = static_cast< ::QSGNode::Flag>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlag(QSGNode::Flag,bool)
            cppSelf->setFlag(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeFunc_setFlags(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.setFlags";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:setFlags", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGNode::setFlags(QFlags<QSGNode::Flag>,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGNode_Flag_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setFlags(QFlags<QSGNode::Flag>,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setFlags(QFlags<QSGNode::Flag>,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_arg__2 = Shiboken::String::createStaticString("arg__2");
            if (PyDict_Contains(kwds, key_arg__2) != 0) {
                value = PyDict_GetItem(kwds, key_arg__2);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_arg__2);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_arg__2);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QFlags<QSGNode::Flag> cppArg0 = QFlags<QSGNode::Flag>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QSGNode::Flag>,bool)
            cppSelf->setFlags(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGNodeFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGNode.type";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // type()const
            QSGNode::NodeType cppResult = const_cast<const ::QSGNode *>(cppSelf)->type();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_NodeType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSGNode_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSGNode_EnumFlagInfo[] = {
    "DirtyStateBit:Flag:DirtyState",
    "Flag:Flag:Flags",
    "NodeType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGNode_methods[] = {
    {"appendChildNode", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_appendChildNode), METH_O, nullptr},
    {"childAtIndex", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_childAtIndex), METH_O, nullptr},
    {"childCount", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_childCount), METH_NOARGS, nullptr},
    {"clearDirty", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_clearDirty), METH_NOARGS, nullptr},
    {"dirtyState", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_dirtyState), METH_NOARGS, nullptr},
    {"firstChild", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_firstChild), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_flags), METH_NOARGS, nullptr},
    {"insertChildNodeAfter", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_insertChildNodeAfter), METH_VARARGS, nullptr},
    {"insertChildNodeBefore", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_insertChildNodeBefore), METH_VARARGS, nullptr},
    {"isSubtreeBlocked", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_isSubtreeBlocked), METH_NOARGS, nullptr},
    {"lastChild", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_lastChild), METH_NOARGS, nullptr},
    {"markDirty", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_markDirty), METH_O, nullptr},
    {"nextSibling", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_nextSibling), METH_NOARGS, nullptr},
    {"parent", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_parent), METH_NOARGS, nullptr},
    {"prependChildNode", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_prependChildNode), METH_O, nullptr},
    {"preprocess", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_preprocess), METH_NOARGS, nullptr},
    {"previousSibling", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_previousSibling), METH_NOARGS, nullptr},
    {"removeAllChildNodes", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_removeAllChildNodes), METH_NOARGS, nullptr},
    {"removeChildNode", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_removeChildNode), METH_O, nullptr},
    {"reparentChildNodesTo", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_reparentChildNodesTo), METH_O, nullptr},
    {"setFlag", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_setFlag), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_setFlags), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QSGNodeFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGNode_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGNodeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGNode_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGNode_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QSGNode__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGNode_Type = nullptr;
static PyTypeObject *Sbk_QSGNode_TypeF(void)
{
    return _Sbk_QSGNode_Type;
}

static PyType_Slot Sbk_QSGNode_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QSGNode__repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGNode_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGNode_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGNode_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGNode_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGNode_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGNode_spec = {
    "2:PySide6.QtQuick.QSGNode",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGNode_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QSGNode_NodeType_PythonToCpp_QSGNode_NodeType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGNode::NodeType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGNode::NodeType *>(cppOut) = value;

}
static PythonToCppFunc is_QSGNode_NodeType_PythonToCpp_QSGNode_NodeType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_NodeType_IDX])))
        return QSGNode_NodeType_PythonToCpp_QSGNode_NodeType;
    return {};
}
static PyObject *QSGNode_NodeType_CppToPython_QSGNode_NodeType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSGNode::NodeType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_NodeType_IDX]), castCppIn);

}

static void QSGNode_Flag_PythonToCpp_QSGNode_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGNode::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGNode::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_QSGNode_Flag_PythonToCpp_QSGNode_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_Flag_IDX])))
        return QSGNode_Flag_PythonToCpp_QSGNode_Flag;
    return {};
}
static PyObject *QSGNode_Flag_CppToPython_QSGNode_Flag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSGNode::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_Flag_IDX]), castCppIn);

}

static void QSGNode_DirtyStateBit_PythonToCpp_QSGNode_DirtyStateBit(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGNode::DirtyStateBit>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGNode::DirtyStateBit *>(cppOut) = value;

}
static PythonToCppFunc is_QSGNode_DirtyStateBit_PythonToCpp_QSGNode_DirtyStateBit_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_DirtyStateBit_IDX])))
        return QSGNode_DirtyStateBit_PythonToCpp_QSGNode_DirtyStateBit;
    return {};
}
static PyObject *QSGNode_DirtyStateBit_CppToPython_QSGNode_DirtyStateBit(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSGNode::DirtyStateBit *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_DirtyStateBit_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGNode_PythonToCpp_QSGNode_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGNode_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGNode_PythonToCpp_QSGNode_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGNode_TypeF()))
        return QSGNode_PythonToCpp_QSGNode_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGNode_PTR_CppToPython_QSGNode(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QSGNode *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QSGNode_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QSGNode_SignatureStrings[] = {
    "1:PySide6.QtQuick.QSGNode(self)",
    "0:PySide6.QtQuick.QSGNode(self,type:PySide6.QtQuick.QSGNode.NodeType)",
    "PySide6.QtQuick.QSGNode.appendChildNode(self,node:PySide6.QtQuick.QSGNode)",
    "PySide6.QtQuick.QSGNode.childAtIndex(self,i:int)->PySide6.QtQuick.QSGNode",
    "PySide6.QtQuick.QSGNode.childCount(self)->int",
    "PySide6.QtQuick.QSGNode.clearDirty(self)",
    "PySide6.QtQuick.QSGNode.dirtyState(self)->PySide6.QtQuick.QSGNode.DirtyStateBit",
    "PySide6.QtQuick.QSGNode.firstChild(self)->PySide6.QtQuick.QSGNode",
    "PySide6.QtQuick.QSGNode.flags(self)->PySide6.QtQuick.QSGNode.Flag",
    "PySide6.QtQuick.QSGNode.insertChildNodeAfter(self,node:PySide6.QtQuick.QSGNode,after:PySide6.QtQuick.QSGNode)",
    "PySide6.QtQuick.QSGNode.insertChildNodeBefore(self,node:PySide6.QtQuick.QSGNode,before:PySide6.QtQuick.QSGNode)",
    "PySide6.QtQuick.QSGNode.isSubtreeBlocked(self)->bool",
    "PySide6.QtQuick.QSGNode.lastChild(self)->PySide6.QtQuick.QSGNode",
    "PySide6.QtQuick.QSGNode.markDirty(self,bits:PySide6.QtQuick.QSGNode.DirtyStateBit)",
    "PySide6.QtQuick.QSGNode.nextSibling(self)->PySide6.QtQuick.QSGNode",
    "PySide6.QtQuick.QSGNode.parent(self)->PySide6.QtQuick.QSGNode",
    "PySide6.QtQuick.QSGNode.prependChildNode(self,node:PySide6.QtQuick.QSGNode)",
    "PySide6.QtQuick.QSGNode.preprocess(self)",
    "PySide6.QtQuick.QSGNode.previousSibling(self)->PySide6.QtQuick.QSGNode",
    "PySide6.QtQuick.QSGNode.removeAllChildNodes(self)",
    "PySide6.QtQuick.QSGNode.removeChildNode(self,node:PySide6.QtQuick.QSGNode)",
    "PySide6.QtQuick.QSGNode.reparentChildNodesTo(self,newParent:PySide6.QtQuick.QSGNode)",
    "PySide6.QtQuick.QSGNode.setFlag(self,arg__1:PySide6.QtQuick.QSGNode.Flag,arg__2:bool=true)",
    "PySide6.QtQuick.QSGNode.setFlags(self,arg__1:PySide6.QtQuick.QSGNode.Flag,arg__2:bool=true)",
    "PySide6.QtQuick.QSGNode.type(self)->PySide6.QtQuick.QSGNode.NodeType",
    nullptr}; // Sentinel

PyTypeObject *init_QSGNode(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGNode_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSGNode_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGNode",
        "QSGNode*",
        &Sbk_QSGNode_spec,
        &Shiboken::callCppDestructor< QSGNode >,
        Sbk_QSGNode_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGNode_TypeF(); // references _Sbk_QSGNode_Type
    InitSignatureStrings(pyType, QSGNode_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGNode_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGNode_PythonToCpp_QSGNode_PTR,
        is_QSGNode_PythonToCpp_QSGNode_PTR_Convertible,
        QSGNode_PTR_CppToPython_QSGNode);

    Shiboken::Conversions::registerConverterName(converter, "QSGNode");
    Shiboken::Conversions::registerConverterName(converter, "QSGNode*");
    Shiboken::Conversions::registerConverterName(converter, "QSGNode&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGNode).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGNodeWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSGNode_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'NodeType'.
    const char *NodeType_Initializer[] = {
        "BasicNodeType",
        "GeometryNodeType",
        "TransformNodeType",
        "ClipNodeType",
        "OpacityNodeType",
        "RootNodeType",
        "RenderNodeType",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t NodeType_InitializerValues[] = {
        uint8_t(QSGNode::NodeType::BasicNodeType),     //  0x00  0
        uint8_t(QSGNode::NodeType::GeometryNodeType),  //  0x01  1
        uint8_t(QSGNode::NodeType::TransformNodeType), //  0x02  2
        uint8_t(QSGNode::NodeType::ClipNodeType),      //  0x03  3
        uint8_t(QSGNode::NodeType::OpacityNodeType),   //  0x04  4
        uint8_t(QSGNode::NodeType::RootNodeType),      //  0x05  5
        uint8_t(QSGNode::NodeType::RenderNodeType)     //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGNode_TypeF(),
        "2:PySide6.QtQuick.QSGNode.NodeType",
        NodeType_Initializer, NodeType_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_NodeType_IDX].type = EType;
    // Register converter for enum 'QSGNode::NodeType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGNode_NodeType_CppToPython_QSGNode_NodeType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGNode_NodeType_PythonToCpp_QSGNode_NodeType,
            is_QSGNode_NodeType_PythonToCpp_QSGNode_NodeType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGNode::NodeType");
        Shiboken::Conversions::registerConverterName(converter, "NodeType");
    }
    // End of 'NodeType' enum.

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "OwnedByParent",
        "UsePreprocess",
        "OwnsGeometry",
        "OwnsMaterial",
        "OwnsOpaqueMaterial",
        "IsVisitableNode",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t Flag_InitializerValues[] = {
        uint32_t(QSGNode::Flag::OwnedByParent),      //  0x00000001  1
        uint32_t(QSGNode::Flag::UsePreprocess),      //  0x00000002  2
        uint32_t(QSGNode::Flag::OwnsGeometry),       //  0x00010000  65536
        uint32_t(QSGNode::Flag::OwnsMaterial),       //  0x00020000  131072
        uint32_t(QSGNode::Flag::OwnsOpaqueMaterial), //  0x00040000  262144
        uint32_t(QSGNode::Flag::IsVisitableNode)     //  0x01000000  16777216
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGNode_TypeF(),
        "2:PySide6.QtQuick.QSGNode.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGNode_Flag_IDX].type =
        EType;
    // Register converter for enum 'QSGNode::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGNode_Flag_CppToPython_QSGNode_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGNode_Flag_PythonToCpp_QSGNode_Flag,
            is_QSGNode_Flag_PythonToCpp_QSGNode_Flag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGNode::Flag");
        Shiboken::Conversions::registerConverterName(converter, "Flag");
        // Register converter for flag 'QFlags<QSGNode::Flag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QSGNode::Flag>");
        Shiboken::Conversions::registerConverterName(converter, "QSGNode::Flags");
    }
    // End of 'Flag' enum/flags.

    // Initialization of enum 'DirtyStateBit'.
    const char *DirtyStateBit_Initializer[] = {
        "DirtySubtreeBlocked",
        "DirtyMatrix",
        "DirtyNodeAdded",
        "DirtyNodeRemoved",
        "DirtyGeometry",
        "DirtyMaterial",
        "DirtyOpacity",
        "DirtyForceUpdate",
        "DirtyUsePreprocess",
        "DirtyPropagationMask",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t DirtyStateBit_InitializerValues[] = {
        uint16_t(QSGNode::DirtyStateBit::DirtySubtreeBlocked), //  0x0080  128
        uint16_t(QSGNode::DirtyStateBit::DirtyMatrix),         //  0x0100  256
        uint16_t(QSGNode::DirtyStateBit::DirtyNodeAdded),      //  0x0400  1024
        uint16_t(QSGNode::DirtyStateBit::DirtyNodeRemoved),    //  0x0800  2048
        uint16_t(QSGNode::DirtyStateBit::DirtyGeometry),       //  0x1000  4096
        uint16_t(QSGNode::DirtyStateBit::DirtyMaterial),       //  0x2000  8192
        uint16_t(QSGNode::DirtyStateBit::DirtyOpacity),        //  0x4000  16384
        uint16_t(QSGNode::DirtyStateBit::DirtyForceUpdate),    //  0x8000  32768
        uint16_t(QSGNode::DirtyStateBit::DirtyUsePreprocess),  //  0x0002  2
        uint16_t(QSGNode::DirtyStateBit::DirtyPropagationMask) //  0xc500  50432
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGNode_TypeF(),
        "2:PySide6.QtQuick.QSGNode.DirtyStateBit",
        DirtyStateBit_Initializer, DirtyStateBit_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_DirtyStateBit_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGNode_DirtyStateBit_IDX].type =
        EType;
    // Register converter for enum 'QSGNode::DirtyStateBit'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGNode_DirtyStateBit_CppToPython_QSGNode_DirtyStateBit);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGNode_DirtyStateBit_PythonToCpp_QSGNode_DirtyStateBit,
            is_QSGNode_DirtyStateBit_PythonToCpp_QSGNode_DirtyStateBit_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGNode::DirtyStateBit");
        Shiboken::Conversions::registerConverterName(converter, "DirtyStateBit");
        // Register converter for flag 'QFlags<QSGNode::DirtyStateBit>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QSGNode::DirtyStateBit>");
        Shiboken::Conversions::registerConverterName(converter, "QSGNode::DirtyState");
    }
    // End of 'DirtyStateBit' enum/flags.

    qRegisterMetaType< ::QSGNode *>();
    qRegisterMetaType< ::QSGNode::NodeType >("QSGNode::NodeType");
    qRegisterMetaType< ::QSGNode::Flag >("QSGNode::Flag");
    qRegisterMetaType< ::QSGNode::DirtyStateBit >("QSGNode::DirtyStateBit");

    return pyType;
}
