// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgopaquetexturematerial_wrapper.h"

// Argument includes
#include <QtQuick/qsgmaterial.h>
#include <QtQuick/qsgmaterialshader.h>
#include <QtQuick/qsgmaterialtype.h>
#include <QtQuick/qsgrendererinterface.h>
#include <QtQuick/qsgtexture.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGOpaqueTextureMaterialWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGOpaqueTextureMaterialWrapper::QSGOpaqueTextureMaterialWrapper() : QSGOpaqueTextureMaterial()
{
    resetPyMethodCache();
    // ... middle
}

int QSGOpaqueTextureMaterialWrapper::compare(const ::QSGMaterial * other) const
{
    if (m_PyMethodCache[0])
        return this->::QSGOpaqueTextureMaterial::compare(other);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "compare";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGOpaqueTextureMaterial::compare(other);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), other)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), other)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGOpaqueTextureMaterial", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSGMaterialShader * QSGOpaqueTextureMaterialWrapper::createShader(::QSGRendererInterface::RenderMode renderMode) const
{
    if (m_PyMethodCache[1])
        return this->::QSGOpaqueTextureMaterial::createShader(renderMode);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createShader";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSGOpaqueTextureMaterial::createShader(renderMode);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX])))->converter, &renderMode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX])))->converter, &renderMode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGOpaqueTextureMaterial", funcName, Shiboken::SbkType< QSGMaterialShader >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSGMaterialShader *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSGMaterialType * QSGOpaqueTextureMaterialWrapper::type() const
{
    if (m_PyMethodCache[2])
        return this->::QSGOpaqueTextureMaterial::type();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "type";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QSGOpaqueTextureMaterial::type();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialType_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGOpaqueTextureMaterial", funcName, Shiboken::SbkType< QSGMaterialType >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSGMaterialType *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QSGOpaqueTextureMaterialWrapper::~QSGOpaqueTextureMaterialWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGOpaqueTextureMaterial_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGOpaqueTextureMaterial >()))
        return -1;

    QSGOpaqueTextureMaterialWrapper *cptr{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSGOpaqueTextureMaterial()
            cptr = new QSGOpaqueTextureMaterialWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGOpaqueTextureMaterial >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_anisotropyLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.anisotropyLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // anisotropyLevel()const
            QSGTexture::AnisotropyLevel cppResult = const_cast<const ::QSGOpaqueTextureMaterial *>(cppSelf)->anisotropyLevel();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_AnisotropyLevel_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_compare(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.compare";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGMaterial::compare(const QSGMaterial*)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]), (pyArg)))) {
        overloadId = 0; // compare(const QSGMaterial*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGMaterial *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // compare(const QSGMaterial*)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSGOpaqueTextureMaterial *>(cppSelf)->::QSGOpaqueTextureMaterial::compare(cppArg0)
                : const_cast<const ::QSGOpaqueTextureMaterial *>(cppSelf)->compare(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_createShader(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.createShader";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGMaterial::createShader(QSGRendererInterface::RenderMode)const->QSGMaterialShader*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // createShader(QSGRendererInterface::RenderMode)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QSGRendererInterface::RenderMode cppArg0{QSGRendererInterface::RenderMode2D};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createShader(QSGRendererInterface::RenderMode)const
            QSGMaterialShader * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSGOpaqueTextureMaterial *>(cppSelf)->::QSGOpaqueTextureMaterial::createShader(cppArg0)
                : const_cast<const ::QSGOpaqueTextureMaterial *>(cppSelf)->createShader(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_filtering(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.filtering";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // filtering()const
            QSGTexture::Filtering cppResult = const_cast<const ::QSGOpaqueTextureMaterial *>(cppSelf)->filtering();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_Filtering_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_horizontalWrapMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.horizontalWrapMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // horizontalWrapMode()const
            QSGTexture::WrapMode cppResult = const_cast<const ::QSGOpaqueTextureMaterial *>(cppSelf)->horizontalWrapMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_WrapMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_mipmapFiltering(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.mipmapFiltering";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mipmapFiltering()const
            QSGTexture::Filtering cppResult = const_cast<const ::QSGOpaqueTextureMaterial *>(cppSelf)->mipmapFiltering();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_Filtering_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_setAnisotropyLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.setAnisotropyLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGOpaqueTextureMaterial::setAnisotropyLevel(QSGTexture::AnisotropyLevel)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_AnisotropyLevel_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAnisotropyLevel(QSGTexture::AnisotropyLevel)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QSGTexture::AnisotropyLevel cppArg0{QSGTexture::AnisotropyNone};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAnisotropyLevel(QSGTexture::AnisotropyLevel)
            cppSelf->setAnisotropyLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_setFiltering(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.setFiltering";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGOpaqueTextureMaterial::setFiltering(QSGTexture::Filtering)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_Filtering_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFiltering(QSGTexture::Filtering)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QSGTexture::Filtering cppArg0{QSGTexture::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFiltering(QSGTexture::Filtering)
            cppSelf->setFiltering(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_setHorizontalWrapMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.setHorizontalWrapMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGOpaqueTextureMaterial::setHorizontalWrapMode(QSGTexture::WrapMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_WrapMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setHorizontalWrapMode(QSGTexture::WrapMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QSGTexture::WrapMode cppArg0{QSGTexture::Repeat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHorizontalWrapMode(QSGTexture::WrapMode)
            cppSelf->setHorizontalWrapMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_setMipmapFiltering(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.setMipmapFiltering";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGOpaqueTextureMaterial::setMipmapFiltering(QSGTexture::Filtering)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_Filtering_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMipmapFiltering(QSGTexture::Filtering)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QSGTexture::Filtering cppArg0{QSGTexture::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMipmapFiltering(QSGTexture::Filtering)
            cppSelf->setMipmapFiltering(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_setTexture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.setTexture";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGOpaqueTextureMaterial::setTexture(QSGTexture*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_IDX]), (pyArg)))) {
        overloadId = 0; // setTexture(QSGTexture*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSGTexture *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTexture(QSGTexture*)
            cppSelf->setTexture(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_setVerticalWrapMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.setVerticalWrapMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QSGOpaqueTextureMaterial::setVerticalWrapMode(QSGTexture::WrapMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_WrapMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setVerticalWrapMode(QSGTexture::WrapMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QSGTexture::WrapMode cppArg0{QSGTexture::Repeat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVerticalWrapMode(QSGTexture::WrapMode)
            cppSelf->setVerticalWrapMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_texture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.texture";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // texture()const
            QSGTexture * cppResult = const_cast<const ::QSGOpaqueTextureMaterial *>(cppSelf)->texture();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.type";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // type()const
            QSGMaterialType * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QSGOpaqueTextureMaterial *>(cppSelf)->::QSGOpaqueTextureMaterial::type()
                : const_cast<const ::QSGOpaqueTextureMaterial *>(cppSelf)->type();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialType_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGOpaqueTextureMaterialFunc_verticalWrapMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGOpaqueTextureMaterial.verticalWrapMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // verticalWrapMode()const
            QSGTexture::WrapMode cppResult = const_cast<const ::QSGOpaqueTextureMaterial *>(cppSelf)->verticalWrapMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_WrapMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSGOpaqueTextureMaterial_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGOpaqueTextureMaterial_methods[] = {
    {"anisotropyLevel", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_anisotropyLevel), METH_NOARGS, nullptr},
    {"compare", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_compare), METH_O, nullptr},
    {"createShader", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_createShader), METH_O, nullptr},
    {"filtering", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_filtering), METH_NOARGS, nullptr},
    {"horizontalWrapMode", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_horizontalWrapMode), METH_NOARGS, nullptr},
    {"mipmapFiltering", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_mipmapFiltering), METH_NOARGS, nullptr},
    {"setAnisotropyLevel", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_setAnisotropyLevel), METH_O, nullptr},
    {"setFiltering", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_setFiltering), METH_O, nullptr},
    {"setHorizontalWrapMode", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_setHorizontalWrapMode), METH_O, nullptr},
    {"setMipmapFiltering", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_setMipmapFiltering), METH_O, nullptr},
    {"setTexture", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_setTexture), METH_O, nullptr},
    {"setVerticalWrapMode", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_setVerticalWrapMode), METH_O, nullptr},
    {"texture", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_texture), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_type), METH_NOARGS, nullptr},
    {"verticalWrapMode", reinterpret_cast<PyCFunction>(Sbk_QSGOpaqueTextureMaterialFunc_verticalWrapMode), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGOpaqueTextureMaterial_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGOpaqueTextureMaterialWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QSGOpaqueTextureMaterial_get_m_texture(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_IDX]), cppSelf->m_texture);
    return pyOut;
}
static int Sbk_QSGOpaqueTextureMaterial_set_m_texture(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_texture");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTexture_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_texture", "QSGTexture");
        return -1;
    }

    auto *&cppOut_ptr = cppSelf->m_texture;
    pythonToCpp(pyIn, &cppOut_ptr);

    Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "m_texture", pyIn);
    return 0;
}

static PyObject *Sbk_QSGOpaqueTextureMaterial_get_m_filtering(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    uint cppOut_local = cppSelf->m_filtering;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QSGOpaqueTextureMaterial_set_m_filtering(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_filtering");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_filtering", "uint");
        return -1;
    }

    auto cppOut_local = cppSelf->m_filtering;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_filtering = cppOut_local;

    return 0;
}

static PyObject *Sbk_QSGOpaqueTextureMaterial_get_m_mipmap_filtering(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    uint cppOut_local = cppSelf->m_mipmap_filtering;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QSGOpaqueTextureMaterial_set_m_mipmap_filtering(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_mipmap_filtering");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_mipmap_filtering", "uint");
        return -1;
    }

    auto cppOut_local = cppSelf->m_mipmap_filtering;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_mipmap_filtering = cppOut_local;

    return 0;
}

static PyObject *Sbk_QSGOpaqueTextureMaterial_get_m_horizontal_wrap(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    uint cppOut_local = cppSelf->m_horizontal_wrap;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QSGOpaqueTextureMaterial_set_m_horizontal_wrap(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_horizontal_wrap");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_horizontal_wrap", "uint");
        return -1;
    }

    auto cppOut_local = cppSelf->m_horizontal_wrap;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_horizontal_wrap = cppOut_local;

    return 0;
}

static PyObject *Sbk_QSGOpaqueTextureMaterial_get_m_vertical_wrap(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    uint cppOut_local = cppSelf->m_vertical_wrap;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QSGOpaqueTextureMaterial_set_m_vertical_wrap(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_vertical_wrap");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_vertical_wrap", "uint");
        return -1;
    }

    auto cppOut_local = cppSelf->m_vertical_wrap;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_vertical_wrap = cppOut_local;

    return 0;
}

static PyObject *Sbk_QSGOpaqueTextureMaterial_get_m_anisotropy_level(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    uint cppOut_local = cppSelf->m_anisotropy_level;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QSGOpaqueTextureMaterial_set_m_anisotropy_level(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_anisotropy_level");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_anisotropy_level", "uint");
        return -1;
    }

    auto cppOut_local = cppSelf->m_anisotropy_level;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_anisotropy_level = cppOut_local;

    return 0;
}

static PyObject *Sbk_QSGOpaqueTextureMaterial_get_m_reserved(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    uint cppOut_local = cppSelf->m_reserved;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QSGOpaqueTextureMaterial_set_m_reserved(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QSGOpaqueTextureMaterial *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_reserved");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_reserved", "uint");
        return -1;
    }

    auto cppOut_local = cppSelf->m_reserved;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_reserved = cppOut_local;

    return 0;
}

// Getters and Setters for QSGOpaqueTextureMaterial
static PyGetSetDef Sbk_QSGOpaqueTextureMaterial_getsetlist[] = {
    {const_cast<char *>("m_texture"), Sbk_QSGOpaqueTextureMaterial_get_m_texture, Sbk_QSGOpaqueTextureMaterial_set_m_texture, nullptr, nullptr},
    {const_cast<char *>("m_filtering"), Sbk_QSGOpaqueTextureMaterial_get_m_filtering, Sbk_QSGOpaqueTextureMaterial_set_m_filtering, nullptr, nullptr},
    {const_cast<char *>("m_mipmap_filtering"), Sbk_QSGOpaqueTextureMaterial_get_m_mipmap_filtering, Sbk_QSGOpaqueTextureMaterial_set_m_mipmap_filtering, nullptr, nullptr},
    {const_cast<char *>("m_horizontal_wrap"), Sbk_QSGOpaqueTextureMaterial_get_m_horizontal_wrap, Sbk_QSGOpaqueTextureMaterial_set_m_horizontal_wrap, nullptr, nullptr},
    {const_cast<char *>("m_vertical_wrap"), Sbk_QSGOpaqueTextureMaterial_get_m_vertical_wrap, Sbk_QSGOpaqueTextureMaterial_set_m_vertical_wrap, nullptr, nullptr},
    {const_cast<char *>("m_anisotropy_level"), Sbk_QSGOpaqueTextureMaterial_get_m_anisotropy_level, Sbk_QSGOpaqueTextureMaterial_set_m_anisotropy_level, nullptr, nullptr},
    {const_cast<char *>("m_reserved"), Sbk_QSGOpaqueTextureMaterial_get_m_reserved, Sbk_QSGOpaqueTextureMaterial_set_m_reserved, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QSGOpaqueTextureMaterial_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGOpaqueTextureMaterial_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGOpaqueTextureMaterial_Type = nullptr;
static PyTypeObject *Sbk_QSGOpaqueTextureMaterial_TypeF(void)
{
    return _Sbk_QSGOpaqueTextureMaterial_Type;
}

static PyType_Slot Sbk_QSGOpaqueTextureMaterial_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGOpaqueTextureMaterial_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGOpaqueTextureMaterial_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGOpaqueTextureMaterial_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGOpaqueTextureMaterial_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QSGOpaqueTextureMaterial_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGOpaqueTextureMaterial_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGOpaqueTextureMaterial_spec = {
    "2:PySide6.QtQuick.QSGOpaqueTextureMaterial",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGOpaqueTextureMaterial_slots
};

} //extern "C"

static void *Sbk_QSGOpaqueTextureMaterial_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QSGMaterial >())
        return dynamic_cast< ::QSGOpaqueTextureMaterial *>(reinterpret_cast< ::QSGMaterial *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGOpaqueTextureMaterial_PythonToCpp_QSGOpaqueTextureMaterial_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGOpaqueTextureMaterial_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGOpaqueTextureMaterial_PythonToCpp_QSGOpaqueTextureMaterial_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGOpaqueTextureMaterial_TypeF()))
        return QSGOpaqueTextureMaterial_PythonToCpp_QSGOpaqueTextureMaterial_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGOpaqueTextureMaterial_PTR_CppToPython_QSGOpaqueTextureMaterial(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QSGOpaqueTextureMaterial *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QSGOpaqueTextureMaterial_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QSGOpaqueTextureMaterial_SignatureStrings[] = {
    "PySide6.QtQuick.QSGOpaqueTextureMaterial(self)",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.anisotropyLevel(self)->PySide6.QtQuick.QSGTexture.AnisotropyLevel",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.compare(self,other:PySide6.QtQuick.QSGMaterial)->int",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.createShader(self,renderMode:PySide6.QtQuick.QSGRendererInterface.RenderMode)->PySide6.QtQuick.QSGMaterialShader",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.filtering(self)->PySide6.QtQuick.QSGTexture.Filtering",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.horizontalWrapMode(self)->PySide6.QtQuick.QSGTexture.WrapMode",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.mipmapFiltering(self)->PySide6.QtQuick.QSGTexture.Filtering",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.setAnisotropyLevel(self,level:PySide6.QtQuick.QSGTexture.AnisotropyLevel)",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.setFiltering(self,filteringType:PySide6.QtQuick.QSGTexture.Filtering)",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.setHorizontalWrapMode(self,mode:PySide6.QtQuick.QSGTexture.WrapMode)",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.setMipmapFiltering(self,filteringType:PySide6.QtQuick.QSGTexture.Filtering)",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.setTexture(self,texture:PySide6.QtQuick.QSGTexture)",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.setVerticalWrapMode(self,mode:PySide6.QtQuick.QSGTexture.WrapMode)",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.texture(self)->PySide6.QtQuick.QSGTexture",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.type(self)->PySide6.QtQuick.QSGMaterialType",
    "PySide6.QtQuick.QSGOpaqueTextureMaterial.verticalWrapMode(self)->PySide6.QtQuick.QSGTexture.WrapMode",
    nullptr}; // Sentinel

PyTypeObject *init_QSGOpaqueTextureMaterial(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGOpaqueTextureMaterial_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterial_IDX]))));

    _Sbk_QSGOpaqueTextureMaterial_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGOpaqueTextureMaterial",
        "QSGOpaqueTextureMaterial*",
        &Sbk_QSGOpaqueTextureMaterial_spec,
        &Shiboken::callCppDestructor< QSGOpaqueTextureMaterial >,
        Sbk_QSGOpaqueTextureMaterial_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGOpaqueTextureMaterial_TypeF(); // references _Sbk_QSGOpaqueTextureMaterial_Type
    InitSignatureStrings(pyType, QSGOpaqueTextureMaterial_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGOpaqueTextureMaterial_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGOpaqueTextureMaterial_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGOpaqueTextureMaterial_PythonToCpp_QSGOpaqueTextureMaterial_PTR,
        is_QSGOpaqueTextureMaterial_PythonToCpp_QSGOpaqueTextureMaterial_PTR_Convertible,
        QSGOpaqueTextureMaterial_PTR_CppToPython_QSGOpaqueTextureMaterial);

    Shiboken::Conversions::registerConverterName(converter, "QSGOpaqueTextureMaterial");
    Shiboken::Conversions::registerConverterName(converter, "QSGOpaqueTextureMaterial*");
    Shiboken::Conversions::registerConverterName(converter, "QSGOpaqueTextureMaterial&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGOpaqueTextureMaterial).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGOpaqueTextureMaterialWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QSGOpaqueTextureMaterial_TypeF(), &Sbk_QSGOpaqueTextureMaterial_typeDiscovery);

    qRegisterMetaType< ::QSGOpaqueTextureMaterial *>();

    return pyType;
}
