// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qsgrendererinterface_wrapper.h"

// Argument includes
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgrendererinterface.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QSGRendererInterfaceWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QSGRendererInterfaceWrapper::QSGRendererInterfaceWrapper() : QSGRendererInterface()
{
    resetPyMethodCache();
    // ... middle
}

void * QSGRendererInterfaceWrapper::getResource(::QQuickWindow * window, ::QSGRendererInterface::Resource resource) const
{
    if (m_PyMethodCache[0])
        return this->::QSGRendererInterface::getResource(window, resource);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "getResource";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QSGRendererInterface::getResource(window, resource);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_IDX]), window),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_Resource_IDX])))->converter, &resource)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_IDX]), window),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_Resource_IDX])))->converter, &resource)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGRendererInterface", funcName, Shiboken::SbkType< void >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    void* cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void * QSGRendererInterfaceWrapper::getResource(::QQuickWindow * window, const char * resource) const
{
    if (m_PyMethodCache[1])
        return this->::QSGRendererInterface::getResource(window, resource);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "getResource";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QSGRendererInterface::getResource(window, resource);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_IDX]), window),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), resource)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_IDX]), window),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), resource)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGRendererInterface", funcName, Shiboken::SbkType< void >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    void* cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSGRendererInterface::GraphicsApi QSGRendererInterfaceWrapper::graphicsApi() const
{
    if (m_PyMethodCache[2]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSGRendererInterface.graphicsApi");
        return QSGRendererInterface::Unknown;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QSGRendererInterface::Unknown;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "graphicsApi";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSGRendererInterface.graphicsApi");
        return QSGRendererInterface::Unknown;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QSGRendererInterface::Unknown;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_GraphicsApi_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGRendererInterface", funcName, Shiboken::SbkType< QSGRendererInterface::GraphicsApi >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QSGRendererInterface::Unknown;
    }
    ::QSGRendererInterface::GraphicsApi cppResult{QSGRendererInterface::Unknown};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QFlags<QSGRendererInterface::ShaderCompilationType> QSGRendererInterfaceWrapper::shaderCompilationType() const
{
    if (m_PyMethodCache[3]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSGRendererInterface.shaderCompilationType");
        return QFlags<QSGRendererInterface::ShaderCompilationType>(0);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QFlags<QSGRendererInterface::ShaderCompilationType>(0);
    static PyObject *nameCache[2] = {};
    static const char *funcName = "shaderCompilationType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSGRendererInterface.shaderCompilationType");
        return QFlags<QSGRendererInterface::ShaderCompilationType>(0);
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QFlags<QSGRendererInterface::ShaderCompilationType>(0);
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRendererInterface_ShaderCompilationType_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGRendererInterface", funcName, Shiboken::SbkType< QFlags<QSGRendererInterface::ShaderCompilationType> >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QFlags<QSGRendererInterface::ShaderCompilationType>(0);
    }
    ::QFlags<QSGRendererInterface::ShaderCompilationType> cppResult = QFlags<QSGRendererInterface::ShaderCompilationType>(0);
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QFlags<QSGRendererInterface::ShaderSourceType> QSGRendererInterfaceWrapper::shaderSourceType() const
{
    if (m_PyMethodCache[4]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSGRendererInterface.shaderSourceType");
        return QFlags<QSGRendererInterface::ShaderSourceType>(0);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QFlags<QSGRendererInterface::ShaderSourceType>(0);
    static PyObject *nameCache[2] = {};
    static const char *funcName = "shaderSourceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSGRendererInterface.shaderSourceType");
        return QFlags<QSGRendererInterface::ShaderSourceType>(0);
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QFlags<QSGRendererInterface::ShaderSourceType>(0);
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRendererInterface_ShaderSourceType_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGRendererInterface", funcName, Shiboken::SbkType< QFlags<QSGRendererInterface::ShaderSourceType> >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QFlags<QSGRendererInterface::ShaderSourceType>(0);
    }
    ::QFlags<QSGRendererInterface::ShaderSourceType> cppResult = QFlags<QSGRendererInterface::ShaderSourceType>(0);
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSGRendererInterface::ShaderType QSGRendererInterfaceWrapper::shaderType() const
{
    if (m_PyMethodCache[5]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QSGRendererInterface.shaderType");
        return QSGRendererInterface::UnknownShadingLanguage;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QSGRendererInterface::UnknownShadingLanguage;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "shaderType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        Shiboken::Errors::setPureVirtualMethodError("QSGRendererInterface.shaderType");
        return QSGRendererInterface::UnknownShadingLanguage;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return QSGRendererInterface::UnknownShadingLanguage;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_ShaderType_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QSGRendererInterface", funcName, Shiboken::SbkType< QSGRendererInterface::ShaderType >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QSGRendererInterface::UnknownShadingLanguage;
    }
    ::QSGRendererInterface::ShaderType cppResult{QSGRendererInterface::UnknownShadingLanguage};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QSGRendererInterfaceWrapper::~QSGRendererInterfaceWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSGRendererInterface_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QSGRendererInterface");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QSGRendererInterface >()))
        return -1;

    QSGRendererInterfaceWrapper *cptr{};
    static const char fullName[] = "PySide6.QtQuick.QSGRendererInterface.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QSGRendererInterface()
            cptr = new QSGRendererInterfaceWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QSGRendererInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QSGRendererInterfaceFunc_getResource(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRendererInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGRendererInterface.getResource";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "getResource", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QSGRendererInterface::getResource(QQuickWindow*,const char*)const->void*
    // 1: QSGRendererInterface::getResource(QQuickWindow*,QSGRendererInterface::Resource)const->void*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_IDX]), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_Resource_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // getResource(QQuickWindow*,QSGRendererInterface::Resource)const
        } else if (numArgs == 2
            && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            overloadId = 0; // getResource(QQuickWindow*,const char*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // getResource(QQuickWindow * window, const char * resource) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQuickWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // getResource(QQuickWindow*,const char*)const
                void * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? const_cast<const ::QSGRendererInterface *>(cppSelf)->::QSGRendererInterface::getResource(cppArg0, cppArg1)
                    : const_cast<const ::QSGRendererInterface *>(cppSelf)->getResource(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
            }
            break;
        }
        case 1: // getResource(QQuickWindow * window, QSGRendererInterface::Resource resource) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQuickWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QSGRendererInterface::Resource cppArg1{QSGRendererInterface::DeviceResource};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // getResource(QQuickWindow*,QSGRendererInterface::Resource)const
                void * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? const_cast<const ::QSGRendererInterface *>(cppSelf)->::QSGRendererInterface::getResource(cppArg0, cppArg1)
                    : const_cast<const ::QSGRendererInterface *>(cppSelf)->getResource(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRendererInterfaceFunc_graphicsApi(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRendererInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGRendererInterface.graphicsApi";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // graphicsApi()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGRendererInterface.graphicsApi");
                return {};
            }
            QSGRendererInterface::GraphicsApi cppResult = const_cast<const ::QSGRendererInterface *>(cppSelf)->graphicsApi();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_GraphicsApi_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRendererInterfaceFunc_isApiRhiBased(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick.QSGRendererInterface.isApiRhiBased";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QSGRendererInterface::isApiRhiBased(QSGRendererInterface::GraphicsApi)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_GraphicsApi_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // isApiRhiBased(QSGRendererInterface::GraphicsApi)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QSGRendererInterface::GraphicsApi cppArg0{QSGRendererInterface::Unknown};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isApiRhiBased(QSGRendererInterface::GraphicsApi)
            bool cppResult = ::QSGRendererInterface::isApiRhiBased(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRendererInterfaceFunc_shaderCompilationType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRendererInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGRendererInterface.shaderCompilationType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // shaderCompilationType()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGRendererInterface.shaderCompilationType");
                return {};
            }
            QFlags<QSGRendererInterface::ShaderCompilationType> cppResult = const_cast<const ::QSGRendererInterface *>(cppSelf)->shaderCompilationType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRendererInterface_ShaderCompilationType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRendererInterfaceFunc_shaderSourceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRendererInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGRendererInterface.shaderSourceType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // shaderSourceType()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGRendererInterface.shaderSourceType");
                return {};
            }
            QFlags<QSGRendererInterface::ShaderSourceType> cppResult = const_cast<const ::QSGRendererInterface *>(cppSelf)->shaderSourceType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRendererInterface_ShaderSourceType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QSGRendererInterfaceFunc_shaderType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QSGRendererInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtQuick.QSGRendererInterface.shaderType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // shaderType()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QSGRendererInterface.shaderType");
                return {};
            }
            QSGRendererInterface::ShaderType cppResult = const_cast<const ::QSGRendererInterface *>(cppSelf)->shaderType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_ShaderType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QSGRendererInterface_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QSGRendererInterface_EnumFlagInfo[] = {
    "GraphicsApi:Enum",
    "RenderMode:Enum",
    "Resource:Enum",
    "ShaderCompilationType:Flag:ShaderCompilationTypes",
    "ShaderSourceType:Flag:ShaderSourceTypes",
    "ShaderType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QSGRendererInterface_methods[] = {
    {"getResource", reinterpret_cast<PyCFunction>(Sbk_QSGRendererInterfaceFunc_getResource), METH_VARARGS, nullptr},
    {"graphicsApi", reinterpret_cast<PyCFunction>(Sbk_QSGRendererInterfaceFunc_graphicsApi), METH_NOARGS, nullptr},
    {"isApiRhiBased", reinterpret_cast<PyCFunction>(Sbk_QSGRendererInterfaceFunc_isApiRhiBased), METH_O|METH_STATIC, nullptr},
    {"shaderCompilationType", reinterpret_cast<PyCFunction>(Sbk_QSGRendererInterfaceFunc_shaderCompilationType), METH_NOARGS, nullptr},
    {"shaderSourceType", reinterpret_cast<PyCFunction>(Sbk_QSGRendererInterfaceFunc_shaderSourceType), METH_NOARGS, nullptr},
    {"shaderType", reinterpret_cast<PyCFunction>(Sbk_QSGRendererInterfaceFunc_shaderType), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QSGRendererInterface_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QSGRendererInterface *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QSGRendererInterfaceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QSGRendererInterface_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QSGRendererInterface_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QSGRendererInterface_Type = nullptr;
static PyTypeObject *Sbk_QSGRendererInterface_TypeF(void)
{
    return _Sbk_QSGRendererInterface_Type;
}

static PyType_Slot Sbk_QSGRendererInterface_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QSGRendererInterface_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QSGRendererInterface_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QSGRendererInterface_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QSGRendererInterface_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QSGRendererInterface_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QSGRendererInterface_spec = {
    "2:PySide6.QtQuick.QSGRendererInterface",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QSGRendererInterface_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QSGRendererInterface_GraphicsApi_PythonToCpp_QSGRendererInterface_GraphicsApi(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGRendererInterface::GraphicsApi>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGRendererInterface::GraphicsApi *>(cppOut) = value;

}
static PythonToCppFunc is_QSGRendererInterface_GraphicsApi_PythonToCpp_QSGRendererInterface_GraphicsApi_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_GraphicsApi_IDX])))
        return QSGRendererInterface_GraphicsApi_PythonToCpp_QSGRendererInterface_GraphicsApi;
    return {};
}
static PyObject *QSGRendererInterface_GraphicsApi_CppToPython_QSGRendererInterface_GraphicsApi(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSGRendererInterface::GraphicsApi *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_GraphicsApi_IDX]), castCppIn);

}

static void QSGRendererInterface_Resource_PythonToCpp_QSGRendererInterface_Resource(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGRendererInterface::Resource>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGRendererInterface::Resource *>(cppOut) = value;

}
static PythonToCppFunc is_QSGRendererInterface_Resource_PythonToCpp_QSGRendererInterface_Resource_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_Resource_IDX])))
        return QSGRendererInterface_Resource_PythonToCpp_QSGRendererInterface_Resource;
    return {};
}
static PyObject *QSGRendererInterface_Resource_CppToPython_QSGRendererInterface_Resource(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSGRendererInterface::Resource *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_Resource_IDX]), castCppIn);

}

static void QSGRendererInterface_ShaderType_PythonToCpp_QSGRendererInterface_ShaderType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGRendererInterface::ShaderType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGRendererInterface::ShaderType *>(cppOut) = value;

}
static PythonToCppFunc is_QSGRendererInterface_ShaderType_PythonToCpp_QSGRendererInterface_ShaderType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_ShaderType_IDX])))
        return QSGRendererInterface_ShaderType_PythonToCpp_QSGRendererInterface_ShaderType;
    return {};
}
static PyObject *QSGRendererInterface_ShaderType_CppToPython_QSGRendererInterface_ShaderType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSGRendererInterface::ShaderType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_ShaderType_IDX]), castCppIn);

}

static void QSGRendererInterface_ShaderCompilationType_PythonToCpp_QSGRendererInterface_ShaderCompilationType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGRendererInterface::ShaderCompilationType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGRendererInterface::ShaderCompilationType *>(cppOut) = value;

}
static PythonToCppFunc is_QSGRendererInterface_ShaderCompilationType_PythonToCpp_QSGRendererInterface_ShaderCompilationType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_ShaderCompilationType_IDX])))
        return QSGRendererInterface_ShaderCompilationType_PythonToCpp_QSGRendererInterface_ShaderCompilationType;
    return {};
}
static PyObject *QSGRendererInterface_ShaderCompilationType_CppToPython_QSGRendererInterface_ShaderCompilationType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSGRendererInterface::ShaderCompilationType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_ShaderCompilationType_IDX]), castCppIn);

}

static void QSGRendererInterface_ShaderSourceType_PythonToCpp_QSGRendererInterface_ShaderSourceType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGRendererInterface::ShaderSourceType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGRendererInterface::ShaderSourceType *>(cppOut) = value;

}
static PythonToCppFunc is_QSGRendererInterface_ShaderSourceType_PythonToCpp_QSGRendererInterface_ShaderSourceType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_ShaderSourceType_IDX])))
        return QSGRendererInterface_ShaderSourceType_PythonToCpp_QSGRendererInterface_ShaderSourceType;
    return {};
}
static PyObject *QSGRendererInterface_ShaderSourceType_CppToPython_QSGRendererInterface_ShaderSourceType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSGRendererInterface::ShaderSourceType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_ShaderSourceType_IDX]), castCppIn);

}

static void QSGRendererInterface_RenderMode_PythonToCpp_QSGRendererInterface_RenderMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QSGRendererInterface::RenderMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QSGRendererInterface::RenderMode *>(cppOut) = value;

}
static PythonToCppFunc is_QSGRendererInterface_RenderMode_PythonToCpp_QSGRendererInterface_RenderMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX])))
        return QSGRendererInterface_RenderMode_PythonToCpp_QSGRendererInterface_RenderMode;
    return {};
}
static PyObject *QSGRendererInterface_RenderMode_CppToPython_QSGRendererInterface_RenderMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QSGRendererInterface::RenderMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QSGRendererInterface_PythonToCpp_QSGRendererInterface_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QSGRendererInterface_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QSGRendererInterface_PythonToCpp_QSGRendererInterface_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QSGRendererInterface_TypeF()))
        return QSGRendererInterface_PythonToCpp_QSGRendererInterface_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QSGRendererInterface_PTR_CppToPython_QSGRendererInterface(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QSGRendererInterface *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QSGRendererInterface_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QSGRendererInterface_SignatureStrings[] = {
    "PySide6.QtQuick.QSGRendererInterface(self)",
    "1:PySide6.QtQuick.QSGRendererInterface.getResource(self,window:PySide6.QtQuick.QQuickWindow,resource:char*)->void",
    "0:PySide6.QtQuick.QSGRendererInterface.getResource(self,window:PySide6.QtQuick.QQuickWindow,resource:PySide6.QtQuick.QSGRendererInterface.Resource)->void",
    "PySide6.QtQuick.QSGRendererInterface.graphicsApi(self)->PySide6.QtQuick.QSGRendererInterface.GraphicsApi",
    "PySide6.QtQuick.QSGRendererInterface.isApiRhiBased(api:PySide6.QtQuick.QSGRendererInterface.GraphicsApi)->bool",
    "PySide6.QtQuick.QSGRendererInterface.shaderCompilationType(self)->PySide6.QtQuick.QSGRendererInterface.ShaderCompilationType",
    "PySide6.QtQuick.QSGRendererInterface.shaderSourceType(self)->PySide6.QtQuick.QSGRendererInterface.ShaderSourceType",
    "PySide6.QtQuick.QSGRendererInterface.shaderType(self)->PySide6.QtQuick.QSGRendererInterface.ShaderType",
    nullptr}; // Sentinel

PyTypeObject *init_QSGRendererInterface(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_IDX].type;

    Shiboken::AutoDecRef Sbk_QSGRendererInterface_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QSGRendererInterface_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QSGRendererInterface",
        "QSGRendererInterface*",
        &Sbk_QSGRendererInterface_spec,
        &Shiboken::callCppDestructor< QSGRendererInterface >,
        Sbk_QSGRendererInterface_Type_bases.object(),
        0);
    auto *pyType = Sbk_QSGRendererInterface_TypeF(); // references _Sbk_QSGRendererInterface_Type
    InitSignatureStrings(pyType, QSGRendererInterface_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QSGRendererInterface_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QSGRendererInterface_PythonToCpp_QSGRendererInterface_PTR,
        is_QSGRendererInterface_PythonToCpp_QSGRendererInterface_PTR_Convertible,
        QSGRendererInterface_PTR_CppToPython_QSGRendererInterface);

    Shiboken::Conversions::registerConverterName(converter, "QSGRendererInterface");
    Shiboken::Conversions::registerConverterName(converter, "QSGRendererInterface*");
    Shiboken::Conversions::registerConverterName(converter, "QSGRendererInterface&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QSGRendererInterface).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QSGRendererInterfaceWrapper).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QSGRendererInterface_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'GraphicsApi'.
    const char *GraphicsApi_Initializer[] = {
        "Unknown",
        "Software",
        "OpenVG",
        "OpenGL",
        "Direct3D11",
        "Vulkan",
        "Metal",
        "Null",
        "Direct3D12",
        "OpenGLRhi",
        "Direct3D11Rhi",
        "VulkanRhi",
        "MetalRhi",
        "NullRhi",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t GraphicsApi_InitializerValues[] = {
        uint8_t(QSGRendererInterface::GraphicsApi::Unknown),       //  0x00  0
        uint8_t(QSGRendererInterface::GraphicsApi::Software),      //  0x01  1
        uint8_t(QSGRendererInterface::GraphicsApi::OpenVG),        //  0x02  2
        uint8_t(QSGRendererInterface::GraphicsApi::OpenGL),        //  0x03  3
        uint8_t(QSGRendererInterface::GraphicsApi::Direct3D11),    //  0x04  4
        uint8_t(QSGRendererInterface::GraphicsApi::Vulkan),        //  0x05  5
        uint8_t(QSGRendererInterface::GraphicsApi::Metal),         //  0x06  6
        uint8_t(QSGRendererInterface::GraphicsApi::Null),          //  0x07  7
        uint8_t(QSGRendererInterface::GraphicsApi::Direct3D12),    //  0x08  8
        uint8_t(QSGRendererInterface::GraphicsApi::OpenGLRhi),     //  0x03  3
        uint8_t(QSGRendererInterface::GraphicsApi::Direct3D11Rhi), //  0x04  4
        uint8_t(QSGRendererInterface::GraphicsApi::VulkanRhi),     //  0x05  5
        uint8_t(QSGRendererInterface::GraphicsApi::MetalRhi),      //  0x06  6
        uint8_t(QSGRendererInterface::GraphicsApi::NullRhi)        //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGRendererInterface_TypeF(),
        "2:PySide6.QtQuick.QSGRendererInterface.GraphicsApi",
        GraphicsApi_Initializer, GraphicsApi_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_GraphicsApi_IDX].type = EType;
    // Register converter for enum 'QSGRendererInterface::GraphicsApi'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGRendererInterface_GraphicsApi_CppToPython_QSGRendererInterface_GraphicsApi);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGRendererInterface_GraphicsApi_PythonToCpp_QSGRendererInterface_GraphicsApi,
            is_QSGRendererInterface_GraphicsApi_PythonToCpp_QSGRendererInterface_GraphicsApi_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGRendererInterface::GraphicsApi");
        Shiboken::Conversions::registerConverterName(converter, "GraphicsApi");
    }
    // End of 'GraphicsApi' enum.

    // Initialization of enum 'Resource'.
    const char *Resource_Initializer[] = {
        "DeviceResource",
        "CommandQueueResource",
        "CommandListResource",
        "PainterResource",
        "RhiResource",
        "RhiSwapchainResource",
        "RhiRedirectCommandBuffer",
        "RhiRedirectRenderTarget",
        "PhysicalDeviceResource",
        "OpenGLContextResource",
        "DeviceContextResource",
        "CommandEncoderResource",
        "VulkanInstanceResource",
        "RenderPassResource",
        "RedirectPaintDevice",
        "GraphicsQueueFamilyIndexResource",
        "GraphicsQueueIndexResource",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Resource_InitializerValues[] = {
        uint8_t(QSGRendererInterface::Resource::DeviceResource),                   //  0x00  0
        uint8_t(QSGRendererInterface::Resource::CommandQueueResource),             //  0x01  1
        uint8_t(QSGRendererInterface::Resource::CommandListResource),              //  0x02  2
        uint8_t(QSGRendererInterface::Resource::PainterResource),                  //  0x03  3
        uint8_t(QSGRendererInterface::Resource::RhiResource),                      //  0x04  4
        uint8_t(QSGRendererInterface::Resource::RhiSwapchainResource),             //  0x05  5
        uint8_t(QSGRendererInterface::Resource::RhiRedirectCommandBuffer),         //  0x06  6
        uint8_t(QSGRendererInterface::Resource::RhiRedirectRenderTarget),          //  0x07  7
        uint8_t(QSGRendererInterface::Resource::PhysicalDeviceResource),           //  0x08  8
        uint8_t(QSGRendererInterface::Resource::OpenGLContextResource),            //  0x09  9
        uint8_t(QSGRendererInterface::Resource::DeviceContextResource),            //  0x0a  10
        uint8_t(QSGRendererInterface::Resource::CommandEncoderResource),           //  0x0b  11
        uint8_t(QSGRendererInterface::Resource::VulkanInstanceResource),           //  0x0c  12
        uint8_t(QSGRendererInterface::Resource::RenderPassResource),               //  0x0d  13
        uint8_t(QSGRendererInterface::Resource::RedirectPaintDevice),              //  0x0e  14
        uint8_t(QSGRendererInterface::Resource::GraphicsQueueFamilyIndexResource), //  0x0f  15
        uint8_t(QSGRendererInterface::Resource::GraphicsQueueIndexResource)        //  0x10  16
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGRendererInterface_TypeF(),
        "2:PySide6.QtQuick.QSGRendererInterface.Resource",
        Resource_Initializer, Resource_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_Resource_IDX].type = EType;
    // Register converter for enum 'QSGRendererInterface::Resource'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGRendererInterface_Resource_CppToPython_QSGRendererInterface_Resource);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGRendererInterface_Resource_PythonToCpp_QSGRendererInterface_Resource,
            is_QSGRendererInterface_Resource_PythonToCpp_QSGRendererInterface_Resource_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGRendererInterface::Resource");
        Shiboken::Conversions::registerConverterName(converter, "Resource");
    }
    // End of 'Resource' enum.

    // Initialization of enum 'ShaderType'.
    const char *ShaderType_Initializer[] = {
        "UnknownShadingLanguage",
        "GLSL",
        "HLSL",
        "RhiShader",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ShaderType_InitializerValues[] = {
        uint8_t(QSGRendererInterface::ShaderType::UnknownShadingLanguage), //  0x00  0
        uint8_t(QSGRendererInterface::ShaderType::GLSL),                   //  0x01  1
        uint8_t(QSGRendererInterface::ShaderType::HLSL),                   //  0x02  2
        uint8_t(QSGRendererInterface::ShaderType::RhiShader)               //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGRendererInterface_TypeF(),
        "2:PySide6.QtQuick.QSGRendererInterface.ShaderType",
        ShaderType_Initializer, ShaderType_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_ShaderType_IDX].type = EType;
    // Register converter for enum 'QSGRendererInterface::ShaderType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGRendererInterface_ShaderType_CppToPython_QSGRendererInterface_ShaderType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGRendererInterface_ShaderType_PythonToCpp_QSGRendererInterface_ShaderType,
            is_QSGRendererInterface_ShaderType_PythonToCpp_QSGRendererInterface_ShaderType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGRendererInterface::ShaderType");
        Shiboken::Conversions::registerConverterName(converter, "ShaderType");
    }
    // End of 'ShaderType' enum.

    // Initialization of enum 'ShaderCompilationType'.
    const char *ShaderCompilationType_Initializer[] = {
        "RuntimeCompilation",
        "OfflineCompilation",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ShaderCompilationType_InitializerValues[] = {
        uint8_t(QSGRendererInterface::ShaderCompilationType::RuntimeCompilation), //  0x01  1
        uint8_t(QSGRendererInterface::ShaderCompilationType::OfflineCompilation)  //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGRendererInterface_TypeF(),
        "2:PySide6.QtQuick.QSGRendererInterface.ShaderCompilationType",
        ShaderCompilationType_Initializer, ShaderCompilationType_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_ShaderCompilationType_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRendererInterface_ShaderCompilationType_IDX].type =
        EType;
    // Register converter for enum 'QSGRendererInterface::ShaderCompilationType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGRendererInterface_ShaderCompilationType_CppToPython_QSGRendererInterface_ShaderCompilationType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGRendererInterface_ShaderCompilationType_PythonToCpp_QSGRendererInterface_ShaderCompilationType,
            is_QSGRendererInterface_ShaderCompilationType_PythonToCpp_QSGRendererInterface_ShaderCompilationType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGRendererInterface::ShaderCompilationType");
        Shiboken::Conversions::registerConverterName(converter, "ShaderCompilationType");
        // Register converter for flag 'QFlags<QSGRendererInterface::ShaderCompilationType>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QSGRendererInterface::ShaderCompilationType>");
        Shiboken::Conversions::registerConverterName(converter, "QSGRendererInterface::ShaderCompilationTypes");
    }
    // End of 'ShaderCompilationType' enum/flags.

    // Initialization of enum 'ShaderSourceType'.
    const char *ShaderSourceType_Initializer[] = {
        "ShaderSourceString",
        "ShaderSourceFile",
        "ShaderByteCode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ShaderSourceType_InitializerValues[] = {
        uint8_t(QSGRendererInterface::ShaderSourceType::ShaderSourceString), //  0x01  1
        uint8_t(QSGRendererInterface::ShaderSourceType::ShaderSourceFile),   //  0x02  2
        uint8_t(QSGRendererInterface::ShaderSourceType::ShaderByteCode)      //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGRendererInterface_TypeF(),
        "2:PySide6.QtQuick.QSGRendererInterface.ShaderSourceType",
        ShaderSourceType_Initializer, ShaderSourceType_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_ShaderSourceType_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGRendererInterface_ShaderSourceType_IDX].type =
        EType;
    // Register converter for enum 'QSGRendererInterface::ShaderSourceType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGRendererInterface_ShaderSourceType_CppToPython_QSGRendererInterface_ShaderSourceType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGRendererInterface_ShaderSourceType_PythonToCpp_QSGRendererInterface_ShaderSourceType,
            is_QSGRendererInterface_ShaderSourceType_PythonToCpp_QSGRendererInterface_ShaderSourceType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGRendererInterface::ShaderSourceType");
        Shiboken::Conversions::registerConverterName(converter, "ShaderSourceType");
        // Register converter for flag 'QFlags<QSGRendererInterface::ShaderSourceType>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QSGRendererInterface::ShaderSourceType>");
        Shiboken::Conversions::registerConverterName(converter, "QSGRendererInterface::ShaderSourceTypes");
    }
    // End of 'ShaderSourceType' enum/flags.

    // Initialization of enum 'RenderMode'.
    const char *RenderMode_Initializer[] = {
        "RenderMode2D",
        "RenderMode2DNoDepthBuffer",
        "RenderMode3D",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RenderMode_InitializerValues[] = {
        uint8_t(QSGRendererInterface::RenderMode::RenderMode2D),              //  0x00  0
        uint8_t(QSGRendererInterface::RenderMode::RenderMode2DNoDepthBuffer), //  0x01  1
        uint8_t(QSGRendererInterface::RenderMode::RenderMode3D)               //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QSGRendererInterface_TypeF(),
        "2:PySide6.QtQuick.QSGRendererInterface.RenderMode",
        RenderMode_Initializer, RenderMode_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QSGRendererInterface_RenderMode_IDX].type = EType;
    // Register converter for enum 'QSGRendererInterface::RenderMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QSGRendererInterface_RenderMode_CppToPython_QSGRendererInterface_RenderMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QSGRendererInterface_RenderMode_PythonToCpp_QSGRendererInterface_RenderMode,
            is_QSGRendererInterface_RenderMode_PythonToCpp_QSGRendererInterface_RenderMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QSGRendererInterface::RenderMode");
        Shiboken::Conversions::registerConverterName(converter, "RenderMode");
    }
    // End of 'RenderMode' enum.

    qRegisterMetaType< ::QSGRendererInterface *>();
    qRegisterMetaType< ::QSGRendererInterface::GraphicsApi >("QSGRendererInterface::GraphicsApi");
    qRegisterMetaType< ::QSGRendererInterface::Resource >("QSGRendererInterface::Resource");
    qRegisterMetaType< ::QSGRendererInterface::ShaderType >("QSGRendererInterface::ShaderType");
    qRegisterMetaType< ::QSGRendererInterface::ShaderCompilationType >("QSGRendererInterface::ShaderCompilationType");
    qRegisterMetaType< ::QSGRendererInterface::ShaderSourceType >("QSGRendererInterface::ShaderSourceType");
    qRegisterMetaType< ::QSGRendererInterface::RenderMode >("QSGRendererInterface::RenderMode");

    return pyType;
}
