// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick3d_python.h"

// main header
#include "qquick3d_wrapper.h"

// Argument includes
#include <QtGui/qsurfaceformat.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuick3D_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuick3D >()))
        return -1;

    ::QQuick3D *cptr{};
    static const char fullName[] = "PySide6.QtQuick3D.QQuick3D.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QQuick3D()
            cptr = new ::QQuick3D();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QQuick3D >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QQuick3DFunc_idealSurfaceFormat(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtQuick3D.QQuick3D.idealSurfaceFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:idealSurfaceFormat", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QQuick3D::idealSurfaceFormat(int=)->QSurfaceFormat
    if (numArgs == 0) {
        overloadId = 0; // idealSurfaceFormat(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // idealSurfaceFormat(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_samples = Shiboken::String::createStaticString("samples");
            if (PyDict_Contains(kwds, key_samples) != 0) {
                value = PyDict_GetItem(kwds, key_samples);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_samples);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_samples);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        int cppArg0 = -1;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // idealSurfaceFormat(int)
            QSurfaceFormat cppResult = ::QQuick3D::idealSurfaceFormat(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QSurfaceFormat_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQuick3D_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuick3D_methods[] = {
    {"idealSurfaceFormat", reinterpret_cast<PyCFunction>(Sbk_QQuick3DFunc_idealSurfaceFormat), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QQuick3D_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuick3D_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuick3D_Type = nullptr;
static PyTypeObject *Sbk_QQuick3D_TypeF(void)
{
    return _Sbk_QQuick3D_Type;
}

static PyType_Slot Sbk_QQuick3D_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuick3D_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuick3D_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuick3D_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuick3D_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuick3D_spec = {
    "2:PySide6.QtQuick3D.QQuick3D",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuick3D_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuick3D_PythonToCpp_QQuick3D_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuick3D_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuick3D_PythonToCpp_QQuick3D_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuick3D_TypeF()))
        return QQuick3D_PythonToCpp_QQuick3D_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuick3D_PTR_CppToPython_QQuick3D(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QQuick3D *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QQuick3D_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QQuick3D_SignatureStrings[] = {
    "PySide6.QtQuick3D.QQuick3D(self)",
    "PySide6.QtQuick3D.QQuick3D.idealSurfaceFormat(samples:int=-1)->PySide6.QtGui.QSurfaceFormat",
    nullptr}; // Sentinel

PyTypeObject *init_QQuick3D(PyObject *module)
{
    if (SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3D_IDX].type != nullptr)
        return SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3D_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuick3D_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QQuick3D_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuick3D",
        "QQuick3D*",
        &Sbk_QQuick3D_spec,
        &Shiboken::callCppDestructor< ::QQuick3D >,
        Sbk_QQuick3D_Type_bases.object(),
        0);
    auto *pyType = Sbk_QQuick3D_TypeF(); // references _Sbk_QQuick3D_Type
    InitSignatureStrings(pyType, QQuick3D_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuick3D_PropertyStrings);
    SbkPySide6_QtQuick3DTypeStructs[SBK_QQuick3D_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuick3D_PythonToCpp_QQuick3D_PTR,
        is_QQuick3D_PythonToCpp_QQuick3D_PTR_Convertible,
        QQuick3D_PTR_CppToPython_QQuick3D);

    Shiboken::Conversions::registerConverterName(converter, "QQuick3D");
    Shiboken::Conversions::registerConverterName(converter, "QQuick3D*");
    Shiboken::Conversions::registerConverterName(converter, "QQuick3D&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuick3D).name());

    qRegisterMetaType< ::QQuick3D *>();

    return pyType;
}
