// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtremoteobjects_python.h"

// main header
#include "qtroclientfactory_wrapper.h"

// Argument includes
#include <QtRemoteObjects/qconnectionfactories.h>
#include <qobject.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QtROClientFactoryFunc_create(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtROClientFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtRemoteObjects.QtROClientFactory.create";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:create", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QtROClientFactory::create(QUrl,QObject*=)->QtROClientIoDevice*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // create(QUrl,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // create(QUrl,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // create(QUrl,QObject*)
            QtROClientIoDevice * cppResult = cppSelf->create(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientIoDevice_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtROClientFactoryFunc_instance(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtRemoteObjects.QtROClientFactory.instance";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // instance()
            QtROClientFactory * cppResult = ::QtROClientFactory::instance();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QtROClientFactoryFunc_isValid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QtROClientFactory *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtRemoteObjects.QtROClientFactory.isValid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QtROClientFactory::isValid(QUrl)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // isValid(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid(QUrl)
            bool cppResult = cppSelf->isValid(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QtROClientFactory_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QtROClientFactory_methods[] = {
    {"create", reinterpret_cast<PyCFunction>(Sbk_QtROClientFactoryFunc_create), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"instance", reinterpret_cast<PyCFunction>(Sbk_QtROClientFactoryFunc_instance), METH_NOARGS|METH_STATIC, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QtROClientFactoryFunc_isValid), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QtROClientFactory_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QtROClientFactory_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QtROClientFactory_Type = nullptr;
static PyTypeObject *Sbk_QtROClientFactory_TypeF(void)
{
    return _Sbk_QtROClientFactory_Type;
}

static PyType_Slot Sbk_QtROClientFactory_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QtROClientFactory_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QtROClientFactory_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QtROClientFactory_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QtROClientFactory_spec = {
    "2:PySide6.QtRemoteObjects.QtROClientFactory",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QtROClientFactory_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QtROClientFactory_PythonToCpp_QtROClientFactory_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QtROClientFactory_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QtROClientFactory_PythonToCpp_QtROClientFactory_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QtROClientFactory_TypeF()))
        return QtROClientFactory_PythonToCpp_QtROClientFactory_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QtROClientFactory_PTR_CppToPython_QtROClientFactory(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QtROClientFactory *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QtROClientFactory_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QtROClientFactory_SignatureStrings[] = {
    "PySide6.QtRemoteObjects.QtROClientFactory.create(self,url:typing.Union[PySide6.QtCore.QUrl, QString],parent:PySide6.QtCore.QObject=nullptr)->PySide6.QtRemoteObjects.QtROClientIoDevice",
    "PySide6.QtRemoteObjects.QtROClientFactory.instance()->PySide6.QtRemoteObjects.QtROClientFactory",
    "PySide6.QtRemoteObjects.QtROClientFactory.isValid(self,url:typing.Union[PySide6.QtCore.QUrl, QString])->bool",
    nullptr}; // Sentinel

PyTypeObject *init_QtROClientFactory(PyObject *module)
{
    if (SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX].type != nullptr)
        return SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX].type;

    Shiboken::AutoDecRef Sbk_QtROClientFactory_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QtROClientFactory_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QtROClientFactory",
        "QtROClientFactory*",
        &Sbk_QtROClientFactory_spec,
        &Shiboken::callCppDestructor< ::QtROClientFactory >,
        Sbk_QtROClientFactory_Type_bases.object(),
        0);
    auto *pyType = Sbk_QtROClientFactory_TypeF(); // references _Sbk_QtROClientFactory_Type
    InitSignatureStrings(pyType, QtROClientFactory_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QtROClientFactory_PropertyStrings);
    SbkPySide6_QtRemoteObjectsTypeStructs[SBK_QtROClientFactory_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QtROClientFactory_PythonToCpp_QtROClientFactory_PTR,
        is_QtROClientFactory_PythonToCpp_QtROClientFactory_PTR_Convertible,
        QtROClientFactory_PTR_CppToPython_QtROClientFactory);

    Shiboken::Conversions::registerConverterName(converter, "QtROClientFactory");
    Shiboken::Conversions::registerConverterName(converter, "QtROClientFactory*");
    Shiboken::Conversions::registerConverterName(converter, "QtROClientFactory&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QtROClientFactory).name());

    qRegisterMetaType< ::QtROClientFactory *>();

    return pyType;
}
