// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qcanbusdevice_filter_wrapper.h"

// Argument includes
#include <QtSerialBus/qcanbusdevice.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCanBusDevice_Filter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCanBusDevice::Filter >()))
        return -1;

    ::QCanBusDevice::Filter *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSerialBus.QCanBusDevice.Filter.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "Filter", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: Filter::Filter()
    // 1: Filter::Filter(QCanBusDevice::Filter)
    if (numArgs == 0) {
        overloadId = 0; // Filter()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), (pyArgs[0])))) {
        overloadId = 1; // Filter(QCanBusDevice::Filter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // Filter()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // Filter()
                cptr = new ::QCanBusDevice::Filter();
            }
            break;
        }
        case 1: // Filter(const QCanBusDevice::Filter & Filter)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QCanBusDevice::Filter cppArg0_local;
            ::QCanBusDevice::Filter *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // Filter(QCanBusDevice::Filter)
                cptr = new ::QCanBusDevice::Filter(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCanBusDevice::Filter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCanBusDevice_Filter__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCanBusDevice::Filter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCanBusDevice_Filter_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QCanBusDevice_Filter_EnumFlagInfo[] = {
    "FormatFilter:Flag:FormatFilters",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCanBusDevice_Filter_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QCanBusDevice_Filter__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QCanBusDevice_Filter_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QCanBusDevice::Filter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), (pyArg)))) {
                // operator!=(const QCanBusDevice::Filter & b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCanBusDevice::Filter cppArg0_local;
                ::QCanBusDevice::Filter *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), (pyArg)))) {
                // operator==(const QCanBusDevice::Filter & b)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QCanBusDevice::Filter cppArg0_local;
                ::QCanBusDevice::Filter *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

static PyObject *Sbk_QCanBusDevice_Filter_get_frameId(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice::Filter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    unsigned int cppOut_local = cppSelf->frameId;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QCanBusDevice_Filter_set_frameId(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice::Filter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("frameId");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("frameId", "unsigned int");
        return -1;
    }

    auto cppOut_local = cppSelf->frameId;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->frameId = cppOut_local;

    return 0;
}

static PyObject *Sbk_QCanBusDevice_Filter_get_frameIdMask(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice::Filter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    unsigned int cppOut_local = cppSelf->frameIdMask;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QCanBusDevice_Filter_set_frameIdMask(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice::Filter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("frameIdMask");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("frameIdMask", "unsigned int");
        return -1;
    }

    auto cppOut_local = cppSelf->frameIdMask;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->frameIdMask = cppOut_local;

    return 0;
}

static PyObject *Sbk_QCanBusDevice_Filter_get_type(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice::Filter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QCanBusFrame::FrameType cppOut_local = cppSelf->type;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_FrameType_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QCanBusDevice_Filter_set_type(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice::Filter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("type");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusFrame_FrameType_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("type", "FrameType");
        return -1;
    }

    auto cppOut_local = cppSelf->type;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->type = cppOut_local;

    return 0;
}

static PyObject *Sbk_QCanBusDevice_Filter_get_format(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice::Filter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QCanBusDevice::Filter::FormatFilter cppOut_local = cppSelf->format;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_FormatFilter_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QCanBusDevice_Filter_set_format(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QCanBusDevice::Filter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("format");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_FormatFilter_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("format", "FormatFilter");
        return -1;
    }

    auto cppOut_local = cppSelf->format;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->format = cppOut_local;

    return 0;
}

// Getters and Setters for Filter
static PyGetSetDef Sbk_QCanBusDevice_Filter_getsetlist[] = {
    {const_cast<char *>("frameId"), Sbk_QCanBusDevice_Filter_get_frameId, Sbk_QCanBusDevice_Filter_set_frameId, nullptr, nullptr},
    {const_cast<char *>("frameIdMask"), Sbk_QCanBusDevice_Filter_get_frameIdMask, Sbk_QCanBusDevice_Filter_set_frameIdMask, nullptr, nullptr},
    {const_cast<char *>("type"), Sbk_QCanBusDevice_Filter_get_type, Sbk_QCanBusDevice_Filter_set_type, nullptr, nullptr},
    {const_cast<char *>("format"), Sbk_QCanBusDevice_Filter_get_format, Sbk_QCanBusDevice_Filter_set_format, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QCanBusDevice_Filter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCanBusDevice_Filter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCanBusDevice_Filter_Type = nullptr;
static PyTypeObject *Sbk_QCanBusDevice_Filter_TypeF(void)
{
    return _Sbk_QCanBusDevice_Filter_Type;
}

static PyType_Slot Sbk_QCanBusDevice_Filter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCanBusDevice_Filter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCanBusDevice_Filter_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QCanBusDevice_Filter_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCanBusDevice_Filter_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QCanBusDevice_Filter_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCanBusDevice_Filter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCanBusDevice_Filter_spec = {
    "2:PySide6.QtSerialBus.QCanBusDevice.Filter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCanBusDevice_Filter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QCanBusDevice_Filter_FormatFilter_PythonToCpp_QCanBusDevice_Filter_FormatFilter(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCanBusDevice::Filter::FormatFilter>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCanBusDevice::Filter::FormatFilter *>(cppOut) = value;

}
static PythonToCppFunc is_QCanBusDevice_Filter_FormatFilter_PythonToCpp_QCanBusDevice_Filter_FormatFilter_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_FormatFilter_IDX])))
        return QCanBusDevice_Filter_FormatFilter_PythonToCpp_QCanBusDevice_Filter_FormatFilter;
    return {};
}
static PyObject *QCanBusDevice_Filter_FormatFilter_CppToPython_QCanBusDevice_Filter_FormatFilter(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCanBusDevice::Filter::FormatFilter *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_FormatFilter_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Filter_PythonToCpp_Filter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCanBusDevice_Filter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Filter_PythonToCpp_Filter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCanBusDevice_Filter_TypeF()))
        return Filter_PythonToCpp_Filter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Filter_PTR_CppToPython_Filter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QCanBusDevice::Filter *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QCanBusDevice_Filter_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *Filter_COPY_CppToPython_Filter(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QCanBusDevice::Filter *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QCanBusDevice_Filter_TypeF(), new ::QCanBusDevice::Filter(*source), true, true);
}

// Python to C++ copy conversion.
static void Filter_PythonToCpp_Filter_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QCanBusDevice::Filter *>(cppOut) = *reinterpret_cast< ::QCanBusDevice::Filter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_Filter_PythonToCpp_Filter_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QCanBusDevice_Filter_TypeF()))
        return Filter_PythonToCpp_Filter_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QCanBusDevice_Filter_SignatureStrings[] = {
    "1:PySide6.QtSerialBus.QCanBusDevice.Filter(self)",
    "0:PySide6.QtSerialBus.QCanBusDevice.Filter(self,Filter:PySide6.QtSerialBus.QCanBusDevice.Filter)",
    "PySide6.QtSerialBus.QCanBusDevice.Filter.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QCanBusDevice_Filter(PyObject *enclosingClass)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX].type;

    Shiboken::AutoDecRef Sbk_QCanBusDevice_Filter_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCanBusDevice_Filter_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Filter",
        "QCanBusDevice::Filter",
        &Sbk_QCanBusDevice_Filter_spec,
        &Shiboken::callCppDestructor< ::QCanBusDevice::Filter >,
        Sbk_QCanBusDevice_Filter_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QCanBusDevice_Filter_TypeF(); // references _Sbk_QCanBusDevice_Filter_Type
    InitSignatureStrings(pyType, QCanBusDevice_Filter_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCanBusDevice_Filter_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Filter_PythonToCpp_Filter_PTR,
        is_Filter_PythonToCpp_Filter_PTR_Convertible,
        Filter_PTR_CppToPython_Filter,
        Filter_COPY_CppToPython_Filter);

    Shiboken::Conversions::registerConverterName(converter, "QCanBusDevice::Filter");
    Shiboken::Conversions::registerConverterName(converter, "QCanBusDevice::Filter*");
    Shiboken::Conversions::registerConverterName(converter, "QCanBusDevice::Filter&");
    Shiboken::Conversions::registerConverterName(converter, "Filter");
    Shiboken::Conversions::registerConverterName(converter, "Filter*");
    Shiboken::Conversions::registerConverterName(converter, "Filter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCanBusDevice::Filter).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        Filter_PythonToCpp_Filter_COPY,
        is_Filter_PythonToCpp_Filter_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCanBusDevice_Filter_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'FormatFilter'.
    const char *FormatFilter_Initializer[] = {
        "MatchBaseFormat",
        "MatchExtendedFormat",
        "MatchBaseAndExtendedFormat",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FormatFilter_InitializerValues[] = {
        uint8_t(QCanBusDevice::Filter::FormatFilter::MatchBaseFormat),           //  0x01  1
        uint8_t(QCanBusDevice::Filter::FormatFilter::MatchExtendedFormat),       //  0x02  2
        uint8_t(QCanBusDevice::Filter::FormatFilter::MatchBaseAndExtendedFormat) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCanBusDevice_Filter_TypeF(),
        "2:PySide6.QtSerialBus.QCanBusDevice.Filter.FormatFilter",
        FormatFilter_Initializer, FormatFilter_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanBusDevice_Filter_FormatFilter_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtSerialBusTypeStructs[SBK_QFlags_QCanBusDevice_Filter_FormatFilter_IDX].type =
        EType;
    // Register converter for enum 'QCanBusDevice::Filter::FormatFilter'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCanBusDevice_Filter_FormatFilter_CppToPython_QCanBusDevice_Filter_FormatFilter);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCanBusDevice_Filter_FormatFilter_PythonToCpp_QCanBusDevice_Filter_FormatFilter,
            is_QCanBusDevice_Filter_FormatFilter_PythonToCpp_QCanBusDevice_Filter_FormatFilter_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCanBusDevice::Filter::FormatFilter");
        Shiboken::Conversions::registerConverterName(converter, "Filter::FormatFilter");
        Shiboken::Conversions::registerConverterName(converter, "FormatFilter");
        // Register converter for flag 'QFlags<QCanBusDevice::Filter::FormatFilter>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QCanBusDevice::Filter::FormatFilter>");
        Shiboken::Conversions::registerConverterName(converter, "QCanBusDevice::Filter::FormatFilters");
    }
    // End of 'FormatFilter' enum/flags.

    qRegisterMetaType< ::QCanBusDevice::Filter >("Filter");
    qRegisterMetaType< ::QCanBusDevice::Filter >("QCanBusDevice::Filter");
    qRegisterMetaType< ::QCanBusDevice::Filter::FormatFilter >("Filter::FormatFilter");
    qRegisterMetaType< ::QCanBusDevice::Filter::FormatFilter >("QCanBusDevice::Filter::FormatFilter");

    return pyType;
}
