// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtserialbus_python.h"

// main header
#include "qcandbcfileparser_wrapper.h"

// Argument includes
#include <QHash>
#include <QList>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <QtSerialBus/qcancommondefinitions.h>
#include <QtSerialBus/qcandbcfileparser.h>
#include <QtSerialBus/qcanmessagedescription.h>
#include <QtSerialBus/qcanuniqueiddescription.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCanDbcFileParser_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QCanDbcFileParser >()))
        return -1;

    ::QCanDbcFileParser *cptr{};
    static const char fullName[] = "PySide6.QtSerialBus.QCanDbcFileParser.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QCanDbcFileParser()
            cptr = new ::QCanDbcFileParser();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QCanDbcFileParser >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QCanDbcFileParserFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanDbcFileParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialBus.QCanDbcFileParser.error";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // error()const
            QCanDbcFileParser::Error cppResult = const_cast<const ::QCanDbcFileParser *>(cppSelf)->error();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_Error_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanDbcFileParserFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanDbcFileParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialBus.QCanDbcFileParser.errorString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // errorString()const
            QString cppResult = const_cast<const ::QCanDbcFileParser *>(cppSelf)->errorString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanDbcFileParserFunc_messageDescriptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanDbcFileParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialBus.QCanDbcFileParser.messageDescriptions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // messageDescriptions()const
            QList<QCanMessageDescription> cppResult = const_cast<const ::QCanDbcFileParser *>(cppSelf)->messageDescriptions();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QList_QCanMessageDescription_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanDbcFileParserFunc_messageValueDescriptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanDbcFileParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialBus.QCanDbcFileParser.messageValueDescriptions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // messageValueDescriptions()const
            QHash<QtCanBus::UniqueId,QHash< QString,QHash< unsigned int,QString>>> cppResult = const_cast<const ::QCanDbcFileParser *>(cppSelf)->messageValueDescriptions();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtSerialBusTypeConverters[SBK_QtSerialBus_QHash_QtCanBus_UniqueId_QHash_QString_QHash_unsignedint_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanDbcFileParserFunc_parse(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanDbcFileParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSerialBus.QCanDbcFileParser.parse";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanDbcFileParser::parse(QString)->bool
    // 1: QCanDbcFileParser::parse(QStringList)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 1; // parse(QStringList)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // parse(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // parse(const QString & fileName)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // parse(QString)
                bool cppResult = cppSelf->parse(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // parse(const QStringList & fileNames)
        {
            ::QStringList cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // parse(QStringList)
                bool cppResult = cppSelf->parse(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanDbcFileParserFunc_parseData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanDbcFileParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSerialBus.QCanDbcFileParser.parseData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QCanDbcFileParser::parseData(QStringView)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // parseData(QStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // parseData(QStringView)
            bool cppResult = cppSelf->parseData(QStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanDbcFileParserFunc_uniqueIdDescription(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialBus.QCanDbcFileParser.uniqueIdDescription";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // uniqueIdDescription()
            QCanUniqueIdDescription cppResult = ::QCanDbcFileParser::uniqueIdDescription();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanUniqueIdDescription_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QCanDbcFileParserFunc_warnings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QCanDbcFileParser *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSerialBus.QCanDbcFileParser.warnings";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // warnings()const
            QStringList cppResult = const_cast<const ::QCanDbcFileParser *>(cppSelf)->warnings();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QCanDbcFileParser_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QCanDbcFileParser_EnumFlagInfo[] = {
    "Error:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QCanDbcFileParser_methods[] = {
    {"error", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_error), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_errorString), METH_NOARGS, nullptr},
    {"messageDescriptions", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_messageDescriptions), METH_NOARGS, nullptr},
    {"messageValueDescriptions", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_messageValueDescriptions), METH_NOARGS, nullptr},
    {"parse", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_parse), METH_O, nullptr},
    {"parseData", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_parseData), METH_O, nullptr},
    {"uniqueIdDescription", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_uniqueIdDescription), METH_NOARGS|METH_STATIC, nullptr},
    {"warnings", reinterpret_cast<PyCFunction>(Sbk_QCanDbcFileParserFunc_warnings), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QCanDbcFileParser_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QCanDbcFileParser_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QCanDbcFileParser_Type = nullptr;
static PyTypeObject *Sbk_QCanDbcFileParser_TypeF(void)
{
    return _Sbk_QCanDbcFileParser_Type;
}

static PyType_Slot Sbk_QCanDbcFileParser_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QCanDbcFileParser_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QCanDbcFileParser_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QCanDbcFileParser_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QCanDbcFileParser_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QCanDbcFileParser_spec = {
    "2:PySide6.QtSerialBus.QCanDbcFileParser",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QCanDbcFileParser_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QCanDbcFileParser_Error_PythonToCpp_QCanDbcFileParser_Error(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QCanDbcFileParser::Error>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QCanDbcFileParser::Error *>(cppOut) = value;

}
static PythonToCppFunc is_QCanDbcFileParser_Error_PythonToCpp_QCanDbcFileParser_Error_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_Error_IDX])))
        return QCanDbcFileParser_Error_PythonToCpp_QCanDbcFileParser_Error;
    return {};
}
static PyObject *QCanDbcFileParser_Error_CppToPython_QCanDbcFileParser_Error(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QCanDbcFileParser::Error *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_Error_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QCanDbcFileParser_PythonToCpp_QCanDbcFileParser_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QCanDbcFileParser_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QCanDbcFileParser_PythonToCpp_QCanDbcFileParser_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QCanDbcFileParser_TypeF()))
        return QCanDbcFileParser_PythonToCpp_QCanDbcFileParser_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QCanDbcFileParser_PTR_CppToPython_QCanDbcFileParser(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QCanDbcFileParser *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QCanDbcFileParser_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QCanDbcFileParser_SignatureStrings[] = {
    "PySide6.QtSerialBus.QCanDbcFileParser(self)",
    "PySide6.QtSerialBus.QCanDbcFileParser.error(self)->PySide6.QtSerialBus.QCanDbcFileParser.Error",
    "PySide6.QtSerialBus.QCanDbcFileParser.errorString(self)->QString",
    "PySide6.QtSerialBus.QCanDbcFileParser.messageDescriptions(self)->QList[PySide6.QtSerialBus.QCanMessageDescription]",
    "PySide6.QtSerialBus.QCanDbcFileParser.messageValueDescriptions(self)->QHash[PySide6.QtSerialBus.QtCanBus.UniqueId, QHash[QString, QHash[unsigned int, QString]]]",
    "1:PySide6.QtSerialBus.QCanDbcFileParser.parse(self,fileName:QString)->bool",
    "0:PySide6.QtSerialBus.QCanDbcFileParser.parse(self,fileNames:QStringList)->bool",
    "PySide6.QtSerialBus.QCanDbcFileParser.parseData(self,data:QString)->bool",
    "PySide6.QtSerialBus.QCanDbcFileParser.uniqueIdDescription()->PySide6.QtSerialBus.QCanUniqueIdDescription",
    "PySide6.QtSerialBus.QCanDbcFileParser.warnings(self)->QStringList",
    nullptr}; // Sentinel

PyTypeObject *init_QCanDbcFileParser(PyObject *module)
{
    if (SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX].type != nullptr)
        return SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX].type;

    Shiboken::AutoDecRef Sbk_QCanDbcFileParser_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QCanDbcFileParser_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QCanDbcFileParser",
        "QCanDbcFileParser*",
        &Sbk_QCanDbcFileParser_spec,
        &Shiboken::callCppDestructor< ::QCanDbcFileParser >,
        Sbk_QCanDbcFileParser_Type_bases.object(),
        0);
    auto *pyType = Sbk_QCanDbcFileParser_TypeF(); // references _Sbk_QCanDbcFileParser_Type
    InitSignatureStrings(pyType, QCanDbcFileParser_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QCanDbcFileParser_PropertyStrings);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QCanDbcFileParser_PythonToCpp_QCanDbcFileParser_PTR,
        is_QCanDbcFileParser_PythonToCpp_QCanDbcFileParser_PTR_Convertible,
        QCanDbcFileParser_PTR_CppToPython_QCanDbcFileParser);

    Shiboken::Conversions::registerConverterName(converter, "QCanDbcFileParser");
    Shiboken::Conversions::registerConverterName(converter, "QCanDbcFileParser*");
    Shiboken::Conversions::registerConverterName(converter, "QCanDbcFileParser&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QCanDbcFileParser).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QCanDbcFileParser_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Error'.
    const char *Error_Initializer[] = {
        "None_",
        "FileReading",
        "Parsing",
        nullptr};
    // "uint8_t" used instead of "unsigned char"
    constexpr uint8_t Error_InitializerValues[] = {
        uint8_t(QCanDbcFileParser::Error::None),        //  0x00  0
        uint8_t(QCanDbcFileParser::Error::FileReading), //  0x01  1
        uint8_t(QCanDbcFileParser::Error::Parsing)      //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QCanDbcFileParser_TypeF(),
        "2:PySide6.QtSerialBus.QCanDbcFileParser.Error",
        Error_Initializer, Error_InitializerValues);
    SbkPySide6_QtSerialBusTypeStructs[SBK_QCanDbcFileParser_Error_IDX].type = EType;
    // Register converter for enum 'QCanDbcFileParser::Error'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QCanDbcFileParser_Error_CppToPython_QCanDbcFileParser_Error);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QCanDbcFileParser_Error_PythonToCpp_QCanDbcFileParser_Error,
            is_QCanDbcFileParser_Error_PythonToCpp_QCanDbcFileParser_Error_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QCanDbcFileParser::Error");
        Shiboken::Conversions::registerConverterName(converter, "Error");
    }
    // End of 'Error' enum.

    qRegisterMetaType< ::QCanDbcFileParser *>();
    qRegisterMetaType< ::QCanDbcFileParser::Error >("QCanDbcFileParser::Error");

    return pyType;
}
