// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtspatialaudio_python.h"

// main header
#include "qaudioroom_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGui/qquaternion.h>
#include <QtGui/qvectornd.h>
#include <QtSpatialAudio/qaudioengine.h>
#include <QtSpatialAudio/qaudioroom.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAudioRoomWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAudioRoomWrapper::QAudioRoomWrapper(::QAudioEngine * engine) : QAudioRoom(engine)
{
    resetPyMethodCache();
    // ... middle
}

void QAudioRoomWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAudioRoomWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAudioRoomWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QAudioRoomWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QAudioRoomWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAudioRoom", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAudioRoomWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAudioRoom", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAudioRoomWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

const QMetaObject *QAudioRoomWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QAudioRoom::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAudioRoomWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QAudioRoom::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAudioRoomWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAudioRoomWrapper *>(this));
    return QAudioRoom::qt_metacast(_clname);
}

QAudioRoomWrapper::~QAudioRoomWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAudioRoom_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAudioRoom >()))
        return -1;

    QAudioRoomWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAudioRoom", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAudioRoom::QAudioRoom(QAudioEngine*)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioEngine_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QAudioRoom(QAudioEngine*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QAudioEngine *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAudioRoom(QAudioEngine*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QAudioRoomWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QAudioRoomWrapper(cppArg0);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAudioRoom >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    };


    return 1;
}

static PyObject *Sbk_QAudioRoomFunc_dimensions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.dimensions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // dimensions()const
            QVector3D cppResult = const_cast<const ::QAudioRoom *>(cppSelf)->dimensions();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioRoomFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.position";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // position()const
            QVector3D cppResult = const_cast<const ::QAudioRoom *>(cppSelf)->position();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioRoomFunc_reflectionGain(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.reflectionGain";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // reflectionGain()const
            float cppResult = const_cast<const ::QAudioRoom *>(cppSelf)->reflectionGain();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioRoomFunc_reverbBrightness(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.reverbBrightness";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // reverbBrightness()const
            float cppResult = const_cast<const ::QAudioRoom *>(cppSelf)->reverbBrightness();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioRoomFunc_reverbGain(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.reverbGain";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // reverbGain()const
            float cppResult = const_cast<const ::QAudioRoom *>(cppSelf)->reverbGain();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioRoomFunc_reverbTime(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.reverbTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // reverbTime()const
            float cppResult = const_cast<const ::QAudioRoom *>(cppSelf)->reverbTime();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioRoomFunc_rotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.rotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // rotation()const
            QQuaternion cppResult = const_cast<const ::QAudioRoom *>(cppSelf)->rotation();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAudioRoomFunc_setDimensions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.setDimensions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioRoom::setDimensions(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setDimensions(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDimensions(QVector3D)
            cppSelf->setDimensions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioRoomFunc_setPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.setPosition";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioRoom::setPosition(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setPosition(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPosition(QVector3D)
            cppSelf->setPosition(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioRoomFunc_setReflectionGain(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.setReflectionGain";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioRoom::setReflectionGain(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setReflectionGain(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReflectionGain(float)
            cppSelf->setReflectionGain(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioRoomFunc_setReverbBrightness(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.setReverbBrightness";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioRoom::setReverbBrightness(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setReverbBrightness(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReverbBrightness(float)
            cppSelf->setReverbBrightness(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioRoomFunc_setReverbGain(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.setReverbGain";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioRoom::setReverbGain(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setReverbGain(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReverbGain(float)
            cppSelf->setReverbGain(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioRoomFunc_setReverbTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.setReverbTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioRoom::setReverbTime(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setReverbTime(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReverbTime(float)
            cppSelf->setReverbTime(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioRoomFunc_setRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.setRotation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioRoom::setRotation(QQuaternion)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QQuaternion_IDX]), (pyArg)))) {
        overloadId = 0; // setRotation(QQuaternion)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuaternion cppArg0_local;
        ::QQuaternion *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotation(QQuaternion)
            cppSelf->setRotation(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioRoomFunc_setWallMaterial(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.setWallMaterial";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setWallMaterial", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAudioRoom::setWallMaterial(QAudioRoom::Wall,QAudioRoom::Material)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_Wall_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_Material_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // setWallMaterial(QAudioRoom::Wall,QAudioRoom::Material)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QAudioRoom::Wall cppArg0{QAudioRoom::LeftWall};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QAudioRoom::Material cppArg1{QAudioRoom::Transparent};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWallMaterial(QAudioRoom::Wall,QAudioRoom::Material)
            cppSelf->setWallMaterial(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAudioRoomFunc_wallMaterial(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtSpatialAudio.QAudioRoom.wallMaterial";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAudioRoom::wallMaterial(QAudioRoom::Wall)const->QAudioRoom::Material
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_Wall_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // wallMaterial(QAudioRoom::Wall)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QAudioRoom::Wall cppArg0{QAudioRoom::LeftWall};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wallMaterial(QAudioRoom::Wall)const
            QAudioRoom::Material cppResult = const_cast<const ::QAudioRoom *>(cppSelf)->wallMaterial(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_Material_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAudioRoom_PropertyStrings[] = {
    "dimensions::",
    "position::",
    "reflectionGain::",
    "reverbBrightness::",
    "reverbGain::",
    "reverbTime::",
    "rotation::",
    nullptr // Sentinel
};

static const char *Sbk_QAudioRoom_EnumFlagInfo[] = {
    "Material:Enum",
    "Wall:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAudioRoom_methods[] = {
    {"dimensions", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_dimensions), METH_NOARGS, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_position), METH_NOARGS, nullptr},
    {"reflectionGain", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_reflectionGain), METH_NOARGS, nullptr},
    {"reverbBrightness", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_reverbBrightness), METH_NOARGS, nullptr},
    {"reverbGain", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_reverbGain), METH_NOARGS, nullptr},
    {"reverbTime", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_reverbTime), METH_NOARGS, nullptr},
    {"rotation", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_rotation), METH_NOARGS, nullptr},
    {"setDimensions", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_setDimensions), METH_O, nullptr},
    {"setPosition", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_setPosition), METH_O, nullptr},
    {"setReflectionGain", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_setReflectionGain), METH_O, nullptr},
    {"setReverbBrightness", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_setReverbBrightness), METH_O, nullptr},
    {"setReverbGain", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_setReverbGain), METH_O, nullptr},
    {"setReverbTime", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_setReverbTime), METH_O, nullptr},
    {"setRotation", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_setRotation), METH_O, nullptr},
    {"setWallMaterial", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_setWallMaterial), METH_VARARGS, nullptr},
    {"wallMaterial", reinterpret_cast<PyCFunction>(Sbk_QAudioRoomFunc_wallMaterial), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAudioRoom_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAudioRoom *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAudioRoomWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAudioRoom_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAudioRoom_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAudioRoom_Type = nullptr;
static PyTypeObject *Sbk_QAudioRoom_TypeF(void)
{
    return _Sbk_QAudioRoom_Type;
}

static PyType_Slot Sbk_QAudioRoom_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAudioRoom_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAudioRoom_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAudioRoom_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAudioRoom_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAudioRoom_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAudioRoom_spec = {
    "2:PySide6.QtSpatialAudio.QAudioRoom",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAudioRoom_slots
};

} //extern "C"

static void *Sbk_QAudioRoom_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAudioRoom *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QAudioRoom_Material_PythonToCpp_QAudioRoom_Material(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAudioRoom::Material>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAudioRoom::Material *>(cppOut) = value;

}
static PythonToCppFunc is_QAudioRoom_Material_PythonToCpp_QAudioRoom_Material_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_Material_IDX])))
        return QAudioRoom_Material_PythonToCpp_QAudioRoom_Material;
    return {};
}
static PyObject *QAudioRoom_Material_CppToPython_QAudioRoom_Material(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QAudioRoom::Material *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_Material_IDX]), castCppIn);

}

static void QAudioRoom_Wall_PythonToCpp_QAudioRoom_Wall(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAudioRoom::Wall>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAudioRoom::Wall *>(cppOut) = value;

}
static PythonToCppFunc is_QAudioRoom_Wall_PythonToCpp_QAudioRoom_Wall_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_Wall_IDX])))
        return QAudioRoom_Wall_PythonToCpp_QAudioRoom_Wall;
    return {};
}
static PyObject *QAudioRoom_Wall_CppToPython_QAudioRoom_Wall(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QAudioRoom::Wall *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_Wall_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAudioRoom_PythonToCpp_QAudioRoom_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAudioRoom_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAudioRoom_PythonToCpp_QAudioRoom_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAudioRoom_TypeF()))
        return QAudioRoom_PythonToCpp_QAudioRoom_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAudioRoom_PTR_CppToPython_QAudioRoom(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAudioRoom *>(const_cast<void *>(cppIn)), Sbk_QAudioRoom_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QAudioRoom_SignatureStrings[] = {
    "PySide6.QtSpatialAudio.QAudioRoom(self,engine:PySide6.QtSpatialAudio.QAudioEngine)",
    "PySide6.QtSpatialAudio.QAudioRoom.dimensions(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtSpatialAudio.QAudioRoom.position(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtSpatialAudio.QAudioRoom.reflectionGain(self)->float",
    "PySide6.QtSpatialAudio.QAudioRoom.reverbBrightness(self)->float",
    "PySide6.QtSpatialAudio.QAudioRoom.reverbGain(self)->float",
    "PySide6.QtSpatialAudio.QAudioRoom.reverbTime(self)->float",
    "PySide6.QtSpatialAudio.QAudioRoom.rotation(self)->PySide6.QtGui.QQuaternion",
    "PySide6.QtSpatialAudio.QAudioRoom.setDimensions(self,dim:PySide6.QtGui.QVector3D)",
    "PySide6.QtSpatialAudio.QAudioRoom.setPosition(self,pos:PySide6.QtGui.QVector3D)",
    "PySide6.QtSpatialAudio.QAudioRoom.setReflectionGain(self,factor:float)",
    "PySide6.QtSpatialAudio.QAudioRoom.setReverbBrightness(self,factor:float)",
    "PySide6.QtSpatialAudio.QAudioRoom.setReverbGain(self,factor:float)",
    "PySide6.QtSpatialAudio.QAudioRoom.setReverbTime(self,factor:float)",
    "PySide6.QtSpatialAudio.QAudioRoom.setRotation(self,q:PySide6.QtGui.QQuaternion)",
    "PySide6.QtSpatialAudio.QAudioRoom.setWallMaterial(self,wall:PySide6.QtSpatialAudio.QAudioRoom.Wall,material:PySide6.QtSpatialAudio.QAudioRoom.Material)",
    "PySide6.QtSpatialAudio.QAudioRoom.wallMaterial(self,wall:PySide6.QtSpatialAudio.QAudioRoom.Wall)->PySide6.QtSpatialAudio.QAudioRoom.Material",
    nullptr}; // Sentinel

PyTypeObject *init_QAudioRoom(PyObject *module)
{
    if (SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX].type != nullptr)
        return SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX].type;

    Shiboken::AutoDecRef Sbk_QAudioRoom_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QAudioRoom_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAudioRoom",
        "QAudioRoom*",
        &Sbk_QAudioRoom_spec,
        &Shiboken::callCppDestructor< QAudioRoom >,
        Sbk_QAudioRoom_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAudioRoom_TypeF(); // references _Sbk_QAudioRoom_Type
    InitSignatureStrings(pyType, QAudioRoom_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAudioRoom_PropertyStrings);
    SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAudioRoom_PythonToCpp_QAudioRoom_PTR,
        is_QAudioRoom_PythonToCpp_QAudioRoom_PTR_Convertible,
        QAudioRoom_PTR_CppToPython_QAudioRoom);

    Shiboken::Conversions::registerConverterName(converter, "QAudioRoom");
    Shiboken::Conversions::registerConverterName(converter, "QAudioRoom*");
    Shiboken::Conversions::registerConverterName(converter, "QAudioRoom&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAudioRoom).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAudioRoomWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAudioRoom_TypeF(), &Sbk_QAudioRoom_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAudioRoom_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Material'.
    const char *Material_Initializer[] = {
        "Transparent",
        "AcousticCeilingTiles",
        "BrickBare",
        "BrickPainted",
        "ConcreteBlockCoarse",
        "ConcreteBlockPainted",
        "CurtainHeavy",
        "FiberGlassInsulation",
        "GlassThin",
        "GlassThick",
        "Grass",
        "LinoleumOnConcrete",
        "Marble",
        "Metal",
        "ParquetOnConcrete",
        "PlasterRough",
        "PlasterSmooth",
        "PlywoodPanel",
        "PolishedConcreteOrTile",
        "Sheetrock",
        "WaterOrIceSurface",
        "WoodCeiling",
        "WoodPanel",
        "UniformMaterial",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Material_InitializerValues[] = {
        uint8_t(QAudioRoom::Material::Transparent),            //  0x00  0
        uint8_t(QAudioRoom::Material::AcousticCeilingTiles),   //  0x01  1
        uint8_t(QAudioRoom::Material::BrickBare),              //  0x02  2
        uint8_t(QAudioRoom::Material::BrickPainted),           //  0x03  3
        uint8_t(QAudioRoom::Material::ConcreteBlockCoarse),    //  0x04  4
        uint8_t(QAudioRoom::Material::ConcreteBlockPainted),   //  0x05  5
        uint8_t(QAudioRoom::Material::CurtainHeavy),           //  0x06  6
        uint8_t(QAudioRoom::Material::FiberGlassInsulation),   //  0x07  7
        uint8_t(QAudioRoom::Material::GlassThin),              //  0x08  8
        uint8_t(QAudioRoom::Material::GlassThick),             //  0x09  9
        uint8_t(QAudioRoom::Material::Grass),                  //  0x0a  10
        uint8_t(QAudioRoom::Material::LinoleumOnConcrete),     //  0x0b  11
        uint8_t(QAudioRoom::Material::Marble),                 //  0x0c  12
        uint8_t(QAudioRoom::Material::Metal),                  //  0x0d  13
        uint8_t(QAudioRoom::Material::ParquetOnConcrete),      //  0x0e  14
        uint8_t(QAudioRoom::Material::PlasterRough),           //  0x0f  15
        uint8_t(QAudioRoom::Material::PlasterSmooth),          //  0x10  16
        uint8_t(QAudioRoom::Material::PlywoodPanel),           //  0x11  17
        uint8_t(QAudioRoom::Material::PolishedConcreteOrTile), //  0x12  18
        uint8_t(QAudioRoom::Material::Sheetrock),              //  0x13  19
        uint8_t(QAudioRoom::Material::WaterOrIceSurface),      //  0x14  20
        uint8_t(QAudioRoom::Material::WoodCeiling),            //  0x15  21
        uint8_t(QAudioRoom::Material::WoodPanel),              //  0x16  22
        uint8_t(QAudioRoom::Material::UniformMaterial)         //  0x17  23
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAudioRoom_TypeF(),
        "2:PySide6.QtSpatialAudio.QAudioRoom.Material",
        Material_Initializer, Material_InitializerValues);
    SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_Material_IDX].type = EType;
    // Register converter for enum 'QAudioRoom::Material'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAudioRoom_Material_CppToPython_QAudioRoom_Material);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QAudioRoom_Material_PythonToCpp_QAudioRoom_Material,
            is_QAudioRoom_Material_PythonToCpp_QAudioRoom_Material_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QAudioRoom::Material");
        Shiboken::Conversions::registerConverterName(converter, "Material");
    }
    // End of 'Material' enum.

    // Initialization of enum 'Wall'.
    const char *Wall_Initializer[] = {
        "LeftWall",
        "RightWall",
        "Floor",
        "Ceiling",
        "FrontWall",
        "BackWall",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Wall_InitializerValues[] = {
        uint8_t(QAudioRoom::Wall::LeftWall),  //  0x00  0
        uint8_t(QAudioRoom::Wall::RightWall), //  0x01  1
        uint8_t(QAudioRoom::Wall::Floor),     //  0x02  2
        uint8_t(QAudioRoom::Wall::Ceiling),   //  0x03  3
        uint8_t(QAudioRoom::Wall::FrontWall), //  0x04  4
        uint8_t(QAudioRoom::Wall::BackWall)   //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAudioRoom_TypeF(),
        "2:PySide6.QtSpatialAudio.QAudioRoom.Wall",
        Wall_Initializer, Wall_InitializerValues);
    SbkPySide6_QtSpatialAudioTypeStructs[SBK_QAudioRoom_Wall_IDX].type = EType;
    // Register converter for enum 'QAudioRoom::Wall'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAudioRoom_Wall_CppToPython_QAudioRoom_Wall);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QAudioRoom_Wall_PythonToCpp_QAudioRoom_Wall,
            is_QAudioRoom_Wall_PythonToCpp_QAudioRoom_Wall_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QAudioRoom::Wall");
        Shiboken::Conversions::registerConverterName(converter, "Wall");
    }
    // End of 'Wall' enum.

    PySide::Signal::registerSignals(pyType, &::QAudioRoom::staticMetaObject);
    qRegisterMetaType< ::QAudioRoom::Material >("QAudioRoom::Material");
    qRegisterMetaType< ::QAudioRoom::Wall >("QAudioRoom::Wall");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAudioRoom::staticMetaObject, sizeof(QAudioRoomWrapper));

    return pyType;
}
