// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebenginecontextmenurequest_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <QtWebEngineCore/qwebenginecontextmenurequest.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qthread.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QWebEngineContextMenuRequestWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void QWebEngineContextMenuRequestWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QWebEngineContextMenuRequestWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QWebEngineContextMenuRequestWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QWebEngineContextMenuRequestWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QWebEngineContextMenuRequestWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEngineContextMenuRequest", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QWebEngineContextMenuRequestWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEngineContextMenuRequest", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEngineContextMenuRequestWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

const QMetaObject *QWebEngineContextMenuRequestWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QWebEngineContextMenuRequest::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QWebEngineContextMenuRequestWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QWebEngineContextMenuRequest::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QWebEngineContextMenuRequestWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QWebEngineContextMenuRequestWrapper *>(this));
    return QWebEngineContextMenuRequest::qt_metacast(_clname);
}

QWebEngineContextMenuRequestWrapper::~QWebEngineContextMenuRequestWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QWebEngineContextMenuRequestFunc_editFlags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineContextMenuRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.editFlags";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // editFlags()const
            QFlags<QWebEngineContextMenuRequest::EditFlag> cppResult = const_cast<const ::QWebEngineContextMenuRequest *>(cppSelf)->editFlags();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QFlags_QWebEngineContextMenuRequest_EditFlag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineContextMenuRequestFunc_isAccepted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineContextMenuRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.isAccepted";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isAccepted()const
            bool cppResult = const_cast<const ::QWebEngineContextMenuRequest *>(cppSelf)->isAccepted();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineContextMenuRequestFunc_isContentEditable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineContextMenuRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.isContentEditable";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isContentEditable()const
            bool cppResult = const_cast<const ::QWebEngineContextMenuRequest *>(cppSelf)->isContentEditable();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineContextMenuRequestFunc_linkText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineContextMenuRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.linkText";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // linkText()const
            QString cppResult = const_cast<const ::QWebEngineContextMenuRequest *>(cppSelf)->linkText();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineContextMenuRequestFunc_linkUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineContextMenuRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.linkUrl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // linkUrl()const
            QUrl cppResult = const_cast<const ::QWebEngineContextMenuRequest *>(cppSelf)->linkUrl();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineContextMenuRequestFunc_mediaFlags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineContextMenuRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.mediaFlags";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mediaFlags()const
            QFlags<QWebEngineContextMenuRequest::MediaFlag> cppResult = const_cast<const ::QWebEngineContextMenuRequest *>(cppSelf)->mediaFlags();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QFlags_QWebEngineContextMenuRequest_MediaFlag_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineContextMenuRequestFunc_mediaType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineContextMenuRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.mediaType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mediaType()const
            QWebEngineContextMenuRequest::MediaType cppResult = const_cast<const ::QWebEngineContextMenuRequest *>(cppSelf)->mediaType();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_MediaType_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineContextMenuRequestFunc_mediaUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineContextMenuRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.mediaUrl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mediaUrl()const
            QUrl cppResult = const_cast<const ::QWebEngineContextMenuRequest *>(cppSelf)->mediaUrl();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineContextMenuRequestFunc_misspelledWord(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineContextMenuRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.misspelledWord";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // misspelledWord()const
            QString cppResult = const_cast<const ::QWebEngineContextMenuRequest *>(cppSelf)->misspelledWord();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineContextMenuRequestFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineContextMenuRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.position";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // position()const
            QPoint cppResult = const_cast<const ::QWebEngineContextMenuRequest *>(cppSelf)->position();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineContextMenuRequestFunc_selectedText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineContextMenuRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.selectedText";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectedText()const
            QString cppResult = const_cast<const ::QWebEngineContextMenuRequest *>(cppSelf)->selectedText();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineContextMenuRequestFunc_setAccepted(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineContextMenuRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.setAccepted";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineContextMenuRequest::setAccepted(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAccepted(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAccepted(bool)
            cppSelf->setAccepted(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEngineContextMenuRequestFunc_spellCheckerSuggestions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineContextMenuRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.spellCheckerSuggestions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // spellCheckerSuggestions()const
            QStringList cppResult = const_cast<const ::QWebEngineContextMenuRequest *>(cppSelf)->spellCheckerSuggestions();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineContextMenuRequest_PropertyStrings[] = {
    "accepted:isAccepted:",
    "editFlags:",
    "isContentEditable:",
    "linkText:",
    "linkUrl:",
    "mediaFlags:",
    "mediaType:",
    "mediaUrl:",
    "misspelledWord:",
    "position:",
    "selectedText:",
    "spellCheckerSuggestions:",
    nullptr // Sentinel
};

static const char *Sbk_QWebEngineContextMenuRequest_EnumFlagInfo[] = {
    "EditFlag:Flag:EditFlags",
    "MediaFlag:Flag:MediaFlags",
    "MediaType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineContextMenuRequest_methods[] = {
    {"editFlags", reinterpret_cast<PyCFunction>(Sbk_QWebEngineContextMenuRequestFunc_editFlags), METH_NOARGS, nullptr},
    {"isAccepted", reinterpret_cast<PyCFunction>(Sbk_QWebEngineContextMenuRequestFunc_isAccepted), METH_NOARGS, nullptr},
    {"isContentEditable", reinterpret_cast<PyCFunction>(Sbk_QWebEngineContextMenuRequestFunc_isContentEditable), METH_NOARGS, nullptr},
    {"linkText", reinterpret_cast<PyCFunction>(Sbk_QWebEngineContextMenuRequestFunc_linkText), METH_NOARGS, nullptr},
    {"linkUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEngineContextMenuRequestFunc_linkUrl), METH_NOARGS, nullptr},
    {"mediaFlags", reinterpret_cast<PyCFunction>(Sbk_QWebEngineContextMenuRequestFunc_mediaFlags), METH_NOARGS, nullptr},
    {"mediaType", reinterpret_cast<PyCFunction>(Sbk_QWebEngineContextMenuRequestFunc_mediaType), METH_NOARGS, nullptr},
    {"mediaUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEngineContextMenuRequestFunc_mediaUrl), METH_NOARGS, nullptr},
    {"misspelledWord", reinterpret_cast<PyCFunction>(Sbk_QWebEngineContextMenuRequestFunc_misspelledWord), METH_NOARGS, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_QWebEngineContextMenuRequestFunc_position), METH_NOARGS, nullptr},
    {"selectedText", reinterpret_cast<PyCFunction>(Sbk_QWebEngineContextMenuRequestFunc_selectedText), METH_NOARGS, nullptr},
    {"setAccepted", reinterpret_cast<PyCFunction>(Sbk_QWebEngineContextMenuRequestFunc_setAccepted), METH_O, nullptr},
    {"spellCheckerSuggestions", reinterpret_cast<PyCFunction>(Sbk_QWebEngineContextMenuRequestFunc_spellCheckerSuggestions), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QWebEngineContextMenuRequest_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QWebEngineContextMenuRequest *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QWebEngineContextMenuRequestWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QWebEngineContextMenuRequest_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineContextMenuRequest_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineContextMenuRequest_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineContextMenuRequest_TypeF(void)
{
    return _Sbk_QWebEngineContextMenuRequest_Type;
}

static PyType_Slot Sbk_QWebEngineContextMenuRequest_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QWebEngineContextMenuRequest_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineContextMenuRequest_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineContextMenuRequest_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineContextMenuRequest_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineContextMenuRequest_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineContextMenuRequest",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineContextMenuRequest_slots
};

} //extern "C"

static void *Sbk_QWebEngineContextMenuRequest_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QWebEngineContextMenuRequest *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QWebEngineContextMenuRequest_MediaType_PythonToCpp_QWebEngineContextMenuRequest_MediaType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineContextMenuRequest::MediaType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineContextMenuRequest::MediaType *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEngineContextMenuRequest_MediaType_PythonToCpp_QWebEngineContextMenuRequest_MediaType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_MediaType_IDX])))
        return QWebEngineContextMenuRequest_MediaType_PythonToCpp_QWebEngineContextMenuRequest_MediaType;
    return {};
}
static PyObject *QWebEngineContextMenuRequest_MediaType_CppToPython_QWebEngineContextMenuRequest_MediaType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEngineContextMenuRequest::MediaType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_MediaType_IDX]), castCppIn);

}

static void QWebEngineContextMenuRequest_MediaFlag_PythonToCpp_QWebEngineContextMenuRequest_MediaFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineContextMenuRequest::MediaFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineContextMenuRequest::MediaFlag *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEngineContextMenuRequest_MediaFlag_PythonToCpp_QWebEngineContextMenuRequest_MediaFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_MediaFlag_IDX])))
        return QWebEngineContextMenuRequest_MediaFlag_PythonToCpp_QWebEngineContextMenuRequest_MediaFlag;
    return {};
}
static PyObject *QWebEngineContextMenuRequest_MediaFlag_CppToPython_QWebEngineContextMenuRequest_MediaFlag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEngineContextMenuRequest::MediaFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_MediaFlag_IDX]), castCppIn);

}

static void QWebEngineContextMenuRequest_EditFlag_PythonToCpp_QWebEngineContextMenuRequest_EditFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineContextMenuRequest::EditFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineContextMenuRequest::EditFlag *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEngineContextMenuRequest_EditFlag_PythonToCpp_QWebEngineContextMenuRequest_EditFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_EditFlag_IDX])))
        return QWebEngineContextMenuRequest_EditFlag_PythonToCpp_QWebEngineContextMenuRequest_EditFlag;
    return {};
}
static PyObject *QWebEngineContextMenuRequest_EditFlag_CppToPython_QWebEngineContextMenuRequest_EditFlag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEngineContextMenuRequest::EditFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_EditFlag_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineContextMenuRequest_PythonToCpp_QWebEngineContextMenuRequest_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineContextMenuRequest_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineContextMenuRequest_PythonToCpp_QWebEngineContextMenuRequest_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineContextMenuRequest_TypeF()))
        return QWebEngineContextMenuRequest_PythonToCpp_QWebEngineContextMenuRequest_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineContextMenuRequest_PTR_CppToPython_QWebEngineContextMenuRequest(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QWebEngineContextMenuRequest *>(const_cast<void *>(cppIn)), Sbk_QWebEngineContextMenuRequest_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QWebEngineContextMenuRequest_SignatureStrings[] = {
    "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.editFlags(self)->PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.EditFlag",
    "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.isAccepted(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.isContentEditable(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.linkText(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.linkUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.mediaFlags(self)->PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.MediaFlag",
    "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.mediaType(self)->PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.MediaType",
    "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.mediaUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.misspelledWord(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.position(self)->PySide6.QtCore.QPoint",
    "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.selectedText(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.setAccepted(self,accepted:bool)",
    "PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.spellCheckerSuggestions(self)->QStringList",
    nullptr}; // Sentinel

PyTypeObject *init_QWebEngineContextMenuRequest(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineContextMenuRequest_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QWebEngineContextMenuRequest_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineContextMenuRequest",
        "QWebEngineContextMenuRequest*",
        &Sbk_QWebEngineContextMenuRequest_spec,
        &Shiboken::callCppDestructor< QWebEngineContextMenuRequest >,
        Sbk_QWebEngineContextMenuRequest_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWebEngineContextMenuRequest_TypeF(); // references _Sbk_QWebEngineContextMenuRequest_Type
    InitSignatureStrings(pyType, QWebEngineContextMenuRequest_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineContextMenuRequest_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineContextMenuRequest_PythonToCpp_QWebEngineContextMenuRequest_PTR,
        is_QWebEngineContextMenuRequest_PythonToCpp_QWebEngineContextMenuRequest_PTR_Convertible,
        QWebEngineContextMenuRequest_PTR_CppToPython_QWebEngineContextMenuRequest);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineContextMenuRequest");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineContextMenuRequest*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineContextMenuRequest&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineContextMenuRequest).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QWebEngineContextMenuRequestWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QWebEngineContextMenuRequest_TypeF(), &Sbk_QWebEngineContextMenuRequest_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWebEngineContextMenuRequest_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'MediaType'.
    const char *MediaType_Initializer[] = {
        "MediaTypeNone",
        "MediaTypeImage",
        "MediaTypeVideo",
        "MediaTypeAudio",
        "MediaTypeCanvas",
        "MediaTypeFile",
        "MediaTypePlugin",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MediaType_InitializerValues[] = {
        uint8_t(QWebEngineContextMenuRequest::MediaType::MediaTypeNone),   //  0x00  0
        uint8_t(QWebEngineContextMenuRequest::MediaType::MediaTypeImage),  //  0x01  1
        uint8_t(QWebEngineContextMenuRequest::MediaType::MediaTypeVideo),  //  0x02  2
        uint8_t(QWebEngineContextMenuRequest::MediaType::MediaTypeAudio),  //  0x03  3
        uint8_t(QWebEngineContextMenuRequest::MediaType::MediaTypeCanvas), //  0x04  4
        uint8_t(QWebEngineContextMenuRequest::MediaType::MediaTypeFile),   //  0x05  5
        uint8_t(QWebEngineContextMenuRequest::MediaType::MediaTypePlugin)  //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineContextMenuRequest_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.MediaType",
        MediaType_Initializer, MediaType_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_MediaType_IDX].type = EType;
    // Register converter for enum 'QWebEngineContextMenuRequest::MediaType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineContextMenuRequest_MediaType_CppToPython_QWebEngineContextMenuRequest_MediaType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEngineContextMenuRequest_MediaType_PythonToCpp_QWebEngineContextMenuRequest_MediaType,
            is_QWebEngineContextMenuRequest_MediaType_PythonToCpp_QWebEngineContextMenuRequest_MediaType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineContextMenuRequest::MediaType");
        Shiboken::Conversions::registerConverterName(converter, "MediaType");
    }
    // End of 'MediaType' enum.

    // Initialization of enum 'MediaFlag'.
    const char *MediaFlag_Initializer[] = {
        "MediaInError",
        "MediaPaused",
        "MediaMuted",
        "MediaLoop",
        "MediaCanSave",
        "MediaHasAudio",
        "MediaCanToggleControls",
        "MediaControls",
        "MediaCanPrint",
        "MediaCanRotate",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t MediaFlag_InitializerValues[] = {
        uint16_t(QWebEngineContextMenuRequest::MediaFlag::MediaInError),           //  0x0001  1
        uint16_t(QWebEngineContextMenuRequest::MediaFlag::MediaPaused),            //  0x0002  2
        uint16_t(QWebEngineContextMenuRequest::MediaFlag::MediaMuted),             //  0x0004  4
        uint16_t(QWebEngineContextMenuRequest::MediaFlag::MediaLoop),              //  0x0008  8
        uint16_t(QWebEngineContextMenuRequest::MediaFlag::MediaCanSave),           //  0x0010  16
        uint16_t(QWebEngineContextMenuRequest::MediaFlag::MediaHasAudio),          //  0x0020  32
        uint16_t(QWebEngineContextMenuRequest::MediaFlag::MediaCanToggleControls), //  0x0040  64
        uint16_t(QWebEngineContextMenuRequest::MediaFlag::MediaControls),          //  0x0080  128
        uint16_t(QWebEngineContextMenuRequest::MediaFlag::MediaCanPrint),          //  0x0100  256
        uint16_t(QWebEngineContextMenuRequest::MediaFlag::MediaCanRotate)          //  0x0200  512
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineContextMenuRequest_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.MediaFlag",
        MediaFlag_Initializer, MediaFlag_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_MediaFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QFlags_QWebEngineContextMenuRequest_MediaFlag_IDX].type =
        EType;
    // Register converter for enum 'QWebEngineContextMenuRequest::MediaFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineContextMenuRequest_MediaFlag_CppToPython_QWebEngineContextMenuRequest_MediaFlag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEngineContextMenuRequest_MediaFlag_PythonToCpp_QWebEngineContextMenuRequest_MediaFlag,
            is_QWebEngineContextMenuRequest_MediaFlag_PythonToCpp_QWebEngineContextMenuRequest_MediaFlag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineContextMenuRequest::MediaFlag");
        Shiboken::Conversions::registerConverterName(converter, "MediaFlag");
        // Register converter for flag 'QFlags<QWebEngineContextMenuRequest::MediaFlag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QWebEngineContextMenuRequest::MediaFlag>");
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineContextMenuRequest::MediaFlags");
    }
    // End of 'MediaFlag' enum/flags.

    // Initialization of enum 'EditFlag'.
    const char *EditFlag_Initializer[] = {
        "CanUndo",
        "CanRedo",
        "CanCut",
        "CanCopy",
        "CanPaste",
        "CanDelete",
        "CanSelectAll",
        "CanTranslate",
        "CanEditRichly",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t EditFlag_InitializerValues[] = {
        uint16_t(QWebEngineContextMenuRequest::EditFlag::CanUndo),      //  0x0001  1
        uint16_t(QWebEngineContextMenuRequest::EditFlag::CanRedo),      //  0x0002  2
        uint16_t(QWebEngineContextMenuRequest::EditFlag::CanCut),       //  0x0004  4
        uint16_t(QWebEngineContextMenuRequest::EditFlag::CanCopy),      //  0x0008  8
        uint16_t(QWebEngineContextMenuRequest::EditFlag::CanPaste),     //  0x0010  16
        uint16_t(QWebEngineContextMenuRequest::EditFlag::CanDelete),    //  0x0020  32
        uint16_t(QWebEngineContextMenuRequest::EditFlag::CanSelectAll), //  0x0040  64
        uint16_t(QWebEngineContextMenuRequest::EditFlag::CanTranslate), //  0x0080  128
        uint16_t(QWebEngineContextMenuRequest::EditFlag::CanEditRichly) //  0x0100  256
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineContextMenuRequest_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.EditFlag",
        EditFlag_Initializer, EditFlag_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineContextMenuRequest_EditFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QFlags_QWebEngineContextMenuRequest_EditFlag_IDX].type =
        EType;
    // Register converter for enum 'QWebEngineContextMenuRequest::EditFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineContextMenuRequest_EditFlag_CppToPython_QWebEngineContextMenuRequest_EditFlag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEngineContextMenuRequest_EditFlag_PythonToCpp_QWebEngineContextMenuRequest_EditFlag,
            is_QWebEngineContextMenuRequest_EditFlag_PythonToCpp_QWebEngineContextMenuRequest_EditFlag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineContextMenuRequest::EditFlag");
        Shiboken::Conversions::registerConverterName(converter, "EditFlag");
        // Register converter for flag 'QFlags<QWebEngineContextMenuRequest::EditFlag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QWebEngineContextMenuRequest::EditFlag>");
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineContextMenuRequest::EditFlags");
    }
    // End of 'EditFlag' enum/flags.

    qRegisterMetaType< ::QWebEngineContextMenuRequest::MediaType >("QWebEngineContextMenuRequest::MediaType");
    qRegisterMetaType< ::QWebEngineContextMenuRequest::MediaFlag >("QWebEngineContextMenuRequest::MediaFlag");
    qRegisterMetaType< ::QWebEngineContextMenuRequest::EditFlag >("QWebEngineContextMenuRequest::EditFlag");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QWebEngineContextMenuRequest::staticMetaObject, sizeof(QWebEngineContextMenuRequestWrapper));

    return pyType;
}
