// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebengineloadinginfo_wrapper.h"

// Argument includes
#include <QMultiMap>
#include <QString>
#include <QtWebEngineCore/qwebengineloadinginfo.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineLoadingInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineLoadingInfo >()))
        return -1;

    ::QWebEngineLoadingInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QWebEngineLoadingInfo", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebEngineLoadingInfo::QWebEngineLoadingInfo(QWebEngineLoadingInfo)
    if (numArgs == 1
        && (pyArgs[0] != Py_None && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), (pyArgs[0]))))) {
        overloadId = 0; // QWebEngineLoadingInfo(QWebEngineLoadingInfo)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QWebEngineLoadingInfo *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QWebEngineLoadingInfo(QWebEngineLoadingInfo)
            cptr = new ::QWebEngineLoadingInfo(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEngineLoadingInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_errorCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.errorCode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // errorCode()const
            int cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->errorCode();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_errorDomain(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.errorDomain";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // errorDomain()const
            QWebEngineLoadingInfo::ErrorDomain cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->errorDomain();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_ErrorDomain_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.errorString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // errorString()const
            QString cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->errorString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_isErrorPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.isErrorPage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isErrorPage()const
            bool cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->isErrorPage();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_responseHeaders(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.responseHeaders";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // responseHeaders()const
            QMultiMap<QByteArray,QByteArray> cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->responseHeaders();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWebEngineCoreTypeConverters[SBK_QtWebEngineCore_QMultiMap_QByteArray_QByteArray_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_status(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.status";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // status()const
            QWebEngineLoadingInfo::LoadStatus cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->status();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_LoadStatus_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.url";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // url()const
            QUrl cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->url();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEngineLoadingInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineLoadingInfo_PropertyStrings[] = {
    "errorCode:",
    "errorDomain:",
    "errorString:",
    "isErrorPage:",
    "responseHeaders:",
    "status:",
    "url:",
    nullptr // Sentinel
};

static const char *Sbk_QWebEngineLoadingInfo_EnumFlagInfo[] = {
    "ErrorDomain:Enum",
    "LoadStatus:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineLoadingInfo_methods[] = {
    {"errorCode", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_errorCode), METH_NOARGS, nullptr},
    {"errorDomain", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_errorDomain), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_errorString), METH_NOARGS, nullptr},
    {"isErrorPage", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_isErrorPage), METH_NOARGS, nullptr},
    {"responseHeaders", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_responseHeaders), METH_NOARGS, nullptr},
    {"status", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_status), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_url), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QWebEngineLoadingInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineLoadingInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineLoadingInfo_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineLoadingInfo_TypeF(void)
{
    return _Sbk_QWebEngineLoadingInfo_Type;
}

static PyType_Slot Sbk_QWebEngineLoadingInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineLoadingInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineLoadingInfo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineLoadingInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineLoadingInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineLoadingInfo_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineLoadingInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineLoadingInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QWebEngineLoadingInfo_LoadStatus_PythonToCpp_QWebEngineLoadingInfo_LoadStatus(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineLoadingInfo::LoadStatus>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineLoadingInfo::LoadStatus *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEngineLoadingInfo_LoadStatus_PythonToCpp_QWebEngineLoadingInfo_LoadStatus_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_LoadStatus_IDX])))
        return QWebEngineLoadingInfo_LoadStatus_PythonToCpp_QWebEngineLoadingInfo_LoadStatus;
    return {};
}
static PyObject *QWebEngineLoadingInfo_LoadStatus_CppToPython_QWebEngineLoadingInfo_LoadStatus(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEngineLoadingInfo::LoadStatus *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_LoadStatus_IDX]), castCppIn);

}

static void QWebEngineLoadingInfo_ErrorDomain_PythonToCpp_QWebEngineLoadingInfo_ErrorDomain(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineLoadingInfo::ErrorDomain>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineLoadingInfo::ErrorDomain *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEngineLoadingInfo_ErrorDomain_PythonToCpp_QWebEngineLoadingInfo_ErrorDomain_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_ErrorDomain_IDX])))
        return QWebEngineLoadingInfo_ErrorDomain_PythonToCpp_QWebEngineLoadingInfo_ErrorDomain;
    return {};
}
static PyObject *QWebEngineLoadingInfo_ErrorDomain_CppToPython_QWebEngineLoadingInfo_ErrorDomain(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEngineLoadingInfo::ErrorDomain *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_ErrorDomain_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineLoadingInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineLoadingInfo_TypeF()))
        return QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineLoadingInfo_PTR_CppToPython_QWebEngineLoadingInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QWebEngineLoadingInfo *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QWebEngineLoadingInfo_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QWebEngineLoadingInfo_COPY_CppToPython_QWebEngineLoadingInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QWebEngineLoadingInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QWebEngineLoadingInfo_TypeF(), new ::QWebEngineLoadingInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QWebEngineLoadingInfo *>(cppOut) = *reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineLoadingInfo_TypeF()))
        return QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QWebEngineLoadingInfo_SignatureStrings[] = {
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo(self,other:PySide6.QtWebEngineCore.QWebEngineLoadingInfo)",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.errorCode(self)->int",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.errorDomain(self)->PySide6.QtWebEngineCore.QWebEngineLoadingInfo.ErrorDomain",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.errorString(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.isErrorPage(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.responseHeaders(self)->QMultiMap[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.status(self)->PySide6.QtWebEngineCore.QWebEngineLoadingInfo.LoadStatus",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.url(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QWebEngineLoadingInfo(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineLoadingInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEngineLoadingInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineLoadingInfo",
        "QWebEngineLoadingInfo",
        &Sbk_QWebEngineLoadingInfo_spec,
        &Shiboken::callCppDestructor< ::QWebEngineLoadingInfo >,
        Sbk_QWebEngineLoadingInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QWebEngineLoadingInfo_TypeF(); // references _Sbk_QWebEngineLoadingInfo_Type
    InitSignatureStrings(pyType, QWebEngineLoadingInfo_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineLoadingInfo_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_PTR,
        is_QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_PTR_Convertible,
        QWebEngineLoadingInfo_PTR_CppToPython_QWebEngineLoadingInfo,
        QWebEngineLoadingInfo_COPY_CppToPython_QWebEngineLoadingInfo);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineLoadingInfo");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineLoadingInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineLoadingInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineLoadingInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_COPY,
        is_QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWebEngineLoadingInfo_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'LoadStatus'.
    const char *LoadStatus_Initializer[] = {
        "LoadStartedStatus",
        "LoadStoppedStatus",
        "LoadSucceededStatus",
        "LoadFailedStatus",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t LoadStatus_InitializerValues[] = {
        uint8_t(QWebEngineLoadingInfo::LoadStatus::LoadStartedStatus),   //  0x00  0
        uint8_t(QWebEngineLoadingInfo::LoadStatus::LoadStoppedStatus),   //  0x01  1
        uint8_t(QWebEngineLoadingInfo::LoadStatus::LoadSucceededStatus), //  0x02  2
        uint8_t(QWebEngineLoadingInfo::LoadStatus::LoadFailedStatus)     //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineLoadingInfo_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineLoadingInfo.LoadStatus",
        LoadStatus_Initializer, LoadStatus_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_LoadStatus_IDX].type = EType;
    // Register converter for enum 'QWebEngineLoadingInfo::LoadStatus'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineLoadingInfo_LoadStatus_CppToPython_QWebEngineLoadingInfo_LoadStatus);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEngineLoadingInfo_LoadStatus_PythonToCpp_QWebEngineLoadingInfo_LoadStatus,
            is_QWebEngineLoadingInfo_LoadStatus_PythonToCpp_QWebEngineLoadingInfo_LoadStatus_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineLoadingInfo::LoadStatus");
        Shiboken::Conversions::registerConverterName(converter, "LoadStatus");
    }
    // End of 'LoadStatus' enum.

    // Initialization of enum 'ErrorDomain'.
    const char *ErrorDomain_Initializer[] = {
        "NoErrorDomain",
        "InternalErrorDomain",
        "ConnectionErrorDomain",
        "CertificateErrorDomain",
        "HttpErrorDomain",
        "FtpErrorDomain",
        "DnsErrorDomain",
        "HttpStatusCodeDomain",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ErrorDomain_InitializerValues[] = {
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::NoErrorDomain),          //  0x00  0
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::InternalErrorDomain),    //  0x01  1
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::ConnectionErrorDomain),  //  0x02  2
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::CertificateErrorDomain), //  0x03  3
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::HttpErrorDomain),        //  0x04  4
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::FtpErrorDomain),         //  0x05  5
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::DnsErrorDomain),         //  0x06  6
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::HttpStatusCodeDomain)    //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineLoadingInfo_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineLoadingInfo.ErrorDomain",
        ErrorDomain_Initializer, ErrorDomain_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_ErrorDomain_IDX].type = EType;
    // Register converter for enum 'QWebEngineLoadingInfo::ErrorDomain'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineLoadingInfo_ErrorDomain_CppToPython_QWebEngineLoadingInfo_ErrorDomain);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEngineLoadingInfo_ErrorDomain_PythonToCpp_QWebEngineLoadingInfo_ErrorDomain,
            is_QWebEngineLoadingInfo_ErrorDomain_PythonToCpp_QWebEngineLoadingInfo_ErrorDomain_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineLoadingInfo::ErrorDomain");
        Shiboken::Conversions::registerConverterName(converter, "ErrorDomain");
    }
    // End of 'ErrorDomain' enum.

    qRegisterMetaType< ::QWebEngineLoadingInfo::LoadStatus >("QWebEngineLoadingInfo::LoadStatus");
    qRegisterMetaType< ::QWebEngineLoadingInfo::ErrorDomain >("QWebEngineLoadingInfo::ErrorDomain");

    return pyType;
}
