// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebsockets_python.h"

// main header
#include "qwebsocketcorsauthenticator_wrapper.h"

// Argument includes
#include <QString>
#include <QtWebSockets/qwebsocketcorsauthenticator.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebSocketCorsAuthenticator_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebSocketCorsAuthenticator >()))
        return -1;

    ::QWebSocketCorsAuthenticator *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebSockets.QWebSocketCorsAuthenticator.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QWebSocketCorsAuthenticator", 1, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(QString)
    // 1: QWebSocketCorsAuthenticator::QWebSocketCorsAuthenticator(QWebSocketCorsAuthenticator)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketCorsAuthenticator_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QWebSocketCorsAuthenticator(QWebSocketCorsAuthenticator)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // QWebSocketCorsAuthenticator(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QWebSocketCorsAuthenticator(const QString & origin)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QWebSocketCorsAuthenticator(QString)
                cptr = new ::QWebSocketCorsAuthenticator(cppArg0);
            }
            break;
        }
        case 1: // QWebSocketCorsAuthenticator(const QWebSocketCorsAuthenticator & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWebSocketCorsAuthenticator *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QWebSocketCorsAuthenticator(QWebSocketCorsAuthenticator)
                cptr = new ::QWebSocketCorsAuthenticator(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebSocketCorsAuthenticator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWebSocketCorsAuthenticatorFunc_allowed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketCorsAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketCorsAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebSockets.QWebSocketCorsAuthenticator.allowed";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // allowed()const
            bool cppResult = const_cast<const ::QWebSocketCorsAuthenticator *>(cppSelf)->allowed();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketCorsAuthenticatorFunc_origin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketCorsAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketCorsAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebSockets.QWebSocketCorsAuthenticator.origin";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // origin()const
            QString cppResult = const_cast<const ::QWebSocketCorsAuthenticator *>(cppSelf)->origin();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebSocketCorsAuthenticatorFunc_setAllowed(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketCorsAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketCorsAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebSockets.QWebSocketCorsAuthenticator.setAllowed";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocketCorsAuthenticator::setAllowed(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAllowed(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAllowed(bool)
            cppSelf->setAllowed(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebSocketCorsAuthenticatorFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebSocketCorsAuthenticator *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketCorsAuthenticator_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebSockets.QWebSocketCorsAuthenticator.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebSocketCorsAuthenticator::swap(QWebSocketCorsAuthenticator&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketCorsAuthenticator_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QWebSocketCorsAuthenticator&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebSocketCorsAuthenticator *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QWebSocketCorsAuthenticator&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QWebSocketCorsAuthenticator_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebSocketCorsAuthenticator_methods[] = {
    {"allowed", reinterpret_cast<PyCFunction>(Sbk_QWebSocketCorsAuthenticatorFunc_allowed), METH_NOARGS, nullptr},
    {"origin", reinterpret_cast<PyCFunction>(Sbk_QWebSocketCorsAuthenticatorFunc_origin), METH_NOARGS, nullptr},
    {"setAllowed", reinterpret_cast<PyCFunction>(Sbk_QWebSocketCorsAuthenticatorFunc_setAllowed), METH_O, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QWebSocketCorsAuthenticatorFunc_swap), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QWebSocketCorsAuthenticator_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebSocketCorsAuthenticator_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebSocketCorsAuthenticator_Type = nullptr;
static PyTypeObject *Sbk_QWebSocketCorsAuthenticator_TypeF(void)
{
    return _Sbk_QWebSocketCorsAuthenticator_Type;
}

static PyType_Slot Sbk_QWebSocketCorsAuthenticator_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebSocketCorsAuthenticator_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebSocketCorsAuthenticator_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebSocketCorsAuthenticator_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebSocketCorsAuthenticator_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebSocketCorsAuthenticator_spec = {
    "2:PySide6.QtWebSockets.QWebSocketCorsAuthenticator",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebSocketCorsAuthenticator_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebSocketCorsAuthenticator_PythonToCpp_QWebSocketCorsAuthenticator_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebSocketCorsAuthenticator_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebSocketCorsAuthenticator_PythonToCpp_QWebSocketCorsAuthenticator_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebSocketCorsAuthenticator_TypeF()))
        return QWebSocketCorsAuthenticator_PythonToCpp_QWebSocketCorsAuthenticator_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebSocketCorsAuthenticator_PTR_CppToPython_QWebSocketCorsAuthenticator(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QWebSocketCorsAuthenticator *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QWebSocketCorsAuthenticator_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QWebSocketCorsAuthenticator_SignatureStrings[] = {
    "1:PySide6.QtWebSockets.QWebSocketCorsAuthenticator(self,origin:QString)",
    "0:PySide6.QtWebSockets.QWebSocketCorsAuthenticator(self,other:PySide6.QtWebSockets.QWebSocketCorsAuthenticator)",
    "PySide6.QtWebSockets.QWebSocketCorsAuthenticator.allowed(self)->bool",
    "PySide6.QtWebSockets.QWebSocketCorsAuthenticator.origin(self)->QString",
    "PySide6.QtWebSockets.QWebSocketCorsAuthenticator.setAllowed(self,allowed:bool)",
    "PySide6.QtWebSockets.QWebSocketCorsAuthenticator.swap(self,other:PySide6.QtWebSockets.QWebSocketCorsAuthenticator)",
    nullptr}; // Sentinel

PyTypeObject *init_QWebSocketCorsAuthenticator(PyObject *module)
{
    if (SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketCorsAuthenticator_IDX].type != nullptr)
        return SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketCorsAuthenticator_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebSocketCorsAuthenticator_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebSocketCorsAuthenticator_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebSocketCorsAuthenticator",
        "QWebSocketCorsAuthenticator*",
        &Sbk_QWebSocketCorsAuthenticator_spec,
        &Shiboken::callCppDestructor< ::QWebSocketCorsAuthenticator >,
        Sbk_QWebSocketCorsAuthenticator_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWebSocketCorsAuthenticator_TypeF(); // references _Sbk_QWebSocketCorsAuthenticator_Type
    InitSignatureStrings(pyType, QWebSocketCorsAuthenticator_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebSocketCorsAuthenticator_PropertyStrings);
    SbkPySide6_QtWebSocketsTypeStructs[SBK_QWebSocketCorsAuthenticator_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebSocketCorsAuthenticator_PythonToCpp_QWebSocketCorsAuthenticator_PTR,
        is_QWebSocketCorsAuthenticator_PythonToCpp_QWebSocketCorsAuthenticator_PTR_Convertible,
        QWebSocketCorsAuthenticator_PTR_CppToPython_QWebSocketCorsAuthenticator);

    Shiboken::Conversions::registerConverterName(converter, "QWebSocketCorsAuthenticator");
    Shiboken::Conversions::registerConverterName(converter, "QWebSocketCorsAuthenticator*");
    Shiboken::Conversions::registerConverterName(converter, "QWebSocketCorsAuthenticator&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebSocketCorsAuthenticator).name());

    qRegisterMetaType< ::QWebSocketCorsAuthenticator *>();

    return pyType;
}
