// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qitemeditorcreatorbase_wrapper.h"

// Argument includes
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QItemEditorCreatorBaseWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QItemEditorCreatorBaseWrapper::QItemEditorCreatorBaseWrapper() : QItemEditorCreatorBase()
{
    resetPyMethodCache();
    // ... middle
}

::QWidget * QItemEditorCreatorBaseWrapper::createWidget(::QWidget * parent) const
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QItemEditorCreatorBase.createWidget");
        return nullptr;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createWidget";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QItemEditorCreatorBase.createWidget");
        return nullptr;
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), parent)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), parent)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QItemEditorCreatorBase", funcName, Shiboken::SbkType< QWidget >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QWidget *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QByteArray QItemEditorCreatorBaseWrapper::valuePropertyName() const
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QItemEditorCreatorBase.valuePropertyName");
        return {};
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "valuePropertyName";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QItemEditorCreatorBase.valuePropertyName");
        return {};
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QItemEditorCreatorBase", funcName, Shiboken::SbkType< QByteArray >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QByteArray cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QItemEditorCreatorBaseWrapper::~QItemEditorCreatorBaseWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QItemEditorCreatorBase_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QItemEditorCreatorBase_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QItemEditorCreatorBase");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QItemEditorCreatorBase >()))
        return -1;

    QItemEditorCreatorBaseWrapper *cptr{};
    static const char fullName[] = "PySide6.QtWidgets.QItemEditorCreatorBase.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QItemEditorCreatorBase()
            cptr = new QItemEditorCreatorBaseWrapper();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QItemEditorCreatorBase >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QItemEditorCreatorBaseFunc_createWidget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemEditorCreatorBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QItemEditorCreatorBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QItemEditorCreatorBase.createWidget";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QItemEditorCreatorBase::createWidget(QWidget*)const->QWidget*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArg)))) {
        overloadId = 0; // createWidget(QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createWidget(QWidget*)const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QItemEditorCreatorBase.createWidget");
                return {};
            }
            QWidget * cppResult = const_cast<const ::QItemEditorCreatorBase *>(cppSelf)->createWidget(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QItemEditorCreatorBaseFunc_valuePropertyName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QItemEditorCreatorBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QItemEditorCreatorBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWidgets.QItemEditorCreatorBase.valuePropertyName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // valuePropertyName()const
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QItemEditorCreatorBase.valuePropertyName");
                return {};
            }
            QByteArray cppResult = const_cast<const ::QItemEditorCreatorBase *>(cppSelf)->valuePropertyName();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QItemEditorCreatorBase_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QItemEditorCreatorBase_methods[] = {
    {"createWidget", reinterpret_cast<PyCFunction>(Sbk_QItemEditorCreatorBaseFunc_createWidget), METH_O, nullptr},
    {"valuePropertyName", reinterpret_cast<PyCFunction>(Sbk_QItemEditorCreatorBaseFunc_valuePropertyName), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QItemEditorCreatorBase_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QItemEditorCreatorBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QItemEditorCreatorBase_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QItemEditorCreatorBaseWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QItemEditorCreatorBase_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QItemEditorCreatorBase_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QItemEditorCreatorBase_Type = nullptr;
static PyTypeObject *Sbk_QItemEditorCreatorBase_TypeF(void)
{
    return _Sbk_QItemEditorCreatorBase_Type;
}

static PyType_Slot Sbk_QItemEditorCreatorBase_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QItemEditorCreatorBase_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QItemEditorCreatorBase_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QItemEditorCreatorBase_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QItemEditorCreatorBase_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QItemEditorCreatorBase_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QItemEditorCreatorBase_spec = {
    "2:PySide6.QtWidgets.QItemEditorCreatorBase",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QItemEditorCreatorBase_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QItemEditorCreatorBase_PythonToCpp_QItemEditorCreatorBase_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QItemEditorCreatorBase_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QItemEditorCreatorBase_PythonToCpp_QItemEditorCreatorBase_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QItemEditorCreatorBase_TypeF()))
        return QItemEditorCreatorBase_PythonToCpp_QItemEditorCreatorBase_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QItemEditorCreatorBase_PTR_CppToPython_QItemEditorCreatorBase(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QItemEditorCreatorBase *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QItemEditorCreatorBase_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QItemEditorCreatorBase_SignatureStrings[] = {
    "PySide6.QtWidgets.QItemEditorCreatorBase(self)",
    "PySide6.QtWidgets.QItemEditorCreatorBase.createWidget(self,parent:PySide6.QtWidgets.QWidget)->PySide6.QtWidgets.QWidget",
    "PySide6.QtWidgets.QItemEditorCreatorBase.valuePropertyName(self)->PySide6.QtCore.QByteArray",
    nullptr}; // Sentinel

PyTypeObject *init_QItemEditorCreatorBase(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QItemEditorCreatorBase_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QItemEditorCreatorBase_IDX].type;

    Shiboken::AutoDecRef Sbk_QItemEditorCreatorBase_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QItemEditorCreatorBase_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QItemEditorCreatorBase",
        "QItemEditorCreatorBase*",
        &Sbk_QItemEditorCreatorBase_spec,
        &Shiboken::callCppDestructor< QItemEditorCreatorBase >,
        Sbk_QItemEditorCreatorBase_Type_bases.object(),
        0);
    auto *pyType = Sbk_QItemEditorCreatorBase_TypeF(); // references _Sbk_QItemEditorCreatorBase_Type
    InitSignatureStrings(pyType, QItemEditorCreatorBase_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QItemEditorCreatorBase_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QItemEditorCreatorBase_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QItemEditorCreatorBase_PythonToCpp_QItemEditorCreatorBase_PTR,
        is_QItemEditorCreatorBase_PythonToCpp_QItemEditorCreatorBase_PTR_Convertible,
        QItemEditorCreatorBase_PTR_CppToPython_QItemEditorCreatorBase);

    Shiboken::Conversions::registerConverterName(converter, "QItemEditorCreatorBase");
    Shiboken::Conversions::registerConverterName(converter, "QItemEditorCreatorBase*");
    Shiboken::Conversions::registerConverterName(converter, "QItemEditorCreatorBase&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QItemEditorCreatorBase).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QItemEditorCreatorBaseWrapper).name());

    qRegisterMetaType< ::QItemEditorCreatorBase *>();

    return pyType;
}
