// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qstyleoptioncombobox_wrapper.h"

// Argument includes
#include <QtWidgets/qstyleoption.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionComboBox_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QStyleOptionComboBox >()))
        return -1;

    ::QStyleOptionComboBox *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QStyleOptionComboBox.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QStyleOptionComboBox", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QStyleOptionComboBox::QStyleOptionComboBox()
    // 1: QStyleOptionComboBox::QStyleOptionComboBox(QStyleOptionComboBox)
    // 2: QStyleOptionComboBox::QStyleOptionComboBox(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionComboBox()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 2; // QStyleOptionComboBox(int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QStyleOptionComboBox(QStyleOptionComboBox)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QStyleOptionComboBox()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionComboBox()
                cptr = new ::QStyleOptionComboBox();
            }
            break;
        }
        case 1: // QStyleOptionComboBox(const QStyleOptionComboBox & other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QStyleOptionComboBox *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionComboBox(QStyleOptionComboBox)
                cptr = new ::QStyleOptionComboBox(*cppArg0);
            }
            break;
        }
        case 2: // QStyleOptionComboBox(int version)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QStyleOptionComboBox(int)
                cptr = new ::QStyleOptionComboBox(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QStyleOptionComboBox >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}


static const char *Sbk_QStyleOptionComboBox_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QStyleOptionComboBox_EnumFlagInfo[] = {
    "StyleOptionType:Enum",
    "StyleOptionVersion:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QStyleOptionComboBox_methods[] = {
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QStyleOptionComboBox_get_editable(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->editable;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionComboBox_set_editable(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("editable");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("editable", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->editable;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->editable = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionComboBox_get_popupRect(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->popupRect)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->popupRect))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->popupRect)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &(cppSelf->popupRect), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOptionComboBox_set_popupRect(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("popupRect");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("popupRect", "QRect");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->popupRect;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionComboBox_get_frame(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->frame;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QStyleOptionComboBox_set_frame(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("frame");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("frame", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->frame;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->frame = cppOut_local;

    return 0;
}

static PyObject *Sbk_QStyleOptionComboBox_get_currentText(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppSelf->currentText);
    return pyOut;
}
static int Sbk_QStyleOptionComboBox_set_currentText(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("currentText");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("currentText", "QString");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->currentText;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionComboBox_get_currentIcon(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->currentIcon)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->currentIcon))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->currentIcon)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), &(cppSelf->currentIcon), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOptionComboBox_set_currentIcon(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("currentIcon");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("currentIcon", "QIcon");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->currentIcon;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionComboBox_get_iconSize(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->iconSize)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->iconSize))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->iconSize)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), &(cppSelf->iconSize), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QStyleOptionComboBox_set_iconSize(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("iconSize");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("iconSize", "QSize");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->iconSize;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QStyleOptionComboBox_get_textAlignment(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->converter, &cppSelf->textAlignment);
    return pyOut;
}
static int Sbk_QStyleOptionComboBox_set_textAlignment(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QStyleOptionComboBox *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("textAlignment");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_AlignmentFlag_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("textAlignment", "Alignment");
        return -1;
    }

    auto cppOut_local = cppSelf->textAlignment;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->textAlignment = cppOut_local;

    return 0;
}

// Getters and Setters for QStyleOptionComboBox
static PyGetSetDef Sbk_QStyleOptionComboBox_getsetlist[] = {
    {const_cast<char *>("editable"), Sbk_QStyleOptionComboBox_get_editable, Sbk_QStyleOptionComboBox_set_editable, nullptr, nullptr},
    {const_cast<char *>("popupRect"), Sbk_QStyleOptionComboBox_get_popupRect, Sbk_QStyleOptionComboBox_set_popupRect, nullptr, nullptr},
    {const_cast<char *>("frame"), Sbk_QStyleOptionComboBox_get_frame, Sbk_QStyleOptionComboBox_set_frame, nullptr, nullptr},
    {const_cast<char *>("currentText"), Sbk_QStyleOptionComboBox_get_currentText, Sbk_QStyleOptionComboBox_set_currentText, nullptr, nullptr},
    {const_cast<char *>("currentIcon"), Sbk_QStyleOptionComboBox_get_currentIcon, Sbk_QStyleOptionComboBox_set_currentIcon, nullptr, nullptr},
    {const_cast<char *>("iconSize"), Sbk_QStyleOptionComboBox_get_iconSize, Sbk_QStyleOptionComboBox_set_iconSize, nullptr, nullptr},
    {const_cast<char *>("textAlignment"), Sbk_QStyleOptionComboBox_get_textAlignment, Sbk_QStyleOptionComboBox_set_textAlignment, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QStyleOptionComboBox_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QStyleOptionComboBox_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QStyleOptionComboBox_Type = nullptr;
static PyTypeObject *Sbk_QStyleOptionComboBox_TypeF(void)
{
    return _Sbk_QStyleOptionComboBox_Type;
}

static PyType_Slot Sbk_QStyleOptionComboBox_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QStyleOptionComboBox_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QStyleOptionComboBox_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QStyleOptionComboBox_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QStyleOptionComboBox_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QStyleOptionComboBox_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QStyleOptionComboBox_spec = {
    "2:PySide6.QtWidgets.QStyleOptionComboBox",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QStyleOptionComboBox_slots
};

} //extern "C"

static void *Sbk_QStyleOptionComboBox_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (qstyleoption_cast<const QStyleOptionComboBox *>( reinterpret_cast< ::QStyleOption *>(cptr)) != nullptr)
        return cptr;
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QStyleOptionComboBox_StyleOptionType_PythonToCpp_QStyleOptionComboBox_StyleOptionType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionComboBox::StyleOptionType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionComboBox::StyleOptionType *>(cppOut) = value;

}
static PythonToCppFunc is_QStyleOptionComboBox_StyleOptionType_PythonToCpp_QStyleOptionComboBox_StyleOptionType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_StyleOptionType_IDX])))
        return QStyleOptionComboBox_StyleOptionType_PythonToCpp_QStyleOptionComboBox_StyleOptionType;
    return {};
}
static PyObject *QStyleOptionComboBox_StyleOptionType_CppToPython_QStyleOptionComboBox_StyleOptionType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyleOptionComboBox::StyleOptionType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_StyleOptionType_IDX]), castCppIn);

}

static void QStyleOptionComboBox_StyleOptionVersion_PythonToCpp_QStyleOptionComboBox_StyleOptionVersion(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QStyleOptionComboBox::StyleOptionVersion>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QStyleOptionComboBox::StyleOptionVersion *>(cppOut) = value;

}
static PythonToCppFunc is_QStyleOptionComboBox_StyleOptionVersion_PythonToCpp_QStyleOptionComboBox_StyleOptionVersion_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_StyleOptionVersion_IDX])))
        return QStyleOptionComboBox_StyleOptionVersion_PythonToCpp_QStyleOptionComboBox_StyleOptionVersion;
    return {};
}
static PyObject *QStyleOptionComboBox_StyleOptionVersion_CppToPython_QStyleOptionComboBox_StyleOptionVersion(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QStyleOptionComboBox::StyleOptionVersion *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_StyleOptionVersion_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QStyleOptionComboBox_PythonToCpp_QStyleOptionComboBox_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QStyleOptionComboBox_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QStyleOptionComboBox_PythonToCpp_QStyleOptionComboBox_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QStyleOptionComboBox_TypeF()))
        return QStyleOptionComboBox_PythonToCpp_QStyleOptionComboBox_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QStyleOptionComboBox_PTR_CppToPython_QStyleOptionComboBox(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QStyleOptionComboBox *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QStyleOptionComboBox_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QStyleOptionComboBox_SignatureStrings[] = {
    "2:PySide6.QtWidgets.QStyleOptionComboBox(self)",
    "1:PySide6.QtWidgets.QStyleOptionComboBox(self,other:PySide6.QtWidgets.QStyleOptionComboBox)",
    "0:PySide6.QtWidgets.QStyleOptionComboBox(self,version:int)",
    nullptr}; // Sentinel

PyTypeObject *init_QStyleOptionComboBox(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX].type;

    Shiboken::AutoDecRef Sbk_QStyleOptionComboBox_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]))));

    _Sbk_QStyleOptionComboBox_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QStyleOptionComboBox",
        "QStyleOptionComboBox*",
        &Sbk_QStyleOptionComboBox_spec,
        &Shiboken::callCppDestructor< ::QStyleOptionComboBox >,
        Sbk_QStyleOptionComboBox_Type_bases.object(),
        0);
    auto *pyType = Sbk_QStyleOptionComboBox_TypeF(); // references _Sbk_QStyleOptionComboBox_Type
    InitSignatureStrings(pyType, QStyleOptionComboBox_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QStyleOptionComboBox_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QStyleOptionComboBox_PythonToCpp_QStyleOptionComboBox_PTR,
        is_QStyleOptionComboBox_PythonToCpp_QStyleOptionComboBox_PTR_Convertible,
        QStyleOptionComboBox_PTR_CppToPython_QStyleOptionComboBox);

    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionComboBox");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionComboBox*");
    Shiboken::Conversions::registerConverterName(converter, "QStyleOptionComboBox&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QStyleOptionComboBox).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QStyleOptionComboBox_TypeF(), &Sbk_QStyleOptionComboBox_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QStyleOptionComboBox_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StyleOptionType'.
    const char *StyleOptionType_Initializer[] = {
        "Type",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t StyleOptionType_InitializerValues[] = {
        uint32_t(QStyleOptionComboBox::StyleOptionType::Type) //  0x000f0004  983044
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionComboBox_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionComboBox.StyleOptionType",
        StyleOptionType_Initializer, StyleOptionType_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_StyleOptionType_IDX].type = EType;
    // Register converter for enum 'QStyleOptionComboBox::StyleOptionType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionComboBox_StyleOptionType_CppToPython_QStyleOptionComboBox_StyleOptionType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyleOptionComboBox_StyleOptionType_PythonToCpp_QStyleOptionComboBox_StyleOptionType,
            is_QStyleOptionComboBox_StyleOptionType_PythonToCpp_QStyleOptionComboBox_StyleOptionType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionComboBox::StyleOptionType");
        Shiboken::Conversions::registerConverterName(converter, "StyleOptionType");
    }
    // End of 'StyleOptionType' enum.

    // Initialization of enum 'StyleOptionVersion'.
    const char *StyleOptionVersion_Initializer[] = {
        "Version",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleOptionVersion_InitializerValues[] = {
        uint8_t(QStyleOptionComboBox::StyleOptionVersion::Version) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QStyleOptionComboBox_TypeF(),
        "2:PySide6.QtWidgets.QStyleOptionComboBox.StyleOptionVersion",
        StyleOptionVersion_Initializer, StyleOptionVersion_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_StyleOptionVersion_IDX].type = EType;
    // Register converter for enum 'QStyleOptionComboBox::StyleOptionVersion'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QStyleOptionComboBox_StyleOptionVersion_CppToPython_QStyleOptionComboBox_StyleOptionVersion);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QStyleOptionComboBox_StyleOptionVersion_PythonToCpp_QStyleOptionComboBox_StyleOptionVersion,
            is_QStyleOptionComboBox_StyleOptionVersion_PythonToCpp_QStyleOptionComboBox_StyleOptionVersion_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QStyleOptionComboBox::StyleOptionVersion");
        Shiboken::Conversions::registerConverterName(converter, "StyleOptionVersion");
    }
    // End of 'StyleOptionVersion' enum.

    qRegisterMetaType< ::QStyleOptionComboBox *>();
    qRegisterMetaType< ::QStyleOptionComboBox::StyleOptionType >("QStyleOptionComboBox::StyleOptionType");
    qRegisterMetaType< ::QStyleOptionComboBox::StyleOptionVersion >("QStyleOptionComboBox::StyleOptionVersion");

    return pyType;
}
