// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QTableWidgetWrapper_H
#define SBK_QTableWidgetWrapper_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWidgets/qtablewidget.h>

namespace PySide { class DynamicQMetaObject; }

// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
class QTableWidgetWrapper : public QTableWidget
{
public:
    QTableWidgetWrapper(const QTableWidgetWrapper &) = delete;
    QTableWidgetWrapper& operator=(const QTableWidgetWrapper &) = delete;
    QTableWidgetWrapper(QTableWidgetWrapper &&) = delete;
    QTableWidgetWrapper& operator=(QTableWidgetWrapper &&) = delete;

    QTableWidgetWrapper(::QWidget * parent = nullptr);
    QTableWidgetWrapper(int rows, int columns, ::QWidget * parent = nullptr);
    void actionEvent(::QActionEvent * event) override;
    void changeEvent(::QEvent * arg__1) override;
    void childEvent(::QChildEvent * event) override;
    void closeEditor(::QWidget * editor, ::QAbstractItemDelegate::EndEditHint hint) override;
    void closeEvent(::QCloseEvent * event) override;
    void commitData(::QWidget * editor) override;
    void connectNotify(const ::QMetaMethod & signal) override;
    void contextMenuEvent(::QContextMenuEvent * arg__1) override;
    void currentChanged(const ::QModelIndex & current, const ::QModelIndex & previous) override;
    void customEvent(::QEvent * event) override;
    void dataChanged(const ::QModelIndex & topLeft, const ::QModelIndex & bottomRight, const ::QList<int> & roles = QList<int>()) override;
    int devType() const override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    void doItemsLayout() override;
    void dragEnterEvent(::QDragEnterEvent * event) override;
    void dragLeaveEvent(::QDragLeaveEvent * event) override;
    void dragMoveEvent(::QDragMoveEvent * event) override;
    void dropEvent(::QDropEvent * event) override;
    bool dropMimeData(int row, int column, const ::QMimeData * data, ::Qt::DropAction action) override;
    bool edit(const ::QModelIndex & index, ::QAbstractItemView::EditTrigger trigger, ::QEvent * event) override;
    void editorDestroyed(::QObject * editor) override;
    void enterEvent(::QEnterEvent * event) override;
    bool event(::QEvent * e) override;
    bool eventFilter(::QObject * object, ::QEvent * event) override;
    void focusInEvent(::QFocusEvent * event) override;
    bool focusNextPrevChild(bool next) override;
    void focusOutEvent(::QFocusEvent * event) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(::QHideEvent * event) override;
    int horizontalOffset() const override;
    void horizontalScrollbarAction(int action) override;
    void horizontalScrollbarValueChanged(int value) override;
    ::QModelIndex indexAt(const ::QPoint & p) const override;
    void initPainter(::QPainter * painter) const override;
    void initStyleOption(::QStyleOptionFrame * option) const override;
    void initViewItemOption(::QStyleOptionViewItem * option) const override;
    void inputMethodEvent(::QInputMethodEvent * event) override;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery query) const override;
    bool isIndexHidden(const ::QModelIndex & index) const override;
    ::QAbstractItemDelegate * itemDelegateForIndex(const ::QModelIndex & index) const override;
    void keyPressEvent(::QKeyEvent * event) override;
    void keyReleaseEvent(::QKeyEvent * event) override;
    void keyboardSearch(const ::QString & search) override;
    void leaveEvent(::QEvent * event) override;
    int metric(::QPaintDevice::PaintDeviceMetric arg__1) const override;
    ::QMimeData * mimeData(const ::QList<QTableWidgetItem*> & items) const override;
    ::QStringList mimeTypes() const override;
    ::QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(::QMouseEvent * event) override;
    void mouseMoveEvent(::QMouseEvent * event) override;
    void mousePressEvent(::QMouseEvent * event) override;
    void mouseReleaseEvent(::QMouseEvent * event) override;
    ::QModelIndex moveCursor(::QAbstractItemView::CursorAction cursorAction, ::QFlags<Qt::KeyboardModifier> modifiers) override;
    void moveEvent(::QMoveEvent * event) override;
    bool nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result) override;
    ::QPaintEngine * paintEngine() const override;
    void paintEvent(::QPaintEvent * e) override;
    ::QPaintDevice * redirected(::QPoint * offset) const override;
    void reset() override;
    void resizeEvent(::QResizeEvent * event) override;
    void rowsAboutToBeRemoved(const ::QModelIndex & parent, int start, int end) override;
    void rowsInserted(const ::QModelIndex & parent, int start, int end) override;
    void scrollContentsBy(int dx, int dy) override;
    void scrollTo(const ::QModelIndex & index, ::QAbstractItemView::ScrollHint hint = QAbstractItemView::ScrollHint::EnsureVisible) override;
    void selectAll() override;
    ::QList<QModelIndex> selectedIndexes() const override;
    void selectionChanged(const ::QItemSelection & selected, const ::QItemSelection & deselected) override;
    ::QFlags<QItemSelectionModel::SelectionFlag> selectionCommand(const ::QModelIndex & index, const ::QEvent * event = nullptr) const override;
    void setRootIndex(const ::QModelIndex & index) override;
    void setSelection(const ::QRect & rect, ::QFlags<QItemSelectionModel::SelectionFlag> command) override;
    void setSelectionModel(::QItemSelectionModel * selectionModel) override;
    void setVisible(bool visible) override;
    void setupViewport(::QWidget * viewport) override;
    ::QPainter * sharedPainter() const override;
    void showEvent(::QShowEvent * event) override;
    ::QSize sizeHint() const override;
    int sizeHintForColumn(int column) const override;
    int sizeHintForRow(int row) const override;
    void startDrag(::QFlags<Qt::DropAction> supportedActions) override;
    ::QFlags<Qt::DropAction> supportedDropActions() const override;
    void tabletEvent(::QTabletEvent * event) override;
    void timerEvent(::QTimerEvent * event) override;
    void updateEditorData() override;
    void updateEditorGeometries() override;
    void updateGeometries() override;
    int verticalOffset() const override;
    void verticalScrollbarAction(int action) override;
    void verticalScrollbarValueChanged(int value) override;
    bool viewportEvent(::QEvent * event) override;
    ::QSize viewportSizeHint() const override;
    ::QRect visualRect(const ::QModelIndex & index) const override;
    ::QRegion visualRegionForSelection(const ::QItemSelection & selection) const override;
    void wheelEvent(::QWheelEvent * arg__1) override;
    ~QTableWidgetWrapper() override;

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();
    void resetPyMethodCache();
private:
    mutable bool m_PyMethodCache[94];
};

#endif // SBK_QTableWidgetWrapper_H

