// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qtextedit_extraselection_wrapper.h"

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextEdit_ExtraSelection_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextEdit::ExtraSelection >()))
        return -1;

    ::QTextEdit::ExtraSelection *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.QTextEdit.ExtraSelection.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "ExtraSelection", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: ExtraSelection::ExtraSelection()
    // 1: ExtraSelection::ExtraSelection(QTextEdit::ExtraSelection)
    if (numArgs == 0) {
        overloadId = 0; // ExtraSelection()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_ExtraSelection_IDX]), (pyArgs[0])))) {
        overloadId = 1; // ExtraSelection(QTextEdit::ExtraSelection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // ExtraSelection()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // ExtraSelection()
                cptr = new ::QTextEdit::ExtraSelection();
            }
            break;
        }
        case 1: // ExtraSelection(const QTextEdit::ExtraSelection & ExtraSelection)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QTextEdit::ExtraSelection cppArg0_local;
            ::QTextEdit::ExtraSelection *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // ExtraSelection(QTextEdit::ExtraSelection)
                cptr = new ::QTextEdit::ExtraSelection(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QTextEdit::ExtraSelection >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QTextEdit_ExtraSelection__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QTextEdit::ExtraSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_ExtraSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_ExtraSelection_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextEdit_ExtraSelection_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextEdit_ExtraSelection_methods[] = {
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QTextEdit_ExtraSelection__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QTextEdit_ExtraSelection_get_cursor(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextEdit::ExtraSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_ExtraSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->cursor)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->cursor))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->cursor)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), &(cppSelf->cursor), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QTextEdit_ExtraSelection_set_cursor(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QTextEdit::ExtraSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_ExtraSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("cursor");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("cursor", "QTextCursor");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->cursor;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QTextEdit_ExtraSelection_get_format(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextEdit::ExtraSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_ExtraSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->format)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->format))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->format)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &(cppSelf->format), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QTextEdit_ExtraSelection_set_format(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QTextEdit::ExtraSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_ExtraSelection_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("format");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("format", "QTextCharFormat");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->format;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

// Getters and Setters for ExtraSelection
static PyGetSetDef Sbk_QTextEdit_ExtraSelection_getsetlist[] = {
    {const_cast<char *>("cursor"), Sbk_QTextEdit_ExtraSelection_get_cursor, Sbk_QTextEdit_ExtraSelection_set_cursor, nullptr, nullptr},
    {const_cast<char *>("format"), Sbk_QTextEdit_ExtraSelection_get_format, Sbk_QTextEdit_ExtraSelection_set_format, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTextEdit_ExtraSelection_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextEdit_ExtraSelection_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextEdit_ExtraSelection_Type = nullptr;
static PyTypeObject *Sbk_QTextEdit_ExtraSelection_TypeF(void)
{
    return _Sbk_QTextEdit_ExtraSelection_Type;
}

static PyType_Slot Sbk_QTextEdit_ExtraSelection_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextEdit_ExtraSelection_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextEdit_ExtraSelection_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextEdit_ExtraSelection_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QTextEdit_ExtraSelection_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextEdit_ExtraSelection_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextEdit_ExtraSelection_spec = {
    "2:PySide6.QtWidgets.QTextEdit.ExtraSelection",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextEdit_ExtraSelection_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void ExtraSelection_PythonToCpp_ExtraSelection_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextEdit_ExtraSelection_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_ExtraSelection_PythonToCpp_ExtraSelection_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextEdit_ExtraSelection_TypeF()))
        return ExtraSelection_PythonToCpp_ExtraSelection_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *ExtraSelection_PTR_CppToPython_ExtraSelection(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QTextEdit::ExtraSelection *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QTextEdit_ExtraSelection_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *ExtraSelection_COPY_CppToPython_ExtraSelection(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QTextEdit::ExtraSelection *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QTextEdit_ExtraSelection_TypeF(), new ::QTextEdit::ExtraSelection(*source), true, true);
}

// Python to C++ copy conversion.
static void ExtraSelection_PythonToCpp_ExtraSelection_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QTextEdit::ExtraSelection *>(cppOut) = *reinterpret_cast< ::QTextEdit::ExtraSelection *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_ExtraSelection_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_ExtraSelection_PythonToCpp_ExtraSelection_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QTextEdit_ExtraSelection_TypeF()))
        return ExtraSelection_PythonToCpp_ExtraSelection_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QTextEdit_ExtraSelection_SignatureStrings[] = {
    "1:PySide6.QtWidgets.QTextEdit.ExtraSelection(self)",
    "0:PySide6.QtWidgets.QTextEdit.ExtraSelection(self,ExtraSelection:PySide6.QtWidgets.QTextEdit.ExtraSelection)",
    "PySide6.QtWidgets.QTextEdit.ExtraSelection.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QTextEdit_ExtraSelection(PyObject *enclosingClass)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_ExtraSelection_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_ExtraSelection_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextEdit_ExtraSelection_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTextEdit_ExtraSelection_Type = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "ExtraSelection",
        "QTextEdit::ExtraSelection",
        &Sbk_QTextEdit_ExtraSelection_spec,
        &Shiboken::callCppDestructor< ::QTextEdit::ExtraSelection >,
        Sbk_QTextEdit_ExtraSelection_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass | Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QTextEdit_ExtraSelection_TypeF(); // references _Sbk_QTextEdit_ExtraSelection_Type
    InitSignatureStrings(pyType, QTextEdit_ExtraSelection_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextEdit_ExtraSelection_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_ExtraSelection_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        ExtraSelection_PythonToCpp_ExtraSelection_PTR,
        is_ExtraSelection_PythonToCpp_ExtraSelection_PTR_Convertible,
        ExtraSelection_PTR_CppToPython_ExtraSelection,
        ExtraSelection_COPY_CppToPython_ExtraSelection);

    Shiboken::Conversions::registerConverterName(converter, "QTextEdit::ExtraSelection");
    Shiboken::Conversions::registerConverterName(converter, "QTextEdit::ExtraSelection*");
    Shiboken::Conversions::registerConverterName(converter, "QTextEdit::ExtraSelection&");
    Shiboken::Conversions::registerConverterName(converter, "ExtraSelection");
    Shiboken::Conversions::registerConverterName(converter, "ExtraSelection*");
    Shiboken::Conversions::registerConverterName(converter, "ExtraSelection&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextEdit::ExtraSelection).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        ExtraSelection_PythonToCpp_ExtraSelection_COPY,
        is_ExtraSelection_PythonToCpp_ExtraSelection_COPY_Convertible);

    qRegisterMetaType< ::QTextEdit::ExtraSelection >("ExtraSelection");
    qRegisterMetaType< ::QTextEdit::ExtraSelection >("QTextEdit::ExtraSelection");

    return pyType;
}
