// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qlocale_wrapper.h"

// Extra includes
#include <QDate>

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <qcalendar.h>
#include <qdatetime.h>
#include <qlocale.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLocale_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QLocale >()))
        return -1;

    ::QLocale *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:QLocale", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QLocale::QLocale()
    // 1: QLocale::QLocale(QLocale::Language,QLocale::Country)
    // 2: QLocale::QLocale(QLocale::Language,QLocale::Script=,QLocale::Country=)
    // 3: QLocale::QLocale(QStringView)
    // 4: QLocale::QLocale(QLocale)
    // 5: QLocale::QLocale(QString)
    if (numArgs == 0) {
        overloadId = 0; // QLocale()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 5; // QLocale(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 3; // QLocale(QStringView)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Language_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // QLocale(QLocale::Language,QLocale::Script,QLocale::Country)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Script_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // QLocale(QLocale::Language,QLocale::Script,QLocale::Country)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 2; // QLocale(QLocale::Language,QLocale::Script,QLocale::Country)
            }
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // QLocale(QLocale::Language,QLocale::Country)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArgs[0])))) {
        overloadId = 4; // QLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QLocale()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QLocale()
                cptr = new ::QLocale();
            }
            break;
        }
        case 1: // QLocale(QLocale::Language language, QLocale::Country territory)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QLocale::Language cppArg0{QLocale::AnyLanguage};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QLocale::Country cppArg1{QLocale::AnyCountry};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QLocale(QLocale::Language,QLocale::Country)
                cptr = new ::QLocale(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QLocale(QLocale::Language language, QLocale::Script script, QLocale::Country territory)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_script = Shiboken::String::createStaticString("script");
                if (PyDict_Contains(kwds, key_script) != 0) {
                    value = PyDict_GetItem(kwds, key_script);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_script);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Script_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_script);
                }
                static PyObject *const key_territory = Shiboken::String::createStaticString("territory");
                if (PyDict_Contains(kwds, key_territory) != 0) {
                    value = PyDict_GetItem(kwds, key_territory);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_territory);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_territory);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            ::QLocale::Language cppArg0{QLocale::AnyLanguage};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QLocale::Script cppArg1(QLocale::Script::AnyScript);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QLocale::Country cppArg2(QLocale::Country::AnyTerritory);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QLocale(QLocale::Language,QLocale::Script,QLocale::Country)
                cptr = new ::QLocale(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 3: // QLocale(QStringView name)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QLocale(QStringView)
                cptr = new ::QLocale(QStringView(cppArg0));
            }
            break;
        }
        case 4: // QLocale(const QLocale & other)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QLocale cppArg0_local;
            ::QLocale *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QLocale(QLocale)
                cptr = new ::QLocale(*cppArg0);
            }
            break;
        }
        case 5: // QLocale(const QString & name)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QLocale(QString)
                cptr = new ::QLocale(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QLocale >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QLocaleFunc_amText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.amText";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // amText()const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->amText();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_bcp47Name(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.bcp47Name";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:bcp47Name", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::bcp47Name(QLocale::TagSeparator=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // bcp47Name(QLocale::TagSeparator)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_TagSeparator_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // bcp47Name(QLocale::TagSeparator)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_separator = Shiboken::String::createStaticString("separator");
            if (PyDict_Contains(kwds, key_separator) != 0) {
                value = PyDict_GetItem(kwds, key_separator);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_separator);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_TagSeparator_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_separator);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QLocale::TagSeparator cppArg0(QLocale::TagSeparator::Dash);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // bcp47Name(QLocale::TagSeparator)const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->bcp47Name(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_c(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.c";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // c()
            QLocale cppResult = ::QLocale::c();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_codeToCountry(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.codeToCountry";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLocale::codeToCountry(QStringView)->QLocale::Country
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // codeToCountry(QStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QLocale", "codeToCountry(QStringView countryCode)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // codeToCountry(QStringView)
            QLocale::Country cppResult = ::QLocale::codeToCountry(QStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_codeToLanguage(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.codeToLanguage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:codeToLanguage", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QLocale::codeToLanguage(QStringView,QFlags<QLocale::LanguageCodeType>=)->QLocale::Language
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // codeToLanguage(QStringView,QFlags<QLocale::LanguageCodeType>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QLocale_LanguageCodeType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // codeToLanguage(QStringView,QFlags<QLocale::LanguageCodeType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_codeTypes = Shiboken::String::createStaticString("codeTypes");
            if (PyDict_Contains(kwds, key_codeTypes) != 0) {
                value = PyDict_GetItem(kwds, key_codeTypes);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_codeTypes);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QLocale_LanguageCodeType_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_codeTypes);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QLocale::LanguageCodeType> cppArg1(QLocale::LanguageCodeType::AnyLanguageCode);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // codeToLanguage(QStringView,QFlags<QLocale::LanguageCodeType>)
            QLocale::Language cppResult = ::QLocale::codeToLanguage(QStringView(cppArg0), cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Language_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_codeToScript(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.codeToScript";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLocale::codeToScript(QStringView)->QLocale::Script
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // codeToScript(QStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // codeToScript(QStringView)
            QLocale::Script cppResult = ::QLocale::codeToScript(QStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Script_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_codeToTerritory(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.codeToTerritory";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLocale::codeToTerritory(QStringView)->QLocale::Country
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // codeToTerritory(QStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // codeToTerritory(QStringView)
            QLocale::Country cppResult = ::QLocale::codeToTerritory(QStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_collation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.collation";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // collation()const
            QLocale cppResult = const_cast<const ::QLocale *>(cppSelf)->collation();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_countriesForLanguage(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.countriesForLanguage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLocale::countriesForLanguage(QLocale::Language)->QList< QLocale::Country>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Language_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // countriesForLanguage(QLocale::Language)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QLocale", "countriesForLanguage(QLocale.Language lang)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        ::QLocale::Language cppArg0{QLocale::AnyLanguage};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // countriesForLanguage(QLocale::Language)
            QList<QLocale::Country> cppResult = ::QLocale::countriesForLanguage(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QLocale_Country_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_country(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.country";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QLocale", "country() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        if (Shiboken::Errors::occurred() == nullptr) {
            // country()const
            QLocale::Country cppResult = const_cast<const ::QLocale *>(cppSelf)->country();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_countryToCode(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.countryToCode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLocale::countryToCode(QLocale::Country)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // countryToCode(QLocale::Country)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QLocale", "countryToCode(QLocale.Country country)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        ::QLocale::Country cppArg0{QLocale::AnyCountry};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // countryToCode(QLocale::Country)
            QString cppResult = ::QLocale::countryToCode(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_countryToString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.countryToString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLocale::countryToString(QLocale::Country)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // countryToString(QLocale::Country)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QLocale", "countryToString(QLocale.Country country)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        ::QLocale::Country cppArg0{QLocale::AnyCountry};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // countryToString(QLocale::Country)
            QString cppResult = ::QLocale::countryToString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_createSeparatedList(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.createSeparatedList";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocale::createSeparatedList(QStringList)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // createSeparatedList(QStringList)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createSeparatedList(QStringList)const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->createSeparatedList(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_currencySymbol(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.currencySymbol";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:currencySymbol", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::currencySymbol(QLocale::CurrencySymbolFormat=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // currencySymbol(QLocale::CurrencySymbolFormat)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_CurrencySymbolFormat_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // currencySymbol(QLocale::CurrencySymbolFormat)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_arg__1 = Shiboken::String::createStaticString("arg__1");
            if (PyDict_Contains(kwds, key_arg__1) != 0) {
                value = PyDict_GetItem(kwds, key_arg__1);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_arg__1);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_CurrencySymbolFormat_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_arg__1);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QLocale::CurrencySymbolFormat cppArg0(QLocale::CurrencySymbolFormat::CurrencySymbol);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // currencySymbol(QLocale::CurrencySymbolFormat)const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->currencySymbol(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_dateFormat(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.dateFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:dateFormat", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::dateFormat(QLocale::FormatType=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // dateFormat(QLocale::FormatType)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // dateFormat(QLocale::FormatType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QLocale::FormatType cppArg0(QLocale::FormatType::LongFormat);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dateFormat(QLocale::FormatType)const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->dateFormat(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_dateTimeFormat(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.dateTimeFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:dateTimeFormat", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::dateTimeFormat(QLocale::FormatType=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // dateTimeFormat(QLocale::FormatType)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // dateTimeFormat(QLocale::FormatType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QLocale::FormatType cppArg0(QLocale::FormatType::LongFormat);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dateTimeFormat(QLocale::FormatType)const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->dateTimeFormat(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_dayName(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.dayName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:dayName", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::dayName(int,QLocale::FormatType=)const->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // dayName(int,QLocale::FormatType)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // dayName(int,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QLocale::FormatType cppArg1(QLocale::FormatType::LongFormat);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dayName(int,QLocale::FormatType)const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->dayName(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_decimalPoint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.decimalPoint";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // decimalPoint()const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->decimalPoint();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_exponential(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.exponential";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // exponential()const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->exponential();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_firstDayOfWeek(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.firstDayOfWeek";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // firstDayOfWeek()const
            Qt::DayOfWeek cppResult = const_cast<const ::QLocale *>(cppSelf)->firstDayOfWeek();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_DayOfWeek_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_formattedDataSize(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.formattedDataSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:formattedDataSize", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::formattedDataSize(qint64,int=,QFlags<QLocale::DataSizeFormat>=)const->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // formattedDataSize(qint64,int,QFlags<QLocale::DataSizeFormat>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // formattedDataSize(qint64,int,QFlags<QLocale::DataSizeFormat>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QLocale_DataSizeFormat_IDX])))->converter, (pyArgs[2])))) {
                overloadId = 0; // formattedDataSize(qint64,int,QFlags<QLocale::DataSizeFormat>)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_precision = Shiboken::String::createStaticString("precision");
            if (PyDict_Contains(kwds, key_precision) != 0) {
                value = PyDict_GetItem(kwds, key_precision);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_precision);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_precision);
            }
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QLocale_DataSizeFormat_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        qint64 cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 2;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFlags<QLocale::DataSizeFormat> cppArg2(QLocale::DataSizeFormat::DataSizeIecFormat);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // formattedDataSize(qint64,int,QFlags<QLocale::DataSizeFormat>)const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->formattedDataSize(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_groupSeparator(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.groupSeparator";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // groupSeparator()const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->groupSeparator();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_language(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.language";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // language()const
            QLocale::Language cppResult = const_cast<const ::QLocale *>(cppSelf)->language();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Language_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_languageToCode(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.languageToCode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:languageToCode", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QLocale::languageToCode(QLocale::Language,QFlags<QLocale::LanguageCodeType>=)->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Language_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // languageToCode(QLocale::Language,QFlags<QLocale::LanguageCodeType>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QLocale_LanguageCodeType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // languageToCode(QLocale::Language,QFlags<QLocale::LanguageCodeType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_codeTypes = Shiboken::String::createStaticString("codeTypes");
            if (PyDict_Contains(kwds, key_codeTypes) != 0) {
                value = PyDict_GetItem(kwds, key_codeTypes);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_codeTypes);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QLocale_LanguageCodeType_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_codeTypes);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QLocale::Language cppArg0{QLocale::AnyLanguage};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QLocale::LanguageCodeType> cppArg1(QLocale::LanguageCodeType::AnyLanguageCode);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // languageToCode(QLocale::Language,QFlags<QLocale::LanguageCodeType>)
            QString cppResult = ::QLocale::languageToCode(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_languageToString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.languageToString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLocale::languageToString(QLocale::Language)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Language_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // languageToString(QLocale::Language)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QLocale::Language cppArg0{QLocale::AnyLanguage};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // languageToString(QLocale::Language)
            QString cppResult = ::QLocale::languageToString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_matchingLocales(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.matchingLocales";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "matchingLocales", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QLocale::matchingLocales(QLocale::Language,QLocale::Script,QLocale::Country)->QList< QLocale>
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Language_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Script_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 0; // matchingLocales(QLocale::Language,QLocale::Script,QLocale::Country)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QLocale::Language cppArg0{QLocale::AnyLanguage};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QLocale::Script cppArg1{QLocale::AnyScript};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QLocale::Country cppArg2{QLocale::AnyCountry};
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // matchingLocales(QLocale::Language,QLocale::Script,QLocale::Country)
            QList<QLocale> cppResult = ::QLocale::matchingLocales(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QLocale_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_measurementSystem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.measurementSystem";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // measurementSystem()const
            QLocale::MeasurementSystem cppResult = const_cast<const ::QLocale *>(cppSelf)->measurementSystem();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_MeasurementSystem_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_monthName(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.monthName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:monthName", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::monthName(int,QLocale::FormatType=)const->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // monthName(int,QLocale::FormatType)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // monthName(int,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QLocale::FormatType cppArg1(QLocale::FormatType::LongFormat);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // monthName(int,QLocale::FormatType)const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->monthName(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_name(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.name";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:name", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::name(QLocale::TagSeparator=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // name(QLocale::TagSeparator)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_TagSeparator_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // name(QLocale::TagSeparator)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_separator = Shiboken::String::createStaticString("separator");
            if (PyDict_Contains(kwds, key_separator) != 0) {
                value = PyDict_GetItem(kwds, key_separator);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_separator);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_TagSeparator_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_separator);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QLocale::TagSeparator cppArg0(QLocale::TagSeparator::Underscore);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // name(QLocale::TagSeparator)const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->name(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_nativeCountryName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.nativeCountryName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QLocale", "nativeCountryName() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        if (Shiboken::Errors::occurred() == nullptr) {
            // nativeCountryName()const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->nativeCountryName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_nativeLanguageName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.nativeLanguageName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // nativeLanguageName()const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->nativeLanguageName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_nativeTerritoryName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.nativeTerritoryName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // nativeTerritoryName()const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->nativeTerritoryName();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_negativeSign(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.negativeSign";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // negativeSign()const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->negativeSign();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_numberOptions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.numberOptions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // numberOptions()const
            QFlags<QLocale::NumberOption> cppResult = const_cast<const ::QLocale *>(cppSelf)->numberOptions();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QLocale_NumberOption_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_percent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.percent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // percent()const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->percent();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_pmText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.pmText";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // pmText()const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->pmText();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_positiveSign(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.positiveSign";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // positiveSign()const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->positiveSign();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_quoteString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.quoteString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:quoteString", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::quoteString(QStringView,QLocale::QuotationStyle=)const->QString
    // 1: QLocale::quoteString(QString,QLocale::QuotationStyle=)const->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // quoteString(QString,QLocale::QuotationStyle)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_QuotationStyle_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // quoteString(QString,QLocale::QuotationStyle)const
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // quoteString(QStringView,QLocale::QuotationStyle)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_QuotationStyle_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // quoteString(QStringView,QLocale::QuotationStyle)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // quoteString(QStringView str, QLocale::QuotationStyle style) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_style = Shiboken::String::createStaticString("style");
                if (PyDict_Contains(kwds, key_style) != 0) {
                    value = PyDict_GetItem(kwds, key_style);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_style);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_QuotationStyle_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_style);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QLocale::QuotationStyle cppArg1(QLocale::QuotationStyle::StandardQuotation);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // quoteString(QStringView,QLocale::QuotationStyle)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->quoteString(QStringView(cppArg0), cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // quoteString(const QString & str, QLocale::QuotationStyle style) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_style = Shiboken::String::createStaticString("style");
                if (PyDict_Contains(kwds, key_style) != 0) {
                    value = PyDict_GetItem(kwds, key_style);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_style);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_QuotationStyle_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_style);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QLocale::QuotationStyle cppArg1(QLocale::QuotationStyle::StandardQuotation);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // quoteString(QString,QLocale::QuotationStyle)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->quoteString(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_script(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.script";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // script()const
            QLocale::Script cppResult = const_cast<const ::QLocale *>(cppSelf)->script();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Script_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_scriptToCode(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.scriptToCode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLocale::scriptToCode(QLocale::Script)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Script_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // scriptToCode(QLocale::Script)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QLocale::Script cppArg0{QLocale::AnyScript};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // scriptToCode(QLocale::Script)
            QString cppResult = ::QLocale::scriptToCode(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_scriptToString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.scriptToString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLocale::scriptToString(QLocale::Script)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Script_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // scriptToString(QLocale::Script)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QLocale::Script cppArg0{QLocale::AnyScript};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // scriptToString(QLocale::Script)
            QString cppResult = ::QLocale::scriptToString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_setDefault(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.setDefault";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLocale::setDefault(QLocale)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
        overloadId = 0; // setDefault(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefault(QLocale)
            ::QLocale::setDefault(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLocaleFunc_setNumberOptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.setNumberOptions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocale::setNumberOptions(QFlags<QLocale::NumberOption>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QLocale_NumberOption_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setNumberOptions(QFlags<QLocale::NumberOption>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QFlags<QLocale::NumberOption> cppArg0 = QFlags<QLocale::NumberOption>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNumberOptions(QFlags<QLocale::NumberOption>)
            cppSelf->setNumberOptions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLocaleFunc_standaloneDayName(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.standaloneDayName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:standaloneDayName", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::standaloneDayName(int,QLocale::FormatType=)const->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // standaloneDayName(int,QLocale::FormatType)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // standaloneDayName(int,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QLocale::FormatType cppArg1(QLocale::FormatType::LongFormat);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // standaloneDayName(int,QLocale::FormatType)const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->standaloneDayName(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_standaloneMonthName(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.standaloneMonthName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:standaloneMonthName", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::standaloneMonthName(int,QLocale::FormatType=)const->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // standaloneMonthName(int,QLocale::FormatType)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // standaloneMonthName(int,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QLocale::FormatType cppArg1(QLocale::FormatType::LongFormat);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // standaloneMonthName(int,QLocale::FormatType)const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->standaloneMonthName(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.swap";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocale::swap(QLocale&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QLocale&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QLocale&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QLocaleFunc_system(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.system";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // system()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qlocale_system)]
            // For darwin systems, QLocale::system() involves looking at the Info.plist of the application
            // bundle to detect the system localization. In the case of Qt for Python, the application bundle
            // is the used Python framework. To enable retreival of localized string, the property list key
            // CFBunldeAllowMixedLocalizations should be set to True inside the Info.plist file. Otherwise,
            // CFBundleDevelopmentRegion will be used to find the language preference of the user, which in the
            // case of Python is always english.
            // This is a hack until CFBunldeAllowMixedLocalizations will be set in the Python framework
            // installation in darwin systems.
            // Upstream issue in CPython: https://github.com/python/cpython/issues/108269
#ifdef Q_OS_DARWIN
                Shiboken::AutoDecRef locale(PyImport_ImportModule("locale"));
                Shiboken::AutoDecRef getLocale(PyObject_GetAttrString(locale, "getlocale"));
                Shiboken::AutoDecRef systemLocale(PyObject_CallObject(getLocale, nullptr));
                PyObject* localeCode = PyTuple_GetItem(systemLocale, 0);
                ::QLocale cppResult;
                if (localeCode != Py_None) {
                    QString localeCodeStr = PySide::pyStringToQString(localeCode);
                    cppResult = QLocale(localeCodeStr);
                } else {
                   // The default locale is 'C' locale as mentioned in
                   // https://docs.python.org/3/library/locale.html
                    cppResult = ::QLocale::c();
                }
#else
                ::QLocale cppResult = QLocale::system();
#endif
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppResult);
            // END of custom code block [file: ../glue/qtcore.cpp (qlocale_system)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_territory(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.territory";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // territory()const
            QLocale::Country cppResult = const_cast<const ::QLocale *>(cppSelf)->territory();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_territoryToCode(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.territoryToCode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLocale::territoryToCode(QLocale::Country)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // territoryToCode(QLocale::Country)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QLocale::Country cppArg0{QLocale::AnyCountry};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // territoryToCode(QLocale::Country)
            QString cppResult = ::QLocale::territoryToCode(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_territoryToString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.territoryToString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QLocale::territoryToString(QLocale::Country)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // territoryToString(QLocale::Country)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QLocale::Country cppArg0{QLocale::AnyCountry};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // territoryToString(QLocale::Country)
            QString cppResult = ::QLocale::territoryToString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_textDirection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.textDirection";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // textDirection()const
            Qt::LayoutDirection cppResult = const_cast<const ::QLocale *>(cppSelf)->textDirection();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_timeFormat(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.timeFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:timeFormat", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::timeFormat(QLocale::FormatType=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // timeFormat(QLocale::FormatType)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // timeFormat(QLocale::FormatType)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QLocale::FormatType cppArg0(QLocale::FormatType::LongFormat);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // timeFormat(QLocale::FormatType)const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->timeFormat(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toCurrencyString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toCurrencyString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:toCurrencyString", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::toCurrencyString(double,const QString&=,int=)const->QString
    // 1: QLocale::toCurrencyString(float,const QString&=,int=)const->QString
    // 2: QLocale::toCurrencyString(int,const QString&=)const->QString
    // 3: QLocale::toCurrencyString(qlonglong,const QString&=)const->QString
    if (numArgs >= 1
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // toCurrencyString(double,QString,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // toCurrencyString(double,QString,int)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 0; // toCurrencyString(double,QString,int)const
            }
        }
    } else if (numArgs >= 1
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // toCurrencyString(float,QString,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // toCurrencyString(float,QString,int)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 1; // toCurrencyString(float,QString,int)const
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qlonglong>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // toCurrencyString(qlonglong,QString)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 3; // toCurrencyString(qlonglong,QString)const
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // toCurrencyString(int,QString)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 2; // toCurrencyString(int,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // toCurrencyString(double arg__1, const QString & symbol, int precision) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_symbol = Shiboken::String::createStaticString("symbol");
                if (PyDict_Contains(kwds, key_symbol) != 0) {
                    value = PyDict_GetItem(kwds, key_symbol);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_symbol);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_symbol);
                }
                static PyObject *const key_precision = Shiboken::String::createStaticString("precision");
                if (PyDict_Contains(kwds, key_precision) != 0) {
                    value = PyDict_GetItem(kwds, key_precision);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_precision);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_precision);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            double cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = -1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toCurrencyString(double,QString,int)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toCurrencyString(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // toCurrencyString(float i, const QString & symbol, int precision) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_symbol = Shiboken::String::createStaticString("symbol");
                if (PyDict_Contains(kwds, key_symbol) != 0) {
                    value = PyDict_GetItem(kwds, key_symbol);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_symbol);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_symbol);
                }
                static PyObject *const key_precision = Shiboken::String::createStaticString("precision");
                if (PyDict_Contains(kwds, key_precision) != 0) {
                    value = PyDict_GetItem(kwds, key_precision);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_precision);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_precision);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = -1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toCurrencyString(float,QString,int)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toCurrencyString(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 2: // toCurrencyString(int i, const QString & symbol) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_symbol = Shiboken::String::createStaticString("symbol");
                if (PyDict_Contains(kwds, key_symbol) != 0) {
                    value = PyDict_GetItem(kwds, key_symbol);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_symbol);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_symbol);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toCurrencyString(int,QString)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toCurrencyString(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 3: // toCurrencyString(qlonglong arg__1, const QString & symbol) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_symbol = Shiboken::String::createStaticString("symbol");
                if (PyDict_Contains(kwds, key_symbol) != 0) {
                    value = PyDict_GetItem(kwds, key_symbol);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_symbol);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_symbol);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            qlonglong cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toCurrencyString(qlonglong,QString)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toCurrencyString(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toDate(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toDate";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:toDate", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::toDate(QString,QLocale::FormatType,QCalendar,int=)const->QDate
    // 1: QLocale::toDate(QString,QLocale::FormatType=,int=)const->QDate
    // 2: QLocale::toDate(QString,QString,QCalendar,int=)const->QDate
    // 3: QLocale::toDate(QString,QString,int=)const->QDate
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // toDate(QString,QLocale::FormatType,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 3; // toDate(QString,QString,int)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 3; // toDate(QString,QString,int)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 2; // toDate(QString,QString,QCalendar,int)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 2; // toDate(QString,QString,QCalendar,int)const
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // toDate(QString,QLocale::FormatType,int)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 1; // toDate(QString,QLocale::FormatType,int)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // toDate(QString,QLocale::FormatType,QCalendar,int)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 0; // toDate(QString,QLocale::FormatType,QCalendar,int)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // toDate(const QString & string, QLocale::FormatType format, QCalendar cal, int baseYear) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_baseYear = Shiboken::String::createStaticString("baseYear");
                if (PyDict_Contains(kwds, key_baseYear) != 0) {
                    value = PyDict_GetItem(kwds, key_baseYear);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_baseYear);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_baseYear);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QLocale::FormatType cppArg1{QLocale::LongFormat};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QCalendar cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = 1900;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toDate(QString,QLocale::FormatType,QCalendar,int)const
                QDate cppResult = const_cast<const ::QLocale *>(cppSelf)->toDate(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 1: // toDate(const QString & string, QLocale::FormatType format, int baseYear) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                static PyObject *const key_baseYear = Shiboken::String::createStaticString("baseYear");
                if (PyDict_Contains(kwds, key_baseYear) != 0) {
                    value = PyDict_GetItem(kwds, key_baseYear);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_baseYear);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_baseYear);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QLocale::FormatType cppArg1(QLocale::FormatType::LongFormat);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = 1900;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toDate(QString,QLocale::FormatType,int)const
                QDate cppResult = const_cast<const ::QLocale *>(cppSelf)->toDate(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 2: // toDate(const QString & string, const QString & format, QCalendar cal, int baseYear) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_baseYear = Shiboken::String::createStaticString("baseYear");
                if (PyDict_Contains(kwds, key_baseYear) != 0) {
                    value = PyDict_GetItem(kwds, key_baseYear);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_baseYear);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_baseYear);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QCalendar cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = 1900;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toDate(QString,QString,QCalendar,int)const
                QDate cppResult = const_cast<const ::QLocale *>(cppSelf)->toDate(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
        case 3: // toDate(const QString & string, const QString & format, int baseYear) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_baseYear = Shiboken::String::createStaticString("baseYear");
                if (PyDict_Contains(kwds, key_baseYear) != 0) {
                    value = PyDict_GetItem(kwds, key_baseYear);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_baseYear);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_baseYear);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = 1900;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toDate(QString,QString,int)const
                QDate cppResult = const_cast<const ::QLocale *>(cppSelf)->toDate(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toDateTime(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toDateTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOO:toDateTime", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::toDateTime(QString,QLocale::FormatType,QCalendar,int=)const->QDateTime
    // 1: QLocale::toDateTime(QString,QLocale::FormatType=,int=)const->QDateTime
    // 2: QLocale::toDateTime(QString,QString,QCalendar,int=)const->QDateTime
    // 3: QLocale::toDateTime(QString,QString,int=)const->QDateTime
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // toDateTime(QString,QLocale::FormatType,int)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 3; // toDateTime(QString,QString,int)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 3; // toDateTime(QString,QString,int)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 2; // toDateTime(QString,QString,QCalendar,int)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 2; // toDateTime(QString,QString,QCalendar,int)const
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // toDateTime(QString,QLocale::FormatType,int)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 1; // toDateTime(QString,QLocale::FormatType,int)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // toDateTime(QString,QLocale::FormatType,QCalendar,int)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 0; // toDateTime(QString,QLocale::FormatType,QCalendar,int)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // toDateTime(const QString & string, QLocale::FormatType format, QCalendar cal, int baseYear) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_baseYear = Shiboken::String::createStaticString("baseYear");
                if (PyDict_Contains(kwds, key_baseYear) != 0) {
                    value = PyDict_GetItem(kwds, key_baseYear);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_baseYear);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_baseYear);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QLocale::FormatType cppArg1{QLocale::LongFormat};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QCalendar cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = 1900;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toDateTime(QString,QLocale::FormatType,QCalendar,int)const
                QDateTime cppResult = const_cast<const ::QLocale *>(cppSelf)->toDateTime(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
        case 1: // toDateTime(const QString & string, QLocale::FormatType format, int baseYear) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                static PyObject *const key_baseYear = Shiboken::String::createStaticString("baseYear");
                if (PyDict_Contains(kwds, key_baseYear) != 0) {
                    value = PyDict_GetItem(kwds, key_baseYear);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_baseYear);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_baseYear);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QLocale::FormatType cppArg1(QLocale::FormatType::LongFormat);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = 1900;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toDateTime(QString,QLocale::FormatType,int)const
                QDateTime cppResult = const_cast<const ::QLocale *>(cppSelf)->toDateTime(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
        case 2: // toDateTime(const QString & string, const QString & format, QCalendar cal, int baseYear) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_baseYear = Shiboken::String::createStaticString("baseYear");
                if (PyDict_Contains(kwds, key_baseYear) != 0) {
                    value = PyDict_GetItem(kwds, key_baseYear);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_baseYear);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_baseYear);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QCalendar cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = 1900;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toDateTime(QString,QString,QCalendar,int)const
                QDateTime cppResult = const_cast<const ::QLocale *>(cppSelf)->toDateTime(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
        case 3: // toDateTime(const QString & string, const QString & format, int baseYear) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_baseYear = Shiboken::String::createStaticString("baseYear");
                if (PyDict_Contains(kwds, key_baseYear) != 0) {
                    value = PyDict_GetItem(kwds, key_baseYear);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_baseYear);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_baseYear);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = 1900;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toDateTime(QString,QString,int)const
                QDateTime cppResult = const_cast<const ::QLocale *>(cppSelf)->toDateTime(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toDouble(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toDouble";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocale::toDouble(QString,bool*)const->(float, bool ok)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // toDouble(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toDouble(QString,bool*)const
            // Begin code injection
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            double retval_ = cppSelf->toDouble(cppArg0, &ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_args,bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toFloat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toFloat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocale::toFloat(QString,bool*)const->(float, bool ok)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // toFloat(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toFloat(QString,bool*)const
            // Begin code injection
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            float retval_ = cppSelf->toFloat(cppArg0, &ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_args,bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toInt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toInt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocale::toInt(QString,bool*=)const->(int, bool ok)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // toInt(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        bool* removed_cppArg1 = nullptr;
        SBK_UNUSED(removed_cppArg1)

        if (Shiboken::Errors::occurred() == nullptr) {
            // toInt(QString,bool*)const
            // Begin code injection
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            int retval_ = cppSelf->toInt(cppArg0, &ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_args,bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toLong(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toLong";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocale::toLong(QString,bool*=)const->(int, bool ok)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // toLong(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        bool* removed_cppArg1 = nullptr;
        SBK_UNUSED(removed_cppArg1)

        if (Shiboken::Errors::occurred() == nullptr) {
            // toLong(QString,bool*)const
            // Begin code injection
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            long retval_ = cppSelf->toLong(cppArg0, &ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<long>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_args,bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toLongLong(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toLongLong";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocale::toLongLong(QString,bool*=)const->(int, bool ok)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // toLongLong(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        bool* removed_cppArg1 = nullptr;
        SBK_UNUSED(removed_cppArg1)

        if (Shiboken::Errors::occurred() == nullptr) {
            // toLongLong(QString,bool*)const
            // Begin code injection
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            qlonglong retval_ = cppSelf->toLongLong(cppArg0, &ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qlonglong>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_args,bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toLower(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toLower";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocale::toLower(QString)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // toLower(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toLower(QString)const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toLower(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toShort(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toShort";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocale::toShort(QString,bool*=)const->(int, bool ok)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // toShort(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        bool* removed_cppArg1 = nullptr;
        SBK_UNUSED(removed_cppArg1)

        if (Shiboken::Errors::occurred() == nullptr) {
            // toShort(QString,bool*)const
            // Begin code injection
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            short retval_ = cppSelf->toShort(cppArg0, &ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<short>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_args,bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toString";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:toString", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::toString(QDate,QLocale::FormatType=)const->QString
    // 1: QLocale::toString(QDate,QLocale::FormatType,QCalendar)const->QString
    // 2: QLocale::toString(QDate,QString)const->QString
    // 3: QLocale::toString(QTime,QLocale::FormatType=)const->QString
    // 4: QLocale::toString(QTime,QString)const->QString
    // 5: QLocale::toString(QDateTime,QLocale::FormatType=)const->QString
    // 6: QLocale::toString(QDateTime,QLocale::FormatType,QCalendar)const->QString
    // 7: QLocale::toString(QDateTime,QString)const->QString
    // 8: QLocale::toString(double,char=,int=)const->QString
    // 9: QLocale::toString(float,char=,int=)const->QString
    // 10: QLocale::toString(int)const->QString
    // 11: QLocale::toString(long)const->QString
    // 12: QLocale::toString(qlonglong)const->QString
    if (numArgs >= 1
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 8; // toString(double,char,int)const
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 8; // toString(double,char,int)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 8; // toString(double,char,int)const
            }
        }
    } else if (numArgs >= 1
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 9; // toString(float,char,int)const
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 9; // toString(float,char,int)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 9; // toString(float,char,int)const
            }
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qlonglong>(), (pyArgs[0])))) {
        overloadId = 12; // toString(qlonglong)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<long>(), (pyArgs[0])))) {
        overloadId = 11; // toString(long)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 10; // toString(int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 5; // toString(QDateTime,QLocale::FormatType)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 7; // toString(QDateTime,QString)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 5; // toString(QDateTime,QLocale::FormatType)const
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[2])))) {
                overloadId = 6; // toString(QDateTime,QLocale::FormatType,QCalendar)const
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // toString(QTime,QLocale::FormatType)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 4; // toString(QTime,QString)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 3; // toString(QTime,QLocale::FormatType)const
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // toString(QDate,QLocale::FormatType)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 2; // toString(QDate,QString)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // toString(QDate,QLocale::FormatType)const
            } else if (numArgs == 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QCalendar_IDX]), (pyArgs[2])))) {
                overloadId = 1; // toString(QDate,QLocale::FormatType,QCalendar)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // toString(QDate date, QLocale::FormatType format) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDate cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QLocale::FormatType cppArg1(QLocale::FormatType::LongFormat);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QDate,QLocale::FormatType)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toString(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // toString(QDate date, QLocale::FormatType format, QCalendar cal) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDate cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QLocale::FormatType cppArg1{QLocale::LongFormat};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QCalendar cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QDate,QLocale::FormatType,QCalendar)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toString(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 2: // toString(QDate date, const QString & format) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDate cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QDate,QString)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toString(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 3: // toString(QTime time, QLocale::FormatType format) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTime cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QLocale::FormatType cppArg1(QLocale::FormatType::LongFormat);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QTime,QLocale::FormatType)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toString(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 4: // toString(QTime time, const QString & format) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTime cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QTime,QString)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toString(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 5: // toString(const QDateTime & dateTime, QLocale::FormatType format) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDateTime cppArg0_local;
            ::QDateTime *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QLocale::FormatType cppArg1(QLocale::FormatType::LongFormat);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QDateTime,QLocale::FormatType)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toString(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 6: // toString(const QDateTime & dateTime, QLocale::FormatType format, QCalendar cal) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDateTime cppArg0_local;
            ::QDateTime *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QLocale::FormatType cppArg1{QLocale::LongFormat};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QCalendar cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QDateTime,QLocale::FormatType,QCalendar)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toString(*cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 7: // toString(const QDateTime & dateTime, const QString & format) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QDateTime cppArg0_local;
            ::QDateTime *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(QDateTime,QString)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toString(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 8: // toString(double f, char format, int precision) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                static PyObject *const key_precision = Shiboken::String::createStaticString("precision");
                if (PyDict_Contains(kwds, key_precision) != 0) {
                    value = PyDict_GetItem(kwds, key_precision);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_precision);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_precision);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            double cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1 = 'g';
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = 6;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(double,char,int)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toString(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 9: // toString(float f, char format, int precision) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                static PyObject *const key_precision = Shiboken::String::createStaticString("precision");
                if (PyDict_Contains(kwds, key_precision) != 0) {
                    value = PyDict_GetItem(kwds, key_precision);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_precision);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_precision);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1 = 'g';
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = 6;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(float,char,int)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toString(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 10: // toString(int i) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(int)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toString(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 11: // toString(long i) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            long cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(long)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toString(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 12: // toString(qlonglong i) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            qlonglong cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toString(qlonglong)const
                QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toString(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toTime(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toTime";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:toTime", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::toTime(QString,QLocale::FormatType=)const->QTime
    // 1: QLocale::toTime(QString,QString)const->QTime
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // toTime(QString,QLocale::FormatType)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 1; // toTime(QString,QString)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // toTime(QString,QLocale::FormatType)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // toTime(const QString & string, QLocale::FormatType format) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_format = Shiboken::String::createStaticString("format");
                if (PyDict_Contains(kwds, key_format) != 0) {
                    value = PyDict_GetItem(kwds, key_format);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_format);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_format);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QLocale::FormatType cppArg1(QLocale::FormatType::LongFormat);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toTime(QString,QLocale::FormatType)const
                QTime cppResult = const_cast<const ::QLocale *>(cppSelf)->toTime(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppResult);
            }
            break;
        }
        case 1: // toTime(const QString & string, const QString & format) const
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // toTime(QString,QString)const
                QTime cppResult = const_cast<const ::QLocale *>(cppSelf)->toTime(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTime_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toUInt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toUInt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocale::toUInt(QString,bool*)const->(int, bool ok)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // toUInt(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toUInt(QString,bool*)const
            // Begin code injection
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            uint retval_ = cppSelf->toUInt(cppArg0, &ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_args,bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toULong(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toULong";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:toULong", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::toULong(QString,bool*=)const->ulong
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // toULong(QString,bool*)const
        } else if (numArgs >= 2
            && PyBool_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // toULong(QString,bool*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_ok = Shiboken::String::createStaticString("ok");
            if (PyDict_Contains(kwds, key_ok) != 0) {
                value = PyDict_GetItem(kwds, key_ok);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_ok);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_ok);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toULong(QString,bool*)const
            ulong cppResult = const_cast<const ::QLocale *>(cppSelf)->toULong(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<ulong>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toULongLong(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toULongLong";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocale::toULongLong(QString,bool*)const->(int, bool ok)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // toULongLong(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toULongLong(QString,bool*)const
            // Begin code injection
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            qulonglong retval_ = cppSelf->toULongLong(cppArg0, &ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qulonglong>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_args,bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toUShort(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toUShort";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocale::toUShort(QString,bool*=)const->(int, bool ok)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // toUShort(QString,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        bool* removed_cppArg1 = nullptr;
        SBK_UNUSED(removed_cppArg1)

        if (Shiboken::Errors::occurred() == nullptr) {
            // toUShort(QString,bool*)const
            // Begin code injection
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            ushort retval_ = cppSelf->toUShort(cppArg0, &ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_args,bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_toUpper(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.toUpper";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QLocale::toUpper(QString)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // toUpper(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toUpper(QString)const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->toUpper(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_uiLanguages(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QLocale.uiLanguages";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|O:uiLanguages", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QLocale::uiLanguages(QLocale::TagSeparator=)const->QStringList
    if (numArgs == 0) {
        overloadId = 0; // uiLanguages(QLocale::TagSeparator)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_TagSeparator_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // uiLanguages(QLocale::TagSeparator)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_separator = Shiboken::String::createStaticString("separator");
            if (PyDict_Contains(kwds, key_separator) != 0) {
                value = PyDict_GetItem(kwds, key_separator);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_separator);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_TagSeparator_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_separator);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QLocale::TagSeparator cppArg0(QLocale::TagSeparator::Dash);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // uiLanguages(QLocale::TagSeparator)const
            QStringList cppResult = const_cast<const ::QLocale *>(cppSelf)->uiLanguages(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_weekdays(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.weekdays";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // weekdays()const
            QList<Qt::DayOfWeek> cppResult = const_cast<const ::QLocale *>(cppSelf)->weekdays();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_Qt_DayOfWeek_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocaleFunc_zeroDigit(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QLocale.zeroDigit";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // zeroDigit()const
            QString cppResult = const_cast<const ::QLocale *>(cppSelf)->zeroDigit();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QLocale__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QLocale_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QLocale_EnumFlagInfo[] = {
    "Country:Enum",
    "CurrencySymbolFormat:Enum",
    "DataSizeFormat:Flag:DataSizeFormats",
    "FloatingPointPrecisionOption:IntEnum",
    "FormatType:Enum",
    "Language:Enum",
    "LanguageCodeType:IntFlag:LanguageCodeTypes",
    "MeasurementSystem:Enum",
    "NumberOption:Flag:NumberOptions",
    "QuotationStyle:Enum",
    "Script:Enum",
    "TagSeparator:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QLocale_methods[] = {
    {"amText", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_amText), METH_NOARGS, nullptr},
    {"bcp47Name", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_bcp47Name), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"c", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_c), METH_NOARGS|METH_STATIC, nullptr},
    {"codeToCountry", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_codeToCountry), METH_O|METH_STATIC, nullptr},
    {"codeToLanguage", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_codeToLanguage), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"codeToScript", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_codeToScript), METH_O|METH_STATIC, nullptr},
    {"codeToTerritory", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_codeToTerritory), METH_O|METH_STATIC, nullptr},
    {"collation", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_collation), METH_NOARGS, nullptr},
    {"countriesForLanguage", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_countriesForLanguage), METH_O|METH_STATIC, nullptr},
    {"country", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_country), METH_NOARGS, nullptr},
    {"countryToCode", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_countryToCode), METH_O|METH_STATIC, nullptr},
    {"countryToString", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_countryToString), METH_O|METH_STATIC, nullptr},
    {"createSeparatedList", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_createSeparatedList), METH_O, nullptr},
    {"currencySymbol", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_currencySymbol), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"dateFormat", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_dateFormat), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"dateTimeFormat", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_dateTimeFormat), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"dayName", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_dayName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"decimalPoint", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_decimalPoint), METH_NOARGS, nullptr},
    {"exponential", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_exponential), METH_NOARGS, nullptr},
    {"firstDayOfWeek", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_firstDayOfWeek), METH_NOARGS, nullptr},
    {"formattedDataSize", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_formattedDataSize), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"groupSeparator", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_groupSeparator), METH_NOARGS, nullptr},
    {"language", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_language), METH_NOARGS, nullptr},
    {"languageToCode", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_languageToCode), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"languageToString", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_languageToString), METH_O|METH_STATIC, nullptr},
    {"matchingLocales", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_matchingLocales), METH_VARARGS|METH_STATIC, nullptr},
    {"measurementSystem", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_measurementSystem), METH_NOARGS, nullptr},
    {"monthName", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_monthName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_name), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"nativeCountryName", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_nativeCountryName), METH_NOARGS, nullptr},
    {"nativeLanguageName", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_nativeLanguageName), METH_NOARGS, nullptr},
    {"nativeTerritoryName", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_nativeTerritoryName), METH_NOARGS, nullptr},
    {"negativeSign", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_negativeSign), METH_NOARGS, nullptr},
    {"numberOptions", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_numberOptions), METH_NOARGS, nullptr},
    {"percent", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_percent), METH_NOARGS, nullptr},
    {"pmText", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_pmText), METH_NOARGS, nullptr},
    {"positiveSign", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_positiveSign), METH_NOARGS, nullptr},
    {"quoteString", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_quoteString), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"script", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_script), METH_NOARGS, nullptr},
    {"scriptToCode", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_scriptToCode), METH_O|METH_STATIC, nullptr},
    {"scriptToString", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_scriptToString), METH_O|METH_STATIC, nullptr},
    {"setDefault", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_setDefault), METH_O|METH_STATIC, nullptr},
    {"setNumberOptions", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_setNumberOptions), METH_O, nullptr},
    {"standaloneDayName", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_standaloneDayName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"standaloneMonthName", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_standaloneMonthName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_swap), METH_O, nullptr},
    {"system", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_system), METH_NOARGS|METH_STATIC, nullptr},
    {"territory", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_territory), METH_NOARGS, nullptr},
    {"territoryToCode", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_territoryToCode), METH_O|METH_STATIC, nullptr},
    {"territoryToString", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_territoryToString), METH_O|METH_STATIC, nullptr},
    {"textDirection", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_textDirection), METH_NOARGS, nullptr},
    {"timeFormat", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_timeFormat), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toCurrencyString", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toCurrencyString), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toDate", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toDate), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toDateTime", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toDateTime), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toDouble", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toDouble), METH_O, nullptr},
    {"toFloat", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toFloat), METH_O, nullptr},
    {"toInt", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toInt), METH_O, nullptr},
    {"toLong", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toLong), METH_O, nullptr},
    {"toLongLong", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toLongLong), METH_O, nullptr},
    {"toLower", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toLower), METH_O, nullptr},
    {"toShort", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toShort), METH_O, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toString), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toTime", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toTime), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toUInt", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toUInt), METH_O, nullptr},
    {"toULong", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toULong), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toULongLong", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toULongLong), METH_O, nullptr},
    {"toUShort", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toUShort), METH_O, nullptr},
    {"toUpper", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_toUpper), METH_O, nullptr},
    {"uiLanguages", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_uiLanguages), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"weekdays", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_weekdays), METH_NOARGS, nullptr},
    {"zeroDigit", reinterpret_cast<PyCFunction>(Sbk_QLocaleFunc_zeroDigit), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QLocale__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QLocale_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
                // operator!=(const QLocale & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLocale cppArg0_local;
                ::QLocale *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
                // operator==(const QLocale & rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QLocale cppArg0_local;
                ::QLocale *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QLocale_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QLocale_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QLocale_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QLocale__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QLocale_Type = nullptr;
static PyTypeObject *Sbk_QLocale_TypeF(void)
{
    return _Sbk_QLocale_Type;
}

static PyType_Slot Sbk_QLocale_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QLocale__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QLocale_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QLocale_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QLocale_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QLocale_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QLocale_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QLocale_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QLocale_spec = {
    "2:PySide6.QtCore.QLocale",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QLocale_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QLocale_Language_PythonToCpp_QLocale_Language(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLocale::Language>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLocale::Language *>(cppOut) = value;

}
static PythonToCppFunc is_QLocale_Language_PythonToCpp_QLocale_Language_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Language_IDX])))
        return QLocale_Language_PythonToCpp_QLocale_Language;
    return {};
}
static PyObject *QLocale_Language_CppToPython_QLocale_Language(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QLocale::Language *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Language_IDX]), castCppIn);

}

static void QLocale_Script_PythonToCpp_QLocale_Script(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLocale::Script>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLocale::Script *>(cppOut) = value;

}
static PythonToCppFunc is_QLocale_Script_PythonToCpp_QLocale_Script_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Script_IDX])))
        return QLocale_Script_PythonToCpp_QLocale_Script;
    return {};
}
static PyObject *QLocale_Script_CppToPython_QLocale_Script(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QLocale::Script *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Script_IDX]), castCppIn);

}

static void QLocale_Country_PythonToCpp_QLocale_Country(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLocale::Country>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLocale::Country *>(cppOut) = value;

}
static PythonToCppFunc is_QLocale_Country_PythonToCpp_QLocale_Country_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX])))
        return QLocale_Country_PythonToCpp_QLocale_Country;
    return {};
}
static PyObject *QLocale_Country_CppToPython_QLocale_Country(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QLocale::Country *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX]), castCppIn);

}

static void QLocale_MeasurementSystem_PythonToCpp_QLocale_MeasurementSystem(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLocale::MeasurementSystem>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLocale::MeasurementSystem *>(cppOut) = value;

}
static PythonToCppFunc is_QLocale_MeasurementSystem_PythonToCpp_QLocale_MeasurementSystem_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_MeasurementSystem_IDX])))
        return QLocale_MeasurementSystem_PythonToCpp_QLocale_MeasurementSystem;
    return {};
}
static PyObject *QLocale_MeasurementSystem_CppToPython_QLocale_MeasurementSystem(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QLocale::MeasurementSystem *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_MeasurementSystem_IDX]), castCppIn);

}

static void QLocale_FormatType_PythonToCpp_QLocale_FormatType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLocale::FormatType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLocale::FormatType *>(cppOut) = value;

}
static PythonToCppFunc is_QLocale_FormatType_PythonToCpp_QLocale_FormatType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX])))
        return QLocale_FormatType_PythonToCpp_QLocale_FormatType;
    return {};
}
static PyObject *QLocale_FormatType_CppToPython_QLocale_FormatType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QLocale::FormatType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX]), castCppIn);

}

static void QLocale_NumberOption_PythonToCpp_QLocale_NumberOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLocale::NumberOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLocale::NumberOption *>(cppOut) = value;

}
static PythonToCppFunc is_QLocale_NumberOption_PythonToCpp_QLocale_NumberOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_NumberOption_IDX])))
        return QLocale_NumberOption_PythonToCpp_QLocale_NumberOption;
    return {};
}
static PyObject *QLocale_NumberOption_CppToPython_QLocale_NumberOption(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QLocale::NumberOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_NumberOption_IDX]), castCppIn);

}

static void QLocale_FloatingPointPrecisionOption_PythonToCpp_QLocale_FloatingPointPrecisionOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLocale::FloatingPointPrecisionOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLocale::FloatingPointPrecisionOption *>(cppOut) = value;

}
static PythonToCppFunc is_QLocale_FloatingPointPrecisionOption_PythonToCpp_QLocale_FloatingPointPrecisionOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FloatingPointPrecisionOption_IDX])))
        return QLocale_FloatingPointPrecisionOption_PythonToCpp_QLocale_FloatingPointPrecisionOption;
    return {};
}
static PyObject *QLocale_FloatingPointPrecisionOption_CppToPython_QLocale_FloatingPointPrecisionOption(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QLocale::FloatingPointPrecisionOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FloatingPointPrecisionOption_IDX]), castCppIn);

}

static void QLocale_TagSeparator_PythonToCpp_QLocale_TagSeparator(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLocale::TagSeparator>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLocale::TagSeparator *>(cppOut) = value;

}
static PythonToCppFunc is_QLocale_TagSeparator_PythonToCpp_QLocale_TagSeparator_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_TagSeparator_IDX])))
        return QLocale_TagSeparator_PythonToCpp_QLocale_TagSeparator;
    return {};
}
static PyObject *QLocale_TagSeparator_CppToPython_QLocale_TagSeparator(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QLocale::TagSeparator *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_TagSeparator_IDX]), castCppIn);

}

static void QLocale_CurrencySymbolFormat_PythonToCpp_QLocale_CurrencySymbolFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLocale::CurrencySymbolFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLocale::CurrencySymbolFormat *>(cppOut) = value;

}
static PythonToCppFunc is_QLocale_CurrencySymbolFormat_PythonToCpp_QLocale_CurrencySymbolFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_CurrencySymbolFormat_IDX])))
        return QLocale_CurrencySymbolFormat_PythonToCpp_QLocale_CurrencySymbolFormat;
    return {};
}
static PyObject *QLocale_CurrencySymbolFormat_CppToPython_QLocale_CurrencySymbolFormat(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QLocale::CurrencySymbolFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_CurrencySymbolFormat_IDX]), castCppIn);

}

static void QLocale_DataSizeFormat_PythonToCpp_QLocale_DataSizeFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLocale::DataSizeFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLocale::DataSizeFormat *>(cppOut) = value;

}
static PythonToCppFunc is_QLocale_DataSizeFormat_PythonToCpp_QLocale_DataSizeFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_DataSizeFormat_IDX])))
        return QLocale_DataSizeFormat_PythonToCpp_QLocale_DataSizeFormat;
    return {};
}
static PyObject *QLocale_DataSizeFormat_CppToPython_QLocale_DataSizeFormat(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QLocale::DataSizeFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_DataSizeFormat_IDX]), castCppIn);

}

static void QLocale_LanguageCodeType_PythonToCpp_QLocale_LanguageCodeType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLocale::LanguageCodeType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLocale::LanguageCodeType *>(cppOut) = value;

}
static PythonToCppFunc is_QLocale_LanguageCodeType_PythonToCpp_QLocale_LanguageCodeType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_LanguageCodeType_IDX])))
        return QLocale_LanguageCodeType_PythonToCpp_QLocale_LanguageCodeType;
    return {};
}
static PyObject *QLocale_LanguageCodeType_CppToPython_QLocale_LanguageCodeType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QLocale::LanguageCodeType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_LanguageCodeType_IDX]), castCppIn);

}

static void QLocale_QuotationStyle_PythonToCpp_QLocale_QuotationStyle(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QLocale::QuotationStyle>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QLocale::QuotationStyle *>(cppOut) = value;

}
static PythonToCppFunc is_QLocale_QuotationStyle_PythonToCpp_QLocale_QuotationStyle_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_QuotationStyle_IDX])))
        return QLocale_QuotationStyle_PythonToCpp_QLocale_QuotationStyle;
    return {};
}
static PyObject *QLocale_QuotationStyle_CppToPython_QLocale_QuotationStyle(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QLocale::QuotationStyle *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_QuotationStyle_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QLocale_PythonToCpp_QLocale_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QLocale_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QLocale_PythonToCpp_QLocale_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QLocale_TypeF()))
        return QLocale_PythonToCpp_QLocale_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QLocale_PTR_CppToPython_QLocale(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QLocale *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QLocale_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// C++ to Python copy conversion.
static PyObject *QLocale_COPY_CppToPython_QLocale(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QLocale *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QLocale_TypeF(), new ::QLocale(*source), true, true);
}

// Python to C++ copy conversion.
static void QLocale_PythonToCpp_QLocale_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QLocale *>(cppOut) = *reinterpret_cast< ::QLocale *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QLocale_PythonToCpp_QLocale_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QLocale_TypeF()))
        return QLocale_PythonToCpp_QLocale_COPY;
    return {};
}

// Implicit conversions.
static void QLocale_Language_PythonToCpp_QLocale(PyObject *pyIn, void *cppOut)
{
    ::QLocale::Language cppIn{QLocale::AnyLanguage};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Language_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QLocale *>(cppOut) = ::QLocale(cppIn);
}
static PythonToCppFunc is_QLocale_Language_PythonToCpp_QLocale_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Language_IDX]), pyIn))
        return QLocale_Language_PythonToCpp_QLocale;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QLocale_SignatureStrings[] = {
    "5:PySide6.QtCore.QLocale(self)",
    "4:PySide6.QtCore.QLocale(self,language:PySide6.QtCore.QLocale.Language,territory:PySide6.QtCore.QLocale.Country)",
    "3:PySide6.QtCore.QLocale(self,language:PySide6.QtCore.QLocale.Language,script:PySide6.QtCore.QLocale.Script=QLocale.Script.AnyScript,territory:PySide6.QtCore.QLocale.Country=QLocale.Country.AnyTerritory)",
    "2:PySide6.QtCore.QLocale(self,name:QString)",
    "1:PySide6.QtCore.QLocale(self,other:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])",
    "0:PySide6.QtCore.QLocale(self,name:QString)",
    "PySide6.QtCore.QLocale.amText(self)->QString",
    "PySide6.QtCore.QLocale.bcp47Name(self,separator:PySide6.QtCore.QLocale.TagSeparator=QLocale.TagSeparator.Dash)->QString",
    "PySide6.QtCore.QLocale.c()->PySide6.QtCore.QLocale",
    "PySide6.QtCore.QLocale.codeToCountry(countryCode:QString)->PySide6.QtCore.QLocale.Country",
    "PySide6.QtCore.QLocale.codeToLanguage(languageCode:QString,codeTypes:PySide6.QtCore.QLocale.LanguageCodeType=QLocale.LanguageCodeType.AnyLanguageCode)->PySide6.QtCore.QLocale.Language",
    "PySide6.QtCore.QLocale.codeToScript(scriptCode:QString)->PySide6.QtCore.QLocale.Script",
    "PySide6.QtCore.QLocale.codeToTerritory(territoryCode:QString)->PySide6.QtCore.QLocale.Country",
    "PySide6.QtCore.QLocale.collation(self)->PySide6.QtCore.QLocale",
    "PySide6.QtCore.QLocale.countriesForLanguage(lang:PySide6.QtCore.QLocale.Language)->QList[PySide6.QtCore.QLocale.Country]",
    "PySide6.QtCore.QLocale.country(self)->PySide6.QtCore.QLocale.Country",
    "PySide6.QtCore.QLocale.countryToCode(country:PySide6.QtCore.QLocale.Country)->QString",
    "PySide6.QtCore.QLocale.countryToString(country:PySide6.QtCore.QLocale.Country)->QString",
    "PySide6.QtCore.QLocale.createSeparatedList(self,strl:QStringList)->QString",
    "PySide6.QtCore.QLocale.currencySymbol(self,arg__1:PySide6.QtCore.QLocale.CurrencySymbolFormat=QLocale.CurrencySymbolFormat.CurrencySymbol)->QString",
    "PySide6.QtCore.QLocale.dateFormat(self,format:PySide6.QtCore.QLocale.FormatType=QLocale.FormatType.LongFormat)->QString",
    "PySide6.QtCore.QLocale.dateTimeFormat(self,format:PySide6.QtCore.QLocale.FormatType=QLocale.FormatType.LongFormat)->QString",
    "PySide6.QtCore.QLocale.dayName(self,arg__1:int,format:PySide6.QtCore.QLocale.FormatType=QLocale.FormatType.LongFormat)->QString",
    "PySide6.QtCore.QLocale.decimalPoint(self)->QString",
    "PySide6.QtCore.QLocale.exponential(self)->QString",
    "PySide6.QtCore.QLocale.firstDayOfWeek(self)->PySide6.QtCore.Qt.DayOfWeek",
    "PySide6.QtCore.QLocale.formattedDataSize(self,bytes:qint64,precision:int=2,format:PySide6.QtCore.QLocale.DataSizeFormat=QLocale.DataSizeFormat.DataSizeIecFormat)->QString",
    "PySide6.QtCore.QLocale.groupSeparator(self)->QString",
    "PySide6.QtCore.QLocale.language(self)->PySide6.QtCore.QLocale.Language",
    "PySide6.QtCore.QLocale.languageToCode(language:PySide6.QtCore.QLocale.Language,codeTypes:PySide6.QtCore.QLocale.LanguageCodeType=QLocale.LanguageCodeType.AnyLanguageCode)->QString",
    "PySide6.QtCore.QLocale.languageToString(language:PySide6.QtCore.QLocale.Language)->QString",
    "PySide6.QtCore.QLocale.matchingLocales(language:PySide6.QtCore.QLocale.Language,script:PySide6.QtCore.QLocale.Script,territory:PySide6.QtCore.QLocale.Country)->QList[PySide6.QtCore.QLocale]",
    "PySide6.QtCore.QLocale.measurementSystem(self)->PySide6.QtCore.QLocale.MeasurementSystem",
    "PySide6.QtCore.QLocale.monthName(self,arg__1:int,format:PySide6.QtCore.QLocale.FormatType=QLocale.FormatType.LongFormat)->QString",
    "PySide6.QtCore.QLocale.name(self,separator:PySide6.QtCore.QLocale.TagSeparator=QLocale.TagSeparator.Underscore)->QString",
    "PySide6.QtCore.QLocale.nativeCountryName(self)->QString",
    "PySide6.QtCore.QLocale.nativeLanguageName(self)->QString",
    "PySide6.QtCore.QLocale.nativeTerritoryName(self)->QString",
    "PySide6.QtCore.QLocale.negativeSign(self)->QString",
    "PySide6.QtCore.QLocale.numberOptions(self)->PySide6.QtCore.QLocale.NumberOption",
    "PySide6.QtCore.QLocale.percent(self)->QString",
    "PySide6.QtCore.QLocale.pmText(self)->QString",
    "PySide6.QtCore.QLocale.positiveSign(self)->QString",
    "1:PySide6.QtCore.QLocale.quoteString(self,str:QString,style:PySide6.QtCore.QLocale.QuotationStyle=QLocale.QuotationStyle.StandardQuotation)->QString",
    "0:PySide6.QtCore.QLocale.quoteString(self,str:QString,style:PySide6.QtCore.QLocale.QuotationStyle=QLocale.QuotationStyle.StandardQuotation)->QString",
    "PySide6.QtCore.QLocale.script(self)->PySide6.QtCore.QLocale.Script",
    "PySide6.QtCore.QLocale.scriptToCode(script:PySide6.QtCore.QLocale.Script)->QString",
    "PySide6.QtCore.QLocale.scriptToString(script:PySide6.QtCore.QLocale.Script)->QString",
    "PySide6.QtCore.QLocale.setDefault(locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])",
    "PySide6.QtCore.QLocale.setNumberOptions(self,options:PySide6.QtCore.QLocale.NumberOption)",
    "PySide6.QtCore.QLocale.standaloneDayName(self,arg__1:int,format:PySide6.QtCore.QLocale.FormatType=QLocale.FormatType.LongFormat)->QString",
    "PySide6.QtCore.QLocale.standaloneMonthName(self,arg__1:int,format:PySide6.QtCore.QLocale.FormatType=QLocale.FormatType.LongFormat)->QString",
    "PySide6.QtCore.QLocale.swap(self,other:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])",
    "PySide6.QtCore.QLocale.system()->PySide6.QtCore.QLocale",
    "PySide6.QtCore.QLocale.territory(self)->PySide6.QtCore.QLocale.Country",
    "PySide6.QtCore.QLocale.territoryToCode(territory:PySide6.QtCore.QLocale.Country)->QString",
    "PySide6.QtCore.QLocale.territoryToString(territory:PySide6.QtCore.QLocale.Country)->QString",
    "PySide6.QtCore.QLocale.textDirection(self)->PySide6.QtCore.Qt.LayoutDirection",
    "PySide6.QtCore.QLocale.timeFormat(self,format:PySide6.QtCore.QLocale.FormatType=QLocale.FormatType.LongFormat)->QString",
    "3:PySide6.QtCore.QLocale.toCurrencyString(self,arg__1:double,symbol:QString=QString(),precision:int=-1)->QString",
    "2:PySide6.QtCore.QLocale.toCurrencyString(self,i:float,symbol:QString=QString(),precision:int=-1)->QString",
    "1:PySide6.QtCore.QLocale.toCurrencyString(self,i:int,symbol:QString=QString())->QString",
    "0:PySide6.QtCore.QLocale.toCurrencyString(self,arg__1:qlonglong,symbol:QString=QString())->QString",
    "3:PySide6.QtCore.QLocale.toDate(self,string:QString,format:PySide6.QtCore.QLocale.FormatType,cal:PySide6.QtCore.QCalendar,baseYear:int=1900)->PySide6.QtCore.QDate",
    "2:PySide6.QtCore.QLocale.toDate(self,string:QString,format:PySide6.QtCore.QLocale.FormatType=QLocale.FormatType.LongFormat,baseYear:int=1900)->PySide6.QtCore.QDate",
    "1:PySide6.QtCore.QLocale.toDate(self,string:QString,format:QString,cal:PySide6.QtCore.QCalendar,baseYear:int=1900)->PySide6.QtCore.QDate",
    "0:PySide6.QtCore.QLocale.toDate(self,string:QString,format:QString,baseYear:int=1900)->PySide6.QtCore.QDate",
    "3:PySide6.QtCore.QLocale.toDateTime(self,string:QString,format:PySide6.QtCore.QLocale.FormatType,cal:PySide6.QtCore.QCalendar,baseYear:int=1900)->PySide6.QtCore.QDateTime",
    "2:PySide6.QtCore.QLocale.toDateTime(self,string:QString,format:PySide6.QtCore.QLocale.FormatType=QLocale.FormatType.LongFormat,baseYear:int=1900)->PySide6.QtCore.QDateTime",
    "1:PySide6.QtCore.QLocale.toDateTime(self,string:QString,format:QString,cal:PySide6.QtCore.QCalendar,baseYear:int=1900)->PySide6.QtCore.QDateTime",
    "0:PySide6.QtCore.QLocale.toDateTime(self,string:QString,format:QString,baseYear:int=1900)->PySide6.QtCore.QDateTime",
    "PySide6.QtCore.QLocale.toDouble(self,s:QString)->Tuple[float, bool]",
    "PySide6.QtCore.QLocale.toFloat(self,s:QString)->Tuple[float, bool]",
    "PySide6.QtCore.QLocale.toInt(self,s:QString)->Tuple[int, bool]",
    "PySide6.QtCore.QLocale.toLong(self,s:QString)->Tuple[int, bool]",
    "PySide6.QtCore.QLocale.toLongLong(self,s:QString)->Tuple[int, bool]",
    "PySide6.QtCore.QLocale.toLower(self,str:QString)->QString",
    "PySide6.QtCore.QLocale.toShort(self,s:QString)->Tuple[int, bool]",
    "12:PySide6.QtCore.QLocale.toString(self,date:PySide6.QtCore.QDate,format:PySide6.QtCore.QLocale.FormatType=QLocale.FormatType.LongFormat)->QString",
    "11:PySide6.QtCore.QLocale.toString(self,date:PySide6.QtCore.QDate,format:PySide6.QtCore.QLocale.FormatType,cal:PySide6.QtCore.QCalendar)->QString",
    "10:PySide6.QtCore.QLocale.toString(self,date:PySide6.QtCore.QDate,format:QString)->QString",
    "9:PySide6.QtCore.QLocale.toString(self,time:PySide6.QtCore.QTime,format:PySide6.QtCore.QLocale.FormatType=QLocale.FormatType.LongFormat)->QString",
    "8:PySide6.QtCore.QLocale.toString(self,time:PySide6.QtCore.QTime,format:QString)->QString",
    "7:PySide6.QtCore.QLocale.toString(self,dateTime:PySide6.QtCore.QDateTime,format:PySide6.QtCore.QLocale.FormatType=QLocale.FormatType.LongFormat)->QString",
    "6:PySide6.QtCore.QLocale.toString(self,dateTime:PySide6.QtCore.QDateTime,format:PySide6.QtCore.QLocale.FormatType,cal:PySide6.QtCore.QCalendar)->QString",
    "5:PySide6.QtCore.QLocale.toString(self,dateTime:PySide6.QtCore.QDateTime,format:QString)->QString",
    "4:PySide6.QtCore.QLocale.toString(self,f:double,format:char='g',precision:int=6)->QString",
    "3:PySide6.QtCore.QLocale.toString(self,f:float,format:char='g',precision:int=6)->QString",
    "2:PySide6.QtCore.QLocale.toString(self,i:int)->QString",
    "1:PySide6.QtCore.QLocale.toString(self,i:long)->QString",
    "0:PySide6.QtCore.QLocale.toString(self,i:qlonglong)->QString",
    "1:PySide6.QtCore.QLocale.toTime(self,string:QString,format:PySide6.QtCore.QLocale.FormatType=QLocale.FormatType.LongFormat)->PySide6.QtCore.QTime",
    "0:PySide6.QtCore.QLocale.toTime(self,string:QString,format:QString)->PySide6.QtCore.QTime",
    "PySide6.QtCore.QLocale.toUInt(self,s:QString)->Tuple[int, bool]",
    "PySide6.QtCore.QLocale.toULong(self,s:QString,ok:bool*=nullptr)->ulong",
    "PySide6.QtCore.QLocale.toULongLong(self,s:QString)->Tuple[int, bool]",
    "PySide6.QtCore.QLocale.toUShort(self,s:QString)->Tuple[int, bool]",
    "PySide6.QtCore.QLocale.toUpper(self,str:QString)->QString",
    "PySide6.QtCore.QLocale.uiLanguages(self,separator:PySide6.QtCore.QLocale.TagSeparator=QLocale.TagSeparator.Dash)->QStringList",
    "PySide6.QtCore.QLocale.weekdays(self)->QList[PySide6.QtCore.Qt.DayOfWeek]",
    "PySide6.QtCore.QLocale.zeroDigit(self)->QString",
    "PySide6.QtCore.QLocale.__copy__()",
    nullptr}; // Sentinel

PyTypeObject *init_QLocale(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX].type;

    Shiboken::AutoDecRef Sbk_QLocale_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QLocale_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QLocale",
        "QLocale",
        &Sbk_QLocale_spec,
        &Shiboken::callCppDestructor< ::QLocale >,
        Sbk_QLocale_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QLocale_TypeF(); // references _Sbk_QLocale_Type
    InitSignatureStrings(pyType, QLocale_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QLocale_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QLocale_PythonToCpp_QLocale_PTR,
        is_QLocale_PythonToCpp_QLocale_PTR_Convertible,
        QLocale_PTR_CppToPython_QLocale,
        QLocale_COPY_CppToPython_QLocale);

    Shiboken::Conversions::registerConverterName(converter, "QLocale");
    Shiboken::Conversions::registerConverterName(converter, "QLocale*");
    Shiboken::Conversions::registerConverterName(converter, "QLocale&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QLocale).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLocale_PythonToCpp_QLocale_COPY,
        is_QLocale_PythonToCpp_QLocale_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QLocale_Language_PythonToCpp_QLocale,
        is_QLocale_Language_PythonToCpp_QLocale_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QLocale_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Language'.
    const char *Language_Initializer[] = {
        "AnyLanguage",
        "C",
        "Abkhazian",
        "Afar",
        "Afrikaans",
        "Aghem",
        "Akan",
        "Akkadian",
        "Akoose",
        "Albanian",
        "AmericanSignLanguage",
        "Amharic",
        "AncientEgyptian",
        "AncientGreek",
        "Arabic",
        "Aragonese",
        "Aramaic",
        "Armenian",
        "Assamese",
        "Asturian",
        "Asu",
        "Atsam",
        "Avaric",
        "Avestan",
        "Aymara",
        "Azerbaijani",
        "Bafia",
        "Balinese",
        "Bambara",
        "Bamun",
        "Bangla",
        "Basaa",
        "Bashkir",
        "Basque",
        "BatakToba",
        "Belarusian",
        "Bemba",
        "Bena",
        "Bhojpuri",
        "Bislama",
        "Blin",
        "Bodo",
        "Bosnian",
        "Breton",
        "Buginese",
        "Bulgarian",
        "Burmese",
        "Cantonese",
        "Catalan",
        "Cebuano",
        "CentralAtlasTamazight",
        "CentralKurdish",
        "Chakma",
        "Chamorro",
        "Chechen",
        "Cherokee",
        "Chickasaw",
        "Chiga",
        "Chinese",
        "Church",
        "Chuvash",
        "Colognian",
        "Coptic",
        "Cornish",
        "Corsican",
        "Cree",
        "Croatian",
        "Czech",
        "Danish",
        "Divehi",
        "Dogri",
        "Duala",
        "Dutch",
        "Dzongkha",
        "Embu",
        "English",
        "Erzya",
        "Esperanto",
        "Estonian",
        "Ewe",
        "Ewondo",
        "Faroese",
        "Fijian",
        "Filipino",
        "Finnish",
        "French",
        "Friulian",
        "Fulah",
        "Gaelic",
        "Ga",
        "Galician",
        "Ganda",
        "Geez",
        "Georgian",
        "German",
        "Gothic",
        "Greek",
        "Guarani",
        "Gujarati",
        "Gusii",
        "Haitian",
        "Hausa",
        "Hawaiian",
        "Hebrew",
        "Herero",
        "Hindi",
        "HiriMotu",
        "Hungarian",
        "Icelandic",
        "Ido",
        "Igbo",
        "InariSami",
        "Indonesian",
        "Ingush",
        "Interlingua",
        "Interlingue",
        "Inuktitut",
        "Inupiaq",
        "Irish",
        "Italian",
        "Japanese",
        "Javanese",
        "Jju",
        "JolaFonyi",
        "Kabuverdianu",
        "Kabyle",
        "Kako",
        "Kalaallisut",
        "Kalenjin",
        "Kamba",
        "Kannada",
        "Kanuri",
        "Kashmiri",
        "Kazakh",
        "Kenyang",
        "Khmer",
        "Kiche",
        "Kikuyu",
        "Kinyarwanda",
        "Komi",
        "Kongo",
        "Konkani",
        "Korean",
        "Koro",
        "KoyraboroSenni",
        "KoyraChiini",
        "Kpelle",
        "Kuanyama",
        "Kurdish",
        "Kwasio",
        "Kyrgyz",
        "Lakota",
        "Langi",
        "Lao",
        "Latin",
        "Latvian",
        "Lezghian",
        "Limburgish",
        "Lingala",
        "LiteraryChinese",
        "Lithuanian",
        "Lojban",
        "LowerSorbian",
        "LowGerman",
        "LubaKatanga",
        "LuleSami",
        "Luo",
        "Luxembourgish",
        "Luyia",
        "Macedonian",
        "Machame",
        "Maithili",
        "MakhuwaMeetto",
        "Makonde",
        "Malagasy",
        "Malayalam",
        "Malay",
        "Maltese",
        "Mandingo",
        "Manipuri",
        "Manx",
        "Maori",
        "Mapuche",
        "Marathi",
        "Marshallese",
        "Masai",
        "Mazanderani",
        "Mende",
        "Meru",
        "Meta",
        "Mohawk",
        "Mongolian",
        "Morisyen",
        "Mundang",
        "Muscogee",
        "Nama",
        "NauruLanguage",
        "Navajo",
        "Ndonga",
        "Nepali",
        "Newari",
        "Ngiemboon",
        "Ngomba",
        "NigerianPidgin",
        "Nko",
        "NorthernLuri",
        "NorthernSami",
        "NorthernSotho",
        "NorthNdebele",
        "NorwegianBokmal",
        "NorwegianNynorsk",
        "Nuer",
        "Nyanja",
        "Nyankole",
        "Occitan",
        "Odia",
        "Ojibwa",
        "OldIrish",
        "OldNorse",
        "OldPersian",
        "Oromo",
        "Osage",
        "Ossetic",
        "Pahlavi",
        "Palauan",
        "Pali",
        "Papiamento",
        "Pashto",
        "Persian",
        "Phoenician",
        "Polish",
        "Portuguese",
        "Prussian",
        "Punjabi",
        "Quechua",
        "Romanian",
        "Romansh",
        "Rombo",
        "Rundi",
        "Russian",
        "Rwa",
        "Saho",
        "Sakha",
        "Samburu",
        "Samoan",
        "Sango",
        "Sangu",
        "Sanskrit",
        "Santali",
        "Sardinian",
        "Saurashtra",
        "Sena",
        "Serbian",
        "Shambala",
        "Shona",
        "SichuanYi",
        "Sicilian",
        "Sidamo",
        "Silesian",
        "Sindhi",
        "Sinhala",
        "SkoltSami",
        "Slovak",
        "Slovenian",
        "Soga",
        "Somali",
        "SouthernKurdish",
        "SouthernSami",
        "SouthernSotho",
        "SouthNdebele",
        "Spanish",
        "StandardMoroccanTamazight",
        "Sundanese",
        "Swahili",
        "Swati",
        "Swedish",
        "SwissGerman",
        "Syriac",
        "Tachelhit",
        "Tahitian",
        "TaiDam",
        "Taita",
        "Tajik",
        "Tamil",
        "Taroko",
        "Tasawaq",
        "Tatar",
        "Telugu",
        "Teso",
        "Thai",
        "Tibetan",
        "Tigre",
        "Tigrinya",
        "TokelauLanguage",
        "TokPisin",
        "Tongan",
        "Tsonga",
        "Tswana",
        "Turkish",
        "Turkmen",
        "TuvaluLanguage",
        "Tyap",
        "Ugaritic",
        "Ukrainian",
        "UpperSorbian",
        "Urdu",
        "Uyghur",
        "Uzbek",
        "Vai",
        "Venda",
        "Vietnamese",
        "Volapuk",
        "Vunjo",
        "Walloon",
        "Walser",
        "Warlpiri",
        "Welsh",
        "WesternBalochi",
        "WesternFrisian",
        "Wolaytta",
        "Wolof",
        "Xhosa",
        "Yangben",
        "Yiddish",
        "Yoruba",
        "Zarma",
        "Zhuang",
        "Zulu",
        "Kaingang",
        "Nheengatu",
        "Haryanvi",
        "NorthernFrisian",
        "Rajasthani",
        "Moksha",
        "TokiPona",
        "Pijin",
        "Obolo",
        "Baluchi",
        "Ligurian",
        "Rohingya",
        "Torwali",
        "Anii",
        "Kangri",
        "Venetian",
        "Afan",
        "Bengali",
        "Bhutani",
        "Byelorussian",
        "Cambodian",
        "CentralMoroccoTamazight",
        "Chewa",
        "Frisian",
        "Greenlandic",
        "Inupiak",
        "Kirghiz",
        "Kurundi",
        "Kwanyama",
        "Navaho",
        "Oriya",
        "RhaetoRomance",
        "Uighur",
        "Uigur",
        "Walamo",
        "LastLanguage",
        nullptr};
    // "uint16_t" used instead of "unsigned short"
    constexpr uint16_t Language_InitializerValues[] = {
        uint16_t(QLocale::Language::AnyLanguage),               //  0x0000  0
        uint16_t(QLocale::Language::C),                         //  0x0001  1
        uint16_t(QLocale::Language::Abkhazian),                 //  0x0002  2
        uint16_t(QLocale::Language::Afar),                      //  0x0003  3
        uint16_t(QLocale::Language::Afrikaans),                 //  0x0004  4
        uint16_t(QLocale::Language::Aghem),                     //  0x0005  5
        uint16_t(QLocale::Language::Akan),                      //  0x0006  6
        uint16_t(QLocale::Language::Akkadian),                  //  0x0007  7
        uint16_t(QLocale::Language::Akoose),                    //  0x0008  8
        uint16_t(QLocale::Language::Albanian),                  //  0x0009  9
        uint16_t(QLocale::Language::AmericanSignLanguage),      //  0x000a  10
        uint16_t(QLocale::Language::Amharic),                   //  0x000b  11
        uint16_t(QLocale::Language::AncientEgyptian),           //  0x000c  12
        uint16_t(QLocale::Language::AncientGreek),              //  0x000d  13
        uint16_t(QLocale::Language::Arabic),                    //  0x000e  14
        uint16_t(QLocale::Language::Aragonese),                 //  0x000f  15
        uint16_t(QLocale::Language::Aramaic),                   //  0x0010  16
        uint16_t(QLocale::Language::Armenian),                  //  0x0011  17
        uint16_t(QLocale::Language::Assamese),                  //  0x0012  18
        uint16_t(QLocale::Language::Asturian),                  //  0x0013  19
        uint16_t(QLocale::Language::Asu),                       //  0x0014  20
        uint16_t(QLocale::Language::Atsam),                     //  0x0015  21
        uint16_t(QLocale::Language::Avaric),                    //  0x0016  22
        uint16_t(QLocale::Language::Avestan),                   //  0x0017  23
        uint16_t(QLocale::Language::Aymara),                    //  0x0018  24
        uint16_t(QLocale::Language::Azerbaijani),               //  0x0019  25
        uint16_t(QLocale::Language::Bafia),                     //  0x001a  26
        uint16_t(QLocale::Language::Balinese),                  //  0x001b  27
        uint16_t(QLocale::Language::Bambara),                   //  0x001c  28
        uint16_t(QLocale::Language::Bamun),                     //  0x001d  29
        uint16_t(QLocale::Language::Bangla),                    //  0x001e  30
        uint16_t(QLocale::Language::Basaa),                     //  0x001f  31
        uint16_t(QLocale::Language::Bashkir),                   //  0x0020  32
        uint16_t(QLocale::Language::Basque),                    //  0x0021  33
        uint16_t(QLocale::Language::BatakToba),                 //  0x0022  34
        uint16_t(QLocale::Language::Belarusian),                //  0x0023  35
        uint16_t(QLocale::Language::Bemba),                     //  0x0024  36
        uint16_t(QLocale::Language::Bena),                      //  0x0025  37
        uint16_t(QLocale::Language::Bhojpuri),                  //  0x0026  38
        uint16_t(QLocale::Language::Bislama),                   //  0x0027  39
        uint16_t(QLocale::Language::Blin),                      //  0x0028  40
        uint16_t(QLocale::Language::Bodo),                      //  0x0029  41
        uint16_t(QLocale::Language::Bosnian),                   //  0x002a  42
        uint16_t(QLocale::Language::Breton),                    //  0x002b  43
        uint16_t(QLocale::Language::Buginese),                  //  0x002c  44
        uint16_t(QLocale::Language::Bulgarian),                 //  0x002d  45
        uint16_t(QLocale::Language::Burmese),                   //  0x002e  46
        uint16_t(QLocale::Language::Cantonese),                 //  0x002f  47
        uint16_t(QLocale::Language::Catalan),                   //  0x0030  48
        uint16_t(QLocale::Language::Cebuano),                   //  0x0031  49
        uint16_t(QLocale::Language::CentralAtlasTamazight),     //  0x0032  50
        uint16_t(QLocale::Language::CentralKurdish),            //  0x0033  51
        uint16_t(QLocale::Language::Chakma),                    //  0x0034  52
        uint16_t(QLocale::Language::Chamorro),                  //  0x0035  53
        uint16_t(QLocale::Language::Chechen),                   //  0x0036  54
        uint16_t(QLocale::Language::Cherokee),                  //  0x0037  55
        uint16_t(QLocale::Language::Chickasaw),                 //  0x0038  56
        uint16_t(QLocale::Language::Chiga),                     //  0x0039  57
        uint16_t(QLocale::Language::Chinese),                   //  0x003a  58
        uint16_t(QLocale::Language::Church),                    //  0x003b  59
        uint16_t(QLocale::Language::Chuvash),                   //  0x003c  60
        uint16_t(QLocale::Language::Colognian),                 //  0x003d  61
        uint16_t(QLocale::Language::Coptic),                    //  0x003e  62
        uint16_t(QLocale::Language::Cornish),                   //  0x003f  63
        uint16_t(QLocale::Language::Corsican),                  //  0x0040  64
        uint16_t(QLocale::Language::Cree),                      //  0x0041  65
        uint16_t(QLocale::Language::Croatian),                  //  0x0042  66
        uint16_t(QLocale::Language::Czech),                     //  0x0043  67
        uint16_t(QLocale::Language::Danish),                    //  0x0044  68
        uint16_t(QLocale::Language::Divehi),                    //  0x0045  69
        uint16_t(QLocale::Language::Dogri),                     //  0x0046  70
        uint16_t(QLocale::Language::Duala),                     //  0x0047  71
        uint16_t(QLocale::Language::Dutch),                     //  0x0048  72
        uint16_t(QLocale::Language::Dzongkha),                  //  0x0049  73
        uint16_t(QLocale::Language::Embu),                      //  0x004a  74
        uint16_t(QLocale::Language::English),                   //  0x004b  75
        uint16_t(QLocale::Language::Erzya),                     //  0x004c  76
        uint16_t(QLocale::Language::Esperanto),                 //  0x004d  77
        uint16_t(QLocale::Language::Estonian),                  //  0x004e  78
        uint16_t(QLocale::Language::Ewe),                       //  0x004f  79
        uint16_t(QLocale::Language::Ewondo),                    //  0x0050  80
        uint16_t(QLocale::Language::Faroese),                   //  0x0051  81
        uint16_t(QLocale::Language::Fijian),                    //  0x0052  82
        uint16_t(QLocale::Language::Filipino),                  //  0x0053  83
        uint16_t(QLocale::Language::Finnish),                   //  0x0054  84
        uint16_t(QLocale::Language::French),                    //  0x0055  85
        uint16_t(QLocale::Language::Friulian),                  //  0x0056  86
        uint16_t(QLocale::Language::Fulah),                     //  0x0057  87
        uint16_t(QLocale::Language::Gaelic),                    //  0x0058  88
        uint16_t(QLocale::Language::Ga),                        //  0x0059  89
        uint16_t(QLocale::Language::Galician),                  //  0x005a  90
        uint16_t(QLocale::Language::Ganda),                     //  0x005b  91
        uint16_t(QLocale::Language::Geez),                      //  0x005c  92
        uint16_t(QLocale::Language::Georgian),                  //  0x005d  93
        uint16_t(QLocale::Language::German),                    //  0x005e  94
        uint16_t(QLocale::Language::Gothic),                    //  0x005f  95
        uint16_t(QLocale::Language::Greek),                     //  0x0060  96
        uint16_t(QLocale::Language::Guarani),                   //  0x0061  97
        uint16_t(QLocale::Language::Gujarati),                  //  0x0062  98
        uint16_t(QLocale::Language::Gusii),                     //  0x0063  99
        uint16_t(QLocale::Language::Haitian),                   //  0x0064  100
        uint16_t(QLocale::Language::Hausa),                     //  0x0065  101
        uint16_t(QLocale::Language::Hawaiian),                  //  0x0066  102
        uint16_t(QLocale::Language::Hebrew),                    //  0x0067  103
        uint16_t(QLocale::Language::Herero),                    //  0x0068  104
        uint16_t(QLocale::Language::Hindi),                     //  0x0069  105
        uint16_t(QLocale::Language::HiriMotu),                  //  0x006a  106
        uint16_t(QLocale::Language::Hungarian),                 //  0x006b  107
        uint16_t(QLocale::Language::Icelandic),                 //  0x006c  108
        uint16_t(QLocale::Language::Ido),                       //  0x006d  109
        uint16_t(QLocale::Language::Igbo),                      //  0x006e  110
        uint16_t(QLocale::Language::InariSami),                 //  0x006f  111
        uint16_t(QLocale::Language::Indonesian),                //  0x0070  112
        uint16_t(QLocale::Language::Ingush),                    //  0x0071  113
        uint16_t(QLocale::Language::Interlingua),               //  0x0072  114
        uint16_t(QLocale::Language::Interlingue),               //  0x0073  115
        uint16_t(QLocale::Language::Inuktitut),                 //  0x0074  116
        uint16_t(QLocale::Language::Inupiaq),                   //  0x0075  117
        uint16_t(QLocale::Language::Irish),                     //  0x0076  118
        uint16_t(QLocale::Language::Italian),                   //  0x0077  119
        uint16_t(QLocale::Language::Japanese),                  //  0x0078  120
        uint16_t(QLocale::Language::Javanese),                  //  0x0079  121
        uint16_t(QLocale::Language::Jju),                       //  0x007a  122
        uint16_t(QLocale::Language::JolaFonyi),                 //  0x007b  123
        uint16_t(QLocale::Language::Kabuverdianu),              //  0x007c  124
        uint16_t(QLocale::Language::Kabyle),                    //  0x007d  125
        uint16_t(QLocale::Language::Kako),                      //  0x007e  126
        uint16_t(QLocale::Language::Kalaallisut),               //  0x007f  127
        uint16_t(QLocale::Language::Kalenjin),                  //  0x0080  128
        uint16_t(QLocale::Language::Kamba),                     //  0x0081  129
        uint16_t(QLocale::Language::Kannada),                   //  0x0082  130
        uint16_t(QLocale::Language::Kanuri),                    //  0x0083  131
        uint16_t(QLocale::Language::Kashmiri),                  //  0x0084  132
        uint16_t(QLocale::Language::Kazakh),                    //  0x0085  133
        uint16_t(QLocale::Language::Kenyang),                   //  0x0086  134
        uint16_t(QLocale::Language::Khmer),                     //  0x0087  135
        uint16_t(QLocale::Language::Kiche),                     //  0x0088  136
        uint16_t(QLocale::Language::Kikuyu),                    //  0x0089  137
        uint16_t(QLocale::Language::Kinyarwanda),               //  0x008a  138
        uint16_t(QLocale::Language::Komi),                      //  0x008b  139
        uint16_t(QLocale::Language::Kongo),                     //  0x008c  140
        uint16_t(QLocale::Language::Konkani),                   //  0x008d  141
        uint16_t(QLocale::Language::Korean),                    //  0x008e  142
        uint16_t(QLocale::Language::Koro),                      //  0x008f  143
        uint16_t(QLocale::Language::KoyraboroSenni),            //  0x0090  144
        uint16_t(QLocale::Language::KoyraChiini),               //  0x0091  145
        uint16_t(QLocale::Language::Kpelle),                    //  0x0092  146
        uint16_t(QLocale::Language::Kuanyama),                  //  0x0093  147
        uint16_t(QLocale::Language::Kurdish),                   //  0x0094  148
        uint16_t(QLocale::Language::Kwasio),                    //  0x0095  149
        uint16_t(QLocale::Language::Kyrgyz),                    //  0x0096  150
        uint16_t(QLocale::Language::Lakota),                    //  0x0097  151
        uint16_t(QLocale::Language::Langi),                     //  0x0098  152
        uint16_t(QLocale::Language::Lao),                       //  0x0099  153
        uint16_t(QLocale::Language::Latin),                     //  0x009a  154
        uint16_t(QLocale::Language::Latvian),                   //  0x009b  155
        uint16_t(QLocale::Language::Lezghian),                  //  0x009c  156
        uint16_t(QLocale::Language::Limburgish),                //  0x009d  157
        uint16_t(QLocale::Language::Lingala),                   //  0x009e  158
        uint16_t(QLocale::Language::LiteraryChinese),           //  0x009f  159
        uint16_t(QLocale::Language::Lithuanian),                //  0x00a0  160
        uint16_t(QLocale::Language::Lojban),                    //  0x00a1  161
        uint16_t(QLocale::Language::LowerSorbian),              //  0x00a2  162
        uint16_t(QLocale::Language::LowGerman),                 //  0x00a3  163
        uint16_t(QLocale::Language::LubaKatanga),               //  0x00a4  164
        uint16_t(QLocale::Language::LuleSami),                  //  0x00a5  165
        uint16_t(QLocale::Language::Luo),                       //  0x00a6  166
        uint16_t(QLocale::Language::Luxembourgish),             //  0x00a7  167
        uint16_t(QLocale::Language::Luyia),                     //  0x00a8  168
        uint16_t(QLocale::Language::Macedonian),                //  0x00a9  169
        uint16_t(QLocale::Language::Machame),                   //  0x00aa  170
        uint16_t(QLocale::Language::Maithili),                  //  0x00ab  171
        uint16_t(QLocale::Language::MakhuwaMeetto),             //  0x00ac  172
        uint16_t(QLocale::Language::Makonde),                   //  0x00ad  173
        uint16_t(QLocale::Language::Malagasy),                  //  0x00ae  174
        uint16_t(QLocale::Language::Malayalam),                 //  0x00af  175
        uint16_t(QLocale::Language::Malay),                     //  0x00b0  176
        uint16_t(QLocale::Language::Maltese),                   //  0x00b1  177
        uint16_t(QLocale::Language::Mandingo),                  //  0x00b2  178
        uint16_t(QLocale::Language::Manipuri),                  //  0x00b3  179
        uint16_t(QLocale::Language::Manx),                      //  0x00b4  180
        uint16_t(QLocale::Language::Maori),                     //  0x00b5  181
        uint16_t(QLocale::Language::Mapuche),                   //  0x00b6  182
        uint16_t(QLocale::Language::Marathi),                   //  0x00b7  183
        uint16_t(QLocale::Language::Marshallese),               //  0x00b8  184
        uint16_t(QLocale::Language::Masai),                     //  0x00b9  185
        uint16_t(QLocale::Language::Mazanderani),               //  0x00ba  186
        uint16_t(QLocale::Language::Mende),                     //  0x00bb  187
        uint16_t(QLocale::Language::Meru),                      //  0x00bc  188
        uint16_t(QLocale::Language::Meta),                      //  0x00bd  189
        uint16_t(QLocale::Language::Mohawk),                    //  0x00be  190
        uint16_t(QLocale::Language::Mongolian),                 //  0x00bf  191
        uint16_t(QLocale::Language::Morisyen),                  //  0x00c0  192
        uint16_t(QLocale::Language::Mundang),                   //  0x00c1  193
        uint16_t(QLocale::Language::Muscogee),                  //  0x00c2  194
        uint16_t(QLocale::Language::Nama),                      //  0x00c3  195
        uint16_t(QLocale::Language::NauruLanguage),             //  0x00c4  196
        uint16_t(QLocale::Language::Navajo),                    //  0x00c5  197
        uint16_t(QLocale::Language::Ndonga),                    //  0x00c6  198
        uint16_t(QLocale::Language::Nepali),                    //  0x00c7  199
        uint16_t(QLocale::Language::Newari),                    //  0x00c8  200
        uint16_t(QLocale::Language::Ngiemboon),                 //  0x00c9  201
        uint16_t(QLocale::Language::Ngomba),                    //  0x00ca  202
        uint16_t(QLocale::Language::NigerianPidgin),            //  0x00cb  203
        uint16_t(QLocale::Language::Nko),                       //  0x00cc  204
        uint16_t(QLocale::Language::NorthernLuri),              //  0x00cd  205
        uint16_t(QLocale::Language::NorthernSami),              //  0x00ce  206
        uint16_t(QLocale::Language::NorthernSotho),             //  0x00cf  207
        uint16_t(QLocale::Language::NorthNdebele),              //  0x00d0  208
        uint16_t(QLocale::Language::NorwegianBokmal),           //  0x00d1  209
        uint16_t(QLocale::Language::NorwegianNynorsk),          //  0x00d2  210
        uint16_t(QLocale::Language::Nuer),                      //  0x00d3  211
        uint16_t(QLocale::Language::Nyanja),                    //  0x00d4  212
        uint16_t(QLocale::Language::Nyankole),                  //  0x00d5  213
        uint16_t(QLocale::Language::Occitan),                   //  0x00d6  214
        uint16_t(QLocale::Language::Odia),                      //  0x00d7  215
        uint16_t(QLocale::Language::Ojibwa),                    //  0x00d8  216
        uint16_t(QLocale::Language::OldIrish),                  //  0x00d9  217
        uint16_t(QLocale::Language::OldNorse),                  //  0x00da  218
        uint16_t(QLocale::Language::OldPersian),                //  0x00db  219
        uint16_t(QLocale::Language::Oromo),                     //  0x00dc  220
        uint16_t(QLocale::Language::Osage),                     //  0x00dd  221
        uint16_t(QLocale::Language::Ossetic),                   //  0x00de  222
        uint16_t(QLocale::Language::Pahlavi),                   //  0x00df  223
        uint16_t(QLocale::Language::Palauan),                   //  0x00e0  224
        uint16_t(QLocale::Language::Pali),                      //  0x00e1  225
        uint16_t(QLocale::Language::Papiamento),                //  0x00e2  226
        uint16_t(QLocale::Language::Pashto),                    //  0x00e3  227
        uint16_t(QLocale::Language::Persian),                   //  0x00e4  228
        uint16_t(QLocale::Language::Phoenician),                //  0x00e5  229
        uint16_t(QLocale::Language::Polish),                    //  0x00e6  230
        uint16_t(QLocale::Language::Portuguese),                //  0x00e7  231
        uint16_t(QLocale::Language::Prussian),                  //  0x00e8  232
        uint16_t(QLocale::Language::Punjabi),                   //  0x00e9  233
        uint16_t(QLocale::Language::Quechua),                   //  0x00ea  234
        uint16_t(QLocale::Language::Romanian),                  //  0x00eb  235
        uint16_t(QLocale::Language::Romansh),                   //  0x00ec  236
        uint16_t(QLocale::Language::Rombo),                     //  0x00ed  237
        uint16_t(QLocale::Language::Rundi),                     //  0x00ee  238
        uint16_t(QLocale::Language::Russian),                   //  0x00ef  239
        uint16_t(QLocale::Language::Rwa),                       //  0x00f0  240
        uint16_t(QLocale::Language::Saho),                      //  0x00f1  241
        uint16_t(QLocale::Language::Sakha),                     //  0x00f2  242
        uint16_t(QLocale::Language::Samburu),                   //  0x00f3  243
        uint16_t(QLocale::Language::Samoan),                    //  0x00f4  244
        uint16_t(QLocale::Language::Sango),                     //  0x00f5  245
        uint16_t(QLocale::Language::Sangu),                     //  0x00f6  246
        uint16_t(QLocale::Language::Sanskrit),                  //  0x00f7  247
        uint16_t(QLocale::Language::Santali),                   //  0x00f8  248
        uint16_t(QLocale::Language::Sardinian),                 //  0x00f9  249
        uint16_t(QLocale::Language::Saurashtra),                //  0x00fa  250
        uint16_t(QLocale::Language::Sena),                      //  0x00fb  251
        uint16_t(QLocale::Language::Serbian),                   //  0x00fc  252
        uint16_t(QLocale::Language::Shambala),                  //  0x00fd  253
        uint16_t(QLocale::Language::Shona),                     //  0x00fe  254
        uint16_t(QLocale::Language::SichuanYi),                 //  0x00ff  255
        uint16_t(QLocale::Language::Sicilian),                  //  0x0100  256
        uint16_t(QLocale::Language::Sidamo),                    //  0x0101  257
        uint16_t(QLocale::Language::Silesian),                  //  0x0102  258
        uint16_t(QLocale::Language::Sindhi),                    //  0x0103  259
        uint16_t(QLocale::Language::Sinhala),                   //  0x0104  260
        uint16_t(QLocale::Language::SkoltSami),                 //  0x0105  261
        uint16_t(QLocale::Language::Slovak),                    //  0x0106  262
        uint16_t(QLocale::Language::Slovenian),                 //  0x0107  263
        uint16_t(QLocale::Language::Soga),                      //  0x0108  264
        uint16_t(QLocale::Language::Somali),                    //  0x0109  265
        uint16_t(QLocale::Language::SouthernKurdish),           //  0x010a  266
        uint16_t(QLocale::Language::SouthernSami),              //  0x010b  267
        uint16_t(QLocale::Language::SouthernSotho),             //  0x010c  268
        uint16_t(QLocale::Language::SouthNdebele),              //  0x010d  269
        uint16_t(QLocale::Language::Spanish),                   //  0x010e  270
        uint16_t(QLocale::Language::StandardMoroccanTamazight), //  0x010f  271
        uint16_t(QLocale::Language::Sundanese),                 //  0x0110  272
        uint16_t(QLocale::Language::Swahili),                   //  0x0111  273
        uint16_t(QLocale::Language::Swati),                     //  0x0112  274
        uint16_t(QLocale::Language::Swedish),                   //  0x0113  275
        uint16_t(QLocale::Language::SwissGerman),               //  0x0114  276
        uint16_t(QLocale::Language::Syriac),                    //  0x0115  277
        uint16_t(QLocale::Language::Tachelhit),                 //  0x0116  278
        uint16_t(QLocale::Language::Tahitian),                  //  0x0117  279
        uint16_t(QLocale::Language::TaiDam),                    //  0x0118  280
        uint16_t(QLocale::Language::Taita),                     //  0x0119  281
        uint16_t(QLocale::Language::Tajik),                     //  0x011a  282
        uint16_t(QLocale::Language::Tamil),                     //  0x011b  283
        uint16_t(QLocale::Language::Taroko),                    //  0x011c  284
        uint16_t(QLocale::Language::Tasawaq),                   //  0x011d  285
        uint16_t(QLocale::Language::Tatar),                     //  0x011e  286
        uint16_t(QLocale::Language::Telugu),                    //  0x011f  287
        uint16_t(QLocale::Language::Teso),                      //  0x0120  288
        uint16_t(QLocale::Language::Thai),                      //  0x0121  289
        uint16_t(QLocale::Language::Tibetan),                   //  0x0122  290
        uint16_t(QLocale::Language::Tigre),                     //  0x0123  291
        uint16_t(QLocale::Language::Tigrinya),                  //  0x0124  292
        uint16_t(QLocale::Language::TokelauLanguage),           //  0x0125  293
        uint16_t(QLocale::Language::TokPisin),                  //  0x0126  294
        uint16_t(QLocale::Language::Tongan),                    //  0x0127  295
        uint16_t(QLocale::Language::Tsonga),                    //  0x0128  296
        uint16_t(QLocale::Language::Tswana),                    //  0x0129  297
        uint16_t(QLocale::Language::Turkish),                   //  0x012a  298
        uint16_t(QLocale::Language::Turkmen),                   //  0x012b  299
        uint16_t(QLocale::Language::TuvaluLanguage),            //  0x012c  300
        uint16_t(QLocale::Language::Tyap),                      //  0x012d  301
        uint16_t(QLocale::Language::Ugaritic),                  //  0x012e  302
        uint16_t(QLocale::Language::Ukrainian),                 //  0x012f  303
        uint16_t(QLocale::Language::UpperSorbian),              //  0x0130  304
        uint16_t(QLocale::Language::Urdu),                      //  0x0131  305
        uint16_t(QLocale::Language::Uyghur),                    //  0x0132  306
        uint16_t(QLocale::Language::Uzbek),                     //  0x0133  307
        uint16_t(QLocale::Language::Vai),                       //  0x0134  308
        uint16_t(QLocale::Language::Venda),                     //  0x0135  309
        uint16_t(QLocale::Language::Vietnamese),                //  0x0136  310
        uint16_t(QLocale::Language::Volapuk),                   //  0x0137  311
        uint16_t(QLocale::Language::Vunjo),                     //  0x0138  312
        uint16_t(QLocale::Language::Walloon),                   //  0x0139  313
        uint16_t(QLocale::Language::Walser),                    //  0x013a  314
        uint16_t(QLocale::Language::Warlpiri),                  //  0x013b  315
        uint16_t(QLocale::Language::Welsh),                     //  0x013c  316
        uint16_t(QLocale::Language::WesternBalochi),            //  0x013d  317
        uint16_t(QLocale::Language::WesternFrisian),            //  0x013e  318
        uint16_t(QLocale::Language::Wolaytta),                  //  0x013f  319
        uint16_t(QLocale::Language::Wolof),                     //  0x0140  320
        uint16_t(QLocale::Language::Xhosa),                     //  0x0141  321
        uint16_t(QLocale::Language::Yangben),                   //  0x0142  322
        uint16_t(QLocale::Language::Yiddish),                   //  0x0143  323
        uint16_t(QLocale::Language::Yoruba),                    //  0x0144  324
        uint16_t(QLocale::Language::Zarma),                     //  0x0145  325
        uint16_t(QLocale::Language::Zhuang),                    //  0x0146  326
        uint16_t(QLocale::Language::Zulu),                      //  0x0147  327
        uint16_t(QLocale::Language::Kaingang),                  //  0x0148  328
        uint16_t(QLocale::Language::Nheengatu),                 //  0x0149  329
        uint16_t(QLocale::Language::Haryanvi),                  //  0x014a  330
        uint16_t(QLocale::Language::NorthernFrisian),           //  0x014b  331
        uint16_t(QLocale::Language::Rajasthani),                //  0x014c  332
        uint16_t(QLocale::Language::Moksha),                    //  0x014d  333
        uint16_t(QLocale::Language::TokiPona),                  //  0x014e  334
        uint16_t(QLocale::Language::Pijin),                     //  0x014f  335
        uint16_t(QLocale::Language::Obolo),                     //  0x0150  336
        uint16_t(QLocale::Language::Baluchi),                   //  0x0151  337
        uint16_t(QLocale::Language::Ligurian),                  //  0x0152  338
        uint16_t(QLocale::Language::Rohingya),                  //  0x0153  339
        uint16_t(QLocale::Language::Torwali),                   //  0x0154  340
        uint16_t(QLocale::Language::Anii),                      //  0x0155  341
        uint16_t(QLocale::Language::Kangri),                    //  0x0156  342
        uint16_t(QLocale::Language::Venetian),                  //  0x0157  343
        uint16_t(QLocale::Language::Afan),                      //  0x00dc  220
        uint16_t(QLocale::Language::Bengali),                   //  0x001e  30
        uint16_t(QLocale::Language::Bhutani),                   //  0x0049  73
        uint16_t(QLocale::Language::Byelorussian),              //  0x0023  35
        uint16_t(QLocale::Language::Cambodian),                 //  0x0087  135
        uint16_t(QLocale::Language::CentralMoroccoTamazight),   //  0x0032  50
        uint16_t(QLocale::Language::Chewa),                     //  0x00d4  212
        uint16_t(QLocale::Language::Frisian),                   //  0x013e  318
        uint16_t(QLocale::Language::Greenlandic),               //  0x007f  127
        uint16_t(QLocale::Language::Inupiak),                   //  0x0075  117
        uint16_t(QLocale::Language::Kirghiz),                   //  0x0096  150
        uint16_t(QLocale::Language::Kurundi),                   //  0x00ee  238
        uint16_t(QLocale::Language::Kwanyama),                  //  0x0093  147
        uint16_t(QLocale::Language::Navaho),                    //  0x00c5  197
        uint16_t(QLocale::Language::Oriya),                     //  0x00d7  215
        uint16_t(QLocale::Language::RhaetoRomance),             //  0x00ec  236
        uint16_t(QLocale::Language::Uighur),                    //  0x0132  306
        uint16_t(QLocale::Language::Uigur),                     //  0x0132  306
        uint16_t(QLocale::Language::Walamo),                    //  0x013f  319
        uint16_t(QLocale::Language::LastLanguage)               //  0x0157  343
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLocale_TypeF(),
        "2:PySide6.QtCore.QLocale.Language",
        Language_Initializer, Language_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Language_IDX].type = EType;
    // Register converter for enum 'QLocale::Language'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLocale_Language_CppToPython_QLocale_Language);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QLocale_Language_PythonToCpp_QLocale_Language,
            is_QLocale_Language_PythonToCpp_QLocale_Language_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QLocale::Language");
        Shiboken::Conversions::registerConverterName(converter, "Language");
    }
    // End of 'Language' enum.

    // Initialization of enum 'Script'.
    const char *Script_Initializer[] = {
        "AnyScript",
        "AdlamScript",
        "AhomScript",
        "AnatolianHieroglyphsScript",
        "ArabicScript",
        "ArmenianScript",
        "AvestanScript",
        "BalineseScript",
        "BamumScript",
        "BanglaScript",
        "BassaVahScript",
        "BatakScript",
        "BhaiksukiScript",
        "BopomofoScript",
        "BrahmiScript",
        "BrailleScript",
        "BugineseScript",
        "BuhidScript",
        "CanadianAboriginalScript",
        "CarianScript",
        "CaucasianAlbanianScript",
        "ChakmaScript",
        "ChamScript",
        "CherokeeScript",
        "CopticScript",
        "CuneiformScript",
        "CypriotScript",
        "CyrillicScript",
        "DeseretScript",
        "DevanagariScript",
        "DuployanScript",
        "EgyptianHieroglyphsScript",
        "ElbasanScript",
        "EthiopicScript",
        "FraserScript",
        "GeorgianScript",
        "GlagoliticScript",
        "GothicScript",
        "GranthaScript",
        "GreekScript",
        "GujaratiScript",
        "GurmukhiScript",
        "HangulScript",
        "HanScript",
        "HanunooScript",
        "HanWithBopomofoScript",
        "HatranScript",
        "HebrewScript",
        "HiraganaScript",
        "ImperialAramaicScript",
        "InscriptionalPahlaviScript",
        "InscriptionalParthianScript",
        "JamoScript",
        "JapaneseScript",
        "JavaneseScript",
        "KaithiScript",
        "KannadaScript",
        "KatakanaScript",
        "KayahLiScript",
        "KharoshthiScript",
        "KhmerScript",
        "KhojkiScript",
        "KhudawadiScript",
        "KoreanScript",
        "LannaScript",
        "LaoScript",
        "LatinScript",
        "LepchaScript",
        "LimbuScript",
        "LinearAScript",
        "LinearBScript",
        "LycianScript",
        "LydianScript",
        "MahajaniScript",
        "MalayalamScript",
        "MandaeanScript",
        "ManichaeanScript",
        "MarchenScript",
        "MeiteiMayekScript",
        "MendeScript",
        "MeroiticCursiveScript",
        "MeroiticScript",
        "ModiScript",
        "MongolianScript",
        "MroScript",
        "MultaniScript",
        "MyanmarScript",
        "NabataeanScript",
        "NewaScript",
        "NewTaiLueScript",
        "NkoScript",
        "OdiaScript",
        "OghamScript",
        "OlChikiScript",
        "OldHungarianScript",
        "OldItalicScript",
        "OldNorthArabianScript",
        "OldPermicScript",
        "OldPersianScript",
        "OldSouthArabianScript",
        "OrkhonScript",
        "OsageScript",
        "OsmanyaScript",
        "PahawhHmongScript",
        "PalmyreneScript",
        "PauCinHauScript",
        "PhagsPaScript",
        "PhoenicianScript",
        "PollardPhoneticScript",
        "PsalterPahlaviScript",
        "RejangScript",
        "RunicScript",
        "SamaritanScript",
        "SaurashtraScript",
        "SharadaScript",
        "ShavianScript",
        "SiddhamScript",
        "SignWritingScript",
        "SimplifiedHanScript",
        "SinhalaScript",
        "SoraSompengScript",
        "SundaneseScript",
        "SylotiNagriScript",
        "SyriacScript",
        "TagalogScript",
        "TagbanwaScript",
        "TaiLeScript",
        "TaiVietScript",
        "TakriScript",
        "TamilScript",
        "TangutScript",
        "TeluguScript",
        "ThaanaScript",
        "ThaiScript",
        "TibetanScript",
        "TifinaghScript",
        "TirhutaScript",
        "TraditionalHanScript",
        "UgariticScript",
        "VaiScript",
        "VarangKshitiScript",
        "YiScript",
        "HanifiScript",
        "BengaliScript",
        "MendeKikakuiScript",
        "OriyaScript",
        "SimplifiedChineseScript",
        "TraditionalChineseScript",
        "LastScript",
        nullptr};
    // "uint8_t" used instead of "unsigned short"
    constexpr uint8_t Script_InitializerValues[] = {
        uint8_t(QLocale::Script::AnyScript),                   //  0x00  0
        uint8_t(QLocale::Script::AdlamScript),                 //  0x01  1
        uint8_t(QLocale::Script::AhomScript),                  //  0x02  2
        uint8_t(QLocale::Script::AnatolianHieroglyphsScript),  //  0x03  3
        uint8_t(QLocale::Script::ArabicScript),                //  0x04  4
        uint8_t(QLocale::Script::ArmenianScript),              //  0x05  5
        uint8_t(QLocale::Script::AvestanScript),               //  0x06  6
        uint8_t(QLocale::Script::BalineseScript),              //  0x07  7
        uint8_t(QLocale::Script::BamumScript),                 //  0x08  8
        uint8_t(QLocale::Script::BanglaScript),                //  0x09  9
        uint8_t(QLocale::Script::BassaVahScript),              //  0x0a  10
        uint8_t(QLocale::Script::BatakScript),                 //  0x0b  11
        uint8_t(QLocale::Script::BhaiksukiScript),             //  0x0c  12
        uint8_t(QLocale::Script::BopomofoScript),              //  0x0d  13
        uint8_t(QLocale::Script::BrahmiScript),                //  0x0e  14
        uint8_t(QLocale::Script::BrailleScript),               //  0x0f  15
        uint8_t(QLocale::Script::BugineseScript),              //  0x10  16
        uint8_t(QLocale::Script::BuhidScript),                 //  0x11  17
        uint8_t(QLocale::Script::CanadianAboriginalScript),    //  0x12  18
        uint8_t(QLocale::Script::CarianScript),                //  0x13  19
        uint8_t(QLocale::Script::CaucasianAlbanianScript),     //  0x14  20
        uint8_t(QLocale::Script::ChakmaScript),                //  0x15  21
        uint8_t(QLocale::Script::ChamScript),                  //  0x16  22
        uint8_t(QLocale::Script::CherokeeScript),              //  0x17  23
        uint8_t(QLocale::Script::CopticScript),                //  0x18  24
        uint8_t(QLocale::Script::CuneiformScript),             //  0x19  25
        uint8_t(QLocale::Script::CypriotScript),               //  0x1a  26
        uint8_t(QLocale::Script::CyrillicScript),              //  0x1b  27
        uint8_t(QLocale::Script::DeseretScript),               //  0x1c  28
        uint8_t(QLocale::Script::DevanagariScript),            //  0x1d  29
        uint8_t(QLocale::Script::DuployanScript),              //  0x1e  30
        uint8_t(QLocale::Script::EgyptianHieroglyphsScript),   //  0x1f  31
        uint8_t(QLocale::Script::ElbasanScript),               //  0x20  32
        uint8_t(QLocale::Script::EthiopicScript),              //  0x21  33
        uint8_t(QLocale::Script::FraserScript),                //  0x22  34
        uint8_t(QLocale::Script::GeorgianScript),              //  0x23  35
        uint8_t(QLocale::Script::GlagoliticScript),            //  0x24  36
        uint8_t(QLocale::Script::GothicScript),                //  0x25  37
        uint8_t(QLocale::Script::GranthaScript),               //  0x26  38
        uint8_t(QLocale::Script::GreekScript),                 //  0x27  39
        uint8_t(QLocale::Script::GujaratiScript),              //  0x28  40
        uint8_t(QLocale::Script::GurmukhiScript),              //  0x29  41
        uint8_t(QLocale::Script::HangulScript),                //  0x2a  42
        uint8_t(QLocale::Script::HanScript),                   //  0x2b  43
        uint8_t(QLocale::Script::HanunooScript),               //  0x2c  44
        uint8_t(QLocale::Script::HanWithBopomofoScript),       //  0x2d  45
        uint8_t(QLocale::Script::HatranScript),                //  0x2e  46
        uint8_t(QLocale::Script::HebrewScript),                //  0x2f  47
        uint8_t(QLocale::Script::HiraganaScript),              //  0x30  48
        uint8_t(QLocale::Script::ImperialAramaicScript),       //  0x31  49
        uint8_t(QLocale::Script::InscriptionalPahlaviScript),  //  0x32  50
        uint8_t(QLocale::Script::InscriptionalParthianScript), //  0x33  51
        uint8_t(QLocale::Script::JamoScript),                  //  0x34  52
        uint8_t(QLocale::Script::JapaneseScript),              //  0x35  53
        uint8_t(QLocale::Script::JavaneseScript),              //  0x36  54
        uint8_t(QLocale::Script::KaithiScript),                //  0x37  55
        uint8_t(QLocale::Script::KannadaScript),               //  0x38  56
        uint8_t(QLocale::Script::KatakanaScript),              //  0x39  57
        uint8_t(QLocale::Script::KayahLiScript),               //  0x3a  58
        uint8_t(QLocale::Script::KharoshthiScript),            //  0x3b  59
        uint8_t(QLocale::Script::KhmerScript),                 //  0x3c  60
        uint8_t(QLocale::Script::KhojkiScript),                //  0x3d  61
        uint8_t(QLocale::Script::KhudawadiScript),             //  0x3e  62
        uint8_t(QLocale::Script::KoreanScript),                //  0x3f  63
        uint8_t(QLocale::Script::LannaScript),                 //  0x40  64
        uint8_t(QLocale::Script::LaoScript),                   //  0x41  65
        uint8_t(QLocale::Script::LatinScript),                 //  0x42  66
        uint8_t(QLocale::Script::LepchaScript),                //  0x43  67
        uint8_t(QLocale::Script::LimbuScript),                 //  0x44  68
        uint8_t(QLocale::Script::LinearAScript),               //  0x45  69
        uint8_t(QLocale::Script::LinearBScript),               //  0x46  70
        uint8_t(QLocale::Script::LycianScript),                //  0x47  71
        uint8_t(QLocale::Script::LydianScript),                //  0x48  72
        uint8_t(QLocale::Script::MahajaniScript),              //  0x49  73
        uint8_t(QLocale::Script::MalayalamScript),             //  0x4a  74
        uint8_t(QLocale::Script::MandaeanScript),              //  0x4b  75
        uint8_t(QLocale::Script::ManichaeanScript),            //  0x4c  76
        uint8_t(QLocale::Script::MarchenScript),               //  0x4d  77
        uint8_t(QLocale::Script::MeiteiMayekScript),           //  0x4e  78
        uint8_t(QLocale::Script::MendeScript),                 //  0x4f  79
        uint8_t(QLocale::Script::MeroiticCursiveScript),       //  0x50  80
        uint8_t(QLocale::Script::MeroiticScript),              //  0x51  81
        uint8_t(QLocale::Script::ModiScript),                  //  0x52  82
        uint8_t(QLocale::Script::MongolianScript),             //  0x53  83
        uint8_t(QLocale::Script::MroScript),                   //  0x54  84
        uint8_t(QLocale::Script::MultaniScript),               //  0x55  85
        uint8_t(QLocale::Script::MyanmarScript),               //  0x56  86
        uint8_t(QLocale::Script::NabataeanScript),             //  0x57  87
        uint8_t(QLocale::Script::NewaScript),                  //  0x58  88
        uint8_t(QLocale::Script::NewTaiLueScript),             //  0x59  89
        uint8_t(QLocale::Script::NkoScript),                   //  0x5a  90
        uint8_t(QLocale::Script::OdiaScript),                  //  0x5b  91
        uint8_t(QLocale::Script::OghamScript),                 //  0x5c  92
        uint8_t(QLocale::Script::OlChikiScript),               //  0x5d  93
        uint8_t(QLocale::Script::OldHungarianScript),          //  0x5e  94
        uint8_t(QLocale::Script::OldItalicScript),             //  0x5f  95
        uint8_t(QLocale::Script::OldNorthArabianScript),       //  0x60  96
        uint8_t(QLocale::Script::OldPermicScript),             //  0x61  97
        uint8_t(QLocale::Script::OldPersianScript),            //  0x62  98
        uint8_t(QLocale::Script::OldSouthArabianScript),       //  0x63  99
        uint8_t(QLocale::Script::OrkhonScript),                //  0x64  100
        uint8_t(QLocale::Script::OsageScript),                 //  0x65  101
        uint8_t(QLocale::Script::OsmanyaScript),               //  0x66  102
        uint8_t(QLocale::Script::PahawhHmongScript),           //  0x67  103
        uint8_t(QLocale::Script::PalmyreneScript),             //  0x68  104
        uint8_t(QLocale::Script::PauCinHauScript),             //  0x69  105
        uint8_t(QLocale::Script::PhagsPaScript),               //  0x6a  106
        uint8_t(QLocale::Script::PhoenicianScript),            //  0x6b  107
        uint8_t(QLocale::Script::PollardPhoneticScript),       //  0x6c  108
        uint8_t(QLocale::Script::PsalterPahlaviScript),        //  0x6d  109
        uint8_t(QLocale::Script::RejangScript),                //  0x6e  110
        uint8_t(QLocale::Script::RunicScript),                 //  0x6f  111
        uint8_t(QLocale::Script::SamaritanScript),             //  0x70  112
        uint8_t(QLocale::Script::SaurashtraScript),            //  0x71  113
        uint8_t(QLocale::Script::SharadaScript),               //  0x72  114
        uint8_t(QLocale::Script::ShavianScript),               //  0x73  115
        uint8_t(QLocale::Script::SiddhamScript),               //  0x74  116
        uint8_t(QLocale::Script::SignWritingScript),           //  0x75  117
        uint8_t(QLocale::Script::SimplifiedHanScript),         //  0x76  118
        uint8_t(QLocale::Script::SinhalaScript),               //  0x77  119
        uint8_t(QLocale::Script::SoraSompengScript),           //  0x78  120
        uint8_t(QLocale::Script::SundaneseScript),             //  0x79  121
        uint8_t(QLocale::Script::SylotiNagriScript),           //  0x7a  122
        uint8_t(QLocale::Script::SyriacScript),                //  0x7b  123
        uint8_t(QLocale::Script::TagalogScript),               //  0x7c  124
        uint8_t(QLocale::Script::TagbanwaScript),              //  0x7d  125
        uint8_t(QLocale::Script::TaiLeScript),                 //  0x7e  126
        uint8_t(QLocale::Script::TaiVietScript),               //  0x7f  127
        uint8_t(QLocale::Script::TakriScript),                 //  0x80  128
        uint8_t(QLocale::Script::TamilScript),                 //  0x81  129
        uint8_t(QLocale::Script::TangutScript),                //  0x82  130
        uint8_t(QLocale::Script::TeluguScript),                //  0x83  131
        uint8_t(QLocale::Script::ThaanaScript),                //  0x84  132
        uint8_t(QLocale::Script::ThaiScript),                  //  0x85  133
        uint8_t(QLocale::Script::TibetanScript),               //  0x86  134
        uint8_t(QLocale::Script::TifinaghScript),              //  0x87  135
        uint8_t(QLocale::Script::TirhutaScript),               //  0x88  136
        uint8_t(QLocale::Script::TraditionalHanScript),        //  0x89  137
        uint8_t(QLocale::Script::UgariticScript),              //  0x8a  138
        uint8_t(QLocale::Script::VaiScript),                   //  0x8b  139
        uint8_t(QLocale::Script::VarangKshitiScript),          //  0x8c  140
        uint8_t(QLocale::Script::YiScript),                    //  0x8d  141
        uint8_t(QLocale::Script::HanifiScript),                //  0x8e  142
        uint8_t(QLocale::Script::BengaliScript),               //  0x09  9
        uint8_t(QLocale::Script::MendeKikakuiScript),          //  0x4f  79
        uint8_t(QLocale::Script::OriyaScript),                 //  0x5b  91
        uint8_t(QLocale::Script::SimplifiedChineseScript),     //  0x76  118
        uint8_t(QLocale::Script::TraditionalChineseScript),    //  0x89  137
        uint8_t(QLocale::Script::LastScript)                   //  0x8e  142
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLocale_TypeF(),
        "2:PySide6.QtCore.QLocale.Script",
        Script_Initializer, Script_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Script_IDX].type = EType;
    // Register converter for enum 'QLocale::Script'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLocale_Script_CppToPython_QLocale_Script);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QLocale_Script_PythonToCpp_QLocale_Script,
            is_QLocale_Script_PythonToCpp_QLocale_Script_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QLocale::Script");
        Shiboken::Conversions::registerConverterName(converter, "Script");
    }
    // End of 'Script' enum.

    // Initialization of enum 'Country'.
    const char *Country_Initializer[] = {
        "AnyTerritory",
        "Afghanistan",
        "AlandIslands",
        "Albania",
        "Algeria",
        "AmericanSamoa",
        "Andorra",
        "Angola",
        "Anguilla",
        "Antarctica",
        "AntiguaAndBarbuda",
        "Argentina",
        "Armenia",
        "Aruba",
        "AscensionIsland",
        "Australia",
        "Austria",
        "Azerbaijan",
        "Bahamas",
        "Bahrain",
        "Bangladesh",
        "Barbados",
        "Belarus",
        "Belgium",
        "Belize",
        "Benin",
        "Bermuda",
        "Bhutan",
        "Bolivia",
        "BosniaAndHerzegovina",
        "Botswana",
        "BouvetIsland",
        "Brazil",
        "BritishIndianOceanTerritory",
        "BritishVirginIslands",
        "Brunei",
        "Bulgaria",
        "BurkinaFaso",
        "Burundi",
        "Cambodia",
        "Cameroon",
        "Canada",
        "CanaryIslands",
        "CapeVerde",
        "CaribbeanNetherlands",
        "CaymanIslands",
        "CentralAfricanRepublic",
        "CeutaAndMelilla",
        "Chad",
        "Chile",
        "China",
        "ChristmasIsland",
        "ClippertonIsland",
        "CocosIslands",
        "Colombia",
        "Comoros",
        "CongoBrazzaville",
        "CongoKinshasa",
        "CookIslands",
        "CostaRica",
        "Croatia",
        "Cuba",
        "Curacao",
        "Cyprus",
        "Czechia",
        "Denmark",
        "DiegoGarcia",
        "Djibouti",
        "Dominica",
        "DominicanRepublic",
        "Ecuador",
        "Egypt",
        "ElSalvador",
        "EquatorialGuinea",
        "Eritrea",
        "Estonia",
        "Eswatini",
        "Ethiopia",
        "Europe",
        "EuropeanUnion",
        "FalklandIslands",
        "FaroeIslands",
        "Fiji",
        "Finland",
        "France",
        "FrenchGuiana",
        "FrenchPolynesia",
        "FrenchSouthernTerritories",
        "Gabon",
        "Gambia",
        "Georgia",
        "Germany",
        "Ghana",
        "Gibraltar",
        "Greece",
        "Greenland",
        "Grenada",
        "Guadeloupe",
        "Guam",
        "Guatemala",
        "Guernsey",
        "GuineaBissau",
        "Guinea",
        "Guyana",
        "Haiti",
        "HeardAndMcDonaldIslands",
        "Honduras",
        "HongKong",
        "Hungary",
        "Iceland",
        "India",
        "Indonesia",
        "Iran",
        "Iraq",
        "Ireland",
        "IsleOfMan",
        "Israel",
        "Italy",
        "IvoryCoast",
        "Jamaica",
        "Japan",
        "Jersey",
        "Jordan",
        "Kazakhstan",
        "Kenya",
        "Kiribati",
        "Kosovo",
        "Kuwait",
        "Kyrgyzstan",
        "Laos",
        "LatinAmerica",
        "Latvia",
        "Lebanon",
        "Lesotho",
        "Liberia",
        "Libya",
        "Liechtenstein",
        "Lithuania",
        "Luxembourg",
        "Macao",
        "Macedonia",
        "Madagascar",
        "Malawi",
        "Malaysia",
        "Maldives",
        "Mali",
        "Malta",
        "MarshallIslands",
        "Martinique",
        "Mauritania",
        "Mauritius",
        "Mayotte",
        "Mexico",
        "Micronesia",
        "Moldova",
        "Monaco",
        "Mongolia",
        "Montenegro",
        "Montserrat",
        "Morocco",
        "Mozambique",
        "Myanmar",
        "Namibia",
        "NauruTerritory",
        "Nepal",
        "Netherlands",
        "NewCaledonia",
        "NewZealand",
        "Nicaragua",
        "Nigeria",
        "Niger",
        "Niue",
        "NorfolkIsland",
        "NorthernMarianaIslands",
        "NorthKorea",
        "Norway",
        "Oman",
        "OutlyingOceania",
        "Pakistan",
        "Palau",
        "PalestinianTerritories",
        "Panama",
        "PapuaNewGuinea",
        "Paraguay",
        "Peru",
        "Philippines",
        "Pitcairn",
        "Poland",
        "Portugal",
        "PuertoRico",
        "Qatar",
        "Reunion",
        "Romania",
        "Russia",
        "Rwanda",
        "SaintBarthelemy",
        "SaintHelena",
        "SaintKittsAndNevis",
        "SaintLucia",
        "SaintMartin",
        "SaintPierreAndMiquelon",
        "SaintVincentAndGrenadines",
        "Samoa",
        "SanMarino",
        "SaoTomeAndPrincipe",
        "SaudiArabia",
        "Senegal",
        "Serbia",
        "Seychelles",
        "SierraLeone",
        "Singapore",
        "SintMaarten",
        "Slovakia",
        "Slovenia",
        "SolomonIslands",
        "Somalia",
        "SouthAfrica",
        "SouthGeorgiaAndSouthSandwichIslands",
        "SouthKorea",
        "SouthSudan",
        "Spain",
        "SriLanka",
        "Sudan",
        "Suriname",
        "SvalbardAndJanMayen",
        "Sweden",
        "Switzerland",
        "Syria",
        "Taiwan",
        "Tajikistan",
        "Tanzania",
        "Thailand",
        "TimorLeste",
        "Togo",
        "TokelauTerritory",
        "Tonga",
        "TrinidadAndTobago",
        "TristanDaCunha",
        "Tunisia",
        "Turkey",
        "Turkmenistan",
        "TurksAndCaicosIslands",
        "TuvaluTerritory",
        "Uganda",
        "Ukraine",
        "UnitedArabEmirates",
        "UnitedKingdom",
        "UnitedStatesOutlyingIslands",
        "UnitedStates",
        "UnitedStatesVirginIslands",
        "Uruguay",
        "Uzbekistan",
        "Vanuatu",
        "VaticanCity",
        "Venezuela",
        "Vietnam",
        "WallisAndFutuna",
        "WesternSahara",
        "World",
        "Yemen",
        "Zambia",
        "Zimbabwe",
        "AnyCountry",
        "Bonaire",
        "BosniaAndHerzegowina",
        "CuraSao",
        "CzechRepublic",
        "DemocraticRepublicOfCongo",
        "DemocraticRepublicOfKorea",
        "EastTimor",
        "LatinAmericaAndTheCaribbean",
        "Macau",
        "NauruCountry",
        "PeoplesRepublicOfCongo",
        "RepublicOfKorea",
        "RussianFederation",
        "SaintVincentAndTheGrenadines",
        "SouthGeorgiaAndTheSouthSandwichIslands",
        "SvalbardAndJanMayenIslands",
        "Swaziland",
        "SyrianArabRepublic",
        "TokelauCountry",
        "TuvaluCountry",
        "UnitedStatesMinorOutlyingIslands",
        "VaticanCityState",
        "WallisAndFutunaIslands",
        "LastTerritory",
        "LastCountry",
        nullptr};
    // "uint16_t" used instead of "unsigned short"
    constexpr uint16_t Country_InitializerValues[] = {
        uint16_t(QLocale::Country::AnyTerritory),                           //  0x0000  0
        uint16_t(QLocale::Country::Afghanistan),                            //  0x0001  1
        uint16_t(QLocale::Country::AlandIslands),                           //  0x0002  2
        uint16_t(QLocale::Country::Albania),                                //  0x0003  3
        uint16_t(QLocale::Country::Algeria),                                //  0x0004  4
        uint16_t(QLocale::Country::AmericanSamoa),                          //  0x0005  5
        uint16_t(QLocale::Country::Andorra),                                //  0x0006  6
        uint16_t(QLocale::Country::Angola),                                 //  0x0007  7
        uint16_t(QLocale::Country::Anguilla),                               //  0x0008  8
        uint16_t(QLocale::Country::Antarctica),                             //  0x0009  9
        uint16_t(QLocale::Country::AntiguaAndBarbuda),                      //  0x000a  10
        uint16_t(QLocale::Country::Argentina),                              //  0x000b  11
        uint16_t(QLocale::Country::Armenia),                                //  0x000c  12
        uint16_t(QLocale::Country::Aruba),                                  //  0x000d  13
        uint16_t(QLocale::Country::AscensionIsland),                        //  0x000e  14
        uint16_t(QLocale::Country::Australia),                              //  0x000f  15
        uint16_t(QLocale::Country::Austria),                                //  0x0010  16
        uint16_t(QLocale::Country::Azerbaijan),                             //  0x0011  17
        uint16_t(QLocale::Country::Bahamas),                                //  0x0012  18
        uint16_t(QLocale::Country::Bahrain),                                //  0x0013  19
        uint16_t(QLocale::Country::Bangladesh),                             //  0x0014  20
        uint16_t(QLocale::Country::Barbados),                               //  0x0015  21
        uint16_t(QLocale::Country::Belarus),                                //  0x0016  22
        uint16_t(QLocale::Country::Belgium),                                //  0x0017  23
        uint16_t(QLocale::Country::Belize),                                 //  0x0018  24
        uint16_t(QLocale::Country::Benin),                                  //  0x0019  25
        uint16_t(QLocale::Country::Bermuda),                                //  0x001a  26
        uint16_t(QLocale::Country::Bhutan),                                 //  0x001b  27
        uint16_t(QLocale::Country::Bolivia),                                //  0x001c  28
        uint16_t(QLocale::Country::BosniaAndHerzegovina),                   //  0x001d  29
        uint16_t(QLocale::Country::Botswana),                               //  0x001e  30
        uint16_t(QLocale::Country::BouvetIsland),                           //  0x001f  31
        uint16_t(QLocale::Country::Brazil),                                 //  0x0020  32
        uint16_t(QLocale::Country::BritishIndianOceanTerritory),            //  0x0021  33
        uint16_t(QLocale::Country::BritishVirginIslands),                   //  0x0022  34
        uint16_t(QLocale::Country::Brunei),                                 //  0x0023  35
        uint16_t(QLocale::Country::Bulgaria),                               //  0x0024  36
        uint16_t(QLocale::Country::BurkinaFaso),                            //  0x0025  37
        uint16_t(QLocale::Country::Burundi),                                //  0x0026  38
        uint16_t(QLocale::Country::Cambodia),                               //  0x0027  39
        uint16_t(QLocale::Country::Cameroon),                               //  0x0028  40
        uint16_t(QLocale::Country::Canada),                                 //  0x0029  41
        uint16_t(QLocale::Country::CanaryIslands),                          //  0x002a  42
        uint16_t(QLocale::Country::CapeVerde),                              //  0x002b  43
        uint16_t(QLocale::Country::CaribbeanNetherlands),                   //  0x002c  44
        uint16_t(QLocale::Country::CaymanIslands),                          //  0x002d  45
        uint16_t(QLocale::Country::CentralAfricanRepublic),                 //  0x002e  46
        uint16_t(QLocale::Country::CeutaAndMelilla),                        //  0x002f  47
        uint16_t(QLocale::Country::Chad),                                   //  0x0030  48
        uint16_t(QLocale::Country::Chile),                                  //  0x0031  49
        uint16_t(QLocale::Country::China),                                  //  0x0032  50
        uint16_t(QLocale::Country::ChristmasIsland),                        //  0x0033  51
        uint16_t(QLocale::Country::ClippertonIsland),                       //  0x0034  52
        uint16_t(QLocale::Country::CocosIslands),                           //  0x0035  53
        uint16_t(QLocale::Country::Colombia),                               //  0x0036  54
        uint16_t(QLocale::Country::Comoros),                                //  0x0037  55
        uint16_t(QLocale::Country::CongoBrazzaville),                       //  0x0038  56
        uint16_t(QLocale::Country::CongoKinshasa),                          //  0x0039  57
        uint16_t(QLocale::Country::CookIslands),                            //  0x003a  58
        uint16_t(QLocale::Country::CostaRica),                              //  0x003b  59
        uint16_t(QLocale::Country::Croatia),                                //  0x003c  60
        uint16_t(QLocale::Country::Cuba),                                   //  0x003d  61
        uint16_t(QLocale::Country::Curacao),                                //  0x003e  62
        uint16_t(QLocale::Country::Cyprus),                                 //  0x003f  63
        uint16_t(QLocale::Country::Czechia),                                //  0x0040  64
        uint16_t(QLocale::Country::Denmark),                                //  0x0041  65
        uint16_t(QLocale::Country::DiegoGarcia),                            //  0x0042  66
        uint16_t(QLocale::Country::Djibouti),                               //  0x0043  67
        uint16_t(QLocale::Country::Dominica),                               //  0x0044  68
        uint16_t(QLocale::Country::DominicanRepublic),                      //  0x0045  69
        uint16_t(QLocale::Country::Ecuador),                                //  0x0046  70
        uint16_t(QLocale::Country::Egypt),                                  //  0x0047  71
        uint16_t(QLocale::Country::ElSalvador),                             //  0x0048  72
        uint16_t(QLocale::Country::EquatorialGuinea),                       //  0x0049  73
        uint16_t(QLocale::Country::Eritrea),                                //  0x004a  74
        uint16_t(QLocale::Country::Estonia),                                //  0x004b  75
        uint16_t(QLocale::Country::Eswatini),                               //  0x004c  76
        uint16_t(QLocale::Country::Ethiopia),                               //  0x004d  77
        uint16_t(QLocale::Country::Europe),                                 //  0x004e  78
        uint16_t(QLocale::Country::EuropeanUnion),                          //  0x004f  79
        uint16_t(QLocale::Country::FalklandIslands),                        //  0x0050  80
        uint16_t(QLocale::Country::FaroeIslands),                           //  0x0051  81
        uint16_t(QLocale::Country::Fiji),                                   //  0x0052  82
        uint16_t(QLocale::Country::Finland),                                //  0x0053  83
        uint16_t(QLocale::Country::France),                                 //  0x0054  84
        uint16_t(QLocale::Country::FrenchGuiana),                           //  0x0055  85
        uint16_t(QLocale::Country::FrenchPolynesia),                        //  0x0056  86
        uint16_t(QLocale::Country::FrenchSouthernTerritories),              //  0x0057  87
        uint16_t(QLocale::Country::Gabon),                                  //  0x0058  88
        uint16_t(QLocale::Country::Gambia),                                 //  0x0059  89
        uint16_t(QLocale::Country::Georgia),                                //  0x005a  90
        uint16_t(QLocale::Country::Germany),                                //  0x005b  91
        uint16_t(QLocale::Country::Ghana),                                  //  0x005c  92
        uint16_t(QLocale::Country::Gibraltar),                              //  0x005d  93
        uint16_t(QLocale::Country::Greece),                                 //  0x005e  94
        uint16_t(QLocale::Country::Greenland),                              //  0x005f  95
        uint16_t(QLocale::Country::Grenada),                                //  0x0060  96
        uint16_t(QLocale::Country::Guadeloupe),                             //  0x0061  97
        uint16_t(QLocale::Country::Guam),                                   //  0x0062  98
        uint16_t(QLocale::Country::Guatemala),                              //  0x0063  99
        uint16_t(QLocale::Country::Guernsey),                               //  0x0064  100
        uint16_t(QLocale::Country::GuineaBissau),                           //  0x0065  101
        uint16_t(QLocale::Country::Guinea),                                 //  0x0066  102
        uint16_t(QLocale::Country::Guyana),                                 //  0x0067  103
        uint16_t(QLocale::Country::Haiti),                                  //  0x0068  104
        uint16_t(QLocale::Country::HeardAndMcDonaldIslands),                //  0x0069  105
        uint16_t(QLocale::Country::Honduras),                               //  0x006a  106
        uint16_t(QLocale::Country::HongKong),                               //  0x006b  107
        uint16_t(QLocale::Country::Hungary),                                //  0x006c  108
        uint16_t(QLocale::Country::Iceland),                                //  0x006d  109
        uint16_t(QLocale::Country::India),                                  //  0x006e  110
        uint16_t(QLocale::Country::Indonesia),                              //  0x006f  111
        uint16_t(QLocale::Country::Iran),                                   //  0x0070  112
        uint16_t(QLocale::Country::Iraq),                                   //  0x0071  113
        uint16_t(QLocale::Country::Ireland),                                //  0x0072  114
        uint16_t(QLocale::Country::IsleOfMan),                              //  0x0073  115
        uint16_t(QLocale::Country::Israel),                                 //  0x0074  116
        uint16_t(QLocale::Country::Italy),                                  //  0x0075  117
        uint16_t(QLocale::Country::IvoryCoast),                             //  0x0076  118
        uint16_t(QLocale::Country::Jamaica),                                //  0x0077  119
        uint16_t(QLocale::Country::Japan),                                  //  0x0078  120
        uint16_t(QLocale::Country::Jersey),                                 //  0x0079  121
        uint16_t(QLocale::Country::Jordan),                                 //  0x007a  122
        uint16_t(QLocale::Country::Kazakhstan),                             //  0x007b  123
        uint16_t(QLocale::Country::Kenya),                                  //  0x007c  124
        uint16_t(QLocale::Country::Kiribati),                               //  0x007d  125
        uint16_t(QLocale::Country::Kosovo),                                 //  0x007e  126
        uint16_t(QLocale::Country::Kuwait),                                 //  0x007f  127
        uint16_t(QLocale::Country::Kyrgyzstan),                             //  0x0080  128
        uint16_t(QLocale::Country::Laos),                                   //  0x0081  129
        uint16_t(QLocale::Country::LatinAmerica),                           //  0x0082  130
        uint16_t(QLocale::Country::Latvia),                                 //  0x0083  131
        uint16_t(QLocale::Country::Lebanon),                                //  0x0084  132
        uint16_t(QLocale::Country::Lesotho),                                //  0x0085  133
        uint16_t(QLocale::Country::Liberia),                                //  0x0086  134
        uint16_t(QLocale::Country::Libya),                                  //  0x0087  135
        uint16_t(QLocale::Country::Liechtenstein),                          //  0x0088  136
        uint16_t(QLocale::Country::Lithuania),                              //  0x0089  137
        uint16_t(QLocale::Country::Luxembourg),                             //  0x008a  138
        uint16_t(QLocale::Country::Macao),                                  //  0x008b  139
        uint16_t(QLocale::Country::Macedonia),                              //  0x008c  140
        uint16_t(QLocale::Country::Madagascar),                             //  0x008d  141
        uint16_t(QLocale::Country::Malawi),                                 //  0x008e  142
        uint16_t(QLocale::Country::Malaysia),                               //  0x008f  143
        uint16_t(QLocale::Country::Maldives),                               //  0x0090  144
        uint16_t(QLocale::Country::Mali),                                   //  0x0091  145
        uint16_t(QLocale::Country::Malta),                                  //  0x0092  146
        uint16_t(QLocale::Country::MarshallIslands),                        //  0x0093  147
        uint16_t(QLocale::Country::Martinique),                             //  0x0094  148
        uint16_t(QLocale::Country::Mauritania),                             //  0x0095  149
        uint16_t(QLocale::Country::Mauritius),                              //  0x0096  150
        uint16_t(QLocale::Country::Mayotte),                                //  0x0097  151
        uint16_t(QLocale::Country::Mexico),                                 //  0x0098  152
        uint16_t(QLocale::Country::Micronesia),                             //  0x0099  153
        uint16_t(QLocale::Country::Moldova),                                //  0x009a  154
        uint16_t(QLocale::Country::Monaco),                                 //  0x009b  155
        uint16_t(QLocale::Country::Mongolia),                               //  0x009c  156
        uint16_t(QLocale::Country::Montenegro),                             //  0x009d  157
        uint16_t(QLocale::Country::Montserrat),                             //  0x009e  158
        uint16_t(QLocale::Country::Morocco),                                //  0x009f  159
        uint16_t(QLocale::Country::Mozambique),                             //  0x00a0  160
        uint16_t(QLocale::Country::Myanmar),                                //  0x00a1  161
        uint16_t(QLocale::Country::Namibia),                                //  0x00a2  162
        uint16_t(QLocale::Country::NauruTerritory),                         //  0x00a3  163
        uint16_t(QLocale::Country::Nepal),                                  //  0x00a4  164
        uint16_t(QLocale::Country::Netherlands),                            //  0x00a5  165
        uint16_t(QLocale::Country::NewCaledonia),                           //  0x00a6  166
        uint16_t(QLocale::Country::NewZealand),                             //  0x00a7  167
        uint16_t(QLocale::Country::Nicaragua),                              //  0x00a8  168
        uint16_t(QLocale::Country::Nigeria),                                //  0x00a9  169
        uint16_t(QLocale::Country::Niger),                                  //  0x00aa  170
        uint16_t(QLocale::Country::Niue),                                   //  0x00ab  171
        uint16_t(QLocale::Country::NorfolkIsland),                          //  0x00ac  172
        uint16_t(QLocale::Country::NorthernMarianaIslands),                 //  0x00ad  173
        uint16_t(QLocale::Country::NorthKorea),                             //  0x00ae  174
        uint16_t(QLocale::Country::Norway),                                 //  0x00af  175
        uint16_t(QLocale::Country::Oman),                                   //  0x00b0  176
        uint16_t(QLocale::Country::OutlyingOceania),                        //  0x00b1  177
        uint16_t(QLocale::Country::Pakistan),                               //  0x00b2  178
        uint16_t(QLocale::Country::Palau),                                  //  0x00b3  179
        uint16_t(QLocale::Country::PalestinianTerritories),                 //  0x00b4  180
        uint16_t(QLocale::Country::Panama),                                 //  0x00b5  181
        uint16_t(QLocale::Country::PapuaNewGuinea),                         //  0x00b6  182
        uint16_t(QLocale::Country::Paraguay),                               //  0x00b7  183
        uint16_t(QLocale::Country::Peru),                                   //  0x00b8  184
        uint16_t(QLocale::Country::Philippines),                            //  0x00b9  185
        uint16_t(QLocale::Country::Pitcairn),                               //  0x00ba  186
        uint16_t(QLocale::Country::Poland),                                 //  0x00bb  187
        uint16_t(QLocale::Country::Portugal),                               //  0x00bc  188
        uint16_t(QLocale::Country::PuertoRico),                             //  0x00bd  189
        uint16_t(QLocale::Country::Qatar),                                  //  0x00be  190
        uint16_t(QLocale::Country::Reunion),                                //  0x00bf  191
        uint16_t(QLocale::Country::Romania),                                //  0x00c0  192
        uint16_t(QLocale::Country::Russia),                                 //  0x00c1  193
        uint16_t(QLocale::Country::Rwanda),                                 //  0x00c2  194
        uint16_t(QLocale::Country::SaintBarthelemy),                        //  0x00c3  195
        uint16_t(QLocale::Country::SaintHelena),                            //  0x00c4  196
        uint16_t(QLocale::Country::SaintKittsAndNevis),                     //  0x00c5  197
        uint16_t(QLocale::Country::SaintLucia),                             //  0x00c6  198
        uint16_t(QLocale::Country::SaintMartin),                            //  0x00c7  199
        uint16_t(QLocale::Country::SaintPierreAndMiquelon),                 //  0x00c8  200
        uint16_t(QLocale::Country::SaintVincentAndGrenadines),              //  0x00c9  201
        uint16_t(QLocale::Country::Samoa),                                  //  0x00ca  202
        uint16_t(QLocale::Country::SanMarino),                              //  0x00cb  203
        uint16_t(QLocale::Country::SaoTomeAndPrincipe),                     //  0x00cc  204
        uint16_t(QLocale::Country::SaudiArabia),                            //  0x00cd  205
        uint16_t(QLocale::Country::Senegal),                                //  0x00ce  206
        uint16_t(QLocale::Country::Serbia),                                 //  0x00cf  207
        uint16_t(QLocale::Country::Seychelles),                             //  0x00d0  208
        uint16_t(QLocale::Country::SierraLeone),                            //  0x00d1  209
        uint16_t(QLocale::Country::Singapore),                              //  0x00d2  210
        uint16_t(QLocale::Country::SintMaarten),                            //  0x00d3  211
        uint16_t(QLocale::Country::Slovakia),                               //  0x00d4  212
        uint16_t(QLocale::Country::Slovenia),                               //  0x00d5  213
        uint16_t(QLocale::Country::SolomonIslands),                         //  0x00d6  214
        uint16_t(QLocale::Country::Somalia),                                //  0x00d7  215
        uint16_t(QLocale::Country::SouthAfrica),                            //  0x00d8  216
        uint16_t(QLocale::Country::SouthGeorgiaAndSouthSandwichIslands),    //  0x00d9  217
        uint16_t(QLocale::Country::SouthKorea),                             //  0x00da  218
        uint16_t(QLocale::Country::SouthSudan),                             //  0x00db  219
        uint16_t(QLocale::Country::Spain),                                  //  0x00dc  220
        uint16_t(QLocale::Country::SriLanka),                               //  0x00dd  221
        uint16_t(QLocale::Country::Sudan),                                  //  0x00de  222
        uint16_t(QLocale::Country::Suriname),                               //  0x00df  223
        uint16_t(QLocale::Country::SvalbardAndJanMayen),                    //  0x00e0  224
        uint16_t(QLocale::Country::Sweden),                                 //  0x00e1  225
        uint16_t(QLocale::Country::Switzerland),                            //  0x00e2  226
        uint16_t(QLocale::Country::Syria),                                  //  0x00e3  227
        uint16_t(QLocale::Country::Taiwan),                                 //  0x00e4  228
        uint16_t(QLocale::Country::Tajikistan),                             //  0x00e5  229
        uint16_t(QLocale::Country::Tanzania),                               //  0x00e6  230
        uint16_t(QLocale::Country::Thailand),                               //  0x00e7  231
        uint16_t(QLocale::Country::TimorLeste),                             //  0x00e8  232
        uint16_t(QLocale::Country::Togo),                                   //  0x00e9  233
        uint16_t(QLocale::Country::TokelauTerritory),                       //  0x00ea  234
        uint16_t(QLocale::Country::Tonga),                                  //  0x00eb  235
        uint16_t(QLocale::Country::TrinidadAndTobago),                      //  0x00ec  236
        uint16_t(QLocale::Country::TristanDaCunha),                         //  0x00ed  237
        uint16_t(QLocale::Country::Tunisia),                                //  0x00ee  238
        uint16_t(QLocale::Country::Turkey),                                 //  0x00ef  239
        uint16_t(QLocale::Country::Turkmenistan),                           //  0x00f0  240
        uint16_t(QLocale::Country::TurksAndCaicosIslands),                  //  0x00f1  241
        uint16_t(QLocale::Country::TuvaluTerritory),                        //  0x00f2  242
        uint16_t(QLocale::Country::Uganda),                                 //  0x00f3  243
        uint16_t(QLocale::Country::Ukraine),                                //  0x00f4  244
        uint16_t(QLocale::Country::UnitedArabEmirates),                     //  0x00f5  245
        uint16_t(QLocale::Country::UnitedKingdom),                          //  0x00f6  246
        uint16_t(QLocale::Country::UnitedStatesOutlyingIslands),            //  0x00f7  247
        uint16_t(QLocale::Country::UnitedStates),                           //  0x00f8  248
        uint16_t(QLocale::Country::UnitedStatesVirginIslands),              //  0x00f9  249
        uint16_t(QLocale::Country::Uruguay),                                //  0x00fa  250
        uint16_t(QLocale::Country::Uzbekistan),                             //  0x00fb  251
        uint16_t(QLocale::Country::Vanuatu),                                //  0x00fc  252
        uint16_t(QLocale::Country::VaticanCity),                            //  0x00fd  253
        uint16_t(QLocale::Country::Venezuela),                              //  0x00fe  254
        uint16_t(QLocale::Country::Vietnam),                                //  0x00ff  255
        uint16_t(QLocale::Country::WallisAndFutuna),                        //  0x0100  256
        uint16_t(QLocale::Country::WesternSahara),                          //  0x0101  257
        uint16_t(QLocale::Country::World),                                  //  0x0102  258
        uint16_t(QLocale::Country::Yemen),                                  //  0x0103  259
        uint16_t(QLocale::Country::Zambia),                                 //  0x0104  260
        uint16_t(QLocale::Country::Zimbabwe),                               //  0x0105  261
        uint16_t(QLocale::Country::AnyCountry),                             //  0x0000  0
        uint16_t(QLocale::Country::Bonaire),                                //  0x002c  44
        uint16_t(QLocale::Country::BosniaAndHerzegowina),                   //  0x001d  29
        uint16_t(QLocale::Country::CuraSao),                                //  0x003e  62
        uint16_t(QLocale::Country::CzechRepublic),                          //  0x0040  64
        uint16_t(QLocale::Country::DemocraticRepublicOfCongo),              //  0x0039  57
        uint16_t(QLocale::Country::DemocraticRepublicOfKorea),              //  0x00ae  174
        uint16_t(QLocale::Country::EastTimor),                              //  0x00e8  232
        uint16_t(QLocale::Country::LatinAmericaAndTheCaribbean),            //  0x0082  130
        uint16_t(QLocale::Country::Macau),                                  //  0x008b  139
        uint16_t(QLocale::Country::NauruCountry),                           //  0x00a3  163
        uint16_t(QLocale::Country::PeoplesRepublicOfCongo),                 //  0x0038  56
        uint16_t(QLocale::Country::RepublicOfKorea),                        //  0x00da  218
        uint16_t(QLocale::Country::RussianFederation),                      //  0x00c1  193
        uint16_t(QLocale::Country::SaintVincentAndTheGrenadines),           //  0x00c9  201
        uint16_t(QLocale::Country::SouthGeorgiaAndTheSouthSandwichIslands), //  0x00d9  217
        uint16_t(QLocale::Country::SvalbardAndJanMayenIslands),             //  0x00e0  224
        uint16_t(QLocale::Country::Swaziland),                              //  0x004c  76
        uint16_t(QLocale::Country::SyrianArabRepublic),                     //  0x00e3  227
        uint16_t(QLocale::Country::TokelauCountry),                         //  0x00ea  234
        uint16_t(QLocale::Country::TuvaluCountry),                          //  0x00f2  242
        uint16_t(QLocale::Country::UnitedStatesMinorOutlyingIslands),       //  0x00f7  247
        uint16_t(QLocale::Country::VaticanCityState),                       //  0x00fd  253
        uint16_t(QLocale::Country::WallisAndFutunaIslands),                 //  0x0100  256
        uint16_t(QLocale::Country::LastTerritory),                          //  0x0105  261
        uint16_t(QLocale::Country::LastCountry)                             //  0x0105  261
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLocale_TypeF(),
        "2:PySide6.QtCore.QLocale.Country",
        Country_Initializer, Country_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocale_Country_IDX].type = EType;
    // Register converter for enum 'QLocale::Country'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLocale_Country_CppToPython_QLocale_Country);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QLocale_Country_PythonToCpp_QLocale_Country,
            is_QLocale_Country_PythonToCpp_QLocale_Country_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QLocale::Country");
        Shiboken::Conversions::registerConverterName(converter, "Country");
    }
    // End of 'Country' enum.

    // Initialization of enum 'MeasurementSystem'.
    const char *MeasurementSystem_Initializer[] = {
        "MetricSystem",
        "ImperialUSSystem",
        "ImperialUKSystem",
        "ImperialSystem",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MeasurementSystem_InitializerValues[] = {
        uint8_t(QLocale::MeasurementSystem::MetricSystem),     //  0x00  0
        uint8_t(QLocale::MeasurementSystem::ImperialUSSystem), //  0x01  1
        uint8_t(QLocale::MeasurementSystem::ImperialUKSystem), //  0x02  2
        uint8_t(QLocale::MeasurementSystem::ImperialSystem)    //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLocale_TypeF(),
        "2:PySide6.QtCore.QLocale.MeasurementSystem",
        MeasurementSystem_Initializer, MeasurementSystem_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocale_MeasurementSystem_IDX].type = EType;
    // Register converter for enum 'QLocale::MeasurementSystem'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLocale_MeasurementSystem_CppToPython_QLocale_MeasurementSystem);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QLocale_MeasurementSystem_PythonToCpp_QLocale_MeasurementSystem,
            is_QLocale_MeasurementSystem_PythonToCpp_QLocale_MeasurementSystem_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QLocale::MeasurementSystem");
        Shiboken::Conversions::registerConverterName(converter, "MeasurementSystem");
    }
    // End of 'MeasurementSystem' enum.

    // Initialization of enum 'FormatType'.
    const char *FormatType_Initializer[] = {
        "LongFormat",
        "ShortFormat",
        "NarrowFormat",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FormatType_InitializerValues[] = {
        uint8_t(QLocale::FormatType::LongFormat),  //  0x00  0
        uint8_t(QLocale::FormatType::ShortFormat), //  0x01  1
        uint8_t(QLocale::FormatType::NarrowFormat) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLocale_TypeF(),
        "2:PySide6.QtCore.QLocale.FormatType",
        FormatType_Initializer, FormatType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FormatType_IDX].type = EType;
    // Register converter for enum 'QLocale::FormatType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLocale_FormatType_CppToPython_QLocale_FormatType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QLocale_FormatType_PythonToCpp_QLocale_FormatType,
            is_QLocale_FormatType_PythonToCpp_QLocale_FormatType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QLocale::FormatType");
        Shiboken::Conversions::registerConverterName(converter, "FormatType");
    }
    // End of 'FormatType' enum.

    // Initialization of enum 'NumberOption'.
    const char *NumberOption_Initializer[] = {
        "DefaultNumberOptions",
        "OmitGroupSeparator",
        "RejectGroupSeparator",
        "OmitLeadingZeroInExponent",
        "RejectLeadingZeroInExponent",
        "IncludeTrailingZeroesAfterDot",
        "RejectTrailingZeroesAfterDot",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t NumberOption_InitializerValues[] = {
        uint8_t(QLocale::NumberOption::DefaultNumberOptions),          //  0x00  0
        uint8_t(QLocale::NumberOption::OmitGroupSeparator),            //  0x01  1
        uint8_t(QLocale::NumberOption::RejectGroupSeparator),          //  0x02  2
        uint8_t(QLocale::NumberOption::OmitLeadingZeroInExponent),     //  0x04  4
        uint8_t(QLocale::NumberOption::RejectLeadingZeroInExponent),   //  0x08  8
        uint8_t(QLocale::NumberOption::IncludeTrailingZeroesAfterDot), //  0x10  16
        uint8_t(QLocale::NumberOption::RejectTrailingZeroesAfterDot)   //  0x20  32
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLocale_TypeF(),
        "2:PySide6.QtCore.QLocale.NumberOption",
        NumberOption_Initializer, NumberOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocale_NumberOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QLocale_NumberOption_IDX].type =
        EType;
    // Register converter for enum 'QLocale::NumberOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLocale_NumberOption_CppToPython_QLocale_NumberOption);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QLocale_NumberOption_PythonToCpp_QLocale_NumberOption,
            is_QLocale_NumberOption_PythonToCpp_QLocale_NumberOption_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QLocale::NumberOption");
        Shiboken::Conversions::registerConverterName(converter, "NumberOption");
        // Register converter for flag 'QFlags<QLocale::NumberOption>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QLocale::NumberOption>");
        Shiboken::Conversions::registerConverterName(converter, "QLocale::NumberOptions");
    }
    // End of 'NumberOption' enum/flags.

    // Initialization of enum 'FloatingPointPrecisionOption'.
    const char *FloatingPointPrecisionOption_Initializer[] = {
        "FloatingPointShortest",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t FloatingPointPrecisionOption_InitializerValues[] = {
        int8_t(QLocale::FloatingPointPrecisionOption::FloatingPointShortest) // -0x80 -128
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLocale_TypeF(),
        "2:PySide6.QtCore.QLocale.FloatingPointPrecisionOption",
        FloatingPointPrecisionOption_Initializer, FloatingPointPrecisionOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocale_FloatingPointPrecisionOption_IDX].type = EType;
    // Register converter for enum 'QLocale::FloatingPointPrecisionOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLocale_FloatingPointPrecisionOption_CppToPython_QLocale_FloatingPointPrecisionOption);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QLocale_FloatingPointPrecisionOption_PythonToCpp_QLocale_FloatingPointPrecisionOption,
            is_QLocale_FloatingPointPrecisionOption_PythonToCpp_QLocale_FloatingPointPrecisionOption_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QLocale::FloatingPointPrecisionOption");
        Shiboken::Conversions::registerConverterName(converter, "FloatingPointPrecisionOption");
    }
    // End of 'FloatingPointPrecisionOption' enum.

    // Initialization of enum 'TagSeparator'.
    const char *TagSeparator_Initializer[] = {
        "Dash",
        "Underscore",
        nullptr};
    // "int8_t" used instead of "char"
    constexpr int8_t TagSeparator_InitializerValues[] = {
        int8_t(QLocale::TagSeparator::Dash),      //  0x2d  45
        int8_t(QLocale::TagSeparator::Underscore) //  0x5f  95
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLocale_TypeF(),
        "2:PySide6.QtCore.QLocale.TagSeparator",
        TagSeparator_Initializer, TagSeparator_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocale_TagSeparator_IDX].type = EType;
    // Register converter for enum 'QLocale::TagSeparator'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLocale_TagSeparator_CppToPython_QLocale_TagSeparator);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QLocale_TagSeparator_PythonToCpp_QLocale_TagSeparator,
            is_QLocale_TagSeparator_PythonToCpp_QLocale_TagSeparator_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QLocale::TagSeparator");
        Shiboken::Conversions::registerConverterName(converter, "TagSeparator");
    }
    // End of 'TagSeparator' enum.

    // Initialization of enum 'CurrencySymbolFormat'.
    const char *CurrencySymbolFormat_Initializer[] = {
        "CurrencyIsoCode",
        "CurrencySymbol",
        "CurrencyDisplayName",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CurrencySymbolFormat_InitializerValues[] = {
        uint8_t(QLocale::CurrencySymbolFormat::CurrencyIsoCode),    //  0x00  0
        uint8_t(QLocale::CurrencySymbolFormat::CurrencySymbol),     //  0x01  1
        uint8_t(QLocale::CurrencySymbolFormat::CurrencyDisplayName) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLocale_TypeF(),
        "2:PySide6.QtCore.QLocale.CurrencySymbolFormat",
        CurrencySymbolFormat_Initializer, CurrencySymbolFormat_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocale_CurrencySymbolFormat_IDX].type = EType;
    // Register converter for enum 'QLocale::CurrencySymbolFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLocale_CurrencySymbolFormat_CppToPython_QLocale_CurrencySymbolFormat);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QLocale_CurrencySymbolFormat_PythonToCpp_QLocale_CurrencySymbolFormat,
            is_QLocale_CurrencySymbolFormat_PythonToCpp_QLocale_CurrencySymbolFormat_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QLocale::CurrencySymbolFormat");
        Shiboken::Conversions::registerConverterName(converter, "CurrencySymbolFormat");
    }
    // End of 'CurrencySymbolFormat' enum.

    // Initialization of enum 'DataSizeFormat'.
    const char *DataSizeFormat_Initializer[] = {
        "DataSizeBase1000",
        "DataSizeSIQuantifiers",
        "DataSizeIecFormat",
        "DataSizeTraditionalFormat",
        "DataSizeSIFormat",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DataSizeFormat_InitializerValues[] = {
        uint8_t(QLocale::DataSizeFormat::DataSizeBase1000),          //  0x01  1
        uint8_t(QLocale::DataSizeFormat::DataSizeSIQuantifiers),     //  0x02  2
        uint8_t(QLocale::DataSizeFormat::DataSizeIecFormat),         //  0x00  0
        uint8_t(QLocale::DataSizeFormat::DataSizeTraditionalFormat), //  0x02  2
        uint8_t(QLocale::DataSizeFormat::DataSizeSIFormat)           //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLocale_TypeF(),
        "2:PySide6.QtCore.QLocale.DataSizeFormat",
        DataSizeFormat_Initializer, DataSizeFormat_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocale_DataSizeFormat_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QLocale_DataSizeFormat_IDX].type =
        EType;
    // Register converter for enum 'QLocale::DataSizeFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLocale_DataSizeFormat_CppToPython_QLocale_DataSizeFormat);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QLocale_DataSizeFormat_PythonToCpp_QLocale_DataSizeFormat,
            is_QLocale_DataSizeFormat_PythonToCpp_QLocale_DataSizeFormat_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QLocale::DataSizeFormat");
        Shiboken::Conversions::registerConverterName(converter, "DataSizeFormat");
        // Register converter for flag 'QFlags<QLocale::DataSizeFormat>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QLocale::DataSizeFormat>");
        Shiboken::Conversions::registerConverterName(converter, "QLocale::DataSizeFormats");
    }
    // End of 'DataSizeFormat' enum/flags.

    // Initialization of enum 'LanguageCodeType'.
    const char *LanguageCodeType_Initializer[] = {
        "ISO639Part1",
        "ISO639Part2B",
        "ISO639Part2T",
        "ISO639Part3",
        "LegacyLanguageCode",
        "ISO639Part2",
        "ISO639Alpha2",
        "ISO639Alpha3",
        "ISO639",
        "AnyLanguageCode",
        nullptr};
    // "int32_t" used instead of "int"
    constexpr int32_t LanguageCodeType_InitializerValues[] = {
        int32_t(QLocale::LanguageCodeType::ISO639Part1),        //  0x00000001  1
        int32_t(QLocale::LanguageCodeType::ISO639Part2B),       //  0x00000002  2
        int32_t(QLocale::LanguageCodeType::ISO639Part2T),       //  0x00000004  4
        int32_t(QLocale::LanguageCodeType::ISO639Part3),        //  0x00000008  8
        int32_t(QLocale::LanguageCodeType::LegacyLanguageCode), //  0x00008000  32768
        int32_t(QLocale::LanguageCodeType::ISO639Part2),        //  0x00000006  6
        int32_t(QLocale::LanguageCodeType::ISO639Alpha2),       //  0x00000001  1
        int32_t(QLocale::LanguageCodeType::ISO639Alpha3),       //  0x0000000e  14
        int32_t(QLocale::LanguageCodeType::ISO639),             //  0x0000000f  15
        int32_t(QLocale::LanguageCodeType::AnyLanguageCode)     // -0x00000001 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLocale_TypeF(),
        "2:PySide6.QtCore.QLocale.LanguageCodeType",
        LanguageCodeType_Initializer, LanguageCodeType_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocale_LanguageCodeType_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QLocale_LanguageCodeType_IDX].type =
        EType;
    // Register converter for enum 'QLocale::LanguageCodeType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLocale_LanguageCodeType_CppToPython_QLocale_LanguageCodeType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QLocale_LanguageCodeType_PythonToCpp_QLocale_LanguageCodeType,
            is_QLocale_LanguageCodeType_PythonToCpp_QLocale_LanguageCodeType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QLocale::LanguageCodeType");
        Shiboken::Conversions::registerConverterName(converter, "LanguageCodeType");
        // Register converter for flag 'QFlags<QLocale::LanguageCodeType>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QLocale::LanguageCodeType>");
        Shiboken::Conversions::registerConverterName(converter, "QLocale::LanguageCodeTypes");
    }
    // End of 'LanguageCodeType' enum/flags.

    // Initialization of enum 'QuotationStyle'.
    const char *QuotationStyle_Initializer[] = {
        "StandardQuotation",
        "AlternateQuotation",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t QuotationStyle_InitializerValues[] = {
        uint8_t(QLocale::QuotationStyle::StandardQuotation), //  0x00  0
        uint8_t(QLocale::QuotationStyle::AlternateQuotation) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QLocale_TypeF(),
        "2:PySide6.QtCore.QLocale.QuotationStyle",
        QuotationStyle_Initializer, QuotationStyle_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QLocale_QuotationStyle_IDX].type = EType;
    // Register converter for enum 'QLocale::QuotationStyle'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QLocale_QuotationStyle_CppToPython_QLocale_QuotationStyle);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QLocale_QuotationStyle_PythonToCpp_QLocale_QuotationStyle,
            is_QLocale_QuotationStyle_PythonToCpp_QLocale_QuotationStyle_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QLocale::QuotationStyle");
        Shiboken::Conversions::registerConverterName(converter, "QuotationStyle");
    }
    // End of 'QuotationStyle' enum.

    qRegisterMetaType< ::QLocale >("QLocale");
    qRegisterMetaType< ::QLocale::Language >("QLocale::Language");
    qRegisterMetaType< ::QLocale::Script >("QLocale::Script");
    qRegisterMetaType< ::QLocale::Country >("QLocale::Country");
    qRegisterMetaType< ::QLocale::MeasurementSystem >("QLocale::MeasurementSystem");
    qRegisterMetaType< ::QLocale::FormatType >("QLocale::FormatType");
    qRegisterMetaType< ::QLocale::NumberOption >("QLocale::NumberOption");
    qRegisterMetaType< ::QLocale::FloatingPointPrecisionOption >("QLocale::FloatingPointPrecisionOption");
    qRegisterMetaType< ::QLocale::TagSeparator >("QLocale::TagSeparator");
    qRegisterMetaType< ::QLocale::CurrencySymbolFormat >("QLocale::CurrencySymbolFormat");
    qRegisterMetaType< ::QLocale::DataSizeFormat >("QLocale::DataSizeFormat");
    qRegisterMetaType< ::QLocale::LanguageCodeType >("QLocale::LanguageCodeType");
    qRegisterMetaType< ::QLocale::QuotationStyle >("QLocale::QuotationStyle");

    return pyType;
}

PyTypeObject *init_QLocaleStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QLocale");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "DefaultTwoDigitBaseYear",
                         Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &QLocale::DefaultTwoDigitBaseYear));
    return type;
}
