// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qmetaobject_wrapper.h"

// inner classes
#include "qmetaobject_connection_wrapper.h"

// Extra includes
#include <dynamicqmetaobject.h>
#include <pysidemetatype.h>
#include <pysideutils.h>
#include "glue/core_snippets_p.h"

// Argument includes
#include <qbytearray.h>
#include <qmetaobject.h>
#include <qmetatype.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qtcorehelper.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtcore.cpp (qmetaobject-invokemethod-helpers)]
static InvokeMetaMethodFunc
    createInvokeMetaMethodFunc(QObject *object, const char *methodName,
                               Qt::ConnectionType type = Qt::AutoConnection)
{
    return [object, methodName, type](QGenericArgument a0, QGenericArgument a1,
                                      QGenericArgument a2, QGenericArgument a3,
                                      QGenericArgument a4, QGenericArgument a5,
                                      QGenericArgument a6, QGenericArgument a7,
                                      QGenericArgument a8, QGenericArgument a9) -> bool
    {
        return QMetaObject::invokeMethod(object, methodName, type,
                                         a0, a1, a2, a3, a4, a5, a6, a7, a8, a9);
    };
}

static InvokeMetaMethodFuncWithReturn
    createInvokeMetaMethodFuncWithReturn(QObject *object, const char *methodName,
                                         Qt::ConnectionType type = Qt::AutoConnection)
{
    return [object, methodName, type](QGenericReturnArgument r,
                                      QGenericArgument a0, QGenericArgument a1,
                                      QGenericArgument a2, QGenericArgument a3,
                                      QGenericArgument a4, QGenericArgument a5,
                                      QGenericArgument a6, QGenericArgument a7,
                                      QGenericArgument a8, QGenericArgument a9) -> bool
    {
        return QMetaObject::invokeMethod(object, methodName, type,
                                         r, a0, a1, a2, a3, a4, a5, a6, a7, a8, a9);
    };
}
// END of custom code block [file: ../glue/qtcore.cpp (qmetaobject-invokemethod-helpers)]
// ========================================================================
// End of code injection



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMetaObject_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMetaObject >()))
        return -1;

    ::QMetaObject *cptr{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // QMetaObject()
            cptr = new ::QMetaObject();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMetaObject >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMetaObjectFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.__repr__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __repr__()
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qmetaobject-repr)]
            const QByteArray repr = PySide::MetaObjectBuilder::formatMetaObject(cppSelf).toUtf8();
            pyResult = PyUnicode_FromString(repr.constData());
            // END of custom code block [file: ../glue/qtcore.cpp (qmetaobject-repr)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_cast(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.cast";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaObject::cast(QObject*)const->QObject*
    // 1: QMetaObject::cast(const QObject*)const->const QObject*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // cast(QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // cast(QObject * obj) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QObject *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // cast(QObject*)const
                QObject * cppResult = const_cast<const ::QMetaObject *>(cppSelf)->cast(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
            }
            break;
        }
        case 1: // cast(const QObject * obj) const
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QObject *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // cast(const QObject*)const
                const QObject * cppResult = const_cast<const ::QMetaObject *>(cppSelf)->cast(cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_checkConnectArgs(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.checkConnectArgs";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "checkConnectArgs", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaObject::checkConnectArgs(QMetaMethod,QMetaMethod)->bool
    // 1: static QMetaObject::checkConnectArgs(const char*,const char*)->bool
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        overloadId = 1; // checkConnectArgs(const char*,const char*)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), (pyArgs[1])))) {
        overloadId = 0; // checkConnectArgs(QMetaMethod,QMetaMethod)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // checkConnectArgs(const QMetaMethod & signal, const QMetaMethod & method)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QMetaMethod cppArg0_local;
            ::QMetaMethod *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QMetaMethod cppArg1_local;
            ::QMetaMethod *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // checkConnectArgs(QMetaMethod,QMetaMethod)
                bool cppResult = ::QMetaObject::checkConnectArgs(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // checkConnectArgs(const char * signal, const char * method)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // checkConnectArgs(const char*,const char*)
                bool cppResult = ::QMetaObject::checkConnectArgs(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_classInfo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.classInfo";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaObject::classInfo(int)const->QMetaClassInfo
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // classInfo(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // classInfo(int)const
            QMetaClassInfo cppResult = const_cast<const ::QMetaObject *>(cppSelf)->classInfo(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaClassInfo_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_classInfoCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.classInfoCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // classInfoCount()const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->classInfoCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_classInfoOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.classInfoOffset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // classInfoOffset()const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->classInfoOffset();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_className(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.className";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // className()const
            const char * cppResult = const_cast<const ::QMetaObject *>(cppSelf)->className();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_connectSlotsByName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.connectSlotsByName";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMetaObject::connectSlotsByName(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // connectSlotsByName(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // connectSlotsByName(QObject*)
            ::QMetaObject::connectSlotsByName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QMetaObjectFunc_constructor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.constructor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaObject::constructor(int)const->QMetaMethod
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // constructor(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // constructor(int)const
            QMetaMethod cppResult = const_cast<const ::QMetaObject *>(cppSelf)->constructor(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_constructorCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.constructorCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // constructorCount()const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->constructorCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_disconnect(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.disconnect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "disconnect", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaObject::disconnect(const QObject*,int,const QObject*,int)->bool
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // disconnect(const QObject*,int,const QObject*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QObject *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // disconnect(const QObject*,int,const QObject*,int)
            bool cppResult = ::QMetaObject::disconnect(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_disconnectOne(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.disconnectOne";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "disconnectOne", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaObject::disconnectOne(const QObject*,int,const QObject*,int)->bool
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // disconnectOne(const QObject*,int,const QObject*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QObject *cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // disconnectOne(const QObject*,int,const QObject*,int)
            bool cppResult = ::QMetaObject::disconnectOne(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_enumerator(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.enumerator";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaObject::enumerator(int)const->QMetaEnum
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // enumerator(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // enumerator(int)const
            QMetaEnum cppResult = const_cast<const ::QMetaObject *>(cppSelf)->enumerator(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaEnum_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_enumeratorCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.enumeratorCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // enumeratorCount()const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->enumeratorCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_enumeratorOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.enumeratorOffset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // enumeratorOffset()const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->enumeratorOffset();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_indexOfClassInfo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.indexOfClassInfo";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaObject::indexOfClassInfo(const char*)const->int
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // indexOfClassInfo(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // indexOfClassInfo(const char*)const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->indexOfClassInfo(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_indexOfConstructor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.indexOfConstructor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaObject::indexOfConstructor(const char*)const->int
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // indexOfConstructor(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // indexOfConstructor(const char*)const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->indexOfConstructor(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_indexOfEnumerator(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.indexOfEnumerator";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaObject::indexOfEnumerator(const char*)const->int
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // indexOfEnumerator(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // indexOfEnumerator(const char*)const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->indexOfEnumerator(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_indexOfMethod(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.indexOfMethod";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaObject::indexOfMethod(const char*)const->int
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // indexOfMethod(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // indexOfMethod(const char*)const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->indexOfMethod(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_indexOfProperty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.indexOfProperty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaObject::indexOfProperty(const char*)const->int
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // indexOfProperty(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // indexOfProperty(const char*)const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->indexOfProperty(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_indexOfSignal(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.indexOfSignal";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaObject::indexOfSignal(const char*)const->int
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // indexOfSignal(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // indexOfSignal(const char*)const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->indexOfSignal(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_indexOfSlot(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.indexOfSlot";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaObject::indexOfSlot(const char*)const->int
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // indexOfSlot(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // indexOfSlot(const char*)const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->indexOfSlot(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_inherits(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.inherits";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaObject::inherits(const QMetaObject*)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), (pyArg)))) {
        overloadId = 0; // inherits(const QMetaObject*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMetaObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // inherits(const QMetaObject*)const
            bool cppResult = const_cast<const ::QMetaObject *>(cppSelf)->inherits(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_invokeMethod(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.invokeMethod";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[14];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 14));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOOOOOOOO:invokeMethod", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9]), &(pyArgs[10]), &(pyArgs[11]), &(pyArgs[12]), &(pyArgs[13])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QMetaObject::invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=)->bool
    // 1: static QMetaObject::invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=)->bool
    // 2: static QMetaObject::invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=)->bool
    // 3: static QMetaObject::invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=)->bool
    // 4: static QMetaObject::invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=)->bool
    // 5: static QMetaObject::invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=)->PyObject*
    // 6: static QMetaObject::invokeMethod(QObject*,const char*,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=)->bool
    // 7: static QMetaObject::invokeMethod(QObject*,const char*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=,QtCoreHelper::QGenericArgumentHolder=)->PyObject*
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 6; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericReturnArgumentHolder_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 7; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 7; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 7; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5])))) {
                        if (numArgs == 6) {
                            overloadId = 7; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                        } else if (numArgs >= 7
                            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6])))) {
                            if (numArgs == 7) {
                                overloadId = 7; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                            } else if (numArgs >= 8
                                && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7])))) {
                                if (numArgs == 8) {
                                    overloadId = 7; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                } else if (numArgs >= 9
                                    && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8])))) {
                                    if (numArgs == 9) {
                                        overloadId = 7; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                    } else if (numArgs >= 10
                                        && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9])))) {
                                        if (numArgs == 10) {
                                            overloadId = 7; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                        } else if (numArgs >= 11
                                            && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10])))) {
                                            if (numArgs == 11) {
                                                overloadId = 7; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                            } else if (numArgs >= 12
                                                && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[11])))) {
                                                if (numArgs == 12) {
                                                    overloadId = 7; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                                } else if (numArgs >= 13
                                                    && (pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[12])))) {
                                                    overloadId = 7; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 6; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 6; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 6; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5])))) {
                        if (numArgs == 6) {
                            overloadId = 6; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                        } else if (numArgs >= 7
                            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6])))) {
                            if (numArgs == 7) {
                                overloadId = 6; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                            } else if (numArgs >= 8
                                && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7])))) {
                                if (numArgs == 8) {
                                    overloadId = 6; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                } else if (numArgs >= 9
                                    && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8])))) {
                                    if (numArgs == 9) {
                                        overloadId = 6; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                    } else if (numArgs >= 10
                                        && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9])))) {
                                        if (numArgs == 10) {
                                            overloadId = 6; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                        } else if (numArgs >= 11
                                            && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10])))) {
                                            if (numArgs == 11) {
                                                overloadId = 6; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                            } else if (numArgs >= 12
                                                && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[11])))) {
                                                overloadId = 6; // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ConnectionType_IDX])))->converter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 4; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericReturnArgumentHolder_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 5; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 5; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5])))) {
                        if (numArgs == 6) {
                            overloadId = 5; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                        } else if (numArgs >= 7
                            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6])))) {
                            if (numArgs == 7) {
                                overloadId = 5; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                            } else if (numArgs >= 8
                                && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7])))) {
                                if (numArgs == 8) {
                                    overloadId = 5; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                } else if (numArgs >= 9
                                    && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8])))) {
                                    if (numArgs == 9) {
                                        overloadId = 5; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                    } else if (numArgs >= 10
                                        && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9])))) {
                                        if (numArgs == 10) {
                                            overloadId = 5; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                        } else if (numArgs >= 11
                                            && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10])))) {
                                            if (numArgs == 11) {
                                                overloadId = 5; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                            } else if (numArgs >= 12
                                                && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[11])))) {
                                                if (numArgs == 12) {
                                                    overloadId = 5; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                                } else if (numArgs >= 13
                                                    && (pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[12])))) {
                                                    if (numArgs == 13) {
                                                        overloadId = 5; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                                    } else if (numArgs >= 14
                                                        && (pythonToCpp[13] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[13])))) {
                                                        overloadId = 5; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 4; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 4; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5])))) {
                        if (numArgs == 6) {
                            overloadId = 4; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                        } else if (numArgs >= 7
                            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6])))) {
                            if (numArgs == 7) {
                                overloadId = 4; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                            } else if (numArgs >= 8
                                && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7])))) {
                                if (numArgs == 8) {
                                    overloadId = 4; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                } else if (numArgs >= 9
                                    && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8])))) {
                                    if (numArgs == 9) {
                                        overloadId = 4; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                    } else if (numArgs >= 10
                                        && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9])))) {
                                        if (numArgs == 10) {
                                            overloadId = 4; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                        } else if (numArgs >= 11
                                            && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10])))) {
                                            if (numArgs == 11) {
                                                overloadId = 4; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                            } else if (numArgs >= 12
                                                && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[11])))) {
                                                if (numArgs == 12) {
                                                    overloadId = 4; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                                } else if (numArgs >= 13
                                                    && (pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[12])))) {
                                                    overloadId = 4; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5])))) {
                        if (numArgs == 6) {
                            overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                        } else if (numArgs >= 7
                            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6])))) {
                            if (numArgs == 7) {
                                overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                            } else if (numArgs >= 8
                                && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7])))) {
                                if (numArgs == 8) {
                                    overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                } else if (numArgs >= 9
                                    && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8])))) {
                                    if (numArgs == 9) {
                                        overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                    } else if (numArgs >= 10
                                        && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9])))) {
                                        if (numArgs == 10) {
                                            overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                        } else if (numArgs >= 11
                                            && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10])))) {
                                            if (numArgs == 11) {
                                                overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            } else if (numArgs >= 12
                                                && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11])))) {
                                                if (numArgs == 12) {
                                                    overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                } else if (numArgs >= 13
                                                    && (pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[12])))) {
                                                    if (numArgs == 13) {
                                                        overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                    } else if (numArgs >= 14
                                                        && (pythonToCpp[13] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[13])))) {
                                                        overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5])))) {
                        if (numArgs == 6) {
                            overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                        } else if (numArgs >= 7
                            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6])))) {
                            if (numArgs == 7) {
                                overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                            } else if (numArgs >= 8
                                && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7])))) {
                                if (numArgs == 8) {
                                    overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                } else if (numArgs >= 9
                                    && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8])))) {
                                    if (numArgs == 9) {
                                        overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                    } else if (numArgs >= 10
                                        && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9])))) {
                                        if (numArgs == 10) {
                                            overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                        } else if (numArgs >= 11
                                            && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10])))) {
                                            if (numArgs == 11) {
                                                overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            } else if (numArgs >= 12
                                                && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11])))) {
                                                if (numArgs == 12) {
                                                    overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                } else if (numArgs >= 13
                                                    && (pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[12])))) {
                                                    overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericReturnArgument_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5])))) {
                        if (numArgs == 6) {
                            overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                        } else if (numArgs >= 7
                            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6])))) {
                            if (numArgs == 7) {
                                overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                            } else if (numArgs >= 8
                                && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7])))) {
                                if (numArgs == 8) {
                                    overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                } else if (numArgs >= 9
                                    && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8])))) {
                                    if (numArgs == 9) {
                                        overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                    } else if (numArgs >= 10
                                        && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9])))) {
                                        if (numArgs == 10) {
                                            overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                        } else if (numArgs >= 11
                                            && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10])))) {
                                            if (numArgs == 11) {
                                                overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            } else if (numArgs >= 12
                                                && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11])))) {
                                                if (numArgs == 12) {
                                                    overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                } else if (numArgs >= 13
                                                    && (pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[12])))) {
                                                    overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5])))) {
                        if (numArgs == 6) {
                            overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                        } else if (numArgs >= 7
                            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6])))) {
                            if (numArgs == 7) {
                                overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                            } else if (numArgs >= 8
                                && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7])))) {
                                if (numArgs == 8) {
                                    overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                } else if (numArgs >= 9
                                    && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8])))) {
                                    if (numArgs == 9) {
                                        overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                    } else if (numArgs >= 10
                                        && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9])))) {
                                        if (numArgs == 10) {
                                            overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                        } else if (numArgs >= 11
                                            && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10])))) {
                                            if (numArgs == 11) {
                                                overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            } else if (numArgs >= 12
                                                && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11])))) {
                                                overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // invokeMethod(QObject * obj, const char * member, QGenericArgument val0, QGenericArgument val1, QGenericArgument val2, QGenericArgument val3, QGenericArgument val4, QGenericArgument val5, QGenericArgument val6, QGenericArgument val7, QGenericArgument val8, QGenericArgument val9)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_val1 = Shiboken::String::createStaticString("val1");
                if (PyDict_Contains(kwds, key_val1) != 0) {
                    value = PyDict_GetItem(kwds, key_val1);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_val1);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val1);
                }
                static PyObject *const key_val2 = Shiboken::String::createStaticString("val2");
                if (PyDict_Contains(kwds, key_val2) != 0) {
                    value = PyDict_GetItem(kwds, key_val2);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_val2);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val2);
                }
                static PyObject *const key_val3 = Shiboken::String::createStaticString("val3");
                if (PyDict_Contains(kwds, key_val3) != 0) {
                    value = PyDict_GetItem(kwds, key_val3);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_val3);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val3);
                }
                static PyObject *const key_val4 = Shiboken::String::createStaticString("val4");
                if (PyDict_Contains(kwds, key_val4) != 0) {
                    value = PyDict_GetItem(kwds, key_val4);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_val4);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val4);
                }
                static PyObject *const key_val5 = Shiboken::String::createStaticString("val5");
                if (PyDict_Contains(kwds, key_val5) != 0) {
                    value = PyDict_GetItem(kwds, key_val5);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_val5);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val5);
                }
                static PyObject *const key_val6 = Shiboken::String::createStaticString("val6");
                if (PyDict_Contains(kwds, key_val6) != 0) {
                    value = PyDict_GetItem(kwds, key_val6);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_val6);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val6);
                }
                static PyObject *const key_val7 = Shiboken::String::createStaticString("val7");
                if (PyDict_Contains(kwds, key_val7) != 0) {
                    value = PyDict_GetItem(kwds, key_val7);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_val7);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val7);
                }
                static PyObject *const key_val8 = Shiboken::String::createStaticString("val8");
                if (PyDict_Contains(kwds, key_val8) != 0) {
                    value = PyDict_GetItem(kwds, key_val8);
                    if (value != nullptr && pyArgs[10] != nullptr ) {
                        errInfo.reset(key_val8);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[10] = value;
                        if (!(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val8);
                }
                static PyObject *const key_val9 = Shiboken::String::createStaticString("val9");
                if (PyDict_Contains(kwds, key_val9) != 0) {
                    value = PyDict_GetItem(kwds, key_val9);
                    if (value != nullptr && pyArgs[11] != nullptr ) {
                        errInfo.reset(key_val9);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[11] = value;
                        if (!(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val9);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QGenericArgument cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QGenericArgument cppArg3 = QGenericArgument();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QGenericArgument cppArg4 = QGenericArgument();
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QGenericArgument cppArg5 = QGenericArgument();
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QGenericArgument cppArg6 = QGenericArgument();
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QGenericArgument cppArg7 = QGenericArgument();
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QGenericArgument cppArg8 = QGenericArgument();
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QGenericArgument cppArg9 = QGenericArgument();
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QGenericArgument cppArg10 = QGenericArgument();
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QGenericArgument cppArg11 = QGenericArgument();
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);

            if (Shiboken::Errors::occurred() == nullptr) {
                // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = ::QMetaObject::invokeMethod(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // invokeMethod(QObject * obj, const char * member, QGenericReturnArgument ret, QGenericArgument val0, QGenericArgument val1, QGenericArgument val2, QGenericArgument val3, QGenericArgument val4, QGenericArgument val5, QGenericArgument val6, QGenericArgument val7, QGenericArgument val8, QGenericArgument val9)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_val0 = Shiboken::String::createStaticString("val0");
                if (PyDict_Contains(kwds, key_val0) != 0) {
                    value = PyDict_GetItem(kwds, key_val0);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_val0);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val0);
                }
                static PyObject *const key_val1 = Shiboken::String::createStaticString("val1");
                if (PyDict_Contains(kwds, key_val1) != 0) {
                    value = PyDict_GetItem(kwds, key_val1);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_val1);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val1);
                }
                static PyObject *const key_val2 = Shiboken::String::createStaticString("val2");
                if (PyDict_Contains(kwds, key_val2) != 0) {
                    value = PyDict_GetItem(kwds, key_val2);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_val2);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val2);
                }
                static PyObject *const key_val3 = Shiboken::String::createStaticString("val3");
                if (PyDict_Contains(kwds, key_val3) != 0) {
                    value = PyDict_GetItem(kwds, key_val3);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_val3);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val3);
                }
                static PyObject *const key_val4 = Shiboken::String::createStaticString("val4");
                if (PyDict_Contains(kwds, key_val4) != 0) {
                    value = PyDict_GetItem(kwds, key_val4);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_val4);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val4);
                }
                static PyObject *const key_val5 = Shiboken::String::createStaticString("val5");
                if (PyDict_Contains(kwds, key_val5) != 0) {
                    value = PyDict_GetItem(kwds, key_val5);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_val5);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val5);
                }
                static PyObject *const key_val6 = Shiboken::String::createStaticString("val6");
                if (PyDict_Contains(kwds, key_val6) != 0) {
                    value = PyDict_GetItem(kwds, key_val6);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_val6);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val6);
                }
                static PyObject *const key_val7 = Shiboken::String::createStaticString("val7");
                if (PyDict_Contains(kwds, key_val7) != 0) {
                    value = PyDict_GetItem(kwds, key_val7);
                    if (value != nullptr && pyArgs[10] != nullptr ) {
                        errInfo.reset(key_val7);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[10] = value;
                        if (!(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val7);
                }
                static PyObject *const key_val8 = Shiboken::String::createStaticString("val8");
                if (PyDict_Contains(kwds, key_val8) != 0) {
                    value = PyDict_GetItem(kwds, key_val8);
                    if (value != nullptr && pyArgs[11] != nullptr ) {
                        errInfo.reset(key_val8);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[11] = value;
                        if (!(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val8);
                }
                static PyObject *const key_val9 = Shiboken::String::createStaticString("val9");
                if (PyDict_Contains(kwds, key_val9) != 0) {
                    value = PyDict_GetItem(kwds, key_val9);
                    if (value != nullptr && pyArgs[12] != nullptr ) {
                        errInfo.reset(key_val9);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[12] = value;
                        if (!(pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[12]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val9);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QGenericReturnArgument cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QGenericArgument cppArg3 = QGenericArgument(nullptr);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QGenericArgument cppArg4 = QGenericArgument();
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QGenericArgument cppArg5 = QGenericArgument();
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QGenericArgument cppArg6 = QGenericArgument();
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QGenericArgument cppArg7 = QGenericArgument();
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QGenericArgument cppArg8 = QGenericArgument();
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QGenericArgument cppArg9 = QGenericArgument();
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QGenericArgument cppArg10 = QGenericArgument();
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QGenericArgument cppArg11 = QGenericArgument();
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);
            if (!Shiboken::Object::isValid(pyArgs[12]))
                return {};
            ::QGenericArgument cppArg12 = QGenericArgument();
            if (pythonToCpp[12])
                pythonToCpp[12](pyArgs[12], &cppArg12);

            if (Shiboken::Errors::occurred() == nullptr) {
                // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = ::QMetaObject::invokeMethod(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // invokeMethod(QObject * obj, const char * member, Qt::ConnectionType arg__3, QGenericReturnArgument ret, QGenericArgument val0, QGenericArgument val1, QGenericArgument val2, QGenericArgument val3, QGenericArgument val4, QGenericArgument val5, QGenericArgument val6, QGenericArgument val7, QGenericArgument val8, QGenericArgument val9)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_val0 = Shiboken::String::createStaticString("val0");
                if (PyDict_Contains(kwds, key_val0) != 0) {
                    value = PyDict_GetItem(kwds, key_val0);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_val0);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val0);
                }
                static PyObject *const key_val1 = Shiboken::String::createStaticString("val1");
                if (PyDict_Contains(kwds, key_val1) != 0) {
                    value = PyDict_GetItem(kwds, key_val1);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_val1);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val1);
                }
                static PyObject *const key_val2 = Shiboken::String::createStaticString("val2");
                if (PyDict_Contains(kwds, key_val2) != 0) {
                    value = PyDict_GetItem(kwds, key_val2);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_val2);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val2);
                }
                static PyObject *const key_val3 = Shiboken::String::createStaticString("val3");
                if (PyDict_Contains(kwds, key_val3) != 0) {
                    value = PyDict_GetItem(kwds, key_val3);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_val3);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val3);
                }
                static PyObject *const key_val4 = Shiboken::String::createStaticString("val4");
                if (PyDict_Contains(kwds, key_val4) != 0) {
                    value = PyDict_GetItem(kwds, key_val4);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_val4);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val4);
                }
                static PyObject *const key_val5 = Shiboken::String::createStaticString("val5");
                if (PyDict_Contains(kwds, key_val5) != 0) {
                    value = PyDict_GetItem(kwds, key_val5);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_val5);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val5);
                }
                static PyObject *const key_val6 = Shiboken::String::createStaticString("val6");
                if (PyDict_Contains(kwds, key_val6) != 0) {
                    value = PyDict_GetItem(kwds, key_val6);
                    if (value != nullptr && pyArgs[10] != nullptr ) {
                        errInfo.reset(key_val6);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[10] = value;
                        if (!(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val6);
                }
                static PyObject *const key_val7 = Shiboken::String::createStaticString("val7");
                if (PyDict_Contains(kwds, key_val7) != 0) {
                    value = PyDict_GetItem(kwds, key_val7);
                    if (value != nullptr && pyArgs[11] != nullptr ) {
                        errInfo.reset(key_val7);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[11] = value;
                        if (!(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val7);
                }
                static PyObject *const key_val8 = Shiboken::String::createStaticString("val8");
                if (PyDict_Contains(kwds, key_val8) != 0) {
                    value = PyDict_GetItem(kwds, key_val8);
                    if (value != nullptr && pyArgs[12] != nullptr ) {
                        errInfo.reset(key_val8);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[12] = value;
                        if (!(pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[12]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val8);
                }
                static PyObject *const key_val9 = Shiboken::String::createStaticString("val9");
                if (PyDict_Contains(kwds, key_val9) != 0) {
                    value = PyDict_GetItem(kwds, key_val9);
                    if (value != nullptr && pyArgs[13] != nullptr ) {
                        errInfo.reset(key_val9);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[13] = value;
                        if (!(pythonToCpp[13] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[13]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val9);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::ConnectionType cppArg2{Qt::AutoConnection};
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QGenericReturnArgument cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QGenericArgument cppArg4 = QGenericArgument(nullptr);
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QGenericArgument cppArg5 = QGenericArgument();
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QGenericArgument cppArg6 = QGenericArgument();
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QGenericArgument cppArg7 = QGenericArgument();
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QGenericArgument cppArg8 = QGenericArgument();
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QGenericArgument cppArg9 = QGenericArgument();
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QGenericArgument cppArg10 = QGenericArgument();
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QGenericArgument cppArg11 = QGenericArgument();
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);
            if (!Shiboken::Object::isValid(pyArgs[12]))
                return {};
            ::QGenericArgument cppArg12 = QGenericArgument();
            if (pythonToCpp[12])
                pythonToCpp[12](pyArgs[12], &cppArg12);
            if (!Shiboken::Object::isValid(pyArgs[13]))
                return {};
            ::QGenericArgument cppArg13 = QGenericArgument();
            if (pythonToCpp[13])
                pythonToCpp[13](pyArgs[13], &cppArg13);

            if (Shiboken::Errors::occurred() == nullptr) {
                // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = ::QMetaObject::invokeMethod(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12, cppArg13);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 3: // invokeMethod(QObject * obj, const char * member, Qt::ConnectionType type, QGenericArgument val0, QGenericArgument val1, QGenericArgument val2, QGenericArgument val3, QGenericArgument val4, QGenericArgument val5, QGenericArgument val6, QGenericArgument val7, QGenericArgument val8, QGenericArgument val9)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_val1 = Shiboken::String::createStaticString("val1");
                if (PyDict_Contains(kwds, key_val1) != 0) {
                    value = PyDict_GetItem(kwds, key_val1);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_val1);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val1);
                }
                static PyObject *const key_val2 = Shiboken::String::createStaticString("val2");
                if (PyDict_Contains(kwds, key_val2) != 0) {
                    value = PyDict_GetItem(kwds, key_val2);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_val2);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val2);
                }
                static PyObject *const key_val3 = Shiboken::String::createStaticString("val3");
                if (PyDict_Contains(kwds, key_val3) != 0) {
                    value = PyDict_GetItem(kwds, key_val3);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_val3);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val3);
                }
                static PyObject *const key_val4 = Shiboken::String::createStaticString("val4");
                if (PyDict_Contains(kwds, key_val4) != 0) {
                    value = PyDict_GetItem(kwds, key_val4);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_val4);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val4);
                }
                static PyObject *const key_val5 = Shiboken::String::createStaticString("val5");
                if (PyDict_Contains(kwds, key_val5) != 0) {
                    value = PyDict_GetItem(kwds, key_val5);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_val5);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val5);
                }
                static PyObject *const key_val6 = Shiboken::String::createStaticString("val6");
                if (PyDict_Contains(kwds, key_val6) != 0) {
                    value = PyDict_GetItem(kwds, key_val6);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_val6);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val6);
                }
                static PyObject *const key_val7 = Shiboken::String::createStaticString("val7");
                if (PyDict_Contains(kwds, key_val7) != 0) {
                    value = PyDict_GetItem(kwds, key_val7);
                    if (value != nullptr && pyArgs[10] != nullptr ) {
                        errInfo.reset(key_val7);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[10] = value;
                        if (!(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[10]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val7);
                }
                static PyObject *const key_val8 = Shiboken::String::createStaticString("val8");
                if (PyDict_Contains(kwds, key_val8) != 0) {
                    value = PyDict_GetItem(kwds, key_val8);
                    if (value != nullptr && pyArgs[11] != nullptr ) {
                        errInfo.reset(key_val8);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[11] = value;
                        if (!(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[11]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val8);
                }
                static PyObject *const key_val9 = Shiboken::String::createStaticString("val9");
                if (PyDict_Contains(kwds, key_val9) != 0) {
                    value = PyDict_GetItem(kwds, key_val9);
                    if (value != nullptr && pyArgs[12] != nullptr ) {
                        errInfo.reset(key_val9);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[12] = value;
                        if (!(pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[12]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val9);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::ConnectionType cppArg2{Qt::AutoConnection};
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QGenericArgument cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QGenericArgument cppArg4 = QGenericArgument();
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QGenericArgument cppArg5 = QGenericArgument();
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QGenericArgument cppArg6 = QGenericArgument();
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QGenericArgument cppArg7 = QGenericArgument();
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QGenericArgument cppArg8 = QGenericArgument();
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QGenericArgument cppArg9 = QGenericArgument();
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QGenericArgument cppArg10 = QGenericArgument();
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QGenericArgument cppArg11 = QGenericArgument();
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);
            if (!Shiboken::Object::isValid(pyArgs[12]))
                return {};
            ::QGenericArgument cppArg12 = QGenericArgument();
            if (pythonToCpp[12])
                pythonToCpp[12](pyArgs[12], &cppArg12);

            if (Shiboken::Errors::occurred() == nullptr) {
                // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = ::QMetaObject::invokeMethod(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 4: // invokeMethod(QObject * object, const char * member, Qt::ConnectionType type, QtCoreHelper::QGenericArgumentHolder val0, QtCoreHelper::QGenericArgumentHolder val1, QtCoreHelper::QGenericArgumentHolder val2, QtCoreHelper::QGenericArgumentHolder val3, QtCoreHelper::QGenericArgumentHolder val4, QtCoreHelper::QGenericArgumentHolder val5, QtCoreHelper::QGenericArgumentHolder val6, QtCoreHelper::QGenericArgumentHolder val7, QtCoreHelper::QGenericArgumentHolder val8, QtCoreHelper::QGenericArgumentHolder val9)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_val0 = Shiboken::String::createStaticString("val0");
                if (PyDict_Contains(kwds, key_val0) != 0) {
                    value = PyDict_GetItem(kwds, key_val0);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_val0);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val0);
                }
                static PyObject *const key_val1 = Shiboken::String::createStaticString("val1");
                if (PyDict_Contains(kwds, key_val1) != 0) {
                    value = PyDict_GetItem(kwds, key_val1);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_val1);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val1);
                }
                static PyObject *const key_val2 = Shiboken::String::createStaticString("val2");
                if (PyDict_Contains(kwds, key_val2) != 0) {
                    value = PyDict_GetItem(kwds, key_val2);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_val2);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val2);
                }
                static PyObject *const key_val3 = Shiboken::String::createStaticString("val3");
                if (PyDict_Contains(kwds, key_val3) != 0) {
                    value = PyDict_GetItem(kwds, key_val3);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_val3);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val3);
                }
                static PyObject *const key_val4 = Shiboken::String::createStaticString("val4");
                if (PyDict_Contains(kwds, key_val4) != 0) {
                    value = PyDict_GetItem(kwds, key_val4);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_val4);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val4);
                }
                static PyObject *const key_val5 = Shiboken::String::createStaticString("val5");
                if (PyDict_Contains(kwds, key_val5) != 0) {
                    value = PyDict_GetItem(kwds, key_val5);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_val5);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val5);
                }
                static PyObject *const key_val6 = Shiboken::String::createStaticString("val6");
                if (PyDict_Contains(kwds, key_val6) != 0) {
                    value = PyDict_GetItem(kwds, key_val6);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_val6);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val6);
                }
                static PyObject *const key_val7 = Shiboken::String::createStaticString("val7");
                if (PyDict_Contains(kwds, key_val7) != 0) {
                    value = PyDict_GetItem(kwds, key_val7);
                    if (value != nullptr && pyArgs[10] != nullptr ) {
                        errInfo.reset(key_val7);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[10] = value;
                        if (!(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val7);
                }
                static PyObject *const key_val8 = Shiboken::String::createStaticString("val8");
                if (PyDict_Contains(kwds, key_val8) != 0) {
                    value = PyDict_GetItem(kwds, key_val8);
                    if (value != nullptr && pyArgs[11] != nullptr ) {
                        errInfo.reset(key_val8);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[11] = value;
                        if (!(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[11]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val8);
                }
                static PyObject *const key_val9 = Shiboken::String::createStaticString("val9");
                if (PyDict_Contains(kwds, key_val9) != 0) {
                    value = PyDict_GetItem(kwds, key_val9);
                    if (value != nullptr && pyArgs[12] != nullptr ) {
                        errInfo.reset(key_val9);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[12] = value;
                        if (!(pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[12]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val9);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            ::Qt::ConnectionType cppArg2{Qt::AutoConnection};
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg3{};
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            SBK_UNUSED(cppArg3)
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg4{};
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            SBK_UNUSED(cppArg4)
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg5{};
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            SBK_UNUSED(cppArg5)
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg6{};
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            SBK_UNUSED(cppArg6)
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg7{};
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            SBK_UNUSED(cppArg7)
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg8{};
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            SBK_UNUSED(cppArg8)
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg9{};
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            SBK_UNUSED(cppArg9)
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg10{};
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            SBK_UNUSED(cppArg10)
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg11{};
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);
            SBK_UNUSED(cppArg11)
            if (!Shiboken::Object::isValid(pyArgs[12]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg12{};
            if (pythonToCpp[12])
                pythonToCpp[12](pyArgs[12], &cppArg12);
            SBK_UNUSED(cppArg12)

            if (Shiboken::Errors::occurred() == nullptr) {
                // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmetaobject-invokemethod-conn-type-arg)]
                pyResult = invokeMetaMethod(createInvokeMetaMethodFunc(cppArg0, cppArg1, cppArg2),
                                             cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12);
                // END of custom code block [file: ../glue/qtcore.cpp (qmetaobject-invokemethod-conn-type-arg)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 5: // invokeMethod(QObject * object, const char * member, Qt::ConnectionType type, QtCoreHelper::QGenericReturnArgumentHolder ret, QtCoreHelper::QGenericArgumentHolder val0, QtCoreHelper::QGenericArgumentHolder val1, QtCoreHelper::QGenericArgumentHolder val2, QtCoreHelper::QGenericArgumentHolder val3, QtCoreHelper::QGenericArgumentHolder val4, QtCoreHelper::QGenericArgumentHolder val5, QtCoreHelper::QGenericArgumentHolder val6, QtCoreHelper::QGenericArgumentHolder val7, QtCoreHelper::QGenericArgumentHolder val8, QtCoreHelper::QGenericArgumentHolder val9)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_val0 = Shiboken::String::createStaticString("val0");
                if (PyDict_Contains(kwds, key_val0) != 0) {
                    value = PyDict_GetItem(kwds, key_val0);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_val0);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val0);
                }
                static PyObject *const key_val1 = Shiboken::String::createStaticString("val1");
                if (PyDict_Contains(kwds, key_val1) != 0) {
                    value = PyDict_GetItem(kwds, key_val1);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_val1);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val1);
                }
                static PyObject *const key_val2 = Shiboken::String::createStaticString("val2");
                if (PyDict_Contains(kwds, key_val2) != 0) {
                    value = PyDict_GetItem(kwds, key_val2);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_val2);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val2);
                }
                static PyObject *const key_val3 = Shiboken::String::createStaticString("val3");
                if (PyDict_Contains(kwds, key_val3) != 0) {
                    value = PyDict_GetItem(kwds, key_val3);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_val3);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val3);
                }
                static PyObject *const key_val4 = Shiboken::String::createStaticString("val4");
                if (PyDict_Contains(kwds, key_val4) != 0) {
                    value = PyDict_GetItem(kwds, key_val4);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_val4);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val4);
                }
                static PyObject *const key_val5 = Shiboken::String::createStaticString("val5");
                if (PyDict_Contains(kwds, key_val5) != 0) {
                    value = PyDict_GetItem(kwds, key_val5);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_val5);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val5);
                }
                static PyObject *const key_val6 = Shiboken::String::createStaticString("val6");
                if (PyDict_Contains(kwds, key_val6) != 0) {
                    value = PyDict_GetItem(kwds, key_val6);
                    if (value != nullptr && pyArgs[10] != nullptr ) {
                        errInfo.reset(key_val6);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[10] = value;
                        if (!(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val6);
                }
                static PyObject *const key_val7 = Shiboken::String::createStaticString("val7");
                if (PyDict_Contains(kwds, key_val7) != 0) {
                    value = PyDict_GetItem(kwds, key_val7);
                    if (value != nullptr && pyArgs[11] != nullptr ) {
                        errInfo.reset(key_val7);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[11] = value;
                        if (!(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[11]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val7);
                }
                static PyObject *const key_val8 = Shiboken::String::createStaticString("val8");
                if (PyDict_Contains(kwds, key_val8) != 0) {
                    value = PyDict_GetItem(kwds, key_val8);
                    if (value != nullptr && pyArgs[12] != nullptr ) {
                        errInfo.reset(key_val8);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[12] = value;
                        if (!(pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[12]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val8);
                }
                static PyObject *const key_val9 = Shiboken::String::createStaticString("val9");
                if (PyDict_Contains(kwds, key_val9) != 0) {
                    value = PyDict_GetItem(kwds, key_val9);
                    if (value != nullptr && pyArgs[13] != nullptr ) {
                        errInfo.reset(key_val9);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[13] = value;
                        if (!(pythonToCpp[13] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[13]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val9);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            ::Qt::ConnectionType cppArg2{Qt::AutoConnection};
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QtCoreHelper::QGenericReturnArgumentHolder cppArg3 = ::QtCoreHelper::QGenericReturnArgumentHolder(::QMetaType(), static_cast<void*>(nullptr));
            pythonToCpp[3](pyArgs[3], &cppArg3);
            SBK_UNUSED(cppArg3)
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg4{};
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            SBK_UNUSED(cppArg4)
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg5{};
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            SBK_UNUSED(cppArg5)
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg6{};
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            SBK_UNUSED(cppArg6)
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg7{};
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            SBK_UNUSED(cppArg7)
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg8{};
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            SBK_UNUSED(cppArg8)
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg9{};
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            SBK_UNUSED(cppArg9)
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg10{};
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            SBK_UNUSED(cppArg10)
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg11{};
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);
            SBK_UNUSED(cppArg11)
            if (!Shiboken::Object::isValid(pyArgs[12]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg12{};
            if (pythonToCpp[12])
                pythonToCpp[12](pyArgs[12], &cppArg12);
            SBK_UNUSED(cppArg12)
            if (!Shiboken::Object::isValid(pyArgs[13]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg13{};
            if (pythonToCpp[13])
                pythonToCpp[13](pyArgs[13], &cppArg13);
            SBK_UNUSED(cppArg13)

            if (Shiboken::Errors::occurred() == nullptr) {
                // invokeMethod(QObject*,const char*,Qt::ConnectionType,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmetaobject-invokemethod-conn-type-return-arg)]
                pyResult = invokeMetaMethodWithReturn(createInvokeMetaMethodFuncWithReturn(cppArg0, cppArg1, cppArg2),
                                                      cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12, cppArg13);
                // END of custom code block [file: ../glue/qtcore.cpp (qmetaobject-invokemethod-conn-type-return-arg)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 6: // invokeMethod(QObject * object, const char * member, QtCoreHelper::QGenericArgumentHolder val0, QtCoreHelper::QGenericArgumentHolder val1, QtCoreHelper::QGenericArgumentHolder val2, QtCoreHelper::QGenericArgumentHolder val3, QtCoreHelper::QGenericArgumentHolder val4, QtCoreHelper::QGenericArgumentHolder val5, QtCoreHelper::QGenericArgumentHolder val6, QtCoreHelper::QGenericArgumentHolder val7, QtCoreHelper::QGenericArgumentHolder val8, QtCoreHelper::QGenericArgumentHolder val9)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_val0 = Shiboken::String::createStaticString("val0");
                if (PyDict_Contains(kwds, key_val0) != 0) {
                    value = PyDict_GetItem(kwds, key_val0);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_val0);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val0);
                }
                static PyObject *const key_val1 = Shiboken::String::createStaticString("val1");
                if (PyDict_Contains(kwds, key_val1) != 0) {
                    value = PyDict_GetItem(kwds, key_val1);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_val1);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val1);
                }
                static PyObject *const key_val2 = Shiboken::String::createStaticString("val2");
                if (PyDict_Contains(kwds, key_val2) != 0) {
                    value = PyDict_GetItem(kwds, key_val2);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_val2);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val2);
                }
                static PyObject *const key_val3 = Shiboken::String::createStaticString("val3");
                if (PyDict_Contains(kwds, key_val3) != 0) {
                    value = PyDict_GetItem(kwds, key_val3);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_val3);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val3);
                }
                static PyObject *const key_val4 = Shiboken::String::createStaticString("val4");
                if (PyDict_Contains(kwds, key_val4) != 0) {
                    value = PyDict_GetItem(kwds, key_val4);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_val4);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val4);
                }
                static PyObject *const key_val5 = Shiboken::String::createStaticString("val5");
                if (PyDict_Contains(kwds, key_val5) != 0) {
                    value = PyDict_GetItem(kwds, key_val5);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_val5);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val5);
                }
                static PyObject *const key_val6 = Shiboken::String::createStaticString("val6");
                if (PyDict_Contains(kwds, key_val6) != 0) {
                    value = PyDict_GetItem(kwds, key_val6);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_val6);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val6);
                }
                static PyObject *const key_val7 = Shiboken::String::createStaticString("val7");
                if (PyDict_Contains(kwds, key_val7) != 0) {
                    value = PyDict_GetItem(kwds, key_val7);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_val7);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val7);
                }
                static PyObject *const key_val8 = Shiboken::String::createStaticString("val8");
                if (PyDict_Contains(kwds, key_val8) != 0) {
                    value = PyDict_GetItem(kwds, key_val8);
                    if (value != nullptr && pyArgs[10] != nullptr ) {
                        errInfo.reset(key_val8);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[10] = value;
                        if (!(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val8);
                }
                static PyObject *const key_val9 = Shiboken::String::createStaticString("val9");
                if (PyDict_Contains(kwds, key_val9) != 0) {
                    value = PyDict_GetItem(kwds, key_val9);
                    if (value != nullptr && pyArgs[11] != nullptr ) {
                        errInfo.reset(key_val9);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[11] = value;
                        if (!(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[11]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val9);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg2{};
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg3{};
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            SBK_UNUSED(cppArg3)
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg4{};
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            SBK_UNUSED(cppArg4)
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg5{};
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            SBK_UNUSED(cppArg5)
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg6{};
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            SBK_UNUSED(cppArg6)
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg7{};
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            SBK_UNUSED(cppArg7)
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg8{};
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            SBK_UNUSED(cppArg8)
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg9{};
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            SBK_UNUSED(cppArg9)
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg10{};
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            SBK_UNUSED(cppArg10)
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg11{};
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);
            SBK_UNUSED(cppArg11)

            if (Shiboken::Errors::occurred() == nullptr) {
                // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmetaobject-invokemethod-arg)]
                pyResult = invokeMetaMethod(createInvokeMetaMethodFunc(cppArg0, cppArg1),
                                            cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11);
                // END of custom code block [file: ../glue/qtcore.cpp (qmetaobject-invokemethod-arg)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 7: // invokeMethod(QObject * object, const char * member, QtCoreHelper::QGenericReturnArgumentHolder ret, QtCoreHelper::QGenericArgumentHolder val0, QtCoreHelper::QGenericArgumentHolder val1, QtCoreHelper::QGenericArgumentHolder val2, QtCoreHelper::QGenericArgumentHolder val3, QtCoreHelper::QGenericArgumentHolder val4, QtCoreHelper::QGenericArgumentHolder val5, QtCoreHelper::QGenericArgumentHolder val6, QtCoreHelper::QGenericArgumentHolder val7, QtCoreHelper::QGenericArgumentHolder val8, QtCoreHelper::QGenericArgumentHolder val9)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_val0 = Shiboken::String::createStaticString("val0");
                if (PyDict_Contains(kwds, key_val0) != 0) {
                    value = PyDict_GetItem(kwds, key_val0);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_val0);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val0);
                }
                static PyObject *const key_val1 = Shiboken::String::createStaticString("val1");
                if (PyDict_Contains(kwds, key_val1) != 0) {
                    value = PyDict_GetItem(kwds, key_val1);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_val1);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val1);
                }
                static PyObject *const key_val2 = Shiboken::String::createStaticString("val2");
                if (PyDict_Contains(kwds, key_val2) != 0) {
                    value = PyDict_GetItem(kwds, key_val2);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_val2);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val2);
                }
                static PyObject *const key_val3 = Shiboken::String::createStaticString("val3");
                if (PyDict_Contains(kwds, key_val3) != 0) {
                    value = PyDict_GetItem(kwds, key_val3);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_val3);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val3);
                }
                static PyObject *const key_val4 = Shiboken::String::createStaticString("val4");
                if (PyDict_Contains(kwds, key_val4) != 0) {
                    value = PyDict_GetItem(kwds, key_val4);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_val4);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val4);
                }
                static PyObject *const key_val5 = Shiboken::String::createStaticString("val5");
                if (PyDict_Contains(kwds, key_val5) != 0) {
                    value = PyDict_GetItem(kwds, key_val5);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_val5);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val5);
                }
                static PyObject *const key_val6 = Shiboken::String::createStaticString("val6");
                if (PyDict_Contains(kwds, key_val6) != 0) {
                    value = PyDict_GetItem(kwds, key_val6);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_val6);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[9]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val6);
                }
                static PyObject *const key_val7 = Shiboken::String::createStaticString("val7");
                if (PyDict_Contains(kwds, key_val7) != 0) {
                    value = PyDict_GetItem(kwds, key_val7);
                    if (value != nullptr && pyArgs[10] != nullptr ) {
                        errInfo.reset(key_val7);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[10] = value;
                        if (!(pythonToCpp[10] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[10]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val7);
                }
                static PyObject *const key_val8 = Shiboken::String::createStaticString("val8");
                if (PyDict_Contains(kwds, key_val8) != 0) {
                    value = PyDict_GetItem(kwds, key_val8);
                    if (value != nullptr && pyArgs[11] != nullptr ) {
                        errInfo.reset(key_val8);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[11] = value;
                        if (!(pythonToCpp[11] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[11]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val8);
                }
                static PyObject *const key_val9 = Shiboken::String::createStaticString("val9");
                if (PyDict_Contains(kwds, key_val9) != 0) {
                    value = PyDict_GetItem(kwds, key_val9);
                    if (value != nullptr && pyArgs[12] != nullptr ) {
                        errInfo.reset(key_val9);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[12] = value;
                        if (!(pythonToCpp[12] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtCoreHelper_QGenericArgumentHolder_IDX]), (pyArgs[12]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_val9);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QtCoreHelper::QGenericReturnArgumentHolder cppArg2 = ::QtCoreHelper::QGenericReturnArgumentHolder(::QMetaType(), static_cast<void*>(nullptr));
            pythonToCpp[2](pyArgs[2], &cppArg2);
            SBK_UNUSED(cppArg2)
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg3{};
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            SBK_UNUSED(cppArg3)
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg4{};
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            SBK_UNUSED(cppArg4)
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg5{};
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            SBK_UNUSED(cppArg5)
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg6{};
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            SBK_UNUSED(cppArg6)
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg7{};
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            SBK_UNUSED(cppArg7)
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg8{};
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            SBK_UNUSED(cppArg8)
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg9{};
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);
            SBK_UNUSED(cppArg9)
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg10{};
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);
            SBK_UNUSED(cppArg10)
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg11{};
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);
            SBK_UNUSED(cppArg11)
            if (!Shiboken::Object::isValid(pyArgs[12]))
                return {};
            ::QtCoreHelper::QGenericArgumentHolder cppArg12{};
            if (pythonToCpp[12])
                pythonToCpp[12](pyArgs[12], &cppArg12);
            SBK_UNUSED(cppArg12)

            if (Shiboken::Errors::occurred() == nullptr) {
                // invokeMethod(QObject*,const char*,QtCoreHelper::QGenericReturnArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder,QtCoreHelper::QGenericArgumentHolder)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmetaobject-invokemethod-return-arg)]
                pyResult = invokeMetaMethodWithReturn(createInvokeMetaMethodFuncWithReturn(cppArg0, cppArg1),
                                                      cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12);
                // END of custom code block [file: ../glue/qtcore.cpp (qmetaobject-invokemethod-return-arg)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_metaType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.metaType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // metaType()const
            QMetaType cppResult = const_cast<const ::QMetaObject *>(cppSelf)->metaType();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaType_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_method(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.method";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaObject::method(int)const->QMetaMethod
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // method(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // method(int)const
            QMetaMethod cppResult = const_cast<const ::QMetaObject *>(cppSelf)->method(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_methodCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.methodCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // methodCount()const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->methodCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_methodOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.methodOffset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // methodOffset()const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->methodOffset();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_newInstance(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.newInstance";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[10];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 10));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOOOO:newInstance", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMetaObject::newInstance(QGenericArgument,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=,QGenericArgument=)const->QObject*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6])))) {
                                if (numArgs == 7) {
                                    overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                } else if (numArgs >= 8
                                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7])))) {
                                    if (numArgs == 8) {
                                        overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                    } else if (numArgs >= 9
                                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8])))) {
                                        if (numArgs == 9) {
                                            overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        } else if (numArgs >= 10
                                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9])))) {
                                            overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_val1 = Shiboken::String::createStaticString("val1");
            if (PyDict_Contains(kwds, key_val1) != 0) {
                value = PyDict_GetItem(kwds, key_val1);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_val1);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_val1);
            }
            static PyObject *const key_val2 = Shiboken::String::createStaticString("val2");
            if (PyDict_Contains(kwds, key_val2) != 0) {
                value = PyDict_GetItem(kwds, key_val2);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_val2);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_val2);
            }
            static PyObject *const key_val3 = Shiboken::String::createStaticString("val3");
            if (PyDict_Contains(kwds, key_val3) != 0) {
                value = PyDict_GetItem(kwds, key_val3);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_val3);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_val3);
            }
            static PyObject *const key_val4 = Shiboken::String::createStaticString("val4");
            if (PyDict_Contains(kwds, key_val4) != 0) {
                value = PyDict_GetItem(kwds, key_val4);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_val4);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_val4);
            }
            static PyObject *const key_val5 = Shiboken::String::createStaticString("val5");
            if (PyDict_Contains(kwds, key_val5) != 0) {
                value = PyDict_GetItem(kwds, key_val5);
                if (value != nullptr && pyArgs[5] != nullptr ) {
                    errInfo.reset(key_val5);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[5] = value;
                    if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[5]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_val5);
            }
            static PyObject *const key_val6 = Shiboken::String::createStaticString("val6");
            if (PyDict_Contains(kwds, key_val6) != 0) {
                value = PyDict_GetItem(kwds, key_val6);
                if (value != nullptr && pyArgs[6] != nullptr ) {
                    errInfo.reset(key_val6);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[6] = value;
                    if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[6]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_val6);
            }
            static PyObject *const key_val7 = Shiboken::String::createStaticString("val7");
            if (PyDict_Contains(kwds, key_val7) != 0) {
                value = PyDict_GetItem(kwds, key_val7);
                if (value != nullptr && pyArgs[7] != nullptr ) {
                    errInfo.reset(key_val7);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[7] = value;
                    if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[7]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_val7);
            }
            static PyObject *const key_val8 = Shiboken::String::createStaticString("val8");
            if (PyDict_Contains(kwds, key_val8) != 0) {
                value = PyDict_GetItem(kwds, key_val8);
                if (value != nullptr && pyArgs[8] != nullptr ) {
                    errInfo.reset(key_val8);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[8] = value;
                    if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[8]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_val8);
            }
            static PyObject *const key_val9 = Shiboken::String::createStaticString("val9");
            if (PyDict_Contains(kwds, key_val9) != 0) {
                value = PyDict_GetItem(kwds, key_val9);
                if (value != nullptr && pyArgs[9] != nullptr ) {
                    errInfo.reset(key_val9);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[9] = value;
                    if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QGenericArgument_IDX]), (pyArgs[9]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_val9);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QGenericArgument cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QGenericArgument cppArg1 = QGenericArgument();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QGenericArgument cppArg2 = QGenericArgument();
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QGenericArgument cppArg3 = QGenericArgument();
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        if (!Shiboken::Object::isValid(pyArgs[4]))
            return {};
        ::QGenericArgument cppArg4 = QGenericArgument();
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);
        if (!Shiboken::Object::isValid(pyArgs[5]))
            return {};
        ::QGenericArgument cppArg5 = QGenericArgument();
        if (pythonToCpp[5])
            pythonToCpp[5](pyArgs[5], &cppArg5);
        if (!Shiboken::Object::isValid(pyArgs[6]))
            return {};
        ::QGenericArgument cppArg6 = QGenericArgument();
        if (pythonToCpp[6])
            pythonToCpp[6](pyArgs[6], &cppArg6);
        if (!Shiboken::Object::isValid(pyArgs[7]))
            return {};
        ::QGenericArgument cppArg7 = QGenericArgument();
        if (pythonToCpp[7])
            pythonToCpp[7](pyArgs[7], &cppArg7);
        if (!Shiboken::Object::isValid(pyArgs[8]))
            return {};
        ::QGenericArgument cppArg8 = QGenericArgument();
        if (pythonToCpp[8])
            pythonToCpp[8](pyArgs[8], &cppArg8);
        if (!Shiboken::Object::isValid(pyArgs[9]))
            return {};
        ::QGenericArgument cppArg9 = QGenericArgument();
        if (pythonToCpp[9])
            pythonToCpp[9](pyArgs[9], &cppArg9);

        if (Shiboken::Errors::occurred() == nullptr) {
            // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            QObject * cppResult = const_cast<const ::QMetaObject *>(cppSelf)->newInstance(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_normalizedSignature(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.normalizedSignature";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMetaObject::normalizedSignature(const char*)->QByteArray
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // normalizedSignature(const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // normalizedSignature(const char*)
            QByteArray cppResult = ::QMetaObject::normalizedSignature(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_normalizedType(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.normalizedType";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QMetaObject::normalizedType(const char*)->QByteArray
    if (Shiboken::String::check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // normalizedType(const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // normalizedType(const char*)
            QByteArray cppResult = ::QMetaObject::normalizedType(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_property(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.property";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMetaObject::property(int)const->QMetaProperty
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // property(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // property(int)const
            QMetaProperty cppResult = const_cast<const ::QMetaObject *>(cppSelf)->property(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaProperty_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_propertyCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.propertyCount";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // propertyCount()const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->propertyCount();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_propertyOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.propertyOffset";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // propertyOffset()const
            int cppResult = const_cast<const ::QMetaObject *>(cppSelf)->propertyOffset();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_superClass(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.superClass";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // superClass()const
            const QMetaObject * cppResult = const_cast<const ::QMetaObject *>(cppSelf)->superClass();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QMetaObjectFunc_userProperty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMetaObject *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtCore.QMetaObject.userProperty";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // userProperty()const
            QMetaProperty cppResult = const_cast<const ::QMetaObject *>(cppSelf)->userProperty();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaProperty_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QMetaObject_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QMetaObject_EnumFlagInfo[] = {
    "Call:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMetaObject_methods[] = {
    {"cast", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_cast), METH_O, nullptr},
    {"checkConnectArgs", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_checkConnectArgs), METH_VARARGS|METH_STATIC, nullptr},
    {"classInfo", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_classInfo), METH_O, nullptr},
    {"classInfoCount", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_classInfoCount), METH_NOARGS, nullptr},
    {"classInfoOffset", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_classInfoOffset), METH_NOARGS, nullptr},
    {"className", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_className), METH_NOARGS, nullptr},
    {"connectSlotsByName", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_connectSlotsByName), METH_O|METH_STATIC, nullptr},
    {"constructor", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_constructor), METH_O, nullptr},
    {"constructorCount", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_constructorCount), METH_NOARGS, nullptr},
    {"disconnect", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_disconnect), METH_VARARGS|METH_STATIC, nullptr},
    {"disconnectOne", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_disconnectOne), METH_VARARGS|METH_STATIC, nullptr},
    {"enumerator", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_enumerator), METH_O, nullptr},
    {"enumeratorCount", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_enumeratorCount), METH_NOARGS, nullptr},
    {"enumeratorOffset", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_enumeratorOffset), METH_NOARGS, nullptr},
    {"indexOfClassInfo", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_indexOfClassInfo), METH_O, nullptr},
    {"indexOfConstructor", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_indexOfConstructor), METH_O, nullptr},
    {"indexOfEnumerator", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_indexOfEnumerator), METH_O, nullptr},
    {"indexOfMethod", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_indexOfMethod), METH_O, nullptr},
    {"indexOfProperty", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_indexOfProperty), METH_O, nullptr},
    {"indexOfSignal", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_indexOfSignal), METH_O, nullptr},
    {"indexOfSlot", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_indexOfSlot), METH_O, nullptr},
    {"inherits", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_inherits), METH_O, nullptr},
    {"invokeMethod", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_invokeMethod), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"metaType", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_metaType), METH_NOARGS, nullptr},
    {"method", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_method), METH_O, nullptr},
    {"methodCount", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_methodCount), METH_NOARGS, nullptr},
    {"methodOffset", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_methodOffset), METH_NOARGS, nullptr},
    {"newInstance", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_newInstance), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"normalizedSignature", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_normalizedSignature), METH_O|METH_STATIC, nullptr},
    {"normalizedType", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_normalizedType), METH_O|METH_STATIC, nullptr},
    {"property", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_property), METH_O, nullptr},
    {"propertyCount", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_propertyCount), METH_NOARGS, nullptr},
    {"propertyOffset", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_propertyOffset), METH_NOARGS, nullptr},
    {"superClass", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_superClass), METH_NOARGS, nullptr},
    {"userProperty", reinterpret_cast<PyCFunction>(Sbk_QMetaObjectFunc_userProperty), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QMetaObject_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMetaObject_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMetaObject_Type = nullptr;
static PyTypeObject *Sbk_QMetaObject_TypeF(void)
{
    return _Sbk_QMetaObject_Type;
}

static PyType_Slot Sbk_QMetaObject_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QMetaObjectFunc___repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMetaObject_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMetaObject_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMetaObject_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMetaObject_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMetaObject_spec = {
    "2:PySide6.QtCore.QMetaObject",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMetaObject_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QMetaObject_Call_PythonToCpp_QMetaObject_Call(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QMetaObject::Call>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QMetaObject::Call *>(cppOut) = value;

}
static PythonToCppFunc is_QMetaObject_Call_PythonToCpp_QMetaObject_Call_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_Call_IDX])))
        return QMetaObject_Call_PythonToCpp_QMetaObject_Call;
    return {};
}
static PyObject *QMetaObject_Call_CppToPython_QMetaObject_Call(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QMetaObject::Call *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_Call_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMetaObject_PythonToCpp_QMetaObject_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMetaObject_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMetaObject_PythonToCpp_QMetaObject_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMetaObject_TypeF()))
        return QMetaObject_PythonToCpp_QMetaObject_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMetaObject_PTR_CppToPython_QMetaObject(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QMetaObject *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QMetaObject_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QMetaObject_SignatureStrings[] = {
    "PySide6.QtCore.QMetaObject(self)",
    "PySide6.QtCore.QMetaObject.__repr__(self)->PyObject",
    "1:PySide6.QtCore.QMetaObject.cast(self,obj:PySide6.QtCore.QObject)->PySide6.QtCore.QObject",
    "0:PySide6.QtCore.QMetaObject.cast(self,obj:PySide6.QtCore.QObject)->PySide6.QtCore.QObject",
    "1:PySide6.QtCore.QMetaObject.checkConnectArgs(signal:PySide6.QtCore.QMetaMethod,method:PySide6.QtCore.QMetaMethod)->bool",
    "0:PySide6.QtCore.QMetaObject.checkConnectArgs(signal:char*,method:char*)->bool",
    "PySide6.QtCore.QMetaObject.classInfo(self,index:int)->PySide6.QtCore.QMetaClassInfo",
    "PySide6.QtCore.QMetaObject.classInfoCount(self)->int",
    "PySide6.QtCore.QMetaObject.classInfoOffset(self)->int",
    "PySide6.QtCore.QMetaObject.className(self)->char*",
    "PySide6.QtCore.QMetaObject.connectSlotsByName(o:PySide6.QtCore.QObject)",
    "PySide6.QtCore.QMetaObject.constructor(self,index:int)->PySide6.QtCore.QMetaMethod",
    "PySide6.QtCore.QMetaObject.constructorCount(self)->int",
    "PySide6.QtCore.QMetaObject.disconnect(sender:PySide6.QtCore.QObject,signal_index:int,receiver:PySide6.QtCore.QObject,method_index:int)->bool",
    "PySide6.QtCore.QMetaObject.disconnectOne(sender:PySide6.QtCore.QObject,signal_index:int,receiver:PySide6.QtCore.QObject,method_index:int)->bool",
    "PySide6.QtCore.QMetaObject.enumerator(self,index:int)->PySide6.QtCore.QMetaEnum",
    "PySide6.QtCore.QMetaObject.enumeratorCount(self)->int",
    "PySide6.QtCore.QMetaObject.enumeratorOffset(self)->int",
    "PySide6.QtCore.QMetaObject.indexOfClassInfo(self,name:str)->int",
    "PySide6.QtCore.QMetaObject.indexOfConstructor(self,constructor:str)->int",
    "PySide6.QtCore.QMetaObject.indexOfEnumerator(self,name:str)->int",
    "PySide6.QtCore.QMetaObject.indexOfMethod(self,method:str)->int",
    "PySide6.QtCore.QMetaObject.indexOfProperty(self,name:str)->int",
    "PySide6.QtCore.QMetaObject.indexOfSignal(self,signal:str)->int",
    "PySide6.QtCore.QMetaObject.indexOfSlot(self,slot:str)->int",
    "PySide6.QtCore.QMetaObject.inherits(self,metaObject:PySide6.QtCore.QMetaObject)->bool",
    "7:PySide6.QtCore.QMetaObject.invokeMethod(obj:PySide6.QtCore.QObject,member:char*,val0:PySide6.QtCore.QGenericArgument,val1:PySide6.QtCore.QGenericArgument=QGenericArgument(),val2:PySide6.QtCore.QGenericArgument=QGenericArgument(),val3:PySide6.QtCore.QGenericArgument=QGenericArgument(),val4:PySide6.QtCore.QGenericArgument=QGenericArgument(),val5:PySide6.QtCore.QGenericArgument=QGenericArgument(),val6:PySide6.QtCore.QGenericArgument=QGenericArgument(),val7:PySide6.QtCore.QGenericArgument=QGenericArgument(),val8:PySide6.QtCore.QGenericArgument=QGenericArgument(),val9:PySide6.QtCore.QGenericArgument=QGenericArgument())->bool",
    "6:PySide6.QtCore.QMetaObject.invokeMethod(obj:PySide6.QtCore.QObject,member:char*,ret:PySide6.QtCore.QGenericReturnArgument,val0:PySide6.QtCore.QGenericArgument=QGenericArgument(nullptr),val1:PySide6.QtCore.QGenericArgument=QGenericArgument(),val2:PySide6.QtCore.QGenericArgument=QGenericArgument(),val3:PySide6.QtCore.QGenericArgument=QGenericArgument(),val4:PySide6.QtCore.QGenericArgument=QGenericArgument(),val5:PySide6.QtCore.QGenericArgument=QGenericArgument(),val6:PySide6.QtCore.QGenericArgument=QGenericArgument(),val7:PySide6.QtCore.QGenericArgument=QGenericArgument(),val8:PySide6.QtCore.QGenericArgument=QGenericArgument(),val9:PySide6.QtCore.QGenericArgument=QGenericArgument())->bool",
    "5:PySide6.QtCore.QMetaObject.invokeMethod(obj:PySide6.QtCore.QObject,member:char*,arg__3:PySide6.QtCore.Qt.ConnectionType,ret:PySide6.QtCore.QGenericReturnArgument,val0:PySide6.QtCore.QGenericArgument=QGenericArgument(nullptr),val1:PySide6.QtCore.QGenericArgument=QGenericArgument(),val2:PySide6.QtCore.QGenericArgument=QGenericArgument(),val3:PySide6.QtCore.QGenericArgument=QGenericArgument(),val4:PySide6.QtCore.QGenericArgument=QGenericArgument(),val5:PySide6.QtCore.QGenericArgument=QGenericArgument(),val6:PySide6.QtCore.QGenericArgument=QGenericArgument(),val7:PySide6.QtCore.QGenericArgument=QGenericArgument(),val8:PySide6.QtCore.QGenericArgument=QGenericArgument(),val9:PySide6.QtCore.QGenericArgument=QGenericArgument())->bool",
    "4:PySide6.QtCore.QMetaObject.invokeMethod(obj:PySide6.QtCore.QObject,member:char*,type:PySide6.QtCore.Qt.ConnectionType,val0:PySide6.QtCore.QGenericArgument,val1:PySide6.QtCore.QGenericArgument=QGenericArgument(),val2:PySide6.QtCore.QGenericArgument=QGenericArgument(),val3:PySide6.QtCore.QGenericArgument=QGenericArgument(),val4:PySide6.QtCore.QGenericArgument=QGenericArgument(),val5:PySide6.QtCore.QGenericArgument=QGenericArgument(),val6:PySide6.QtCore.QGenericArgument=QGenericArgument(),val7:PySide6.QtCore.QGenericArgument=QGenericArgument(),val8:PySide6.QtCore.QGenericArgument=QGenericArgument(),val9:PySide6.QtCore.QGenericArgument=QGenericArgument())->bool",
    "3:PySide6.QtCore.QMetaObject.invokeMethod(object:PySide6.QtCore.QObject,member:char*,type:PySide6.QtCore.Qt.ConnectionType,val0:PySide6.QtCore.QGenericArgumentHolder={},val1:PySide6.QtCore.QGenericArgumentHolder={},val2:PySide6.QtCore.QGenericArgumentHolder={},val3:PySide6.QtCore.QGenericArgumentHolder={},val4:PySide6.QtCore.QGenericArgumentHolder={},val5:PySide6.QtCore.QGenericArgumentHolder={},val6:PySide6.QtCore.QGenericArgumentHolder={},val7:PySide6.QtCore.QGenericArgumentHolder={},val8:PySide6.QtCore.QGenericArgumentHolder={},val9:PySide6.QtCore.QGenericArgumentHolder={})->bool",
    "2:PySide6.QtCore.QMetaObject.invokeMethod(object:PySide6.QtCore.QObject,member:char*,type:PySide6.QtCore.Qt.ConnectionType,ret:PySide6.QtCore.QGenericReturnArgumentHolder,val0:PySide6.QtCore.QGenericArgumentHolder={},val1:PySide6.QtCore.QGenericArgumentHolder={},val2:PySide6.QtCore.QGenericArgumentHolder={},val3:PySide6.QtCore.QGenericArgumentHolder={},val4:PySide6.QtCore.QGenericArgumentHolder={},val5:PySide6.QtCore.QGenericArgumentHolder={},val6:PySide6.QtCore.QGenericArgumentHolder={},val7:PySide6.QtCore.QGenericArgumentHolder={},val8:PySide6.QtCore.QGenericArgumentHolder={},val9:PySide6.QtCore.QGenericArgumentHolder={})->PyObject",
    "1:PySide6.QtCore.QMetaObject.invokeMethod(object:PySide6.QtCore.QObject,member:char*,val0:PySide6.QtCore.QGenericArgumentHolder={},val1:PySide6.QtCore.QGenericArgumentHolder={},val2:PySide6.QtCore.QGenericArgumentHolder={},val3:PySide6.QtCore.QGenericArgumentHolder={},val4:PySide6.QtCore.QGenericArgumentHolder={},val5:PySide6.QtCore.QGenericArgumentHolder={},val6:PySide6.QtCore.QGenericArgumentHolder={},val7:PySide6.QtCore.QGenericArgumentHolder={},val8:PySide6.QtCore.QGenericArgumentHolder={},val9:PySide6.QtCore.QGenericArgumentHolder={})->bool",
    "0:PySide6.QtCore.QMetaObject.invokeMethod(object:PySide6.QtCore.QObject,member:char*,ret:PySide6.QtCore.QGenericReturnArgumentHolder,val0:PySide6.QtCore.QGenericArgumentHolder={},val1:PySide6.QtCore.QGenericArgumentHolder={},val2:PySide6.QtCore.QGenericArgumentHolder={},val3:PySide6.QtCore.QGenericArgumentHolder={},val4:PySide6.QtCore.QGenericArgumentHolder={},val5:PySide6.QtCore.QGenericArgumentHolder={},val6:PySide6.QtCore.QGenericArgumentHolder={},val7:PySide6.QtCore.QGenericArgumentHolder={},val8:PySide6.QtCore.QGenericArgumentHolder={},val9:PySide6.QtCore.QGenericArgumentHolder={})->PyObject",
    "PySide6.QtCore.QMetaObject.metaType(self)->PySide6.QtCore.QMetaType",
    "PySide6.QtCore.QMetaObject.method(self,index:int)->PySide6.QtCore.QMetaMethod",
    "PySide6.QtCore.QMetaObject.methodCount(self)->int",
    "PySide6.QtCore.QMetaObject.methodOffset(self)->int",
    "PySide6.QtCore.QMetaObject.newInstance(self,val0:PySide6.QtCore.QGenericArgument,val1:PySide6.QtCore.QGenericArgument=QGenericArgument(),val2:PySide6.QtCore.QGenericArgument=QGenericArgument(),val3:PySide6.QtCore.QGenericArgument=QGenericArgument(),val4:PySide6.QtCore.QGenericArgument=QGenericArgument(),val5:PySide6.QtCore.QGenericArgument=QGenericArgument(),val6:PySide6.QtCore.QGenericArgument=QGenericArgument(),val7:PySide6.QtCore.QGenericArgument=QGenericArgument(),val8:PySide6.QtCore.QGenericArgument=QGenericArgument(),val9:PySide6.QtCore.QGenericArgument=QGenericArgument())->PySide6.QtCore.QObject",
    "PySide6.QtCore.QMetaObject.normalizedSignature(method:char*)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QMetaObject.normalizedType(type:char*)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QMetaObject.property(self,index:int)->PySide6.QtCore.QMetaProperty",
    "PySide6.QtCore.QMetaObject.propertyCount(self)->int",
    "PySide6.QtCore.QMetaObject.propertyOffset(self)->int",
    "PySide6.QtCore.QMetaObject.superClass(self)->PySide6.QtCore.QMetaObject",
    "PySide6.QtCore.QMetaObject.userProperty(self)->PySide6.QtCore.QMetaProperty",
    nullptr}; // Sentinel

PyTypeObject *init_QMetaObject(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX].type;

    Shiboken::AutoDecRef Sbk_QMetaObject_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QMetaObject_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMetaObject",
        "QMetaObject*",
        &Sbk_QMetaObject_spec,
        &Shiboken::callCppDestructor< ::QMetaObject >,
        Sbk_QMetaObject_Type_bases.object(),
        0);
    auto *pyType = Sbk_QMetaObject_TypeF(); // references _Sbk_QMetaObject_Type
    InitSignatureStrings(pyType, QMetaObject_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMetaObject_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMetaObject_PythonToCpp_QMetaObject_PTR,
        is_QMetaObject_PythonToCpp_QMetaObject_PTR_Convertible,
        QMetaObject_PTR_CppToPython_QMetaObject);

    Shiboken::Conversions::registerConverterName(converter, "QMetaObject");
    Shiboken::Conversions::registerConverterName(converter, "QMetaObject*");
    Shiboken::Conversions::registerConverterName(converter, "QMetaObject&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMetaObject).name());


    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QMetaObject_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Call'.
    const char *Call_Initializer[] = {
        "InvokeMetaMethod",
        "ReadProperty",
        "WriteProperty",
        "ResetProperty",
        "CreateInstance",
        "IndexOfMethod",
        "RegisterPropertyMetaType",
        "RegisterMethodArgumentMetaType",
        "BindableProperty",
        "CustomCall",
        "ConstructInPlace",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Call_InitializerValues[] = {
        uint8_t(QMetaObject::Call::InvokeMetaMethod),               //  0x00  0
        uint8_t(QMetaObject::Call::ReadProperty),                   //  0x01  1
        uint8_t(QMetaObject::Call::WriteProperty),                  //  0x02  2
        uint8_t(QMetaObject::Call::ResetProperty),                  //  0x03  3
        uint8_t(QMetaObject::Call::CreateInstance),                 //  0x04  4
        uint8_t(QMetaObject::Call::IndexOfMethod),                  //  0x05  5
        uint8_t(QMetaObject::Call::RegisterPropertyMetaType),       //  0x06  6
        uint8_t(QMetaObject::Call::RegisterMethodArgumentMetaType), //  0x07  7
        uint8_t(QMetaObject::Call::BindableProperty),               //  0x08  8
        uint8_t(QMetaObject::Call::CustomCall),                     //  0x09  9
        uint8_t(QMetaObject::Call::ConstructInPlace)                //  0x0a  10
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QMetaObject_TypeF(),
        "2:PySide6.QtCore.QMetaObject.Call",
        Call_Initializer, Call_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QMetaObject_Call_IDX].type = EType;
    // Register converter for enum 'QMetaObject::Call'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QMetaObject_Call_CppToPython_QMetaObject_Call);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QMetaObject_Call_PythonToCpp_QMetaObject_Call,
            is_QMetaObject_Call_PythonToCpp_QMetaObject_Call_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QMetaObject::Call");
        Shiboken::Conversions::registerConverterName(converter, "Call");
    }
    // End of 'Call' enum.


    qRegisterMetaType< ::QMetaObject *>();
    qRegisterMetaType< ::QMetaObject::Call >("QMetaObject::Call");

    return pyType;
}

