// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qopengltexture_wrapper.h"

// Argument includes
#include <QtGui/qcolor.h>
#include <QtGui/qimage.h>
#include <QtOpenGL/qopenglpixeltransferoptions.h>
#include <QtOpenGL/qopengltexture.h>
#include <utility>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOpenGLTexture_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOpenGLTexture >()))
        return -1;

    ::QOpenGLTexture *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:QOpenGLTexture", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QOpenGLTexture::QOpenGLTexture(QOpenGLTexture::Target)
    // 1: QOpenGLTexture::QOpenGLTexture(QImage,QOpenGLTexture::MipMapGeneration=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QOpenGLTexture(QImage,QOpenGLTexture::MipMapGeneration)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_MipMapGeneration_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // QOpenGLTexture(QImage,QOpenGLTexture::MipMapGeneration)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Target_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // QOpenGLTexture(QOpenGLTexture::Target)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QOpenGLTexture(QOpenGLTexture::Target target)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
            }
            ::QOpenGLTexture::Target cppArg0 = static_cast< ::QOpenGLTexture::Target>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLTexture(QOpenGLTexture::Target)
                cptr = new ::QOpenGLTexture(cppArg0);
            }
            break;
        }
        case 1: // QOpenGLTexture(const QImage & image, QOpenGLTexture::MipMapGeneration genMipMaps)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_genMipMaps = Shiboken::String::createStaticString("genMipMaps");
                if (PyDict_Contains(kwds, key_genMipMaps) != 0) {
                    value = PyDict_GetItem(kwds, key_genMipMaps);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_genMipMaps);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_MipMapGeneration_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_genMipMaps);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QImage cppArg0_local;
            ::QImage *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QOpenGLTexture::MipMapGeneration cppArg1(QOpenGLTexture::MipMapGeneration::GenerateMipMaps);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QOpenGLTexture(QImage,QOpenGLTexture::MipMapGeneration)
                cptr = new ::QOpenGLTexture(*cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QOpenGLTexture >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOpenGLTextureFunc_allocateStorage(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.allocateStorage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "allocateStorage", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::allocateStorage()
    // 1: QOpenGLTexture::allocateStorage(QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType)
    if (numArgs == 0) {
        overloadId = 0; // allocateStorage()
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelFormat_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelType_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 1; // allocateStorage(QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // allocateStorage()
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // allocateStorage()
                cppSelf->allocateStorage();
            }
            break;
        }
        case 1: // allocateStorage(QOpenGLTexture::PixelFormat pixelFormat, QOpenGLTexture::PixelType pixelType)
        {
            ::QOpenGLTexture::PixelFormat cppArg0{QOpenGLTexture::NoSourceFormat};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QOpenGLTexture::PixelType cppArg1{QOpenGLTexture::NoPixelType};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // allocateStorage(QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType)
                cppSelf->allocateStorage(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_bind(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.bind";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:bind", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::bind()
    // 1: QOpenGLTexture::bind(uint,QOpenGLTexture::TextureUnitReset=)
    if (numArgs == 0) {
        overloadId = 0; // bind()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // bind(uint,QOpenGLTexture::TextureUnitReset)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureUnitReset_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // bind(uint,QOpenGLTexture::TextureUnitReset)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // bind()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // bind()
                cppSelf->bind();
            }
            break;
        }
        case 1: // bind(uint unit, QOpenGLTexture::TextureUnitReset reset)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_reset = Shiboken::String::createStaticString("reset");
                if (PyDict_Contains(kwds, key_reset) != 0) {
                    value = PyDict_GetItem(kwds, key_reset);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_reset);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureUnitReset_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_reset);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            uint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QOpenGLTexture::TextureUnitReset cppArg1(QOpenGLTexture::TextureUnitReset::DontResetTextureUnit);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bind(uint,QOpenGLTexture::TextureUnitReset)
                cppSelf->bind(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_borderColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.borderColor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // borderColor()const
            QColor cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->borderColor();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_boundTextureId(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.boundTextureId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "boundTextureId", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QOpenGLTexture::boundTextureId(QOpenGLTexture::BindingTarget)->unsigned int
    // 1: static QOpenGLTexture::boundTextureId(uint,QOpenGLTexture::BindingTarget)->unsigned int
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_BindingTarget_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // boundTextureId(QOpenGLTexture::BindingTarget)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_BindingTarget_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 1; // boundTextureId(uint,QOpenGLTexture::BindingTarget)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // boundTextureId(QOpenGLTexture::BindingTarget target)
        {
            ::QOpenGLTexture::BindingTarget cppArg0 = static_cast< ::QOpenGLTexture::BindingTarget>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // boundTextureId(QOpenGLTexture::BindingTarget)
                unsigned int cppResult = ::QOpenGLTexture::boundTextureId(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
            }
            break;
        }
        case 1: // boundTextureId(uint unit, QOpenGLTexture::BindingTarget target)
        {
            uint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QOpenGLTexture::BindingTarget cppArg1 = static_cast< ::QOpenGLTexture::BindingTarget>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // boundTextureId(uint,QOpenGLTexture::BindingTarget)
                unsigned int cppResult = ::QOpenGLTexture::boundTextureId(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_comparisonFunction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.comparisonFunction";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // comparisonFunction()const
            QOpenGLTexture::ComparisonFunction cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->comparisonFunction();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_ComparisonFunction_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_comparisonMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.comparisonMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // comparisonMode()const
            QOpenGLTexture::ComparisonMode cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->comparisonMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_ComparisonMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.create";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // create()
            bool cppResult = cppSelf->create();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_createTextureView(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.createTextureView";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createTextureView", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::createTextureView(QOpenGLTexture::Target,QOpenGLTexture::TextureFormat,int,int,int,int)const->QOpenGLTexture*
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Target_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureFormat_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
        overloadId = 0; // createTextureView(QOpenGLTexture::Target,QOpenGLTexture::TextureFormat,int,int,int,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QOpenGLTexture::Target cppArg0 = static_cast< ::QOpenGLTexture::Target>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QOpenGLTexture::TextureFormat cppArg1{QOpenGLTexture::NoFormat};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createTextureView(QOpenGLTexture::Target,QOpenGLTexture::TextureFormat,int,int,int,int)const
            QOpenGLTexture * cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->createTextureView(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_depth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.depth";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // depth()const
            int cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->depth();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_depthStencilMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.depthStencilMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // depthStencilMode()const
            QOpenGLTexture::DepthStencilMode cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->depthStencilMode();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_DepthStencilMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_destroy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.destroy";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // destroy()
            cppSelf->destroy();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_faces(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.faces";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // faces()const
            int cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->faces();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_format(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.format";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // format()const
            QOpenGLTexture::TextureFormat cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->format();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureFormat_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_generateMipMaps(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.generateMipMaps";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:generateMipMaps", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::generateMipMaps()
    // 1: QOpenGLTexture::generateMipMaps(int,bool=)
    if (numArgs == 0) {
        overloadId = 0; // generateMipMaps()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // generateMipMaps(int,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 1; // generateMipMaps(int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // generateMipMaps()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // generateMipMaps()
                cppSelf->generateMipMaps();
            }
            break;
        }
        case 1: // generateMipMaps(int baseLevel, bool resetBaseLevel)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_resetBaseLevel = Shiboken::String::createStaticString("resetBaseLevel");
                if (PyDict_Contains(kwds, key_resetBaseLevel) != 0) {
                    value = PyDict_GetItem(kwds, key_resetBaseLevel);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_resetBaseLevel);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_resetBaseLevel);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            bool cppArg1 = true;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // generateMipMaps(int,bool)
                cppSelf->generateMipMaps(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_hasFeature(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.hasFeature";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QOpenGLTexture::hasFeature(QOpenGLTexture::Feature)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Feature_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // hasFeature(QOpenGLTexture::Feature)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QOpenGLTexture::Feature cppArg0 = static_cast< ::QOpenGLTexture::Feature>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasFeature(QOpenGLTexture::Feature)
            bool cppResult = ::QOpenGLTexture::hasFeature(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_height(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.height";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // height()const
            int cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->height();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_isAutoMipMapGenerationEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.isAutoMipMapGenerationEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isAutoMipMapGenerationEnabled()const
            bool cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->isAutoMipMapGenerationEnabled();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_isBound(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.isBound";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "isBound", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::isBound()const->bool
    // 1: QOpenGLTexture::isBound(uint)->bool
    if (numArgs == 0) {
        overloadId = 0; // isBound()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))) {
        overloadId = 1; // isBound(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // isBound() const
        {

            if (Shiboken::Errors::occurred() == nullptr) {
                // isBound()const
                bool cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->isBound();
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // isBound(uint unit)
        {
            uint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isBound(uint)
                bool cppResult = cppSelf->isBound(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_isCreated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.isCreated";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isCreated()const
            bool cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->isCreated();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_isFixedSamplePositions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.isFixedSamplePositions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isFixedSamplePositions()const
            bool cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->isFixedSamplePositions();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_isStorageAllocated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.isStorageAllocated";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isStorageAllocated()const
            bool cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->isStorageAllocated();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_isTextureView(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.isTextureView";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isTextureView()const
            bool cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->isTextureView();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_layers(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.layers";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // layers()const
            int cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->layers();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_levelOfDetailRange(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.levelOfDetailRange";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // levelOfDetailRange()const
            std::pair<float,float> cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->levelOfDetailRange();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtOpenGLTypeConverters[SBK_QtOpenGL_std_pair_float_float_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_levelofDetailBias(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.levelofDetailBias";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // levelofDetailBias()const
            float cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->levelofDetailBias();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_magnificationFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.magnificationFilter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // magnificationFilter()const
            QOpenGLTexture::Filter cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->magnificationFilter();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Filter_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_maximumAnisotropy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.maximumAnisotropy";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maximumAnisotropy()const
            float cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->maximumAnisotropy();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_maximumLevelOfDetail(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.maximumLevelOfDetail";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maximumLevelOfDetail()const
            float cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->maximumLevelOfDetail();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_maximumMipLevels(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.maximumMipLevels";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // maximumMipLevels()const
            int cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->maximumMipLevels();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_minMagFilters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.minMagFilters";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minMagFilters()const
            std::pair<QOpenGLTexture::Filter,QOpenGLTexture::Filter> cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->minMagFilters();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtOpenGLTypeConverters[SBK_QtOpenGL_std_pair_QOpenGLTexture_Filter_QOpenGLTexture_Filter_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_minificationFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.minificationFilter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minificationFilter()const
            QOpenGLTexture::Filter cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->minificationFilter();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Filter_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_minimumLevelOfDetail(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.minimumLevelOfDetail";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // minimumLevelOfDetail()const
            float cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->minimumLevelOfDetail();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_mipBaseLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.mipBaseLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mipBaseLevel()const
            int cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->mipBaseLevel();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_mipLevelRange(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.mipLevelRange";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mipLevelRange()const
            std::pair<int,int> cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->mipLevelRange();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtOpenGLTypeConverters[SBK_QtOpenGL_std_pair_int_int_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_mipLevels(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.mipLevels";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mipLevels()const
            int cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->mipLevels();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_mipMaxLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.mipMaxLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // mipMaxLevel()const
            int cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->mipMaxLevel();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_release(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.release";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:release", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::release()
    // 1: QOpenGLTexture::release(uint,QOpenGLTexture::TextureUnitReset=)
    if (numArgs == 0) {
        overloadId = 0; // release()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // release(uint,QOpenGLTexture::TextureUnitReset)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureUnitReset_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // release(uint,QOpenGLTexture::TextureUnitReset)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // release()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // release()
                cppSelf->release();
            }
            break;
        }
        case 1: // release(uint unit, QOpenGLTexture::TextureUnitReset reset)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_reset = Shiboken::String::createStaticString("reset");
                if (PyDict_Contains(kwds, key_reset) != 0) {
                    value = PyDict_GetItem(kwds, key_reset);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_reset);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureUnitReset_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_reset);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            uint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QOpenGLTexture::TextureUnitReset cppArg1(QOpenGLTexture::TextureUnitReset::DontResetTextureUnit);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // release(uint,QOpenGLTexture::TextureUnitReset)
                cppSelf->release(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_samples(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.samples";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // samples()const
            int cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->samples();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_setAutoMipMapGenerationEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setAutoMipMapGenerationEnabled";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setAutoMipMapGenerationEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAutoMipMapGenerationEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAutoMipMapGenerationEnabled(bool)
            cppSelf->setAutoMipMapGenerationEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setBorderColor(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setBorderColor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "setBorderColor", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::setBorderColor(QColor)
    // 1: QOpenGLTexture::setBorderColor(float,float,float,float)
    // 2: QOpenGLTexture::setBorderColor(int,int,int,int)
    // 3: QOpenGLTexture::setBorderColor(uint,uint,uint,uint)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArgs[3])))) {
        overloadId = 3; // setBorderColor(uint,uint,uint,uint)
    } else if (numArgs == 4
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 1; // setBorderColor(float,float,float,float)
    } else if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 2; // setBorderColor(int,int,int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setBorderColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setBorderColor(const QColor & color)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QColor cppArg0_local;
            ::QColor *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setBorderColor(QColor)
                cppSelf->setBorderColor(*cppArg0);
            }
            break;
        }
        case 1: // setBorderColor(float r, float g, float b, float a)
        {
            float cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            float cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            float cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            float cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setBorderColor(float,float,float,float)
                cppSelf->setBorderColor(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 2: // setBorderColor(int r, int g, int b, int a)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setBorderColor(int,int,int,int)
                cppSelf->setBorderColor(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 3: // setBorderColor(uint r, uint g, uint b, uint a)
        {
            uint cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            uint cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            uint cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            uint cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setBorderColor(uint,uint,uint,uint)
                cppSelf->setBorderColor(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setComparisonFunction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setComparisonFunction";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setComparisonFunction(QOpenGLTexture::ComparisonFunction)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_ComparisonFunction_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setComparisonFunction(QOpenGLTexture::ComparisonFunction)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QOpenGLTexture::ComparisonFunction cppArg0 = static_cast< ::QOpenGLTexture::ComparisonFunction>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setComparisonFunction(QOpenGLTexture::ComparisonFunction)
            cppSelf->setComparisonFunction(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setComparisonMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setComparisonMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setComparisonMode(QOpenGLTexture::ComparisonMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_ComparisonMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setComparisonMode(QOpenGLTexture::ComparisonMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QOpenGLTexture::ComparisonMode cppArg0{QOpenGLTexture::CompareNone};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setComparisonMode(QOpenGLTexture::ComparisonMode)
            cppSelf->setComparisonMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setCompressedData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setCompressedData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 7));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOO:setCompressedData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::setCompressedData(int,const void*,const QOpenGLPixelTransferOptions*const=)
    // 1: QOpenGLTexture::setCompressedData(int,int,const void*,const QOpenGLPixelTransferOptions*const=)
    // 2: QOpenGLTexture::setCompressedData(int,int,QOpenGLTexture::CubeMapFace,int,const void*,const QOpenGLPixelTransferOptions*const=)
    // 3: QOpenGLTexture::setCompressedData(int,int,int,const void*,const QOpenGLPixelTransferOptions*const=)
    // 4: QOpenGLTexture::setCompressedData(int,int,int,QOpenGLTexture::CubeMapFace,int,const void*,const QOpenGLPixelTransferOptions*const=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs >= 5
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_CubeMapFace_IDX])))->converter, (pyArgs[2])))
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 2; // setCompressedData(int,int,QOpenGLTexture::CubeMapFace,int,const void*,const QOpenGLPixelTransferOptions*)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[5])))) {
                    overloadId = 2; // setCompressedData(int,int,QOpenGLTexture::CubeMapFace,int,const void*,const QOpenGLPixelTransferOptions*)
                }
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                if (numArgs >= 6
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_CubeMapFace_IDX])))->converter, (pyArgs[3])))
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[5])))) {
                    if (numArgs == 6) {
                        overloadId = 4; // setCompressedData(int,int,int,QOpenGLTexture::CubeMapFace,int,const void*,const QOpenGLPixelTransferOptions*)
                    } else if (numArgs >= 7
                        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[6])))) {
                        overloadId = 4; // setCompressedData(int,int,int,QOpenGLTexture::CubeMapFace,int,const void*,const QOpenGLPixelTransferOptions*)
                    }
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 3; // setCompressedData(int,int,int,const void*,const QOpenGLPixelTransferOptions*)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[4])))) {
                        overloadId = 3; // setCompressedData(int,int,int,const void*,const QOpenGLPixelTransferOptions*)
                    }
                }
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // setCompressedData(int,int,const void*,const QOpenGLPixelTransferOptions*)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[3])))) {
                    overloadId = 1; // setCompressedData(int,int,const void*,const QOpenGLPixelTransferOptions*)
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setCompressedData(int,const void*,const QOpenGLPixelTransferOptions*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[2])))) {
                overloadId = 0; // setCompressedData(int,const void*,const QOpenGLPixelTransferOptions*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setCompressedData(int dataSize, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg2 = nullptr;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setCompressedData(int,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setCompressedData(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // setCompressedData(int mipLevel, int dataSize, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            void* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg3 = nullptr;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setCompressedData(int,int,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setCompressedData(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 2: // setCompressedData(int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, int dataSize, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QOpenGLTexture::CubeMapFace cppArg2 = static_cast< ::QOpenGLTexture::CubeMapFace>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            void* cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg5 = nullptr;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setCompressedData(int,int,QOpenGLTexture::CubeMapFace,int,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setCompressedData(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
        case 3: // setCompressedData(int mipLevel, int layer, int dataSize, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            void* cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setCompressedData(int,int,int,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setCompressedData(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 4: // setCompressedData(int mipLevel, int layer, int layerCount, QOpenGLTexture::CubeMapFace cubeFace, int dataSize, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QOpenGLTexture::CubeMapFace cppArg3 = static_cast< ::QOpenGLTexture::CubeMapFace>(0);
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            void* cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg6 = nullptr;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setCompressedData(int,int,int,QOpenGLTexture::CubeMapFace,int,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setCompressedData(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setData";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[14];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 14));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOOOOOOOO:setData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9]), &(pyArgs[10]), &(pyArgs[11]), &(pyArgs[12]), &(pyArgs[13])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::setData(QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*const=)
    // 1: QOpenGLTexture::setData(QImage,QOpenGLTexture::MipMapGeneration=)
    // 2: QOpenGLTexture::setData(int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*const=)
    // 3: QOpenGLTexture::setData(int,int,QOpenGLTexture::CubeMapFace,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*const=)
    // 4: QOpenGLTexture::setData(int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*const=)
    // 5: QOpenGLTexture::setData(int,int,int,QOpenGLTexture::CubeMapFace,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*const=)
    // 6: QOpenGLTexture::setData(int,int,int,int,int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*const=)
    // 7: QOpenGLTexture::setData(int,int,int,int,int,int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*const=)
    // 8: QOpenGLTexture::setData(int,int,int,int,int,int,int,int,QOpenGLTexture::CubeMapFace,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*const=)
    // 9: QOpenGLTexture::setData(int,int,int,int,int,int,int,int,QOpenGLTexture::CubeMapFace,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*const=)
    // 10: QOpenGLTexture::setData(int,int,int,int,int,int,int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*const=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // setData(QImage,QOpenGLTexture::MipMapGeneration)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_MipMapGeneration_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // setData(QImage,QOpenGLTexture::MipMapGeneration)
        }
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelFormat_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelType_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // setData(QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[3])))) {
            overloadId = 0; // setData(QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs >= 4
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelFormat_IDX])))->converter, (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelType_IDX])))->converter, (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 2; // setData(int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[4])))) {
                overloadId = 2; // setData(int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs >= 5
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelFormat_IDX])))->converter, (pyArgs[2])))
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelType_IDX])))->converter, (pyArgs[3])))
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 4; // setData(int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[5])))) {
                    overloadId = 4; // setData(int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                }
            } else if (numArgs >= 6
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_CubeMapFace_IDX])))->converter, (pyArgs[2])))
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelFormat_IDX])))->converter, (pyArgs[3])))
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelType_IDX])))->converter, (pyArgs[4])))
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[5])))) {
                if (numArgs == 6) {
                    overloadId = 3; // setData(int,int,QOpenGLTexture::CubeMapFace,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                } else if (numArgs >= 7
                    && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[6])))) {
                    overloadId = 3; // setData(int,int,QOpenGLTexture::CubeMapFace,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                }
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                if (numArgs >= 7
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_CubeMapFace_IDX])))->converter, (pyArgs[3])))
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelFormat_IDX])))->converter, (pyArgs[4])))
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelType_IDX])))->converter, (pyArgs[5])))
                    && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[6])))) {
                    if (numArgs == 7) {
                        overloadId = 5; // setData(int,int,int,QOpenGLTexture::CubeMapFace,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                    } else if (numArgs >= 8
                        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[7])))) {
                        overloadId = 5; // setData(int,int,int,QOpenGLTexture::CubeMapFace,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                    }
                } else if (numArgs >= 6
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
                    if (numArgs >= 9
                        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelFormat_IDX])))->converter, (pyArgs[6])))
                        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelType_IDX])))->converter, (pyArgs[7])))
                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[8])))) {
                        if (numArgs == 9) {
                            overloadId = 6; // setData(int,int,int,int,int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                        } else if (numArgs >= 10
                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[9])))) {
                            overloadId = 6; // setData(int,int,int,int,int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                        }
                    } else if (numArgs >= 7
                        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))) {
                        if (numArgs >= 10
                            && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelFormat_IDX])))->converter, (pyArgs[7])))
                            && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelType_IDX])))->converter, (pyArgs[8])))
                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[9])))) {
                            if (numArgs == 10) {
                                overloadId = 7; // setData(int,int,int,int,int,int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                            } else if (numArgs >= 11
                                && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[10])))) {
                                overloadId = 7; // setData(int,int,int,int,int,int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                            }
                        } else if (numArgs >= 8
                            && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))) {
                            if (numArgs >= 11
                                && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelFormat_IDX])))->converter, (pyArgs[8])))
                                && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelType_IDX])))->converter, (pyArgs[9])))
                                && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[10])))) {
                                if (numArgs == 11) {
                                    overloadId = 10; // setData(int,int,int,int,int,int,int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                                } else if (numArgs >= 12
                                    && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[11])))) {
                                    overloadId = 10; // setData(int,int,int,int,int,int,int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                                }
                            } else if (numArgs >= 9
                                && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_CubeMapFace_IDX])))->converter, (pyArgs[8])))) {
                                if (numArgs >= 12
                                    && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelFormat_IDX])))->converter, (pyArgs[9])))
                                    && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelType_IDX])))->converter, (pyArgs[10])))
                                    && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[11])))) {
                                    if (numArgs == 12) {
                                        overloadId = 8; // setData(int,int,int,int,int,int,int,int,QOpenGLTexture::CubeMapFace,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                                    } else if (numArgs >= 13
                                        && (pythonToCpp[12] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[12])))) {
                                        overloadId = 8; // setData(int,int,int,int,int,int,int,int,QOpenGLTexture::CubeMapFace,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                                    }
                                } else if (numArgs >= 13
                                    && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[9])))
                                    && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelFormat_IDX])))->converter, (pyArgs[10])))
                                    && (pythonToCpp[11] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelType_IDX])))->converter, (pyArgs[11])))
                                    && (pythonToCpp[12] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[12])))) {
                                    if (numArgs == 13) {
                                        overloadId = 9; // setData(int,int,int,int,int,int,int,int,QOpenGLTexture::CubeMapFace,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                                    } else if (numArgs >= 14
                                        && (pythonToCpp[13] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[13])))) {
                                        overloadId = 9; // setData(int,int,int,int,int,int,int,int,QOpenGLTexture::CubeMapFace,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setData(QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QOpenGLTexture::PixelFormat cppArg0{QOpenGLTexture::NoSourceFormat};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QOpenGLTexture::PixelType cppArg1{QOpenGLTexture::NoPixelType};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            void* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg3 = nullptr;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setData(QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setData(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 1: // setData(const QImage & image, QOpenGLTexture::MipMapGeneration genMipMaps)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_genMipMaps = Shiboken::String::createStaticString("genMipMaps");
                if (PyDict_Contains(kwds, key_genMipMaps) != 0) {
                    value = PyDict_GetItem(kwds, key_genMipMaps);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_genMipMaps);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_MipMapGeneration_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_genMipMaps);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QImage cppArg0_local;
            ::QImage *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QOpenGLTexture::MipMapGeneration cppArg1(QOpenGLTexture::MipMapGeneration::GenerateMipMaps);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setData(QImage,QOpenGLTexture::MipMapGeneration)
                cppSelf->setData(*cppArg0, cppArg1);
            }
            break;
        }
        case 2: // setData(int mipLevel, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QOpenGLTexture::PixelFormat cppArg1{QOpenGLTexture::NoSourceFormat};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QOpenGLTexture::PixelType cppArg2{QOpenGLTexture::NoPixelType};
            pythonToCpp[2](pyArgs[2], &cppArg2);
            void* cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setData(int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setData(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 3: // setData(int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QOpenGLTexture::CubeMapFace cppArg2 = static_cast< ::QOpenGLTexture::CubeMapFace>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QOpenGLTexture::PixelFormat cppArg3{QOpenGLTexture::NoSourceFormat};
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QOpenGLTexture::PixelType cppArg4{QOpenGLTexture::NoPixelType};
            pythonToCpp[4](pyArgs[4], &cppArg4);
            void* cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg6 = nullptr;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setData(int,int,QOpenGLTexture::CubeMapFace,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setData(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
            }
            break;
        }
        case 4: // setData(int mipLevel, int layer, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QOpenGLTexture::PixelFormat cppArg2{QOpenGLTexture::NoSourceFormat};
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QOpenGLTexture::PixelType cppArg3{QOpenGLTexture::NoPixelType};
            pythonToCpp[3](pyArgs[3], &cppArg3);
            void* cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg5 = nullptr;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setData(int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setData(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
        case 5: // setData(int mipLevel, int layer, int layerCount, QOpenGLTexture::CubeMapFace cubeFace, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QOpenGLTexture::CubeMapFace cppArg3 = static_cast< ::QOpenGLTexture::CubeMapFace>(0);
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QOpenGLTexture::PixelFormat cppArg4{QOpenGLTexture::NoSourceFormat};
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QOpenGLTexture::PixelType cppArg5{QOpenGLTexture::NoPixelType};
            pythonToCpp[5](pyArgs[5], &cppArg5);
            void* cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg7 = nullptr;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setData(int,int,int,QOpenGLTexture::CubeMapFace,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setData(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
            }
            break;
        }
        case 6: // setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[9]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            ::QOpenGLTexture::PixelFormat cppArg6{QOpenGLTexture::NoSourceFormat};
            pythonToCpp[6](pyArgs[6], &cppArg6);
            ::QOpenGLTexture::PixelType cppArg7{QOpenGLTexture::NoPixelType};
            pythonToCpp[7](pyArgs[7], &cppArg7);
            void* cppArg8;
            pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg9 = nullptr;
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setData(int,int,int,int,int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setData(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
            }
            break;
        }
        case 7: // setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, int mipLevel, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[10] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[10] = value;
                        if (!(pythonToCpp[10] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[10]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            ::QOpenGLTexture::PixelFormat cppArg7{QOpenGLTexture::NoSourceFormat};
            pythonToCpp[7](pyArgs[7], &cppArg7);
            ::QOpenGLTexture::PixelType cppArg8{QOpenGLTexture::NoPixelType};
            pythonToCpp[8](pyArgs[8], &cppArg8);
            void* cppArg9;
            pythonToCpp[9](pyArgs[9], &cppArg9);
            if (!Shiboken::Object::isValid(pyArgs[10]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg10 = nullptr;
            if (pythonToCpp[10])
                pythonToCpp[10](pyArgs[10], &cppArg10);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setData(int,int,int,int,int,int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setData(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10);
            }
            break;
        }
        case 8: // setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[12] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[12] = value;
                        if (!(pythonToCpp[12] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[12]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            int cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);
            ::QOpenGLTexture::CubeMapFace cppArg8 = static_cast< ::QOpenGLTexture::CubeMapFace>(0);
            pythonToCpp[8](pyArgs[8], &cppArg8);
            ::QOpenGLTexture::PixelFormat cppArg9{QOpenGLTexture::NoSourceFormat};
            pythonToCpp[9](pyArgs[9], &cppArg9);
            ::QOpenGLTexture::PixelType cppArg10{QOpenGLTexture::NoPixelType};
            pythonToCpp[10](pyArgs[10], &cppArg10);
            void* cppArg11;
            pythonToCpp[11](pyArgs[11], &cppArg11);
            if (!Shiboken::Object::isValid(pyArgs[12]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg12 = nullptr;
            if (pythonToCpp[12])
                pythonToCpp[12](pyArgs[12], &cppArg12);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setData(int,int,int,int,int,int,int,int,QOpenGLTexture::CubeMapFace,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setData(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12);
            }
            break;
        }
        case 9: // setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, int layerCount, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[13] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[13] = value;
                        if (!(pythonToCpp[13] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[13]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            int cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);
            ::QOpenGLTexture::CubeMapFace cppArg8 = static_cast< ::QOpenGLTexture::CubeMapFace>(0);
            pythonToCpp[8](pyArgs[8], &cppArg8);
            int cppArg9;
            pythonToCpp[9](pyArgs[9], &cppArg9);
            ::QOpenGLTexture::PixelFormat cppArg10{QOpenGLTexture::NoSourceFormat};
            pythonToCpp[10](pyArgs[10], &cppArg10);
            ::QOpenGLTexture::PixelType cppArg11{QOpenGLTexture::NoPixelType};
            pythonToCpp[11](pyArgs[11], &cppArg11);
            void* cppArg12;
            pythonToCpp[12](pyArgs[12], &cppArg12);
            if (!Shiboken::Object::isValid(pyArgs[13]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg13 = nullptr;
            if (pythonToCpp[13])
                pythonToCpp[13](pyArgs[13], &cppArg13);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setData(int,int,int,int,int,int,int,int,QOpenGLTexture::CubeMapFace,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setData(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12, cppArg13);
            }
            break;
        }
        case 10: // setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, int mipLevel, int layer, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void * data, const QOpenGLPixelTransferOptions *const options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[11] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[11] = value;
                        if (!(pythonToCpp[11] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLPixelTransferOptions_IDX]), (pyArgs[11]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            int cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);
            ::QOpenGLTexture::PixelFormat cppArg8{QOpenGLTexture::NoSourceFormat};
            pythonToCpp[8](pyArgs[8], &cppArg8);
            ::QOpenGLTexture::PixelType cppArg9{QOpenGLTexture::NoPixelType};
            pythonToCpp[9](pyArgs[9], &cppArg9);
            void* cppArg10;
            pythonToCpp[10](pyArgs[10], &cppArg10);
            if (!Shiboken::Object::isValid(pyArgs[11]))
                return {};
            ::QOpenGLPixelTransferOptions *cppArg11 = nullptr;
            if (pythonToCpp[11])
                pythonToCpp[11](pyArgs[11], &cppArg11);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setData(int,int,int,int,int,int,int,int,QOpenGLTexture::PixelFormat,QOpenGLTexture::PixelType,const void*,const QOpenGLPixelTransferOptions*)
                cppSelf->setData(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setDepthStencilMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setDepthStencilMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setDepthStencilMode(QOpenGLTexture::DepthStencilMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_DepthStencilMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDepthStencilMode(QOpenGLTexture::DepthStencilMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QOpenGLTexture::DepthStencilMode cppArg0 = static_cast< ::QOpenGLTexture::DepthStencilMode>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthStencilMode(QOpenGLTexture::DepthStencilMode)
            cppSelf->setDepthStencilMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setFixedSamplePositions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setFixedSamplePositions";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setFixedSamplePositions(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFixedSamplePositions(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFixedSamplePositions(bool)
            cppSelf->setFixedSamplePositions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setFormat";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setFormat(QOpenGLTexture::TextureFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureFormat_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFormat(QOpenGLTexture::TextureFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QOpenGLTexture::TextureFormat cppArg0{QOpenGLTexture::NoFormat};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFormat(QOpenGLTexture::TextureFormat)
            cppSelf->setFormat(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setLayers(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setLayers";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setLayers(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLayers(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayers(int)
            cppSelf->setLayers(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setLevelOfDetailRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setLevelOfDetailRange";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setLevelOfDetailRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::setLevelOfDetailRange(float,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // setLevelOfDetailRange(float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLevelOfDetailRange(float,float)
            cppSelf->setLevelOfDetailRange(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setLevelofDetailBias(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setLevelofDetailBias";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setLevelofDetailBias(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setLevelofDetailBias(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLevelofDetailBias(float)
            cppSelf->setLevelofDetailBias(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setMagnificationFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setMagnificationFilter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setMagnificationFilter(QOpenGLTexture::Filter)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Filter_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMagnificationFilter(QOpenGLTexture::Filter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QOpenGLTexture::Filter cppArg0 = static_cast< ::QOpenGLTexture::Filter>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMagnificationFilter(QOpenGLTexture::Filter)
            cppSelf->setMagnificationFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setMaximumAnisotropy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setMaximumAnisotropy";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setMaximumAnisotropy(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaximumAnisotropy(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumAnisotropy(float)
            cppSelf->setMaximumAnisotropy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setMaximumLevelOfDetail(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setMaximumLevelOfDetail";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setMaximumLevelOfDetail(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaximumLevelOfDetail(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumLevelOfDetail(float)
            cppSelf->setMaximumLevelOfDetail(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setMinMagFilters(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setMinMagFilters";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setMinMagFilters", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::setMinMagFilters(QOpenGLTexture::Filter,QOpenGLTexture::Filter)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Filter_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Filter_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // setMinMagFilters(QOpenGLTexture::Filter,QOpenGLTexture::Filter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QOpenGLTexture::Filter cppArg0 = static_cast< ::QOpenGLTexture::Filter>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QOpenGLTexture::Filter cppArg1 = static_cast< ::QOpenGLTexture::Filter>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinMagFilters(QOpenGLTexture::Filter,QOpenGLTexture::Filter)
            cppSelf->setMinMagFilters(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setMinificationFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setMinificationFilter";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setMinificationFilter(QOpenGLTexture::Filter)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Filter_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setMinificationFilter(QOpenGLTexture::Filter)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QOpenGLTexture::Filter cppArg0 = static_cast< ::QOpenGLTexture::Filter>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinificationFilter(QOpenGLTexture::Filter)
            cppSelf->setMinificationFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setMinimumLevelOfDetail(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setMinimumLevelOfDetail";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setMinimumLevelOfDetail(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMinimumLevelOfDetail(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinimumLevelOfDetail(float)
            cppSelf->setMinimumLevelOfDetail(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setMipBaseLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setMipBaseLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setMipBaseLevel(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMipBaseLevel(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMipBaseLevel(int)
            cppSelf->setMipBaseLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setMipLevelRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setMipLevelRange";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setMipLevelRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::setMipLevelRange(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // setMipLevelRange(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMipLevelRange(int,int)
            cppSelf->setMipLevelRange(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setMipLevels(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setMipLevels";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setMipLevels(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMipLevels(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMipLevels(int)
            cppSelf->setMipLevels(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setMipMaxLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setMipMaxLevel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setMipMaxLevel(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMipMaxLevel(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMipMaxLevel(int)
            cppSelf->setMipMaxLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setSamples(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setSamples";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::setSamples(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSamples(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSamples(int)
            cppSelf->setSamples(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setSize(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:setSize", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::setSize(int,int=,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setSize(int,int,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setSize(int,int,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 0; // setSize(int,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_height = Shiboken::String::createStaticString("height");
            if (PyDict_Contains(kwds, key_height) != 0) {
                value = PyDict_GetItem(kwds, key_height);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_height);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_height);
            }
            static PyObject *const key_depth = Shiboken::String::createStaticString("depth");
            if (PyDict_Contains(kwds, key_depth) != 0) {
                value = PyDict_GetItem(kwds, key_depth);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_depth);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_depth);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1 = 1;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2 = 1;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSize(int,int,int)
            cppSelf->setSize(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setSwizzleMask(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setSwizzleMask";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 3)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_UnpackTuple(args, "setSwizzleMask", 2, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::setSwizzleMask(QOpenGLTexture::SwizzleComponent,QOpenGLTexture::SwizzleValue)
    // 1: QOpenGLTexture::setSwizzleMask(QOpenGLTexture::SwizzleValue,QOpenGLTexture::SwizzleValue,QOpenGLTexture::SwizzleValue,QOpenGLTexture::SwizzleValue)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_SwizzleValue_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_SwizzleValue_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_SwizzleValue_IDX])))->converter, (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_SwizzleValue_IDX])))->converter, (pyArgs[3])))) {
        overloadId = 1; // setSwizzleMask(QOpenGLTexture::SwizzleValue,QOpenGLTexture::SwizzleValue,QOpenGLTexture::SwizzleValue,QOpenGLTexture::SwizzleValue)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_SwizzleComponent_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_SwizzleValue_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // setSwizzleMask(QOpenGLTexture::SwizzleComponent,QOpenGLTexture::SwizzleValue)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setSwizzleMask(QOpenGLTexture::SwizzleComponent component, QOpenGLTexture::SwizzleValue value)
        {
            ::QOpenGLTexture::SwizzleComponent cppArg0 = static_cast< ::QOpenGLTexture::SwizzleComponent>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QOpenGLTexture::SwizzleValue cppArg1{QOpenGLTexture::ZeroValue};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setSwizzleMask(QOpenGLTexture::SwizzleComponent,QOpenGLTexture::SwizzleValue)
                cppSelf->setSwizzleMask(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setSwizzleMask(QOpenGLTexture::SwizzleValue r, QOpenGLTexture::SwizzleValue g, QOpenGLTexture::SwizzleValue b, QOpenGLTexture::SwizzleValue a)
        {
            ::QOpenGLTexture::SwizzleValue cppArg0{QOpenGLTexture::ZeroValue};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QOpenGLTexture::SwizzleValue cppArg1{QOpenGLTexture::ZeroValue};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QOpenGLTexture::SwizzleValue cppArg2{QOpenGLTexture::ZeroValue};
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QOpenGLTexture::SwizzleValue cppArg3{QOpenGLTexture::ZeroValue};
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setSwizzleMask(QOpenGLTexture::SwizzleValue,QOpenGLTexture::SwizzleValue,QOpenGLTexture::SwizzleValue,QOpenGLTexture::SwizzleValue)
                cppSelf->setSwizzleMask(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_setWrapMode(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.setWrapMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setWrapMode", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLTexture::setWrapMode(QOpenGLTexture::CoordinateDirection,QOpenGLTexture::WrapMode)
    // 1: QOpenGLTexture::setWrapMode(QOpenGLTexture::WrapMode)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_WrapMode_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // setWrapMode(QOpenGLTexture::WrapMode)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_CoordinateDirection_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_WrapMode_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // setWrapMode(QOpenGLTexture::CoordinateDirection,QOpenGLTexture::WrapMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // setWrapMode(QOpenGLTexture::CoordinateDirection direction, QOpenGLTexture::WrapMode mode)
        {
            ::QOpenGLTexture::CoordinateDirection cppArg0 = static_cast< ::QOpenGLTexture::CoordinateDirection>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QOpenGLTexture::WrapMode cppArg1 = static_cast< ::QOpenGLTexture::WrapMode>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setWrapMode(QOpenGLTexture::CoordinateDirection,QOpenGLTexture::WrapMode)
                cppSelf->setWrapMode(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setWrapMode(QOpenGLTexture::WrapMode mode)
        {
            ::QOpenGLTexture::WrapMode cppArg0 = static_cast< ::QOpenGLTexture::WrapMode>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setWrapMode(QOpenGLTexture::WrapMode)
                cppSelf->setWrapMode(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLTextureFunc_swizzleMask(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.swizzleMask";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::swizzleMask(QOpenGLTexture::SwizzleComponent)const->QOpenGLTexture::SwizzleValue
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_SwizzleComponent_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // swizzleMask(QOpenGLTexture::SwizzleComponent)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QOpenGLTexture::SwizzleComponent cppArg0 = static_cast< ::QOpenGLTexture::SwizzleComponent>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // swizzleMask(QOpenGLTexture::SwizzleComponent)const
            QOpenGLTexture::SwizzleValue cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->swizzleMask(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_SwizzleValue_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_target(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.target";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // target()const
            QOpenGLTexture::Target cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->target();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Target_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_textureId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.textureId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // textureId()const
            unsigned int cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->textureId();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_width(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.width";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // width()const
            int cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->width();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLTextureFunc_wrapMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtOpenGL.QOpenGLTexture.wrapMode";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLTexture::wrapMode(QOpenGLTexture::CoordinateDirection)const->QOpenGLTexture::WrapMode
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_CoordinateDirection_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // wrapMode(QOpenGLTexture::CoordinateDirection)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QOpenGLTexture::CoordinateDirection cppArg0 = static_cast< ::QOpenGLTexture::CoordinateDirection>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wrapMode(QOpenGLTexture::CoordinateDirection)const
            QOpenGLTexture::WrapMode cppResult = const_cast<const ::QOpenGLTexture *>(cppSelf)->wrapMode(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_WrapMode_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QOpenGLTexture_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QOpenGLTexture_EnumFlagInfo[] = {
    "BindingTarget:Enum",
    "ComparisonFunction:Enum",
    "ComparisonMode:Enum",
    "CoordinateDirection:Enum",
    "CubeMapFace:Enum",
    "DepthStencilMode:Enum",
    "Feature:Flag:Features",
    "Filter:Enum",
    "MipMapGeneration:Enum",
    "PixelFormat:Enum",
    "PixelType:Enum",
    "SwizzleComponent:Enum",
    "SwizzleValue:Enum",
    "Target:Enum",
    "TextureFormat:Enum",
    "TextureFormatClass:Enum",
    "TextureUnitReset:Enum",
    "WrapMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLTexture_methods[] = {
    {"allocateStorage", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_allocateStorage), METH_VARARGS, nullptr},
    {"bind", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_bind), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"borderColor", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_borderColor), METH_NOARGS, nullptr},
    {"boundTextureId", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_boundTextureId), METH_VARARGS|METH_STATIC, nullptr},
    {"comparisonFunction", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_comparisonFunction), METH_NOARGS, nullptr},
    {"comparisonMode", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_comparisonMode), METH_NOARGS, nullptr},
    {"create", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_create), METH_NOARGS, nullptr},
    {"createTextureView", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_createTextureView), METH_VARARGS, nullptr},
    {"depth", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_depth), METH_NOARGS, nullptr},
    {"depthStencilMode", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_depthStencilMode), METH_NOARGS, nullptr},
    {"destroy", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_destroy), METH_NOARGS, nullptr},
    {"faces", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_faces), METH_NOARGS, nullptr},
    {"format", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_format), METH_NOARGS, nullptr},
    {"generateMipMaps", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_generateMipMaps), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"hasFeature", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_hasFeature), METH_O|METH_STATIC, nullptr},
    {"height", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_height), METH_NOARGS, nullptr},
    {"isAutoMipMapGenerationEnabled", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_isAutoMipMapGenerationEnabled), METH_NOARGS, nullptr},
    {"isBound", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_isBound), METH_VARARGS, nullptr},
    {"isCreated", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_isCreated), METH_NOARGS, nullptr},
    {"isFixedSamplePositions", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_isFixedSamplePositions), METH_NOARGS, nullptr},
    {"isStorageAllocated", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_isStorageAllocated), METH_NOARGS, nullptr},
    {"isTextureView", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_isTextureView), METH_NOARGS, nullptr},
    {"layers", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_layers), METH_NOARGS, nullptr},
    {"levelOfDetailRange", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_levelOfDetailRange), METH_NOARGS, nullptr},
    {"levelofDetailBias", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_levelofDetailBias), METH_NOARGS, nullptr},
    {"magnificationFilter", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_magnificationFilter), METH_NOARGS, nullptr},
    {"maximumAnisotropy", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_maximumAnisotropy), METH_NOARGS, nullptr},
    {"maximumLevelOfDetail", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_maximumLevelOfDetail), METH_NOARGS, nullptr},
    {"maximumMipLevels", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_maximumMipLevels), METH_NOARGS, nullptr},
    {"minMagFilters", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_minMagFilters), METH_NOARGS, nullptr},
    {"minificationFilter", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_minificationFilter), METH_NOARGS, nullptr},
    {"minimumLevelOfDetail", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_minimumLevelOfDetail), METH_NOARGS, nullptr},
    {"mipBaseLevel", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_mipBaseLevel), METH_NOARGS, nullptr},
    {"mipLevelRange", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_mipLevelRange), METH_NOARGS, nullptr},
    {"mipLevels", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_mipLevels), METH_NOARGS, nullptr},
    {"mipMaxLevel", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_mipMaxLevel), METH_NOARGS, nullptr},
    {"release", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_release), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"samples", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_samples), METH_NOARGS, nullptr},
    {"setAutoMipMapGenerationEnabled", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setAutoMipMapGenerationEnabled), METH_O, nullptr},
    {"setBorderColor", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setBorderColor), METH_VARARGS, nullptr},
    {"setComparisonFunction", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setComparisonFunction), METH_O, nullptr},
    {"setComparisonMode", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setComparisonMode), METH_O, nullptr},
    {"setCompressedData", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setCompressedData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setData", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setData), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setDepthStencilMode", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setDepthStencilMode), METH_O, nullptr},
    {"setFixedSamplePositions", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setFixedSamplePositions), METH_O, nullptr},
    {"setFormat", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setFormat), METH_O, nullptr},
    {"setLayers", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setLayers), METH_O, nullptr},
    {"setLevelOfDetailRange", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setLevelOfDetailRange), METH_VARARGS, nullptr},
    {"setLevelofDetailBias", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setLevelofDetailBias), METH_O, nullptr},
    {"setMagnificationFilter", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setMagnificationFilter), METH_O, nullptr},
    {"setMaximumAnisotropy", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setMaximumAnisotropy), METH_O, nullptr},
    {"setMaximumLevelOfDetail", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setMaximumLevelOfDetail), METH_O, nullptr},
    {"setMinMagFilters", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setMinMagFilters), METH_VARARGS, nullptr},
    {"setMinificationFilter", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setMinificationFilter), METH_O, nullptr},
    {"setMinimumLevelOfDetail", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setMinimumLevelOfDetail), METH_O, nullptr},
    {"setMipBaseLevel", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setMipBaseLevel), METH_O, nullptr},
    {"setMipLevelRange", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setMipLevelRange), METH_VARARGS, nullptr},
    {"setMipLevels", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setMipLevels), METH_O, nullptr},
    {"setMipMaxLevel", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setMipMaxLevel), METH_O, nullptr},
    {"setSamples", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setSamples), METH_O, nullptr},
    {"setSize", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setSize), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setSwizzleMask", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setSwizzleMask), METH_VARARGS, nullptr},
    {"setWrapMode", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_setWrapMode), METH_VARARGS, nullptr},
    {"swizzleMask", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_swizzleMask), METH_O, nullptr},
    {"target", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_target), METH_NOARGS, nullptr},
    {"textureId", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_textureId), METH_NOARGS, nullptr},
    {"width", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_width), METH_NOARGS, nullptr},
    {"wrapMode", reinterpret_cast<PyCFunction>(Sbk_QOpenGLTextureFunc_wrapMode), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QOpenGLTexture_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOpenGLTexture_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QOpenGLTexture__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLTexture *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOpenGLTexture_Type = nullptr;
static PyTypeObject *Sbk_QOpenGLTexture_TypeF(void)
{
    return _Sbk_QOpenGLTexture_Type;
}

static PyType_Slot Sbk_QOpenGLTexture_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QOpenGLTexture__repr__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLTexture_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLTexture_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLTexture_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLTexture_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLTexture_spec = {
    "2:PySide6.QtOpenGL.QOpenGLTexture",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLTexture_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void QOpenGLTexture_Target_PythonToCpp_QOpenGLTexture_Target(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::Target>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::Target *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_Target_PythonToCpp_QOpenGLTexture_Target_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Target_IDX])))
        return QOpenGLTexture_Target_PythonToCpp_QOpenGLTexture_Target;
    return {};
}
static PyObject *QOpenGLTexture_Target_CppToPython_QOpenGLTexture_Target(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::Target *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Target_IDX]), castCppIn);

}

static void QOpenGLTexture_BindingTarget_PythonToCpp_QOpenGLTexture_BindingTarget(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::BindingTarget>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::BindingTarget *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_BindingTarget_PythonToCpp_QOpenGLTexture_BindingTarget_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_BindingTarget_IDX])))
        return QOpenGLTexture_BindingTarget_PythonToCpp_QOpenGLTexture_BindingTarget;
    return {};
}
static PyObject *QOpenGLTexture_BindingTarget_CppToPython_QOpenGLTexture_BindingTarget(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::BindingTarget *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_BindingTarget_IDX]), castCppIn);

}

static void QOpenGLTexture_MipMapGeneration_PythonToCpp_QOpenGLTexture_MipMapGeneration(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::MipMapGeneration>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::MipMapGeneration *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_MipMapGeneration_PythonToCpp_QOpenGLTexture_MipMapGeneration_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_MipMapGeneration_IDX])))
        return QOpenGLTexture_MipMapGeneration_PythonToCpp_QOpenGLTexture_MipMapGeneration;
    return {};
}
static PyObject *QOpenGLTexture_MipMapGeneration_CppToPython_QOpenGLTexture_MipMapGeneration(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::MipMapGeneration *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_MipMapGeneration_IDX]), castCppIn);

}

static void QOpenGLTexture_TextureUnitReset_PythonToCpp_QOpenGLTexture_TextureUnitReset(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::TextureUnitReset>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::TextureUnitReset *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_TextureUnitReset_PythonToCpp_QOpenGLTexture_TextureUnitReset_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureUnitReset_IDX])))
        return QOpenGLTexture_TextureUnitReset_PythonToCpp_QOpenGLTexture_TextureUnitReset;
    return {};
}
static PyObject *QOpenGLTexture_TextureUnitReset_CppToPython_QOpenGLTexture_TextureUnitReset(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::TextureUnitReset *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureUnitReset_IDX]), castCppIn);

}

static void QOpenGLTexture_TextureFormat_PythonToCpp_QOpenGLTexture_TextureFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::TextureFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::TextureFormat *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_TextureFormat_PythonToCpp_QOpenGLTexture_TextureFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureFormat_IDX])))
        return QOpenGLTexture_TextureFormat_PythonToCpp_QOpenGLTexture_TextureFormat;
    return {};
}
static PyObject *QOpenGLTexture_TextureFormat_CppToPython_QOpenGLTexture_TextureFormat(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::TextureFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureFormat_IDX]), castCppIn);

}

static void QOpenGLTexture_TextureFormatClass_PythonToCpp_QOpenGLTexture_TextureFormatClass(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::TextureFormatClass>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::TextureFormatClass *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_TextureFormatClass_PythonToCpp_QOpenGLTexture_TextureFormatClass_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureFormatClass_IDX])))
        return QOpenGLTexture_TextureFormatClass_PythonToCpp_QOpenGLTexture_TextureFormatClass;
    return {};
}
static PyObject *QOpenGLTexture_TextureFormatClass_CppToPython_QOpenGLTexture_TextureFormatClass(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::TextureFormatClass *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureFormatClass_IDX]), castCppIn);

}

static void QOpenGLTexture_CubeMapFace_PythonToCpp_QOpenGLTexture_CubeMapFace(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::CubeMapFace>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::CubeMapFace *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_CubeMapFace_PythonToCpp_QOpenGLTexture_CubeMapFace_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_CubeMapFace_IDX])))
        return QOpenGLTexture_CubeMapFace_PythonToCpp_QOpenGLTexture_CubeMapFace;
    return {};
}
static PyObject *QOpenGLTexture_CubeMapFace_CppToPython_QOpenGLTexture_CubeMapFace(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::CubeMapFace *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_CubeMapFace_IDX]), castCppIn);

}

static void QOpenGLTexture_PixelFormat_PythonToCpp_QOpenGLTexture_PixelFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::PixelFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::PixelFormat *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_PixelFormat_PythonToCpp_QOpenGLTexture_PixelFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelFormat_IDX])))
        return QOpenGLTexture_PixelFormat_PythonToCpp_QOpenGLTexture_PixelFormat;
    return {};
}
static PyObject *QOpenGLTexture_PixelFormat_CppToPython_QOpenGLTexture_PixelFormat(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::PixelFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelFormat_IDX]), castCppIn);

}

static void QOpenGLTexture_PixelType_PythonToCpp_QOpenGLTexture_PixelType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::PixelType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::PixelType *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_PixelType_PythonToCpp_QOpenGLTexture_PixelType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelType_IDX])))
        return QOpenGLTexture_PixelType_PythonToCpp_QOpenGLTexture_PixelType;
    return {};
}
static PyObject *QOpenGLTexture_PixelType_CppToPython_QOpenGLTexture_PixelType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::PixelType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelType_IDX]), castCppIn);

}

static void QOpenGLTexture_SwizzleComponent_PythonToCpp_QOpenGLTexture_SwizzleComponent(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::SwizzleComponent>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::SwizzleComponent *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_SwizzleComponent_PythonToCpp_QOpenGLTexture_SwizzleComponent_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_SwizzleComponent_IDX])))
        return QOpenGLTexture_SwizzleComponent_PythonToCpp_QOpenGLTexture_SwizzleComponent;
    return {};
}
static PyObject *QOpenGLTexture_SwizzleComponent_CppToPython_QOpenGLTexture_SwizzleComponent(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::SwizzleComponent *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_SwizzleComponent_IDX]), castCppIn);

}

static void QOpenGLTexture_SwizzleValue_PythonToCpp_QOpenGLTexture_SwizzleValue(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::SwizzleValue>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::SwizzleValue *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_SwizzleValue_PythonToCpp_QOpenGLTexture_SwizzleValue_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_SwizzleValue_IDX])))
        return QOpenGLTexture_SwizzleValue_PythonToCpp_QOpenGLTexture_SwizzleValue;
    return {};
}
static PyObject *QOpenGLTexture_SwizzleValue_CppToPython_QOpenGLTexture_SwizzleValue(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::SwizzleValue *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_SwizzleValue_IDX]), castCppIn);

}

static void QOpenGLTexture_WrapMode_PythonToCpp_QOpenGLTexture_WrapMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::WrapMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::WrapMode *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_WrapMode_PythonToCpp_QOpenGLTexture_WrapMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_WrapMode_IDX])))
        return QOpenGLTexture_WrapMode_PythonToCpp_QOpenGLTexture_WrapMode;
    return {};
}
static PyObject *QOpenGLTexture_WrapMode_CppToPython_QOpenGLTexture_WrapMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::WrapMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_WrapMode_IDX]), castCppIn);

}

static void QOpenGLTexture_CoordinateDirection_PythonToCpp_QOpenGLTexture_CoordinateDirection(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::CoordinateDirection>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::CoordinateDirection *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_CoordinateDirection_PythonToCpp_QOpenGLTexture_CoordinateDirection_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_CoordinateDirection_IDX])))
        return QOpenGLTexture_CoordinateDirection_PythonToCpp_QOpenGLTexture_CoordinateDirection;
    return {};
}
static PyObject *QOpenGLTexture_CoordinateDirection_CppToPython_QOpenGLTexture_CoordinateDirection(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::CoordinateDirection *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_CoordinateDirection_IDX]), castCppIn);

}

static void QOpenGLTexture_Feature_PythonToCpp_QOpenGLTexture_Feature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::Feature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::Feature *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_Feature_PythonToCpp_QOpenGLTexture_Feature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Feature_IDX])))
        return QOpenGLTexture_Feature_PythonToCpp_QOpenGLTexture_Feature;
    return {};
}
static PyObject *QOpenGLTexture_Feature_CppToPython_QOpenGLTexture_Feature(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::Feature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Feature_IDX]), castCppIn);

}

static void QOpenGLTexture_DepthStencilMode_PythonToCpp_QOpenGLTexture_DepthStencilMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::DepthStencilMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::DepthStencilMode *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_DepthStencilMode_PythonToCpp_QOpenGLTexture_DepthStencilMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_DepthStencilMode_IDX])))
        return QOpenGLTexture_DepthStencilMode_PythonToCpp_QOpenGLTexture_DepthStencilMode;
    return {};
}
static PyObject *QOpenGLTexture_DepthStencilMode_CppToPython_QOpenGLTexture_DepthStencilMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::DepthStencilMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_DepthStencilMode_IDX]), castCppIn);

}

static void QOpenGLTexture_ComparisonFunction_PythonToCpp_QOpenGLTexture_ComparisonFunction(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::ComparisonFunction>(Shiboken::Enum::getValue(pyIn));
    switch (value) {
    case QOpenGLTexture::ComparisonFunction::CommpareNotEqual:
        Shiboken::Warnings::warnDeprecatedEnumValue("QOpenGLTexture::ComparisonFunction", "CommpareNotEqual");
        break;
    default:
        break;
    }
    *reinterpret_cast<::QOpenGLTexture::ComparisonFunction *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_ComparisonFunction_PythonToCpp_QOpenGLTexture_ComparisonFunction_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_ComparisonFunction_IDX])))
        return QOpenGLTexture_ComparisonFunction_PythonToCpp_QOpenGLTexture_ComparisonFunction;
    return {};
}
static PyObject *QOpenGLTexture_ComparisonFunction_CppToPython_QOpenGLTexture_ComparisonFunction(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::ComparisonFunction *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_ComparisonFunction_IDX]), castCppIn);

}

static void QOpenGLTexture_ComparisonMode_PythonToCpp_QOpenGLTexture_ComparisonMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::ComparisonMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::ComparisonMode *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_ComparisonMode_PythonToCpp_QOpenGLTexture_ComparisonMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_ComparisonMode_IDX])))
        return QOpenGLTexture_ComparisonMode_PythonToCpp_QOpenGLTexture_ComparisonMode;
    return {};
}
static PyObject *QOpenGLTexture_ComparisonMode_CppToPython_QOpenGLTexture_ComparisonMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::ComparisonMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_ComparisonMode_IDX]), castCppIn);

}

static void QOpenGLTexture_Filter_PythonToCpp_QOpenGLTexture_Filter(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QOpenGLTexture::Filter>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QOpenGLTexture::Filter *>(cppOut) = value;

}
static PythonToCppFunc is_QOpenGLTexture_Filter_PythonToCpp_QOpenGLTexture_Filter_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Filter_IDX])))
        return QOpenGLTexture_Filter_PythonToCpp_QOpenGLTexture_Filter;
    return {};
}
static PyObject *QOpenGLTexture_Filter_CppToPython_QOpenGLTexture_Filter(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QOpenGLTexture::Filter *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Filter_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOpenGLTexture_PythonToCpp_QOpenGLTexture_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLTexture_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOpenGLTexture_PythonToCpp_QOpenGLTexture_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLTexture_TypeF()))
        return QOpenGLTexture_PythonToCpp_QOpenGLTexture_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOpenGLTexture_PTR_CppToPython_QOpenGLTexture(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool exactType = false;
    auto *tCppIn = reinterpret_cast<const ::QOpenGLTexture *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto *sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType != nullptr && Shiboken::ObjectType::hasSpecialCastFunction(sbkType))
        exactType = true;
    PyObject *result = Shiboken::Object::newObject(Sbk_QOpenGLTexture_TypeF(), const_cast<void *>(cppIn), false, exactType, typeName);
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QOpenGLTexture_SignatureStrings[] = {
    "1:PySide6.QtOpenGL.QOpenGLTexture(self,target:PySide6.QtOpenGL.QOpenGLTexture.Target)",
    "0:PySide6.QtOpenGL.QOpenGLTexture(self,image:PySide6.QtGui.QImage,genMipMaps:PySide6.QtOpenGL.QOpenGLTexture.MipMapGeneration=QOpenGLTexture.MipMapGeneration.GenerateMipMaps)",
    "1:PySide6.QtOpenGL.QOpenGLTexture.allocateStorage(self)",
    "0:PySide6.QtOpenGL.QOpenGLTexture.allocateStorage(self,pixelFormat:PySide6.QtOpenGL.QOpenGLTexture.PixelFormat,pixelType:PySide6.QtOpenGL.QOpenGLTexture.PixelType)",
    "1:PySide6.QtOpenGL.QOpenGLTexture.bind(self)",
    "0:PySide6.QtOpenGL.QOpenGLTexture.bind(self,unit:uint,reset:PySide6.QtOpenGL.QOpenGLTexture.TextureUnitReset=QOpenGLTexture.TextureUnitReset.DontResetTextureUnit)",
    "PySide6.QtOpenGL.QOpenGLTexture.borderColor(self)->PySide6.QtGui.QColor",
    "1:PySide6.QtOpenGL.QOpenGLTexture.boundTextureId(target:PySide6.QtOpenGL.QOpenGLTexture.BindingTarget)->unsigned int",
    "0:PySide6.QtOpenGL.QOpenGLTexture.boundTextureId(unit:uint,target:PySide6.QtOpenGL.QOpenGLTexture.BindingTarget)->unsigned int",
    "PySide6.QtOpenGL.QOpenGLTexture.comparisonFunction(self)->PySide6.QtOpenGL.QOpenGLTexture.ComparisonFunction",
    "PySide6.QtOpenGL.QOpenGLTexture.comparisonMode(self)->PySide6.QtOpenGL.QOpenGLTexture.ComparisonMode",
    "PySide6.QtOpenGL.QOpenGLTexture.create(self)->bool",
    "PySide6.QtOpenGL.QOpenGLTexture.createTextureView(self,target:PySide6.QtOpenGL.QOpenGLTexture.Target,viewFormat:PySide6.QtOpenGL.QOpenGLTexture.TextureFormat,minimumMipmapLevel:int,maximumMipmapLevel:int,minimumLayer:int,maximumLayer:int)->PySide6.QtOpenGL.QOpenGLTexture",
    "PySide6.QtOpenGL.QOpenGLTexture.depth(self)->int",
    "PySide6.QtOpenGL.QOpenGLTexture.depthStencilMode(self)->PySide6.QtOpenGL.QOpenGLTexture.DepthStencilMode",
    "PySide6.QtOpenGL.QOpenGLTexture.destroy(self)",
    "PySide6.QtOpenGL.QOpenGLTexture.faces(self)->int",
    "PySide6.QtOpenGL.QOpenGLTexture.format(self)->PySide6.QtOpenGL.QOpenGLTexture.TextureFormat",
    "1:PySide6.QtOpenGL.QOpenGLTexture.generateMipMaps(self)",
    "0:PySide6.QtOpenGL.QOpenGLTexture.generateMipMaps(self,baseLevel:int,resetBaseLevel:bool=true)",
    "PySide6.QtOpenGL.QOpenGLTexture.hasFeature(feature:PySide6.QtOpenGL.QOpenGLTexture.Feature)->bool",
    "PySide6.QtOpenGL.QOpenGLTexture.height(self)->int",
    "PySide6.QtOpenGL.QOpenGLTexture.isAutoMipMapGenerationEnabled(self)->bool",
    "1:PySide6.QtOpenGL.QOpenGLTexture.isBound(self)->bool",
    "0:PySide6.QtOpenGL.QOpenGLTexture.isBound(self,unit:uint)->bool",
    "PySide6.QtOpenGL.QOpenGLTexture.isCreated(self)->bool",
    "PySide6.QtOpenGL.QOpenGLTexture.isFixedSamplePositions(self)->bool",
    "PySide6.QtOpenGL.QOpenGLTexture.isStorageAllocated(self)->bool",
    "PySide6.QtOpenGL.QOpenGLTexture.isTextureView(self)->bool",
    "PySide6.QtOpenGL.QOpenGLTexture.layers(self)->int",
    "PySide6.QtOpenGL.QOpenGLTexture.levelOfDetailRange(self)->std.pair[float, float]",
    "PySide6.QtOpenGL.QOpenGLTexture.levelofDetailBias(self)->float",
    "PySide6.QtOpenGL.QOpenGLTexture.magnificationFilter(self)->PySide6.QtOpenGL.QOpenGLTexture.Filter",
    "PySide6.QtOpenGL.QOpenGLTexture.maximumAnisotropy(self)->float",
    "PySide6.QtOpenGL.QOpenGLTexture.maximumLevelOfDetail(self)->float",
    "PySide6.QtOpenGL.QOpenGLTexture.maximumMipLevels(self)->int",
    "PySide6.QtOpenGL.QOpenGLTexture.minMagFilters(self)->std.pair[PySide6.QtOpenGL.QOpenGLTexture.Filter, PySide6.QtOpenGL.QOpenGLTexture.Filter]",
    "PySide6.QtOpenGL.QOpenGLTexture.minificationFilter(self)->PySide6.QtOpenGL.QOpenGLTexture.Filter",
    "PySide6.QtOpenGL.QOpenGLTexture.minimumLevelOfDetail(self)->float",
    "PySide6.QtOpenGL.QOpenGLTexture.mipBaseLevel(self)->int",
    "PySide6.QtOpenGL.QOpenGLTexture.mipLevelRange(self)->std.pair[int, int]",
    "PySide6.QtOpenGL.QOpenGLTexture.mipLevels(self)->int",
    "PySide6.QtOpenGL.QOpenGLTexture.mipMaxLevel(self)->int",
    "1:PySide6.QtOpenGL.QOpenGLTexture.release(self)",
    "0:PySide6.QtOpenGL.QOpenGLTexture.release(self,unit:uint,reset:PySide6.QtOpenGL.QOpenGLTexture.TextureUnitReset=QOpenGLTexture.TextureUnitReset.DontResetTextureUnit)",
    "PySide6.QtOpenGL.QOpenGLTexture.samples(self)->int",
    "PySide6.QtOpenGL.QOpenGLTexture.setAutoMipMapGenerationEnabled(self,enabled:bool)",
    "3:PySide6.QtOpenGL.QOpenGLTexture.setBorderColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "2:PySide6.QtOpenGL.QOpenGLTexture.setBorderColor(self,r:float,g:float,b:float,a:float)",
    "1:PySide6.QtOpenGL.QOpenGLTexture.setBorderColor(self,r:int,g:int,b:int,a:int)",
    "0:PySide6.QtOpenGL.QOpenGLTexture.setBorderColor(self,r:uint,g:uint,b:uint,a:uint)",
    "PySide6.QtOpenGL.QOpenGLTexture.setComparisonFunction(self,function:PySide6.QtOpenGL.QOpenGLTexture.ComparisonFunction)",
    "PySide6.QtOpenGL.QOpenGLTexture.setComparisonMode(self,mode:PySide6.QtOpenGL.QOpenGLTexture.ComparisonMode)",
    "4:PySide6.QtOpenGL.QOpenGLTexture.setCompressedData(self,dataSize:int,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "3:PySide6.QtOpenGL.QOpenGLTexture.setCompressedData(self,mipLevel:int,dataSize:int,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "2:PySide6.QtOpenGL.QOpenGLTexture.setCompressedData(self,mipLevel:int,layer:int,cubeFace:PySide6.QtOpenGL.QOpenGLTexture.CubeMapFace,dataSize:int,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "1:PySide6.QtOpenGL.QOpenGLTexture.setCompressedData(self,mipLevel:int,layer:int,dataSize:int,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "0:PySide6.QtOpenGL.QOpenGLTexture.setCompressedData(self,mipLevel:int,layer:int,layerCount:int,cubeFace:PySide6.QtOpenGL.QOpenGLTexture.CubeMapFace,dataSize:int,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "10:PySide6.QtOpenGL.QOpenGLTexture.setData(self,sourceFormat:PySide6.QtOpenGL.QOpenGLTexture.PixelFormat,sourceType:PySide6.QtOpenGL.QOpenGLTexture.PixelType,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "9:PySide6.QtOpenGL.QOpenGLTexture.setData(self,image:PySide6.QtGui.QImage,genMipMaps:PySide6.QtOpenGL.QOpenGLTexture.MipMapGeneration=QOpenGLTexture.MipMapGeneration.GenerateMipMaps)",
    "8:PySide6.QtOpenGL.QOpenGLTexture.setData(self,mipLevel:int,sourceFormat:PySide6.QtOpenGL.QOpenGLTexture.PixelFormat,sourceType:PySide6.QtOpenGL.QOpenGLTexture.PixelType,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "7:PySide6.QtOpenGL.QOpenGLTexture.setData(self,mipLevel:int,layer:int,cubeFace:PySide6.QtOpenGL.QOpenGLTexture.CubeMapFace,sourceFormat:PySide6.QtOpenGL.QOpenGLTexture.PixelFormat,sourceType:PySide6.QtOpenGL.QOpenGLTexture.PixelType,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "6:PySide6.QtOpenGL.QOpenGLTexture.setData(self,mipLevel:int,layer:int,sourceFormat:PySide6.QtOpenGL.QOpenGLTexture.PixelFormat,sourceType:PySide6.QtOpenGL.QOpenGLTexture.PixelType,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "5:PySide6.QtOpenGL.QOpenGLTexture.setData(self,mipLevel:int,layer:int,layerCount:int,cubeFace:PySide6.QtOpenGL.QOpenGLTexture.CubeMapFace,sourceFormat:PySide6.QtOpenGL.QOpenGLTexture.PixelFormat,sourceType:PySide6.QtOpenGL.QOpenGLTexture.PixelType,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "4:PySide6.QtOpenGL.QOpenGLTexture.setData(self,xOffset:int,yOffset:int,zOffset:int,width:int,height:int,depth:int,sourceFormat:PySide6.QtOpenGL.QOpenGLTexture.PixelFormat,sourceType:PySide6.QtOpenGL.QOpenGLTexture.PixelType,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "3:PySide6.QtOpenGL.QOpenGLTexture.setData(self,xOffset:int,yOffset:int,zOffset:int,width:int,height:int,depth:int,mipLevel:int,sourceFormat:PySide6.QtOpenGL.QOpenGLTexture.PixelFormat,sourceType:PySide6.QtOpenGL.QOpenGLTexture.PixelType,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "2:PySide6.QtOpenGL.QOpenGLTexture.setData(self,xOffset:int,yOffset:int,zOffset:int,width:int,height:int,depth:int,mipLevel:int,layer:int,cubeFace:PySide6.QtOpenGL.QOpenGLTexture.CubeMapFace,sourceFormat:PySide6.QtOpenGL.QOpenGLTexture.PixelFormat,sourceType:PySide6.QtOpenGL.QOpenGLTexture.PixelType,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "1:PySide6.QtOpenGL.QOpenGLTexture.setData(self,xOffset:int,yOffset:int,zOffset:int,width:int,height:int,depth:int,mipLevel:int,layer:int,cubeFace:PySide6.QtOpenGL.QOpenGLTexture.CubeMapFace,layerCount:int,sourceFormat:PySide6.QtOpenGL.QOpenGLTexture.PixelFormat,sourceType:PySide6.QtOpenGL.QOpenGLTexture.PixelType,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "0:PySide6.QtOpenGL.QOpenGLTexture.setData(self,xOffset:int,yOffset:int,zOffset:int,width:int,height:int,depth:int,mipLevel:int,layer:int,sourceFormat:PySide6.QtOpenGL.QOpenGLTexture.PixelFormat,sourceType:PySide6.QtOpenGL.QOpenGLTexture.PixelType,data:void,options:PySide6.QtOpenGL.QOpenGLPixelTransferOptions=nullptr)",
    "PySide6.QtOpenGL.QOpenGLTexture.setDepthStencilMode(self,mode:PySide6.QtOpenGL.QOpenGLTexture.DepthStencilMode)",
    "PySide6.QtOpenGL.QOpenGLTexture.setFixedSamplePositions(self,fixed:bool)",
    "PySide6.QtOpenGL.QOpenGLTexture.setFormat(self,format:PySide6.QtOpenGL.QOpenGLTexture.TextureFormat)",
    "PySide6.QtOpenGL.QOpenGLTexture.setLayers(self,layers:int)",
    "PySide6.QtOpenGL.QOpenGLTexture.setLevelOfDetailRange(self,min:float,max:float)",
    "PySide6.QtOpenGL.QOpenGLTexture.setLevelofDetailBias(self,bias:float)",
    "PySide6.QtOpenGL.QOpenGLTexture.setMagnificationFilter(self,filter:PySide6.QtOpenGL.QOpenGLTexture.Filter)",
    "PySide6.QtOpenGL.QOpenGLTexture.setMaximumAnisotropy(self,anisotropy:float)",
    "PySide6.QtOpenGL.QOpenGLTexture.setMaximumLevelOfDetail(self,value:float)",
    "PySide6.QtOpenGL.QOpenGLTexture.setMinMagFilters(self,minificationFilter:PySide6.QtOpenGL.QOpenGLTexture.Filter,magnificationFilter:PySide6.QtOpenGL.QOpenGLTexture.Filter)",
    "PySide6.QtOpenGL.QOpenGLTexture.setMinificationFilter(self,filter:PySide6.QtOpenGL.QOpenGLTexture.Filter)",
    "PySide6.QtOpenGL.QOpenGLTexture.setMinimumLevelOfDetail(self,value:float)",
    "PySide6.QtOpenGL.QOpenGLTexture.setMipBaseLevel(self,baseLevel:int)",
    "PySide6.QtOpenGL.QOpenGLTexture.setMipLevelRange(self,baseLevel:int,maxLevel:int)",
    "PySide6.QtOpenGL.QOpenGLTexture.setMipLevels(self,levels:int)",
    "PySide6.QtOpenGL.QOpenGLTexture.setMipMaxLevel(self,maxLevel:int)",
    "PySide6.QtOpenGL.QOpenGLTexture.setSamples(self,samples:int)",
    "PySide6.QtOpenGL.QOpenGLTexture.setSize(self,width:int,height:int=1,depth:int=1)",
    "1:PySide6.QtOpenGL.QOpenGLTexture.setSwizzleMask(self,component:PySide6.QtOpenGL.QOpenGLTexture.SwizzleComponent,value:PySide6.QtOpenGL.QOpenGLTexture.SwizzleValue)",
    "0:PySide6.QtOpenGL.QOpenGLTexture.setSwizzleMask(self,r:PySide6.QtOpenGL.QOpenGLTexture.SwizzleValue,g:PySide6.QtOpenGL.QOpenGLTexture.SwizzleValue,b:PySide6.QtOpenGL.QOpenGLTexture.SwizzleValue,a:PySide6.QtOpenGL.QOpenGLTexture.SwizzleValue)",
    "1:PySide6.QtOpenGL.QOpenGLTexture.setWrapMode(self,direction:PySide6.QtOpenGL.QOpenGLTexture.CoordinateDirection,mode:PySide6.QtOpenGL.QOpenGLTexture.WrapMode)",
    "0:PySide6.QtOpenGL.QOpenGLTexture.setWrapMode(self,mode:PySide6.QtOpenGL.QOpenGLTexture.WrapMode)",
    "PySide6.QtOpenGL.QOpenGLTexture.swizzleMask(self,component:PySide6.QtOpenGL.QOpenGLTexture.SwizzleComponent)->PySide6.QtOpenGL.QOpenGLTexture.SwizzleValue",
    "PySide6.QtOpenGL.QOpenGLTexture.target(self)->PySide6.QtOpenGL.QOpenGLTexture.Target",
    "PySide6.QtOpenGL.QOpenGLTexture.textureId(self)->unsigned int",
    "PySide6.QtOpenGL.QOpenGLTexture.width(self)->int",
    "PySide6.QtOpenGL.QOpenGLTexture.wrapMode(self,direction:PySide6.QtOpenGL.QOpenGLTexture.CoordinateDirection)->PySide6.QtOpenGL.QOpenGLTexture.WrapMode",
    nullptr}; // Sentinel

PyTypeObject *init_QOpenGLTexture(PyObject *module)
{
    if (SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX].type != nullptr)
        return SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX].type;

    Shiboken::AutoDecRef Sbk_QOpenGLTexture_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QOpenGLTexture_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOpenGLTexture",
        "QOpenGLTexture*",
        &Sbk_QOpenGLTexture_spec,
        &Shiboken::callCppDestructor< ::QOpenGLTexture >,
        Sbk_QOpenGLTexture_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOpenGLTexture_TypeF(); // references _Sbk_QOpenGLTexture_Type
    InitSignatureStrings(pyType, QOpenGLTexture_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOpenGLTexture_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOpenGLTexture_PythonToCpp_QOpenGLTexture_PTR,
        is_QOpenGLTexture_PythonToCpp_QOpenGLTexture_PTR_Convertible,
        QOpenGLTexture_PTR_CppToPython_QOpenGLTexture);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLTexture).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QOpenGLTexture_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Target'.
    const char *Target_Initializer[] = {
        "Target1D",
        "Target1DArray",
        "Target2D",
        "Target2DArray",
        "Target3D",
        "TargetCubeMap",
        "TargetCubeMapArray",
        "Target2DMultisample",
        "Target2DMultisampleArray",
        "TargetRectangle",
        "TargetBuffer",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Target_InitializerValues[] = {
        uint16_t(QOpenGLTexture::Target::Target1D),                 //  0x0de0  3552
        uint16_t(QOpenGLTexture::Target::Target1DArray),            //  0x8c18  35864
        uint16_t(QOpenGLTexture::Target::Target2D),                 //  0x0de1  3553
        uint16_t(QOpenGLTexture::Target::Target2DArray),            //  0x8c1a  35866
        uint16_t(QOpenGLTexture::Target::Target3D),                 //  0x806f  32879
        uint16_t(QOpenGLTexture::Target::TargetCubeMap),            //  0x8513  34067
        uint16_t(QOpenGLTexture::Target::TargetCubeMapArray),       //  0x9009  36873
        uint16_t(QOpenGLTexture::Target::Target2DMultisample),      //  0x9100  37120
        uint16_t(QOpenGLTexture::Target::Target2DMultisampleArray), //  0x9102  37122
        uint16_t(QOpenGLTexture::Target::TargetRectangle),          //  0x84f5  34037
        uint16_t(QOpenGLTexture::Target::TargetBuffer)              //  0x8c2a  35882
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.Target",
        Target_Initializer, Target_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Target_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::Target'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_Target_CppToPython_QOpenGLTexture_Target);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_Target_PythonToCpp_QOpenGLTexture_Target,
            is_QOpenGLTexture_Target_PythonToCpp_QOpenGLTexture_Target_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::Target");
        Shiboken::Conversions::registerConverterName(converter, "Target");
    }
    // End of 'Target' enum.

    // Initialization of enum 'BindingTarget'.
    const char *BindingTarget_Initializer[] = {
        "BindingTarget1D",
        "BindingTarget1DArray",
        "BindingTarget2D",
        "BindingTarget2DArray",
        "BindingTarget3D",
        "BindingTargetCubeMap",
        "BindingTargetCubeMapArray",
        "BindingTarget2DMultisample",
        "BindingTarget2DMultisampleArray",
        "BindingTargetRectangle",
        "BindingTargetBuffer",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t BindingTarget_InitializerValues[] = {
        uint16_t(QOpenGLTexture::BindingTarget::BindingTarget1D),                 //  0x8068  32872
        uint16_t(QOpenGLTexture::BindingTarget::BindingTarget1DArray),            //  0x8c1c  35868
        uint16_t(QOpenGLTexture::BindingTarget::BindingTarget2D),                 //  0x8069  32873
        uint16_t(QOpenGLTexture::BindingTarget::BindingTarget2DArray),            //  0x8c1d  35869
        uint16_t(QOpenGLTexture::BindingTarget::BindingTarget3D),                 //  0x806a  32874
        uint16_t(QOpenGLTexture::BindingTarget::BindingTargetCubeMap),            //  0x8514  34068
        uint16_t(QOpenGLTexture::BindingTarget::BindingTargetCubeMapArray),       //  0x900a  36874
        uint16_t(QOpenGLTexture::BindingTarget::BindingTarget2DMultisample),      //  0x9104  37124
        uint16_t(QOpenGLTexture::BindingTarget::BindingTarget2DMultisampleArray), //  0x9105  37125
        uint16_t(QOpenGLTexture::BindingTarget::BindingTargetRectangle),          //  0x84f6  34038
        uint16_t(QOpenGLTexture::BindingTarget::BindingTargetBuffer)              //  0x8c2c  35884
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.BindingTarget",
        BindingTarget_Initializer, BindingTarget_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_BindingTarget_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::BindingTarget'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_BindingTarget_CppToPython_QOpenGLTexture_BindingTarget);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_BindingTarget_PythonToCpp_QOpenGLTexture_BindingTarget,
            is_QOpenGLTexture_BindingTarget_PythonToCpp_QOpenGLTexture_BindingTarget_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::BindingTarget");
        Shiboken::Conversions::registerConverterName(converter, "BindingTarget");
    }
    // End of 'BindingTarget' enum.

    // Initialization of enum 'MipMapGeneration'.
    const char *MipMapGeneration_Initializer[] = {
        "GenerateMipMaps",
        "DontGenerateMipMaps",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MipMapGeneration_InitializerValues[] = {
        uint8_t(QOpenGLTexture::MipMapGeneration::GenerateMipMaps),    //  0x00  0
        uint8_t(QOpenGLTexture::MipMapGeneration::DontGenerateMipMaps) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.MipMapGeneration",
        MipMapGeneration_Initializer, MipMapGeneration_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_MipMapGeneration_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::MipMapGeneration'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_MipMapGeneration_CppToPython_QOpenGLTexture_MipMapGeneration);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_MipMapGeneration_PythonToCpp_QOpenGLTexture_MipMapGeneration,
            is_QOpenGLTexture_MipMapGeneration_PythonToCpp_QOpenGLTexture_MipMapGeneration_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::MipMapGeneration");
        Shiboken::Conversions::registerConverterName(converter, "MipMapGeneration");
    }
    // End of 'MipMapGeneration' enum.

    // Initialization of enum 'TextureUnitReset'.
    const char *TextureUnitReset_Initializer[] = {
        "ResetTextureUnit",
        "DontResetTextureUnit",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TextureUnitReset_InitializerValues[] = {
        uint8_t(QOpenGLTexture::TextureUnitReset::ResetTextureUnit),    //  0x00  0
        uint8_t(QOpenGLTexture::TextureUnitReset::DontResetTextureUnit) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.TextureUnitReset",
        TextureUnitReset_Initializer, TextureUnitReset_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureUnitReset_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::TextureUnitReset'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_TextureUnitReset_CppToPython_QOpenGLTexture_TextureUnitReset);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_TextureUnitReset_PythonToCpp_QOpenGLTexture_TextureUnitReset,
            is_QOpenGLTexture_TextureUnitReset_PythonToCpp_QOpenGLTexture_TextureUnitReset_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::TextureUnitReset");
        Shiboken::Conversions::registerConverterName(converter, "TextureUnitReset");
    }
    // End of 'TextureUnitReset' enum.

    // Initialization of enum 'TextureFormat'.
    const char *TextureFormat_Initializer[] = {
        "NoFormat",
        "R8_UNorm",
        "RG8_UNorm",
        "RGB8_UNorm",
        "RGBA8_UNorm",
        "R16_UNorm",
        "RG16_UNorm",
        "RGB16_UNorm",
        "RGBA16_UNorm",
        "R8_SNorm",
        "RG8_SNorm",
        "RGB8_SNorm",
        "RGBA8_SNorm",
        "R16_SNorm",
        "RG16_SNorm",
        "RGB16_SNorm",
        "RGBA16_SNorm",
        "R8U",
        "RG8U",
        "RGB8U",
        "RGBA8U",
        "R16U",
        "RG16U",
        "RGB16U",
        "RGBA16U",
        "R32U",
        "RG32U",
        "RGB32U",
        "RGBA32U",
        "R8I",
        "RG8I",
        "RGB8I",
        "RGBA8I",
        "R16I",
        "RG16I",
        "RGB16I",
        "RGBA16I",
        "R32I",
        "RG32I",
        "RGB32I",
        "RGBA32I",
        "R16F",
        "RG16F",
        "RGB16F",
        "RGBA16F",
        "R32F",
        "RG32F",
        "RGB32F",
        "RGBA32F",
        "RGB9E5",
        "RG11B10F",
        "RG3B2",
        "R5G6B5",
        "RGB5A1",
        "RGBA4",
        "RGB10A2",
        "D16",
        "D24",
        "D24S8",
        "D32",
        "D32F",
        "D32FS8X24",
        "S8",
        "RGB_DXT1",
        "RGBA_DXT1",
        "RGBA_DXT3",
        "RGBA_DXT5",
        "R_ATI1N_UNorm",
        "R_ATI1N_SNorm",
        "RG_ATI2N_UNorm",
        "RG_ATI2N_SNorm",
        "RGB_BP_UNSIGNED_FLOAT",
        "RGB_BP_SIGNED_FLOAT",
        "RGB_BP_UNorm",
        "R11_EAC_UNorm",
        "R11_EAC_SNorm",
        "RG11_EAC_UNorm",
        "RG11_EAC_SNorm",
        "RGB8_ETC2",
        "SRGB8_ETC2",
        "RGB8_PunchThrough_Alpha1_ETC2",
        "SRGB8_PunchThrough_Alpha1_ETC2",
        "RGBA8_ETC2_EAC",
        "SRGB8_Alpha8_ETC2_EAC",
        "RGB8_ETC1",
        "RGBA_ASTC_4x4",
        "RGBA_ASTC_5x4",
        "RGBA_ASTC_5x5",
        "RGBA_ASTC_6x5",
        "RGBA_ASTC_6x6",
        "RGBA_ASTC_8x5",
        "RGBA_ASTC_8x6",
        "RGBA_ASTC_8x8",
        "RGBA_ASTC_10x5",
        "RGBA_ASTC_10x6",
        "RGBA_ASTC_10x8",
        "RGBA_ASTC_10x10",
        "RGBA_ASTC_12x10",
        "RGBA_ASTC_12x12",
        "SRGB8_Alpha8_ASTC_4x4",
        "SRGB8_Alpha8_ASTC_5x4",
        "SRGB8_Alpha8_ASTC_5x5",
        "SRGB8_Alpha8_ASTC_6x5",
        "SRGB8_Alpha8_ASTC_6x6",
        "SRGB8_Alpha8_ASTC_8x5",
        "SRGB8_Alpha8_ASTC_8x6",
        "SRGB8_Alpha8_ASTC_8x8",
        "SRGB8_Alpha8_ASTC_10x5",
        "SRGB8_Alpha8_ASTC_10x6",
        "SRGB8_Alpha8_ASTC_10x8",
        "SRGB8_Alpha8_ASTC_10x10",
        "SRGB8_Alpha8_ASTC_12x10",
        "SRGB8_Alpha8_ASTC_12x12",
        "SRGB8",
        "SRGB8_Alpha8",
        "SRGB_DXT1",
        "SRGB_Alpha_DXT1",
        "SRGB_Alpha_DXT3",
        "SRGB_Alpha_DXT5",
        "SRGB_BP_UNorm",
        "DepthFormat",
        "AlphaFormat",
        "RGBFormat",
        "RGBAFormat",
        "LuminanceFormat",
        "LuminanceAlphaFormat",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t TextureFormat_InitializerValues[] = {
        uint16_t(QOpenGLTexture::TextureFormat::NoFormat),                       //  0x0000  0
        uint16_t(QOpenGLTexture::TextureFormat::R8_UNorm),                       //  0x8229  33321
        uint16_t(QOpenGLTexture::TextureFormat::RG8_UNorm),                      //  0x822b  33323
        uint16_t(QOpenGLTexture::TextureFormat::RGB8_UNorm),                     //  0x8051  32849
        uint16_t(QOpenGLTexture::TextureFormat::RGBA8_UNorm),                    //  0x8058  32856
        uint16_t(QOpenGLTexture::TextureFormat::R16_UNorm),                      //  0x822a  33322
        uint16_t(QOpenGLTexture::TextureFormat::RG16_UNorm),                     //  0x822c  33324
        uint16_t(QOpenGLTexture::TextureFormat::RGB16_UNorm),                    //  0x8054  32852
        uint16_t(QOpenGLTexture::TextureFormat::RGBA16_UNorm),                   //  0x805b  32859
        uint16_t(QOpenGLTexture::TextureFormat::R8_SNorm),                       //  0x8f94  36756
        uint16_t(QOpenGLTexture::TextureFormat::RG8_SNorm),                      //  0x8f95  36757
        uint16_t(QOpenGLTexture::TextureFormat::RGB8_SNorm),                     //  0x8f96  36758
        uint16_t(QOpenGLTexture::TextureFormat::RGBA8_SNorm),                    //  0x8f97  36759
        uint16_t(QOpenGLTexture::TextureFormat::R16_SNorm),                      //  0x8f98  36760
        uint16_t(QOpenGLTexture::TextureFormat::RG16_SNorm),                     //  0x8f99  36761
        uint16_t(QOpenGLTexture::TextureFormat::RGB16_SNorm),                    //  0x8f9a  36762
        uint16_t(QOpenGLTexture::TextureFormat::RGBA16_SNorm),                   //  0x8f9b  36763
        uint16_t(QOpenGLTexture::TextureFormat::R8U),                            //  0x8232  33330
        uint16_t(QOpenGLTexture::TextureFormat::RG8U),                           //  0x8238  33336
        uint16_t(QOpenGLTexture::TextureFormat::RGB8U),                          //  0x8d7d  36221
        uint16_t(QOpenGLTexture::TextureFormat::RGBA8U),                         //  0x8d7c  36220
        uint16_t(QOpenGLTexture::TextureFormat::R16U),                           //  0x8234  33332
        uint16_t(QOpenGLTexture::TextureFormat::RG16U),                          //  0x823a  33338
        uint16_t(QOpenGLTexture::TextureFormat::RGB16U),                         //  0x8d77  36215
        uint16_t(QOpenGLTexture::TextureFormat::RGBA16U),                        //  0x8d76  36214
        uint16_t(QOpenGLTexture::TextureFormat::R32U),                           //  0x8236  33334
        uint16_t(QOpenGLTexture::TextureFormat::RG32U),                          //  0x823c  33340
        uint16_t(QOpenGLTexture::TextureFormat::RGB32U),                         //  0x8d71  36209
        uint16_t(QOpenGLTexture::TextureFormat::RGBA32U),                        //  0x8d70  36208
        uint16_t(QOpenGLTexture::TextureFormat::R8I),                            //  0x8231  33329
        uint16_t(QOpenGLTexture::TextureFormat::RG8I),                           //  0x8237  33335
        uint16_t(QOpenGLTexture::TextureFormat::RGB8I),                          //  0x8d8f  36239
        uint16_t(QOpenGLTexture::TextureFormat::RGBA8I),                         //  0x8d8e  36238
        uint16_t(QOpenGLTexture::TextureFormat::R16I),                           //  0x8233  33331
        uint16_t(QOpenGLTexture::TextureFormat::RG16I),                          //  0x8239  33337
        uint16_t(QOpenGLTexture::TextureFormat::RGB16I),                         //  0x8d89  36233
        uint16_t(QOpenGLTexture::TextureFormat::RGBA16I),                        //  0x8d88  36232
        uint16_t(QOpenGLTexture::TextureFormat::R32I),                           //  0x8235  33333
        uint16_t(QOpenGLTexture::TextureFormat::RG32I),                          //  0x823b  33339
        uint16_t(QOpenGLTexture::TextureFormat::RGB32I),                         //  0x8d83  36227
        uint16_t(QOpenGLTexture::TextureFormat::RGBA32I),                        //  0x8d82  36226
        uint16_t(QOpenGLTexture::TextureFormat::R16F),                           //  0x822d  33325
        uint16_t(QOpenGLTexture::TextureFormat::RG16F),                          //  0x822f  33327
        uint16_t(QOpenGLTexture::TextureFormat::RGB16F),                         //  0x881b  34843
        uint16_t(QOpenGLTexture::TextureFormat::RGBA16F),                        //  0x881a  34842
        uint16_t(QOpenGLTexture::TextureFormat::R32F),                           //  0x822e  33326
        uint16_t(QOpenGLTexture::TextureFormat::RG32F),                          //  0x8230  33328
        uint16_t(QOpenGLTexture::TextureFormat::RGB32F),                         //  0x8815  34837
        uint16_t(QOpenGLTexture::TextureFormat::RGBA32F),                        //  0x8814  34836
        uint16_t(QOpenGLTexture::TextureFormat::RGB9E5),                         //  0x8c3d  35901
        uint16_t(QOpenGLTexture::TextureFormat::RG11B10F),                       //  0x8c3a  35898
        uint16_t(QOpenGLTexture::TextureFormat::RG3B2),                          //  0x2a10  10768
        uint16_t(QOpenGLTexture::TextureFormat::R5G6B5),                         //  0x8d62  36194
        uint16_t(QOpenGLTexture::TextureFormat::RGB5A1),                         //  0x8057  32855
        uint16_t(QOpenGLTexture::TextureFormat::RGBA4),                          //  0x8056  32854
        uint16_t(QOpenGLTexture::TextureFormat::RGB10A2),                        //  0x906f  36975
        uint16_t(QOpenGLTexture::TextureFormat::D16),                            //  0x81a5  33189
        uint16_t(QOpenGLTexture::TextureFormat::D24),                            //  0x81a6  33190
        uint16_t(QOpenGLTexture::TextureFormat::D24S8),                          //  0x88f0  35056
        uint16_t(QOpenGLTexture::TextureFormat::D32),                            //  0x81a7  33191
        uint16_t(QOpenGLTexture::TextureFormat::D32F),                           //  0x8cac  36012
        uint16_t(QOpenGLTexture::TextureFormat::D32FS8X24),                      //  0x8cad  36013
        uint16_t(QOpenGLTexture::TextureFormat::S8),                             //  0x8d48  36168
        uint16_t(QOpenGLTexture::TextureFormat::RGB_DXT1),                       //  0x83f0  33776
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_DXT1),                      //  0x83f1  33777
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_DXT3),                      //  0x83f2  33778
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_DXT5),                      //  0x83f3  33779
        uint16_t(QOpenGLTexture::TextureFormat::R_ATI1N_UNorm),                  //  0x8dbb  36283
        uint16_t(QOpenGLTexture::TextureFormat::R_ATI1N_SNorm),                  //  0x8dbc  36284
        uint16_t(QOpenGLTexture::TextureFormat::RG_ATI2N_UNorm),                 //  0x8dbd  36285
        uint16_t(QOpenGLTexture::TextureFormat::RG_ATI2N_SNorm),                 //  0x8dbe  36286
        uint16_t(QOpenGLTexture::TextureFormat::RGB_BP_UNSIGNED_FLOAT),          //  0x8e8f  36495
        uint16_t(QOpenGLTexture::TextureFormat::RGB_BP_SIGNED_FLOAT),            //  0x8e8e  36494
        uint16_t(QOpenGLTexture::TextureFormat::RGB_BP_UNorm),                   //  0x8e8c  36492
        uint16_t(QOpenGLTexture::TextureFormat::R11_EAC_UNorm),                  //  0x9270  37488
        uint16_t(QOpenGLTexture::TextureFormat::R11_EAC_SNorm),                  //  0x9271  37489
        uint16_t(QOpenGLTexture::TextureFormat::RG11_EAC_UNorm),                 //  0x9272  37490
        uint16_t(QOpenGLTexture::TextureFormat::RG11_EAC_SNorm),                 //  0x9273  37491
        uint16_t(QOpenGLTexture::TextureFormat::RGB8_ETC2),                      //  0x9274  37492
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_ETC2),                     //  0x9275  37493
        uint16_t(QOpenGLTexture::TextureFormat::RGB8_PunchThrough_Alpha1_ETC2),  //  0x9276  37494
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_PunchThrough_Alpha1_ETC2), //  0x9277  37495
        uint16_t(QOpenGLTexture::TextureFormat::RGBA8_ETC2_EAC),                 //  0x9278  37496
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ETC2_EAC),          //  0x9279  37497
        uint16_t(QOpenGLTexture::TextureFormat::RGB8_ETC1),                      //  0x8d64  36196
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_ASTC_4x4),                  //  0x93b0  37808
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_ASTC_5x4),                  //  0x93b1  37809
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_ASTC_5x5),                  //  0x93b2  37810
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_ASTC_6x5),                  //  0x93b3  37811
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_ASTC_6x6),                  //  0x93b4  37812
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_ASTC_8x5),                  //  0x93b5  37813
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_ASTC_8x6),                  //  0x93b6  37814
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_ASTC_8x8),                  //  0x93b7  37815
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_ASTC_10x5),                 //  0x93b8  37816
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_ASTC_10x6),                 //  0x93b9  37817
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_ASTC_10x8),                 //  0x93ba  37818
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_ASTC_10x10),                //  0x93bb  37819
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_ASTC_12x10),                //  0x93bc  37820
        uint16_t(QOpenGLTexture::TextureFormat::RGBA_ASTC_12x12),                //  0x93bd  37821
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ASTC_4x4),          //  0x93d0  37840
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ASTC_5x4),          //  0x93d1  37841
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ASTC_5x5),          //  0x93d2  37842
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ASTC_6x5),          //  0x93d3  37843
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ASTC_6x6),          //  0x93d4  37844
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ASTC_8x5),          //  0x93d5  37845
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ASTC_8x6),          //  0x93d6  37846
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ASTC_8x8),          //  0x93d7  37847
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ASTC_10x5),         //  0x93d8  37848
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ASTC_10x6),         //  0x93d9  37849
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ASTC_10x8),         //  0x93da  37850
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ASTC_10x10),        //  0x93db  37851
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ASTC_12x10),        //  0x93dc  37852
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8_ASTC_12x12),        //  0x93dd  37853
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8),                          //  0x8c41  35905
        uint16_t(QOpenGLTexture::TextureFormat::SRGB8_Alpha8),                   //  0x8c43  35907
        uint16_t(QOpenGLTexture::TextureFormat::SRGB_DXT1),                      //  0x8c4c  35916
        uint16_t(QOpenGLTexture::TextureFormat::SRGB_Alpha_DXT1),                //  0x8c4d  35917
        uint16_t(QOpenGLTexture::TextureFormat::SRGB_Alpha_DXT3),                //  0x8c4e  35918
        uint16_t(QOpenGLTexture::TextureFormat::SRGB_Alpha_DXT5),                //  0x8c4f  35919
        uint16_t(QOpenGLTexture::TextureFormat::SRGB_BP_UNorm),                  //  0x8e8d  36493
        uint16_t(QOpenGLTexture::TextureFormat::DepthFormat),                    //  0x1902  6402
        uint16_t(QOpenGLTexture::TextureFormat::AlphaFormat),                    //  0x1906  6406
        uint16_t(QOpenGLTexture::TextureFormat::RGBFormat),                      //  0x1907  6407
        uint16_t(QOpenGLTexture::TextureFormat::RGBAFormat),                     //  0x1908  6408
        uint16_t(QOpenGLTexture::TextureFormat::LuminanceFormat),                //  0x1909  6409
        uint16_t(QOpenGLTexture::TextureFormat::LuminanceAlphaFormat)            //  0x190a  6410
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.TextureFormat",
        TextureFormat_Initializer, TextureFormat_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureFormat_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::TextureFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_TextureFormat_CppToPython_QOpenGLTexture_TextureFormat);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_TextureFormat_PythonToCpp_QOpenGLTexture_TextureFormat,
            is_QOpenGLTexture_TextureFormat_PythonToCpp_QOpenGLTexture_TextureFormat_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::TextureFormat");
        Shiboken::Conversions::registerConverterName(converter, "TextureFormat");
    }
    // End of 'TextureFormat' enum.

    // Initialization of enum 'TextureFormatClass'.
    const char *TextureFormatClass_Initializer[] = {
        "NoFormatClass",
        "FormatClass_128Bit",
        "FormatClass_96Bit",
        "FormatClass_64Bit",
        "FormatClass_48Bit",
        "FormatClass_32Bit",
        "FormatClass_24Bit",
        "FormatClass_16Bit",
        "FormatClass_8Bit",
        "FormatClass_RGTC1_R",
        "FormatClass_RGTC2_RG",
        "FormatClass_BPTC_Unorm",
        "FormatClass_BPTC_Float",
        "FormatClass_S3TC_DXT1_RGB",
        "FormatClass_S3TC_DXT1_RGBA",
        "FormatClass_S3TC_DXT3_RGBA",
        "FormatClass_S3TC_DXT5_RGBA",
        "FormatClass_Unique",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TextureFormatClass_InitializerValues[] = {
        uint8_t(QOpenGLTexture::TextureFormatClass::NoFormatClass),              //  0x00  0
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_128Bit),         //  0x01  1
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_96Bit),          //  0x02  2
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_64Bit),          //  0x03  3
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_48Bit),          //  0x04  4
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_32Bit),          //  0x05  5
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_24Bit),          //  0x06  6
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_16Bit),          //  0x07  7
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_8Bit),           //  0x08  8
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_RGTC1_R),        //  0x09  9
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_RGTC2_RG),       //  0x0a  10
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_BPTC_Unorm),     //  0x0b  11
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_BPTC_Float),     //  0x0c  12
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_S3TC_DXT1_RGB),  //  0x0d  13
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_S3TC_DXT1_RGBA), //  0x0e  14
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_S3TC_DXT3_RGBA), //  0x0f  15
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_S3TC_DXT5_RGBA), //  0x10  16
        uint8_t(QOpenGLTexture::TextureFormatClass::FormatClass_Unique)          //  0x11  17
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.TextureFormatClass",
        TextureFormatClass_Initializer, TextureFormatClass_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_TextureFormatClass_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::TextureFormatClass'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_TextureFormatClass_CppToPython_QOpenGLTexture_TextureFormatClass);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_TextureFormatClass_PythonToCpp_QOpenGLTexture_TextureFormatClass,
            is_QOpenGLTexture_TextureFormatClass_PythonToCpp_QOpenGLTexture_TextureFormatClass_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::TextureFormatClass");
        Shiboken::Conversions::registerConverterName(converter, "TextureFormatClass");
    }
    // End of 'TextureFormatClass' enum.

    // Initialization of enum 'CubeMapFace'.
    const char *CubeMapFace_Initializer[] = {
        "CubeMapPositiveX",
        "CubeMapNegativeX",
        "CubeMapPositiveY",
        "CubeMapNegativeY",
        "CubeMapPositiveZ",
        "CubeMapNegativeZ",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t CubeMapFace_InitializerValues[] = {
        uint16_t(QOpenGLTexture::CubeMapFace::CubeMapPositiveX), //  0x8515  34069
        uint16_t(QOpenGLTexture::CubeMapFace::CubeMapNegativeX), //  0x8516  34070
        uint16_t(QOpenGLTexture::CubeMapFace::CubeMapPositiveY), //  0x8517  34071
        uint16_t(QOpenGLTexture::CubeMapFace::CubeMapNegativeY), //  0x8518  34072
        uint16_t(QOpenGLTexture::CubeMapFace::CubeMapPositiveZ), //  0x8519  34073
        uint16_t(QOpenGLTexture::CubeMapFace::CubeMapNegativeZ)  //  0x851a  34074
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.CubeMapFace",
        CubeMapFace_Initializer, CubeMapFace_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_CubeMapFace_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::CubeMapFace'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_CubeMapFace_CppToPython_QOpenGLTexture_CubeMapFace);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_CubeMapFace_PythonToCpp_QOpenGLTexture_CubeMapFace,
            is_QOpenGLTexture_CubeMapFace_PythonToCpp_QOpenGLTexture_CubeMapFace_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::CubeMapFace");
        Shiboken::Conversions::registerConverterName(converter, "CubeMapFace");
    }
    // End of 'CubeMapFace' enum.

    // Initialization of enum 'PixelFormat'.
    const char *PixelFormat_Initializer[] = {
        "NoSourceFormat",
        "Red",
        "RG",
        "RGB",
        "BGR",
        "RGBA",
        "BGRA",
        "Red_Integer",
        "RG_Integer",
        "RGB_Integer",
        "BGR_Integer",
        "RGBA_Integer",
        "BGRA_Integer",
        "Stencil",
        "Depth",
        "DepthStencil",
        "Alpha",
        "Luminance",
        "LuminanceAlpha",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t PixelFormat_InitializerValues[] = {
        uint16_t(QOpenGLTexture::PixelFormat::NoSourceFormat), //  0x0000  0
        uint16_t(QOpenGLTexture::PixelFormat::Red),            //  0x1903  6403
        uint16_t(QOpenGLTexture::PixelFormat::RG),             //  0x8227  33319
        uint16_t(QOpenGLTexture::PixelFormat::RGB),            //  0x1907  6407
        uint16_t(QOpenGLTexture::PixelFormat::BGR),            //  0x80e0  32992
        uint16_t(QOpenGLTexture::PixelFormat::RGBA),           //  0x1908  6408
        uint16_t(QOpenGLTexture::PixelFormat::BGRA),           //  0x80e1  32993
        uint16_t(QOpenGLTexture::PixelFormat::Red_Integer),    //  0x8d94  36244
        uint16_t(QOpenGLTexture::PixelFormat::RG_Integer),     //  0x8228  33320
        uint16_t(QOpenGLTexture::PixelFormat::RGB_Integer),    //  0x8d98  36248
        uint16_t(QOpenGLTexture::PixelFormat::BGR_Integer),    //  0x8d9a  36250
        uint16_t(QOpenGLTexture::PixelFormat::RGBA_Integer),   //  0x8d99  36249
        uint16_t(QOpenGLTexture::PixelFormat::BGRA_Integer),   //  0x8d9b  36251
        uint16_t(QOpenGLTexture::PixelFormat::Stencil),        //  0x1901  6401
        uint16_t(QOpenGLTexture::PixelFormat::Depth),          //  0x1902  6402
        uint16_t(QOpenGLTexture::PixelFormat::DepthStencil),   //  0x84f9  34041
        uint16_t(QOpenGLTexture::PixelFormat::Alpha),          //  0x1906  6406
        uint16_t(QOpenGLTexture::PixelFormat::Luminance),      //  0x1909  6409
        uint16_t(QOpenGLTexture::PixelFormat::LuminanceAlpha)  //  0x190a  6410
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.PixelFormat",
        PixelFormat_Initializer, PixelFormat_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelFormat_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::PixelFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_PixelFormat_CppToPython_QOpenGLTexture_PixelFormat);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_PixelFormat_PythonToCpp_QOpenGLTexture_PixelFormat,
            is_QOpenGLTexture_PixelFormat_PythonToCpp_QOpenGLTexture_PixelFormat_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::PixelFormat");
        Shiboken::Conversions::registerConverterName(converter, "PixelFormat");
    }
    // End of 'PixelFormat' enum.

    // Initialization of enum 'PixelType'.
    const char *PixelType_Initializer[] = {
        "NoPixelType",
        "Int8",
        "UInt8",
        "Int16",
        "UInt16",
        "Int32",
        "UInt32",
        "Float16",
        "Float16OES",
        "Float32",
        "UInt32_RGB9_E5",
        "UInt32_RG11B10F",
        "UInt8_RG3B2",
        "UInt8_RG3B2_Rev",
        "UInt16_RGB5A1",
        "UInt16_RGB5A1_Rev",
        "UInt16_R5G6B5",
        "UInt16_R5G6B5_Rev",
        "UInt16_RGBA4",
        "UInt16_RGBA4_Rev",
        "UInt32_RGBA8",
        "UInt32_RGBA8_Rev",
        "UInt32_RGB10A2",
        "UInt32_RGB10A2_Rev",
        "UInt32_D24S8",
        "Float32_D32_UInt32_S8_X24",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t PixelType_InitializerValues[] = {
        uint16_t(QOpenGLTexture::PixelType::NoPixelType),              //  0x0000  0
        uint16_t(QOpenGLTexture::PixelType::Int8),                     //  0x1400  5120
        uint16_t(QOpenGLTexture::PixelType::UInt8),                    //  0x1401  5121
        uint16_t(QOpenGLTexture::PixelType::Int16),                    //  0x1402  5122
        uint16_t(QOpenGLTexture::PixelType::UInt16),                   //  0x1403  5123
        uint16_t(QOpenGLTexture::PixelType::Int32),                    //  0x1404  5124
        uint16_t(QOpenGLTexture::PixelType::UInt32),                   //  0x1405  5125
        uint16_t(QOpenGLTexture::PixelType::Float16),                  //  0x140b  5131
        uint16_t(QOpenGLTexture::PixelType::Float16OES),               //  0x8d61  36193
        uint16_t(QOpenGLTexture::PixelType::Float32),                  //  0x1406  5126
        uint16_t(QOpenGLTexture::PixelType::UInt32_RGB9_E5),           //  0x8c3e  35902
        uint16_t(QOpenGLTexture::PixelType::UInt32_RG11B10F),          //  0x8c3b  35899
        uint16_t(QOpenGLTexture::PixelType::UInt8_RG3B2),              //  0x8032  32818
        uint16_t(QOpenGLTexture::PixelType::UInt8_RG3B2_Rev),          //  0x8362  33634
        uint16_t(QOpenGLTexture::PixelType::UInt16_RGB5A1),            //  0x8034  32820
        uint16_t(QOpenGLTexture::PixelType::UInt16_RGB5A1_Rev),        //  0x8366  33638
        uint16_t(QOpenGLTexture::PixelType::UInt16_R5G6B5),            //  0x8363  33635
        uint16_t(QOpenGLTexture::PixelType::UInt16_R5G6B5_Rev),        //  0x8364  33636
        uint16_t(QOpenGLTexture::PixelType::UInt16_RGBA4),             //  0x8033  32819
        uint16_t(QOpenGLTexture::PixelType::UInt16_RGBA4_Rev),         //  0x8365  33637
        uint16_t(QOpenGLTexture::PixelType::UInt32_RGBA8),             //  0x8035  32821
        uint16_t(QOpenGLTexture::PixelType::UInt32_RGBA8_Rev),         //  0x8367  33639
        uint16_t(QOpenGLTexture::PixelType::UInt32_RGB10A2),           //  0x8036  32822
        uint16_t(QOpenGLTexture::PixelType::UInt32_RGB10A2_Rev),       //  0x8368  33640
        uint16_t(QOpenGLTexture::PixelType::UInt32_D24S8),             //  0x84fa  34042
        uint16_t(QOpenGLTexture::PixelType::Float32_D32_UInt32_S8_X24) //  0x8dad  36269
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.PixelType",
        PixelType_Initializer, PixelType_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_PixelType_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::PixelType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_PixelType_CppToPython_QOpenGLTexture_PixelType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_PixelType_PythonToCpp_QOpenGLTexture_PixelType,
            is_QOpenGLTexture_PixelType_PythonToCpp_QOpenGLTexture_PixelType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::PixelType");
        Shiboken::Conversions::registerConverterName(converter, "PixelType");
    }
    // End of 'PixelType' enum.

    // Initialization of enum 'SwizzleComponent'.
    const char *SwizzleComponent_Initializer[] = {
        "SwizzleRed",
        "SwizzleGreen",
        "SwizzleBlue",
        "SwizzleAlpha",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t SwizzleComponent_InitializerValues[] = {
        uint16_t(QOpenGLTexture::SwizzleComponent::SwizzleRed),   //  0x8e42  36418
        uint16_t(QOpenGLTexture::SwizzleComponent::SwizzleGreen), //  0x8e43  36419
        uint16_t(QOpenGLTexture::SwizzleComponent::SwizzleBlue),  //  0x8e44  36420
        uint16_t(QOpenGLTexture::SwizzleComponent::SwizzleAlpha)  //  0x8e45  36421
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.SwizzleComponent",
        SwizzleComponent_Initializer, SwizzleComponent_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_SwizzleComponent_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::SwizzleComponent'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_SwizzleComponent_CppToPython_QOpenGLTexture_SwizzleComponent);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_SwizzleComponent_PythonToCpp_QOpenGLTexture_SwizzleComponent,
            is_QOpenGLTexture_SwizzleComponent_PythonToCpp_QOpenGLTexture_SwizzleComponent_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::SwizzleComponent");
        Shiboken::Conversions::registerConverterName(converter, "SwizzleComponent");
    }
    // End of 'SwizzleComponent' enum.

    // Initialization of enum 'SwizzleValue'.
    const char *SwizzleValue_Initializer[] = {
        "RedValue",
        "GreenValue",
        "BlueValue",
        "AlphaValue",
        "ZeroValue",
        "OneValue",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t SwizzleValue_InitializerValues[] = {
        uint16_t(QOpenGLTexture::SwizzleValue::RedValue),   //  0x1903  6403
        uint16_t(QOpenGLTexture::SwizzleValue::GreenValue), //  0x1904  6404
        uint16_t(QOpenGLTexture::SwizzleValue::BlueValue),  //  0x1905  6405
        uint16_t(QOpenGLTexture::SwizzleValue::AlphaValue), //  0x1906  6406
        uint16_t(QOpenGLTexture::SwizzleValue::ZeroValue),  //  0x0000  0
        uint16_t(QOpenGLTexture::SwizzleValue::OneValue)    //  0x0001  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.SwizzleValue",
        SwizzleValue_Initializer, SwizzleValue_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_SwizzleValue_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::SwizzleValue'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_SwizzleValue_CppToPython_QOpenGLTexture_SwizzleValue);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_SwizzleValue_PythonToCpp_QOpenGLTexture_SwizzleValue,
            is_QOpenGLTexture_SwizzleValue_PythonToCpp_QOpenGLTexture_SwizzleValue_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::SwizzleValue");
        Shiboken::Conversions::registerConverterName(converter, "SwizzleValue");
    }
    // End of 'SwizzleValue' enum.

    // Initialization of enum 'WrapMode'.
    const char *WrapMode_Initializer[] = {
        "Repeat",
        "MirroredRepeat",
        "ClampToEdge",
        "ClampToBorder",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t WrapMode_InitializerValues[] = {
        uint16_t(QOpenGLTexture::WrapMode::Repeat),         //  0x2901  10497
        uint16_t(QOpenGLTexture::WrapMode::MirroredRepeat), //  0x8370  33648
        uint16_t(QOpenGLTexture::WrapMode::ClampToEdge),    //  0x812f  33071
        uint16_t(QOpenGLTexture::WrapMode::ClampToBorder)   //  0x812d  33069
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.WrapMode",
        WrapMode_Initializer, WrapMode_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_WrapMode_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::WrapMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_WrapMode_CppToPython_QOpenGLTexture_WrapMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_WrapMode_PythonToCpp_QOpenGLTexture_WrapMode,
            is_QOpenGLTexture_WrapMode_PythonToCpp_QOpenGLTexture_WrapMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::WrapMode");
        Shiboken::Conversions::registerConverterName(converter, "WrapMode");
    }
    // End of 'WrapMode' enum.

    // Initialization of enum 'CoordinateDirection'.
    const char *CoordinateDirection_Initializer[] = {
        "DirectionS",
        "DirectionT",
        "DirectionR",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t CoordinateDirection_InitializerValues[] = {
        uint16_t(QOpenGLTexture::CoordinateDirection::DirectionS), //  0x2802  10242
        uint16_t(QOpenGLTexture::CoordinateDirection::DirectionT), //  0x2803  10243
        uint16_t(QOpenGLTexture::CoordinateDirection::DirectionR)  //  0x8072  32882
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.CoordinateDirection",
        CoordinateDirection_Initializer, CoordinateDirection_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_CoordinateDirection_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::CoordinateDirection'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_CoordinateDirection_CppToPython_QOpenGLTexture_CoordinateDirection);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_CoordinateDirection_PythonToCpp_QOpenGLTexture_CoordinateDirection,
            is_QOpenGLTexture_CoordinateDirection_PythonToCpp_QOpenGLTexture_CoordinateDirection_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::CoordinateDirection");
        Shiboken::Conversions::registerConverterName(converter, "CoordinateDirection");
    }
    // End of 'CoordinateDirection' enum.

    // Initialization of enum 'Feature'.
    const char *Feature_Initializer[] = {
        "ImmutableStorage",
        "ImmutableMultisampleStorage",
        "TextureRectangle",
        "TextureArrays",
        "Texture3D",
        "TextureMultisample",
        "TextureBuffer",
        "TextureCubeMapArrays",
        "Swizzle",
        "StencilTexturing",
        "AnisotropicFiltering",
        "NPOTTextures",
        "NPOTTextureRepeat",
        "Texture1D",
        "TextureComparisonOperators",
        "TextureMipMapLevel",
        "MaxFeatureFlag",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t Feature_InitializerValues[] = {
        uint32_t(QOpenGLTexture::Feature::ImmutableStorage),            //  0x00000001  1
        uint32_t(QOpenGLTexture::Feature::ImmutableMultisampleStorage), //  0x00000002  2
        uint32_t(QOpenGLTexture::Feature::TextureRectangle),            //  0x00000004  4
        uint32_t(QOpenGLTexture::Feature::TextureArrays),               //  0x00000008  8
        uint32_t(QOpenGLTexture::Feature::Texture3D),                   //  0x00000010  16
        uint32_t(QOpenGLTexture::Feature::TextureMultisample),          //  0x00000020  32
        uint32_t(QOpenGLTexture::Feature::TextureBuffer),               //  0x00000040  64
        uint32_t(QOpenGLTexture::Feature::TextureCubeMapArrays),        //  0x00000080  128
        uint32_t(QOpenGLTexture::Feature::Swizzle),                     //  0x00000100  256
        uint32_t(QOpenGLTexture::Feature::StencilTexturing),            //  0x00000200  512
        uint32_t(QOpenGLTexture::Feature::AnisotropicFiltering),        //  0x00000400  1024
        uint32_t(QOpenGLTexture::Feature::NPOTTextures),                //  0x00000800  2048
        uint32_t(QOpenGLTexture::Feature::NPOTTextureRepeat),           //  0x00001000  4096
        uint32_t(QOpenGLTexture::Feature::Texture1D),                   //  0x00002000  8192
        uint32_t(QOpenGLTexture::Feature::TextureComparisonOperators),  //  0x00004000  16384
        uint32_t(QOpenGLTexture::Feature::TextureMipMapLevel),          //  0x00008000  32768
        uint32_t(QOpenGLTexture::Feature::MaxFeatureFlag)               //  0x00010000  65536
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.Feature",
        Feature_Initializer, Feature_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Feature_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtOpenGLTypeStructs[SBK_QFlags_QOpenGLTexture_Feature_IDX].type =
        EType;
    // Register converter for enum 'QOpenGLTexture::Feature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_Feature_CppToPython_QOpenGLTexture_Feature);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_Feature_PythonToCpp_QOpenGLTexture_Feature,
            is_QOpenGLTexture_Feature_PythonToCpp_QOpenGLTexture_Feature_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::Feature");
        Shiboken::Conversions::registerConverterName(converter, "Feature");
        // Register converter for flag 'QFlags<QOpenGLTexture::Feature>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QOpenGLTexture::Feature>");
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::Features");
    }
    // End of 'Feature' enum/flags.

    // Initialization of enum 'DepthStencilMode'.
    const char *DepthStencilMode_Initializer[] = {
        "DepthMode",
        "StencilMode",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t DepthStencilMode_InitializerValues[] = {
        uint16_t(QOpenGLTexture::DepthStencilMode::DepthMode),  //  0x1902  6402
        uint16_t(QOpenGLTexture::DepthStencilMode::StencilMode) //  0x1901  6401
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.DepthStencilMode",
        DepthStencilMode_Initializer, DepthStencilMode_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_DepthStencilMode_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::DepthStencilMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_DepthStencilMode_CppToPython_QOpenGLTexture_DepthStencilMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_DepthStencilMode_PythonToCpp_QOpenGLTexture_DepthStencilMode,
            is_QOpenGLTexture_DepthStencilMode_PythonToCpp_QOpenGLTexture_DepthStencilMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::DepthStencilMode");
        Shiboken::Conversions::registerConverterName(converter, "DepthStencilMode");
    }
    // End of 'DepthStencilMode' enum.

    // Initialization of enum 'ComparisonFunction'.
    const char *ComparisonFunction_Initializer[] = {
        "CompareLessEqual",
        "CompareGreaterEqual",
        "CompareLess",
        "CompareGreater",
        "CompareEqual",
        "CompareNotEqual",
        "CompareAlways",
        "CompareNever",
        "CommpareNotEqual",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t ComparisonFunction_InitializerValues[] = {
        uint16_t(QOpenGLTexture::ComparisonFunction::CompareLessEqual),    //  0x0203  515
        uint16_t(QOpenGLTexture::ComparisonFunction::CompareGreaterEqual), //  0x0206  518
        uint16_t(QOpenGLTexture::ComparisonFunction::CompareLess),         //  0x0201  513
        uint16_t(QOpenGLTexture::ComparisonFunction::CompareGreater),      //  0x0204  516
        uint16_t(QOpenGLTexture::ComparisonFunction::CompareEqual),        //  0x0202  514
        uint16_t(QOpenGLTexture::ComparisonFunction::CompareNotEqual),     //  0x0205  517
        uint16_t(QOpenGLTexture::ComparisonFunction::CompareAlways),       //  0x0207  519
        uint16_t(QOpenGLTexture::ComparisonFunction::CompareNever),        //  0x0200  512
        uint16_t(QOpenGLTexture::ComparisonFunction::CommpareNotEqual)     //  0x0205  517
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.ComparisonFunction",
        ComparisonFunction_Initializer, ComparisonFunction_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_ComparisonFunction_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::ComparisonFunction'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_ComparisonFunction_CppToPython_QOpenGLTexture_ComparisonFunction);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_ComparisonFunction_PythonToCpp_QOpenGLTexture_ComparisonFunction,
            is_QOpenGLTexture_ComparisonFunction_PythonToCpp_QOpenGLTexture_ComparisonFunction_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::ComparisonFunction");
        Shiboken::Conversions::registerConverterName(converter, "ComparisonFunction");
    }
    // End of 'ComparisonFunction' enum.

    // Initialization of enum 'ComparisonMode'.
    const char *ComparisonMode_Initializer[] = {
        "CompareRefToTexture",
        "CompareNone",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t ComparisonMode_InitializerValues[] = {
        uint16_t(QOpenGLTexture::ComparisonMode::CompareRefToTexture), //  0x884e  34894
        uint16_t(QOpenGLTexture::ComparisonMode::CompareNone)          //  0x0000  0
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.ComparisonMode",
        ComparisonMode_Initializer, ComparisonMode_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_ComparisonMode_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::ComparisonMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_ComparisonMode_CppToPython_QOpenGLTexture_ComparisonMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_ComparisonMode_PythonToCpp_QOpenGLTexture_ComparisonMode,
            is_QOpenGLTexture_ComparisonMode_PythonToCpp_QOpenGLTexture_ComparisonMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::ComparisonMode");
        Shiboken::Conversions::registerConverterName(converter, "ComparisonMode");
    }
    // End of 'ComparisonMode' enum.

    // Initialization of enum 'Filter'.
    const char *Filter_Initializer[] = {
        "Nearest",
        "Linear",
        "NearestMipMapNearest",
        "NearestMipMapLinear",
        "LinearMipMapNearest",
        "LinearMipMapLinear",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Filter_InitializerValues[] = {
        uint16_t(QOpenGLTexture::Filter::Nearest),              //  0x2600  9728
        uint16_t(QOpenGLTexture::Filter::Linear),               //  0x2601  9729
        uint16_t(QOpenGLTexture::Filter::NearestMipMapNearest), //  0x2700  9984
        uint16_t(QOpenGLTexture::Filter::NearestMipMapLinear),  //  0x2702  9986
        uint16_t(QOpenGLTexture::Filter::LinearMipMapNearest),  //  0x2701  9985
        uint16_t(QOpenGLTexture::Filter::LinearMipMapLinear)    //  0x2703  9987
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QOpenGLTexture_TypeF(),
        "2:PySide6.QtOpenGL.QOpenGLTexture.Filter",
        Filter_Initializer, Filter_InitializerValues);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLTexture_Filter_IDX].type = EType;
    // Register converter for enum 'QOpenGLTexture::Filter'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QOpenGLTexture_Filter_CppToPython_QOpenGLTexture_Filter);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QOpenGLTexture_Filter_PythonToCpp_QOpenGLTexture_Filter,
            is_QOpenGLTexture_Filter_PythonToCpp_QOpenGLTexture_Filter_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QOpenGLTexture::Filter");
        Shiboken::Conversions::registerConverterName(converter, "Filter");
    }
    // End of 'Filter' enum.

    qRegisterMetaType< ::QOpenGLTexture *>();
    qRegisterMetaType< ::QOpenGLTexture::Target >("QOpenGLTexture::Target");
    qRegisterMetaType< ::QOpenGLTexture::BindingTarget >("QOpenGLTexture::BindingTarget");
    qRegisterMetaType< ::QOpenGLTexture::MipMapGeneration >("QOpenGLTexture::MipMapGeneration");
    qRegisterMetaType< ::QOpenGLTexture::TextureUnitReset >("QOpenGLTexture::TextureUnitReset");
    qRegisterMetaType< ::QOpenGLTexture::TextureFormat >("QOpenGLTexture::TextureFormat");
    qRegisterMetaType< ::QOpenGLTexture::TextureFormatClass >("QOpenGLTexture::TextureFormatClass");
    qRegisterMetaType< ::QOpenGLTexture::CubeMapFace >("QOpenGLTexture::CubeMapFace");
    qRegisterMetaType< ::QOpenGLTexture::PixelFormat >("QOpenGLTexture::PixelFormat");
    qRegisterMetaType< ::QOpenGLTexture::PixelType >("QOpenGLTexture::PixelType");
    qRegisterMetaType< ::QOpenGLTexture::SwizzleComponent >("QOpenGLTexture::SwizzleComponent");
    qRegisterMetaType< ::QOpenGLTexture::SwizzleValue >("QOpenGLTexture::SwizzleValue");
    qRegisterMetaType< ::QOpenGLTexture::WrapMode >("QOpenGLTexture::WrapMode");
    qRegisterMetaType< ::QOpenGLTexture::CoordinateDirection >("QOpenGLTexture::CoordinateDirection");
    qRegisterMetaType< ::QOpenGLTexture::Feature >("QOpenGLTexture::Feature");
    qRegisterMetaType< ::QOpenGLTexture::DepthStencilMode >("QOpenGLTexture::DepthStencilMode");
    qRegisterMetaType< ::QOpenGLTexture::ComparisonFunction >("QOpenGLTexture::ComparisonFunction");
    qRegisterMetaType< ::QOpenGLTexture::ComparisonMode >("QOpenGLTexture::ComparisonMode");
    qRegisterMetaType< ::QOpenGLTexture::Filter >("QOpenGLTexture::Filter");

    return pyType;
}
