// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebenginepage_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGui/qaction.h>
#include <QtGui/qcolor.h>
#include <QtGui/qicon.h>
#include <QtGui/qpagelayout.h>
#include <QtGui/qpageranges.h>
#include <QtNetwork/qauthenticator.h>
#include <QtWebChannel/qwebchannel.h>
#include <QtWebEngineCore/qwebenginecertificateerror.h>
#include <QtWebEngineCore/qwebengineclientcertificateselection.h>
#include <QtWebEngineCore/qwebenginedownloadrequest.h>
#include <QtWebEngineCore/qwebenginefilesystemaccessrequest.h>
#include <QtWebEngineCore/qwebenginefindtextresult.h>
#include <QtWebEngineCore/qwebenginefullscreenrequest.h>
#include <QtWebEngineCore/qwebenginehistory.h>
#include <QtWebEngineCore/qwebenginehttprequest.h>
#include <QtWebEngineCore/qwebengineloadinginfo.h>
#include <QtWebEngineCore/qwebenginenavigationrequest.h>
#include <QtWebEngineCore/qwebenginenewwindowrequest.h>
#include <QtWebEngineCore/qwebenginepage.h>
#include <QtWebEngineCore/qwebengineprofile.h>
#include <QtWebEngineCore/qwebenginequotarequest.h>
#include <QtWebEngineCore/qwebengineregisterprotocolhandlerrequest.h>
#include <QtWebEngineCore/qwebenginescriptcollection.h>
#include <QtWebEngineCore/qwebenginesettings.h>
#include <QtWebEngineCore/qwebengineurlrequestinterceptor.h>
#include <QtWebEngineCore/qwebenginewebauthuxrequest.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qthread.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <typeinfo>

// Native ---------------------------------------------------------

void QWebEnginePageWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QWebEnginePageWrapper::QWebEnginePageWrapper(::QObject * parent) : QWebEnginePage(parent)
{
    resetPyMethodCache();
    // ... middle
}

QWebEnginePageWrapper::QWebEnginePageWrapper(::QWebEngineProfile * profile, ::QObject * parent) : QWebEnginePage(profile, parent)
{
    resetPyMethodCache();
    // ... middle
}

bool QWebEnginePageWrapper::acceptNavigationRequest(const ::QUrl & url, ::QWebEnginePage::NavigationType type, bool isMainFrame)
{
    if (m_PyMethodCache[0])
        return this->::QWebEnginePage::acceptNavigationRequest(url, type, isMainFrame);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "acceptNavigationRequest";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QWebEnginePage::acceptNavigationRequest(url, type, isMainFrame);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_NavigationType_IDX])))->converter, &type),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &isMainFrame)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &url),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_NavigationType_IDX])))->converter, &type),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &isMainFrame)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEnginePage", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEnginePageWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QStringList QWebEnginePageWrapper::chooseFiles(::QWebEnginePage::FileSelectionMode mode, const ::QStringList & oldFiles, const ::QStringList & acceptedMimeTypes)
{
    if (m_PyMethodCache[2])
        return this->::QWebEnginePage::chooseFiles(mode, oldFiles, acceptedMimeTypes);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QStringList();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "chooseFiles";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QWebEnginePage::chooseFiles(mode, oldFiles, acceptedMimeTypes);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_FileSelectionMode_IDX])))->converter, &mode),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &oldFiles),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &acceptedMimeTypes)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_FileSelectionMode_IDX])))->converter, &mode),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &oldFiles),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &acceptedMimeTypes)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return ::QStringList();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEnginePage", funcName, "QStringList", Py_TYPE(pyResult)->tp_name);
        return ::QStringList();
    }
    ::QStringList cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEnginePageWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

::QWebEnginePage * QWebEnginePageWrapper::createWindow(::QWebEnginePage::WebWindowType type)
{
    if (m_PyMethodCache[4])
        return this->::QWebEnginePage::createWindow(type);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createWindow";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QWebEnginePage::createWindow(type);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_WebWindowType_IDX])))->converter, &type)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_WebWindowType_IDX])))->converter, &type)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEnginePage", funcName, Shiboken::SbkType< QWebEnginePage >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QWebEnginePage *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEnginePageWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[5]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QWebEnginePageWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QWebEnginePageWrapper::event(::QEvent * arg__1)
{
    if (m_PyMethodCache[7])
        return this->::QWebEnginePage::event(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QWebEnginePage::event(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEnginePage", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QWebEnginePageWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[8])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEnginePage", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEnginePageWrapper::javaScriptAlert(const ::QUrl & securityOrigin, const ::QString & msg)
{
    if (m_PyMethodCache[9]) {
        return this->::QWebEnginePage::javaScriptAlert(securityOrigin, msg);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "javaScriptAlert";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QWebEnginePage::javaScriptAlert(securityOrigin, msg);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &securityOrigin),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &msg)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &securityOrigin),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &msg)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QWebEnginePageWrapper::javaScriptConfirm(const ::QUrl & securityOrigin, const ::QString & msg)
{
    if (m_PyMethodCache[10])
        return this->::QWebEnginePage::javaScriptConfirm(securityOrigin, msg);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "javaScriptConfirm";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QWebEnginePage::javaScriptConfirm(securityOrigin, msg);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &securityOrigin),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &msg)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &securityOrigin),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &msg)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEnginePage", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QWebEnginePageWrapper::javaScriptConsoleMessage(::QWebEnginePage::JavaScriptConsoleMessageLevel level, const ::QString & message, int lineNumber, const ::QString & sourceID)
{
    if (m_PyMethodCache[11]) {
        return this->::QWebEnginePage::javaScriptConsoleMessage(level, message, lineNumber, sourceID);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "javaScriptConsoleMessage";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QWebEnginePage::javaScriptConsoleMessage(level, message, lineNumber, sourceID);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_JavaScriptConsoleMessageLevel_IDX])))->converter, &level),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &message),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &lineNumber),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &sourceID)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNiN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_JavaScriptConsoleMessageLevel_IDX])))->converter, &level),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &message),
        lineNumber,
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &sourceID)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

bool QWebEnginePageWrapper::javaScriptPrompt(const ::QUrl & securityOrigin, const ::QString & msg, const ::QString & defaultValue, ::QString * result)
{
    if (m_PyMethodCache[12]) {
        return this->::QWebEnginePage::javaScriptPrompt(securityOrigin, msg, defaultValue, result);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "javaScriptPrompt";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        gil.release();
        return this->::QWebEnginePage::javaScriptPrompt(securityOrigin, msg, defaultValue, result);
    }

    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtwebenginecore.cpp (qwebenginepage-javascriptprompt-virtual-redirect)]
    std::pair<bool, QString> resultPair = javaScriptPromptPyOverride(gil, pyOverride.object(), securityOrigin, msg, defaultValue);
    result->assign(resultPair.second);
    return resultPair.first;
    // END of custom code block [file: ../glue/qtwebenginecore.cpp (qwebenginepage-javascriptprompt-virtual-redirect)]
    // ========================================================================
    // End of code injection

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &securityOrigin),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &msg),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &defaultValue)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEnginePage", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);

    return cppResult;
}

void QWebEnginePageWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[13]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GET_ITEM(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

void QWebEnginePageWrapper::triggerAction(::QWebEnginePage::WebAction action, bool checked)
{
    if (m_PyMethodCache[14]) {
        return this->::QWebEnginePage::triggerAction(action, checked);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "triggerAction";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QWebEnginePage::triggerAction(action, checked);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_WebAction_IDX])))->converter, &action),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &checked)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_WebAction_IDX])))->converter, &action),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &checked)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return;
    }
}

const QMetaObject *QWebEnginePageWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QWebEnginePage::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QWebEnginePageWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QWebEnginePage::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QWebEnginePageWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QWebEnginePageWrapper *>(this));
    return QWebEnginePage::qt_metacast(_clname);
}

QWebEnginePageWrapper::~QWebEnginePageWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

::std::pair<bool,QString> QWebEnginePageWrapper::javaScriptPromptPyOverride(Shiboken::GilState &gil, PyObject *pyOverride, ::QUrl securityOrigin, ::QString msg, ::QString defaultValue)
{
    SBK_UNUSED(gil)
    static const char *funcName = "javaScriptPromptPyOverride";
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &securityOrigin),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &msg),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &defaultValue)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &securityOrigin),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &msg),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &defaultValue)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storeErrorOrPrint();
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWebEngineCoreTypeConverters[SBK_QtWebEngineCore_std_pair_bool_QString_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QWebEnginePage", funcName, "tuple", Py_TYPE(pyResult)->tp_name);
        return {};
    }
    std::pair<bool,QString> cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEnginePage_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    const QMetaObject *metaObject;
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEnginePage >()))
        return -1;

    QWebEnginePageWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.__init__";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QWebEnginePage", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebEnginePage::QWebEnginePage(QObject*=)
    // 1: QWebEnginePage::QWebEnginePage(QWebEngineProfile*,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QWebEnginePage(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QWebEnginePage(QWebEngineProfile*,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QWebEnginePage(QWebEngineProfile*,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QWebEnginePage(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, fullName);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QWebEnginePage(QObject * parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QWebEnginePage(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QWebEnginePageWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QWebEnginePageWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QWebEnginePage(QWebEngineProfile * profile, QObject * parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWebEngineProfile *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QWebEnginePage(QWebEngineProfile*,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QWebEnginePageWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QWebEnginePageWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QWebEnginePage >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, fullName, errInfo);
    };


    return 1;
}

static PyObject *Sbk_QWebEnginePageFunc_acceptAsNewWindow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.acceptAsNewWindow";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::acceptAsNewWindow(QWebEngineNewWindowRequest&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineNewWindowRequest_IDX]), (pyArg)))) {
        overloadId = 0; // acceptAsNewWindow(QWebEngineNewWindowRequest&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEngineNewWindowRequest *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // acceptAsNewWindow(QWebEngineNewWindowRequest&)
            cppSelf->acceptAsNewWindow(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_acceptNavigationRequest(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.acceptNavigationRequest";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "acceptNavigationRequest", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::acceptNavigationRequest(QUrl,QWebEnginePage::NavigationType,bool)->bool
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_NavigationType_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2])))) {
        overloadId = 0; // acceptNavigationRequest(QUrl,QWebEnginePage::NavigationType,bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QWebEnginePage::NavigationType cppArg1{QWebEnginePage::NavigationTypeLinkClicked};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        bool cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // acceptNavigationRequest(QUrl,QWebEnginePage::NavigationType,bool)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWebEnginePage::acceptNavigationRequest(*cppArg0, cppArg1, cppArg2)
                : cppSelf->acceptNavigationRequest(*cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_action(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.action";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::action(QWebEnginePage::WebAction)const->QAction*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_WebAction_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // action(QWebEnginePage::WebAction)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QWebEnginePage::WebAction cppArg0{QWebEnginePage::Back};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // action(QWebEnginePage::WebAction)const
            QAction * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->action(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_backgroundColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.backgroundColor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // backgroundColor()const
            QColor cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->backgroundColor();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_chooseFiles(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.chooseFiles";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "chooseFiles", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::chooseFiles(QWebEnginePage::FileSelectionMode,QStringList,QStringList)->QStringList
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_FileSelectionMode_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[2])))) {
        overloadId = 0; // chooseFiles(QWebEnginePage::FileSelectionMode,QStringList,QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QWebEnginePage::FileSelectionMode cppArg0{QWebEnginePage::FileSelectOpen};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QStringList cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QStringList cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // chooseFiles(QWebEnginePage::FileSelectionMode,QStringList,QStringList)
            QStringList cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWebEnginePage::chooseFiles(cppArg0, cppArg1, cppArg2)
                : cppSelf->chooseFiles(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_contentsSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.contentsSize";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // contentsSize()const
            QSizeF cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->contentsSize();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_createWindow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.createWindow";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::createWindow(QWebEnginePage::WebWindowType)->QWebEnginePage*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_WebWindowType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // createWindow(QWebEnginePage::WebWindowType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QWebEnginePage::WebWindowType cppArg0{QWebEnginePage::WebBrowserWindow};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createWindow(QWebEnginePage::WebWindowType)
            QWebEnginePage * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWebEnginePage::createWindow(cppArg0)
                : cppSelf->createWindow(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_devToolsId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.devToolsId";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // devToolsId()const
            QString cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->devToolsId();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_devToolsPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.devToolsPage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // devToolsPage()const
            QWebEnginePage * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->devToolsPage();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_download(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.download";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:download", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::download(QUrl,const QString&=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // download(QUrl,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // download(QUrl,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_filename = Shiboken::String::createStaticString("filename");
            if (PyDict_Contains(kwds, key_filename) != 0) {
                value = PyDict_GetItem(kwds, key_filename);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_filename);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_filename);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // download(QUrl,QString)
            cppSelf->download(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.event";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWebEnginePage::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_findText(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.findText";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:findText", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::findText(QString,QFlags<QWebEnginePage::FindFlag>,PyObject*)
    // 1: QWebEnginePage::findText(QString,QFlags<QWebEnginePage::FindFlag>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // findText(QString,QFlags<QWebEnginePage::FindFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QFlags_QWebEnginePage_FindFlag_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // findText(QString,QFlags<QWebEnginePage::FindFlag>)
            } else if (numArgs == 3
                && true) {
                overloadId = 0; // findText(QString,QFlags<QWebEnginePage::FindFlag>,PyObject*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // findText(const QString & arg__1, QFlags<QWebEnginePage::FindFlag> arg__2, PyObject * arg__3)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            ::QFlags<QWebEnginePage::FindFlag> cppArg1 = QFlags<QWebEnginePage::FindFlag>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // findText(QString,QFlags<QWebEnginePage::FindFlag>,PyObject*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtwebenginewidgets.cpp (qwebenginepage-findtext)]
                auto callable = pyArgs[3-1];
                auto callback = [callable](const QWebEngineFindTextResult &result)
                {
                    if (!PyCallable_Check(callable)) {
                        qWarning("Argument 3 of findText must be a callable.");
                        return;
                    }
                    Shiboken::GilState state;
                    Shiboken::AutoDecRef arglist(PyTuple_New(1));
                    PyTuple_SET_ITEM(arglist, 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineFindTextResult_IDX]), &result));
                    Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
                    Py_DECREF(callable);

                };
                Py_INCREF(callable);
                cppSelf->findText(cppArg0, cppArg1, callback);
                // END of custom code block [file: ../glue/qtwebenginewidgets.cpp (qwebenginepage-findtext)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // findText(const QString & subString, QFlags<QWebEnginePage::FindFlag> options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QFlags_QWebEnginePage_FindFlag_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QWebEnginePage::FindFlag> cppArg1{};
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // findText(QString,QFlags<QWebEnginePage::FindFlag>)
                cppSelf->findText(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_hasSelection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.hasSelection";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasSelection()const
            bool cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->hasSelection();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_history(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.history";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // history()const
            QWebEngineHistory * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->history();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHistory_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_icon(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.icon";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // icon()const
            QIcon cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->icon();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QIcon_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_iconUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.iconUrl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // iconUrl()const
            QUrl cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->iconUrl();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_inspectedPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.inspectedPage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // inspectedPage()const
            QWebEnginePage * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->inspectedPage();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_isAudioMuted(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.isAudioMuted";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isAudioMuted()const
            bool cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->isAudioMuted();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_isLoading(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.isLoading";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isLoading()const
            bool cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->isLoading();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_isVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.isVisible";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isVisible()const
            bool cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->isVisible();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_javaScriptAlert(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.javaScriptAlert";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "javaScriptAlert", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::javaScriptAlert(QUrl,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // javaScriptAlert(QUrl,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // javaScriptAlert(QUrl,QString)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWebEnginePage::javaScriptAlert(*cppArg0, cppArg1)
                : cppSelf->javaScriptAlert(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_javaScriptConfirm(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.javaScriptConfirm";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "javaScriptConfirm", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::javaScriptConfirm(QUrl,QString)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // javaScriptConfirm(QUrl,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // javaScriptConfirm(QUrl,QString)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWebEnginePage::javaScriptConfirm(*cppArg0, cppArg1)
                : cppSelf->javaScriptConfirm(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_javaScriptConsoleMessage(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.javaScriptConsoleMessage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "javaScriptConsoleMessage", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::javaScriptConsoleMessage(QWebEnginePage::JavaScriptConsoleMessageLevel,QString,int,QString)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_JavaScriptConsoleMessageLevel_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
        overloadId = 0; // javaScriptConsoleMessage(QWebEnginePage::JavaScriptConsoleMessageLevel,QString,int,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        ::QWebEnginePage::JavaScriptConsoleMessageLevel cppArg0{QWebEnginePage::InfoMessageLevel};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QString cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // javaScriptConsoleMessage(QWebEnginePage::JavaScriptConsoleMessageLevel,QString,int,QString)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWebEnginePage::javaScriptConsoleMessage(cppArg0, cppArg1, cppArg2, cppArg3)
                : cppSelf->javaScriptConsoleMessage(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_javaScriptPrompt(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.javaScriptPrompt";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "javaScriptPrompt", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::javaScriptPrompt(QUrl,QString,QString,QString*)->bool
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // javaScriptPrompt(QUrl,QString,QString,QString*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // javaScriptPrompt(QUrl,QString,QString,QString*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtwebenginecore.cpp (qwebenginepage-javascriptprompt-return)]
            QString str;
            bool retval_ = (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QWebEnginePage::javaScriptPrompt((*cppArg0), cppArg1, cppArg2, &str) : cppSelf->javaScriptPrompt((*cppArg0), cppArg1, cppArg2, &str));
            pyResult = PyTuple_New(2);
            PyTuple_SET_ITEM(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &retval_));
            PyTuple_SET_ITEM(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &str));
            // END of custom code block [file: ../glue/qtwebenginecore.cpp (qwebenginepage-javascriptprompt-return)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_lifecycleState(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.lifecycleState";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // lifecycleState()const
            QWebEnginePage::LifecycleState cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->lifecycleState();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_LifecycleState_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_load(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.load";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::load(QUrl)
    // 1: QWebEnginePage::load(QWebEngineHttpRequest)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineHttpRequest_IDX]), (pyArg)))) {
        overloadId = 1; // load(QWebEngineHttpRequest)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // load(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // load(const QUrl & url)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QUrl)
                cppSelf->load(*cppArg0);
            }
            break;
        }
        case 1: // load(const QWebEngineHttpRequest & request)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QWebEngineHttpRequest *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // load(QWebEngineHttpRequest)
                cppSelf->load(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_printToPdf(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.printToPdf";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:printToPdf", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::printToPdf(QString,const QPageLayout&=,const QPageRanges&=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // printToPdf(QString,QPageLayout,QPageRanges)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageLayout_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // printToPdf(QString,QPageLayout,QPageRanges)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_IDX]), (pyArgs[2])))) {
                overloadId = 0; // printToPdf(QString,QPageLayout,QPageRanges)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_layout = Shiboken::String::createStaticString("layout");
            if (PyDict_Contains(kwds, key_layout) != 0) {
                value = PyDict_GetItem(kwds, key_layout);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_layout);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageLayout_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_layout);
            }
            static PyObject *const key_ranges = Shiboken::String::createStaticString("ranges");
            if (PyDict_Contains(kwds, key_ranges) != 0) {
                value = PyDict_GetItem(kwds, key_ranges);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_ranges);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPageRanges_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_ranges);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPageLayout cppArg1_local = QPageLayout(QPageSize(QPageSize::A4), QPageLayout::Portrait, QMarginsF());
        ::QPageLayout *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPageRanges cppArg2_local{};
        ::QPageRanges *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // printToPdf(QString,QPageLayout,QPageRanges)
            cppSelf->printToPdf(cppArg0, *cppArg1, *cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_profile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.profile";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // profile()const
            QWebEngineProfile * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->profile();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_recentlyAudible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.recentlyAudible";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // recentlyAudible()const
            bool cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->recentlyAudible();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_recommendedState(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.recommendedState";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // recommendedState()const
            QWebEnginePage::LifecycleState cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->recommendedState();
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_LifecycleState_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_renderProcessPid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.renderProcessPid";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // renderProcessPid()const
            qint64 cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->renderProcessPid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_replaceMisspelledWord(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.replaceMisspelledWord";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::replaceMisspelledWord(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // replaceMisspelledWord(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // replaceMisspelledWord(QString)
            cppSelf->replaceMisspelledWord(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_requestedUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.requestedUrl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // requestedUrl()const
            QUrl cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->requestedUrl();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_runJavaScript(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.runJavaScript";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:runJavaScript", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::runJavaScript(QString,quint32,PyObject*)
    // 1: QWebEnginePage::runJavaScript(QString,quint32=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // runJavaScript(QString,quint32)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // runJavaScript(QString,quint32)
            } else if (numArgs == 3
                && true) {
                overloadId = 0; // runJavaScript(QString,quint32,PyObject*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // runJavaScript(const QString & arg__1, quint32 arg__2, PyObject * arg__3)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)
            quint32 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // runJavaScript(QString,quint32,PyObject*)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtwebenginewidgets.cpp (qwebenginepage-runjavascript)]
                auto callable = pyArgs[3-1];
                auto callback = [callable](const QVariant &result)
                {
                    if (!PyCallable_Check(callable)) {
                        qWarning("Argument 3 of runJavaScript must be a callable.");
                        return;
                    }
                    Shiboken::GilState state;
                    Shiboken::AutoDecRef arglist(PyTuple_New(1));
                    switch (result.type()) {
                    case QVariant::Bool: {
                        const bool value = result.toBool();
                        PyTuple_SET_ITEM(arglist, 0, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &value));
                    }
                        break;
                     case QVariant::Int:
                     case QVariant::UInt:
                     case QVariant::LongLong:
                     case QVariant::ULongLong:
                     case QVariant::Double: {
                        const double number = result.toDouble();
                        PyTuple_SET_ITEM(arglist, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &number));
                    }
                        break;
                    default: {
                        const QString value = result.toString();
                        PyTuple_SET_ITEM(arglist, 0, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &value));
                    }
                        break;
                    }
                   // PyTuple_SET_ITEM(arglist, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &found));
                    Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
                    Py_DECREF(callable);
                };

                Py_INCREF(callable);
                cppSelf->runJavaScript(cppArg0, cppArg1, callback);
                // END of custom code block [file: ../glue/qtwebenginewidgets.cpp (qwebenginepage-runjavascript)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // runJavaScript(const QString & scriptSource, quint32 worldId)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_worldId = Shiboken::String::createStaticString("worldId");
                if (PyDict_Contains(kwds, key_worldId) != 0) {
                    value = PyDict_GetItem(kwds, key_worldId);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_worldId);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_worldId);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            quint32 cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // runJavaScript(QString,quint32)
                cppSelf->runJavaScript(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_save(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.save";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:save", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::save(QString,QWebEngineDownloadRequest::SavePageFormat=)const
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // save(QString,QWebEngineDownloadRequest::SavePageFormat)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_SavePageFormat_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // save(QString,QWebEngineDownloadRequest::SavePageFormat)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineDownloadRequest_SavePageFormat_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QWebEngineDownloadRequest::SavePageFormat cppArg1(QWebEngineDownloadRequest::MimeHtmlSaveFormat);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // save(QString,QWebEngineDownloadRequest::SavePageFormat)const
            const_cast<const ::QWebEnginePage *>(cppSelf)->save(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_scripts(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.scripts";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // scripts()
            QWebEngineScriptCollection & cppResult = cppSelf->scripts();
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineScriptCollection_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_scrollPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.scrollPosition";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // scrollPosition()const
            QPointF cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->scrollPosition();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_selectedText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.selectedText";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectedText()const
            QString cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->selectedText();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_setAudioMuted(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.setAudioMuted";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setAudioMuted(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAudioMuted(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAudioMuted(bool)
            cppSelf->setAudioMuted(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_setBackgroundColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.setBackgroundColor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setBackgroundColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setBackgroundColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0_local;
        ::QColor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackgroundColor(QColor)
            cppSelf->setBackgroundColor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_setContent(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.setContent";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOO:setContent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::setContent(QByteArray,const QString&=,const QUrl&=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setContent(QByteArray,QString,QUrl)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setContent(QByteArray,QString,QUrl)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[2])))) {
                overloadId = 0; // setContent(QByteArray,QString,QUrl)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mimeType = Shiboken::String::createStaticString("mimeType");
            if (PyDict_Contains(kwds, key_mimeType) != 0) {
                value = PyDict_GetItem(kwds, key_mimeType);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mimeType);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_mimeType);
            }
            static PyObject *const key_baseUrl = Shiboken::String::createStaticString("baseUrl");
            if (PyDict_Contains(kwds, key_baseUrl) != 0) {
                value = PyDict_GetItem(kwds, key_baseUrl);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_baseUrl);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_baseUrl);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QUrl cppArg2_local = QUrl();
        ::QUrl *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // setContent(QByteArray,QString,QUrl)
            cppSelf->setContent(*cppArg0, cppArg1, *cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_setDevToolsPage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.setDevToolsPage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setDevToolsPage(QWebEnginePage*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), (pyArg)))) {
        overloadId = 0; // setDevToolsPage(QWebEnginePage*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEnginePage *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDevToolsPage(QWebEnginePage*)
            cppSelf->setDevToolsPage(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_setFeaturePermission(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.setFeaturePermission";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setFeaturePermission", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::setFeaturePermission(QUrl,QWebEnginePage::Feature,QWebEnginePage::PermissionPolicy)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_Feature_IDX])))->converter, (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_PermissionPolicy_IDX])))->converter, (pyArgs[2])))) {
        overloadId = 0; // setFeaturePermission(QUrl,QWebEnginePage::Feature,QWebEnginePage::PermissionPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QWebEnginePage::Feature cppArg1{QWebEnginePage::Notifications};
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QWebEnginePage::PermissionPolicy cppArg2{QWebEnginePage::PermissionUnknown};
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFeaturePermission(QUrl,QWebEnginePage::Feature,QWebEnginePage::PermissionPolicy)
            cppSelf->setFeaturePermission(*cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_setHtml(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.setHtml";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:setHtml", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::setHtml(QString,const QUrl&=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setHtml(QString,QUrl)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[1])))) {
            overloadId = 0; // setHtml(QString,QUrl)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_baseUrl = Shiboken::String::createStaticString("baseUrl");
            if (PyDict_Contains(kwds, key_baseUrl) != 0) {
                value = PyDict_GetItem(kwds, key_baseUrl);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_baseUrl);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_baseUrl);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QUrl cppArg1_local = QUrl();
        ::QUrl *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHtml(QString,QUrl)
            cppSelf->setHtml(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_setInspectedPage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.setInspectedPage";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setInspectedPage(QWebEnginePage*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), (pyArg)))) {
        overloadId = 0; // setInspectedPage(QWebEnginePage*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEnginePage *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setInspectedPage(QWebEnginePage*)
            cppSelf->setInspectedPage(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_setLifecycleState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.setLifecycleState";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setLifecycleState(QWebEnginePage::LifecycleState)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_LifecycleState_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setLifecycleState(QWebEnginePage::LifecycleState)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        ::QWebEnginePage::LifecycleState cppArg0{QWebEnginePage::LifecycleState::Active};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLifecycleState(QWebEnginePage::LifecycleState)
            cppSelf->setLifecycleState(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_setUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.setUrl";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setUrl(QUrl)
            cppSelf->setUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_setUrlRequestInterceptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.setUrlRequestInterceptor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setUrlRequestInterceptor(QWebEngineUrlRequestInterceptor*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestInterceptor_IDX]), (pyArg)))) {
        overloadId = 0; // setUrlRequestInterceptor(QWebEngineUrlRequestInterceptor*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEngineUrlRequestInterceptor *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUrlRequestInterceptor(QWebEngineUrlRequestInterceptor*)
            cppSelf->setUrlRequestInterceptor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_setVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.setVisible";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVisible(bool)
            cppSelf->setVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_setWebChannel(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.setWebChannel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:setWebChannel", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::setWebChannel(QWebChannel*,quint32=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebChannelTypeStructs[SBK_QWebChannel_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setWebChannel(QWebChannel*,quint32)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1])))) {
            overloadId = 0; // setWebChannel(QWebChannel*,quint32)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_worldId = Shiboken::String::createStaticString("worldId");
            if (PyDict_Contains(kwds, key_worldId) != 0) {
                value = PyDict_GetItem(kwds, key_worldId);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_worldId);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_worldId);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWebChannel *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        quint32 cppArg1 = 0;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWebChannel(QWebChannel*,quint32)
            cppSelf->setWebChannel(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_setZoomFactor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.setZoomFactor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::setZoomFactor(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setZoomFactor(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZoomFactor(qreal)
            cppSelf->setZoomFactor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_settings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.settings";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // settings()const
            QWebEngineSettings * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->settings();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineSettings_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_title(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.title";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // title()const
            QString cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->title();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_toHtml(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.toHtml";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::toHtml(PyObject*)const
    if (true) {
        overloadId = 0; // toHtml(PyObject*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toHtml(PyObject*)const
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtwebenginewidgets.cpp (qwebenginepage-convertto)]
            auto callable = pyArg;
            auto callback = [callable](const QString &text)
            {
                if (!PyCallable_Check(callable)) {
                    qWarning("Argument 1 of toHtml must be a callable.");
                    return;
                }
                Shiboken::GilState state;
                Shiboken::AutoDecRef arglist(PyTuple_New(1));
                PyTuple_SET_ITEM(arglist, 0, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &text));
                Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
                Py_DECREF(callable);
            };

            Py_INCREF(callable);
            cppSelf->toHtml(callback);
            // END of custom code block [file: ../glue/qtwebenginewidgets.cpp (qwebenginepage-convertto)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_toPlainText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.toPlainText";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEnginePage::toPlainText(PyObject*)const
    if (true) {
        overloadId = 0; // toPlainText(PyObject*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, fullName, errInfo);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toPlainText(PyObject*)const
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtwebenginewidgets.cpp (qwebenginepage-convertto)]
            auto callable = pyArg;
            auto callback = [callable](const QString &text)
            {
                if (!PyCallable_Check(callable)) {
                    qWarning("Argument 1 of toPlainText must be a callable.");
                    return;
                }
                Shiboken::GilState state;
                Shiboken::AutoDecRef arglist(PyTuple_New(1));
                PyTuple_SET_ITEM(arglist, 0, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &text));
                Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
                Py_DECREF(callable);
            };

            Py_INCREF(callable);
            cppSelf->toPlainText(callback);
            // END of custom code block [file: ../glue/qtwebenginewidgets.cpp (qwebenginepage-convertto)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_triggerAction(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.triggerAction";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OO:triggerAction", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEnginePage::triggerAction(QWebEnginePage::WebAction,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_WebAction_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // triggerAction(QWebEnginePage::WebAction,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // triggerAction(QWebEnginePage::WebAction,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_checked = Shiboken::String::createStaticString("checked");
            if (PyDict_Contains(kwds, key_checked) != 0) {
                value = PyDict_GetItem(kwds, key_checked);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_checked);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
                PyDict_DelItem(kwds_dup, key_checked);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, fullName, errInfo);
            }
        }
        ::QWebEnginePage::WebAction cppArg0{QWebEnginePage::Back};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = false;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // triggerAction(QWebEnginePage::WebAction,bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QWebEnginePage::triggerAction(cppArg0, cppArg1)
                : cppSelf->triggerAction(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QWebEnginePageFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.url";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // url()const
            QUrl cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->url();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_webChannel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.webChannel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // webChannel()const
            QWebChannel * cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->webChannel();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebChannelTypeStructs[SBK_QWebChannel_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QWebEnginePageFunc_zoomFactor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    static const char fullName[] = "PySide6.QtWebEngineCore.QWebEnginePage.zoomFactor";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // zoomFactor()const
            qreal cppResult = const_cast<const ::QWebEnginePage *>(cppSelf)->zoomFactor();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEnginePage_PropertyStrings[] = {
    "audioMuted:isAudioMuted:",
    "backgroundColor::",
    "contentsSize:",
    "hasSelection:",
    "icon:",
    "iconUrl:",
    "lifecycleState::",
    "loading:isLoading",
    "recentlyAudible:",
    "recommendedState:",
    "renderProcessPid:",
    "requestedUrl:",
    "scrollPosition:",
    "selectedText:",
    "title:",
    "url::",
    "visible:isVisible:",
    "zoomFactor::",
    nullptr // Sentinel
};

static const char *Sbk_QWebEnginePage_EnumFlagInfo[] = {
    "Feature:Enum",
    "FileSelectionMode:Enum",
    "FindFlag:Flag:FindFlags",
    "JavaScriptConsoleMessageLevel:Enum",
    "LifecycleState:Enum",
    "NavigationType:Enum",
    "PermissionPolicy:Enum",
    "RenderProcessTerminationStatus:Enum",
    "WebAction:Enum",
    "WebWindowType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEnginePage_methods[] = {
    {"acceptAsNewWindow", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_acceptAsNewWindow), METH_O, nullptr},
    {"acceptNavigationRequest", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_acceptNavigationRequest), METH_VARARGS, nullptr},
    {"action", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_action), METH_O, nullptr},
    {"backgroundColor", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_backgroundColor), METH_NOARGS, nullptr},
    {"chooseFiles", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_chooseFiles), METH_VARARGS, nullptr},
    {"contentsSize", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_contentsSize), METH_NOARGS, nullptr},
    {"createWindow", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_createWindow), METH_O, nullptr},
    {"devToolsId", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_devToolsId), METH_NOARGS, nullptr},
    {"devToolsPage", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_devToolsPage), METH_NOARGS, nullptr},
    {"download", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_download), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_event), METH_O, nullptr},
    {"findText", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_findText), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"hasSelection", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_hasSelection), METH_NOARGS, nullptr},
    {"history", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_history), METH_NOARGS, nullptr},
    {"icon", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_icon), METH_NOARGS, nullptr},
    {"iconUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_iconUrl), METH_NOARGS, nullptr},
    {"inspectedPage", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_inspectedPage), METH_NOARGS, nullptr},
    {"isAudioMuted", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_isAudioMuted), METH_NOARGS, nullptr},
    {"isLoading", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_isLoading), METH_NOARGS, nullptr},
    {"isVisible", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_isVisible), METH_NOARGS, nullptr},
    {"javaScriptAlert", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_javaScriptAlert), METH_VARARGS, nullptr},
    {"javaScriptConfirm", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_javaScriptConfirm), METH_VARARGS, nullptr},
    {"javaScriptConsoleMessage", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_javaScriptConsoleMessage), METH_VARARGS, nullptr},
    {"javaScriptPrompt", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_javaScriptPrompt), METH_VARARGS, nullptr},
    {"lifecycleState", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_lifecycleState), METH_NOARGS, nullptr},
    {"load", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_load), METH_O, nullptr},
    {"printToPdf", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_printToPdf), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"profile", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_profile), METH_NOARGS, nullptr},
    {"recentlyAudible", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_recentlyAudible), METH_NOARGS, nullptr},
    {"recommendedState", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_recommendedState), METH_NOARGS, nullptr},
    {"renderProcessPid", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_renderProcessPid), METH_NOARGS, nullptr},
    {"replaceMisspelledWord", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_replaceMisspelledWord), METH_O, nullptr},
    {"requestedUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_requestedUrl), METH_NOARGS, nullptr},
    {"runJavaScript", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_runJavaScript), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"save", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_save), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"scripts", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_scripts), METH_NOARGS, nullptr},
    {"scrollPosition", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_scrollPosition), METH_NOARGS, nullptr},
    {"selectedText", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_selectedText), METH_NOARGS, nullptr},
    {"setAudioMuted", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setAudioMuted), METH_O, nullptr},
    {"setBackgroundColor", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setBackgroundColor), METH_O, nullptr},
    {"setContent", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setContent), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setDevToolsPage", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setDevToolsPage), METH_O, nullptr},
    {"setFeaturePermission", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setFeaturePermission), METH_VARARGS, nullptr},
    {"setHtml", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setHtml), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setInspectedPage", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setInspectedPage), METH_O, nullptr},
    {"setLifecycleState", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setLifecycleState), METH_O, nullptr},
    {"setUrl", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setUrl), METH_O, nullptr},
    {"setUrlRequestInterceptor", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setUrlRequestInterceptor), METH_O, nullptr},
    {"setVisible", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setVisible), METH_O, nullptr},
    {"setWebChannel", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setWebChannel), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setZoomFactor", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_setZoomFactor), METH_O, nullptr},
    {"settings", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_settings), METH_NOARGS, nullptr},
    {"title", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_title), METH_NOARGS, nullptr},
    {"toHtml", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_toHtml), METH_O, nullptr},
    {"toPlainText", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_toPlainText), METH_O, nullptr},
    {"triggerAction", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_triggerAction), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_url), METH_NOARGS, nullptr},
    {"webChannel", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_webChannel), METH_NOARGS, nullptr},
    {"zoomFactor", reinterpret_cast<PyCFunction>(Sbk_QWebEnginePageFunc_zoomFactor), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QWebEnginePage_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QWebEnginePage *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QWebEnginePageWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QWebEnginePage_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEnginePage_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEnginePage_Type = nullptr;
static PyTypeObject *Sbk_QWebEnginePage_TypeF(void)
{
    return _Sbk_QWebEnginePage_Type;
}

static PyType_Slot Sbk_QWebEnginePage_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QWebEnginePage_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEnginePage_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEnginePage_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEnginePage_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEnginePage_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEnginePage_spec = {
    "2:PySide6.QtWebEngineCore.QWebEnginePage",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEnginePage_slots
};

} //extern "C"

static void *Sbk_QWebEnginePage_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QWebEnginePage *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void QWebEnginePage_WebAction_PythonToCpp_QWebEnginePage_WebAction(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEnginePage::WebAction>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEnginePage::WebAction *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEnginePage_WebAction_PythonToCpp_QWebEnginePage_WebAction_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_WebAction_IDX])))
        return QWebEnginePage_WebAction_PythonToCpp_QWebEnginePage_WebAction;
    return {};
}
static PyObject *QWebEnginePage_WebAction_CppToPython_QWebEnginePage_WebAction(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::WebAction *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_WebAction_IDX]), castCppIn);

}

static void QWebEnginePage_FindFlag_PythonToCpp_QWebEnginePage_FindFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEnginePage::FindFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEnginePage::FindFlag *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEnginePage_FindFlag_PythonToCpp_QWebEnginePage_FindFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_FindFlag_IDX])))
        return QWebEnginePage_FindFlag_PythonToCpp_QWebEnginePage_FindFlag;
    return {};
}
static PyObject *QWebEnginePage_FindFlag_CppToPython_QWebEnginePage_FindFlag(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::FindFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_FindFlag_IDX]), castCppIn);

}

static void QWebEnginePage_WebWindowType_PythonToCpp_QWebEnginePage_WebWindowType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEnginePage::WebWindowType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEnginePage::WebWindowType *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEnginePage_WebWindowType_PythonToCpp_QWebEnginePage_WebWindowType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_WebWindowType_IDX])))
        return QWebEnginePage_WebWindowType_PythonToCpp_QWebEnginePage_WebWindowType;
    return {};
}
static PyObject *QWebEnginePage_WebWindowType_CppToPython_QWebEnginePage_WebWindowType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::WebWindowType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_WebWindowType_IDX]), castCppIn);

}

static void QWebEnginePage_PermissionPolicy_PythonToCpp_QWebEnginePage_PermissionPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEnginePage::PermissionPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEnginePage::PermissionPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEnginePage_PermissionPolicy_PythonToCpp_QWebEnginePage_PermissionPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_PermissionPolicy_IDX])))
        return QWebEnginePage_PermissionPolicy_PythonToCpp_QWebEnginePage_PermissionPolicy;
    return {};
}
static PyObject *QWebEnginePage_PermissionPolicy_CppToPython_QWebEnginePage_PermissionPolicy(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::PermissionPolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_PermissionPolicy_IDX]), castCppIn);

}

static void QWebEnginePage_NavigationType_PythonToCpp_QWebEnginePage_NavigationType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEnginePage::NavigationType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEnginePage::NavigationType *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEnginePage_NavigationType_PythonToCpp_QWebEnginePage_NavigationType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_NavigationType_IDX])))
        return QWebEnginePage_NavigationType_PythonToCpp_QWebEnginePage_NavigationType;
    return {};
}
static PyObject *QWebEnginePage_NavigationType_CppToPython_QWebEnginePage_NavigationType(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::NavigationType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_NavigationType_IDX]), castCppIn);

}

static void QWebEnginePage_Feature_PythonToCpp_QWebEnginePage_Feature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEnginePage::Feature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEnginePage::Feature *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEnginePage_Feature_PythonToCpp_QWebEnginePage_Feature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_Feature_IDX])))
        return QWebEnginePage_Feature_PythonToCpp_QWebEnginePage_Feature;
    return {};
}
static PyObject *QWebEnginePage_Feature_CppToPython_QWebEnginePage_Feature(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::Feature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_Feature_IDX]), castCppIn);

}

static void QWebEnginePage_FileSelectionMode_PythonToCpp_QWebEnginePage_FileSelectionMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEnginePage::FileSelectionMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEnginePage::FileSelectionMode *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEnginePage_FileSelectionMode_PythonToCpp_QWebEnginePage_FileSelectionMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_FileSelectionMode_IDX])))
        return QWebEnginePage_FileSelectionMode_PythonToCpp_QWebEnginePage_FileSelectionMode;
    return {};
}
static PyObject *QWebEnginePage_FileSelectionMode_CppToPython_QWebEnginePage_FileSelectionMode(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::FileSelectionMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_FileSelectionMode_IDX]), castCppIn);

}

static void QWebEnginePage_JavaScriptConsoleMessageLevel_PythonToCpp_QWebEnginePage_JavaScriptConsoleMessageLevel(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEnginePage::JavaScriptConsoleMessageLevel>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEnginePage::JavaScriptConsoleMessageLevel *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEnginePage_JavaScriptConsoleMessageLevel_PythonToCpp_QWebEnginePage_JavaScriptConsoleMessageLevel_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_JavaScriptConsoleMessageLevel_IDX])))
        return QWebEnginePage_JavaScriptConsoleMessageLevel_PythonToCpp_QWebEnginePage_JavaScriptConsoleMessageLevel;
    return {};
}
static PyObject *QWebEnginePage_JavaScriptConsoleMessageLevel_CppToPython_QWebEnginePage_JavaScriptConsoleMessageLevel(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::JavaScriptConsoleMessageLevel *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_JavaScriptConsoleMessageLevel_IDX]), castCppIn);

}

static void QWebEnginePage_RenderProcessTerminationStatus_PythonToCpp_QWebEnginePage_RenderProcessTerminationStatus(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEnginePage::RenderProcessTerminationStatus>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEnginePage::RenderProcessTerminationStatus *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEnginePage_RenderProcessTerminationStatus_PythonToCpp_QWebEnginePage_RenderProcessTerminationStatus_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_RenderProcessTerminationStatus_IDX])))
        return QWebEnginePage_RenderProcessTerminationStatus_PythonToCpp_QWebEnginePage_RenderProcessTerminationStatus;
    return {};
}
static PyObject *QWebEnginePage_RenderProcessTerminationStatus_CppToPython_QWebEnginePage_RenderProcessTerminationStatus(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::RenderProcessTerminationStatus *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_RenderProcessTerminationStatus_IDX]), castCppIn);

}

static void QWebEnginePage_LifecycleState_PythonToCpp_QWebEnginePage_LifecycleState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEnginePage::LifecycleState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEnginePage::LifecycleState *>(cppOut) = value;

}
static PythonToCppFunc is_QWebEnginePage_LifecycleState_PythonToCpp_QWebEnginePage_LifecycleState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_LifecycleState_IDX])))
        return QWebEnginePage_LifecycleState_PythonToCpp_QWebEnginePage_LifecycleState;
    return {};
}
static PyObject *QWebEnginePage_LifecycleState_CppToPython_QWebEnginePage_LifecycleState(const void *cppIn)
{
    const int castCppIn = int(*reinterpret_cast<const ::QWebEnginePage::LifecycleState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_LifecycleState_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEnginePage_PythonToCpp_QWebEnginePage_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEnginePage_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEnginePage_PythonToCpp_QWebEnginePage_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEnginePage_TypeF()))
        return QWebEnginePage_PythonToCpp_QWebEnginePage_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEnginePage_PTR_CppToPython_QWebEnginePage(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QWebEnginePage *>(const_cast<void *>(cppIn)), Sbk_QWebEnginePage_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *QWebEnginePage_SignatureStrings[] = {
    "1:PySide6.QtWebEngineCore.QWebEnginePage(self,parent:PySide6.QtCore.QObject=nullptr)",
    "0:PySide6.QtWebEngineCore.QWebEnginePage(self,profile:PySide6.QtWebEngineCore.QWebEngineProfile,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtWebEngineCore.QWebEnginePage.acceptAsNewWindow(self,request:PySide6.QtWebEngineCore.QWebEngineNewWindowRequest)",
    "PySide6.QtWebEngineCore.QWebEnginePage.acceptNavigationRequest(self,url:typing.Union[PySide6.QtCore.QUrl, QString],type:PySide6.QtWebEngineCore.QWebEnginePage.NavigationType,isMainFrame:bool)->bool",
    "PySide6.QtWebEngineCore.QWebEnginePage.action(self,action:PySide6.QtWebEngineCore.QWebEnginePage.WebAction)->PySide6.QtGui.QAction",
    "PySide6.QtWebEngineCore.QWebEnginePage.backgroundColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtWebEngineCore.QWebEnginePage.chooseFiles(self,mode:PySide6.QtWebEngineCore.QWebEnginePage.FileSelectionMode,oldFiles:QStringList,acceptedMimeTypes:QStringList)->QStringList",
    "PySide6.QtWebEngineCore.QWebEnginePage.contentsSize(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtWebEngineCore.QWebEnginePage.createWindow(self,type:PySide6.QtWebEngineCore.QWebEnginePage.WebWindowType)->PySide6.QtWebEngineCore.QWebEnginePage",
    "PySide6.QtWebEngineCore.QWebEnginePage.devToolsId(self)->QString",
    "PySide6.QtWebEngineCore.QWebEnginePage.devToolsPage(self)->PySide6.QtWebEngineCore.QWebEnginePage",
    "PySide6.QtWebEngineCore.QWebEnginePage.download(self,url:typing.Union[PySide6.QtCore.QUrl, QString],filename:QString=QString())",
    "PySide6.QtWebEngineCore.QWebEnginePage.event(self,arg__1:PySide6.QtCore.QEvent)->bool",
    "1:PySide6.QtWebEngineCore.QWebEnginePage.findText(self,arg__1:QString,arg__2:PySide6.QtWebEngineCore.QWebEnginePage.FindFlag,arg__3:PyObject)",
    "0:PySide6.QtWebEngineCore.QWebEnginePage.findText(self,subString:QString,options:PySide6.QtWebEngineCore.QWebEnginePage.FindFlag={})",
    "PySide6.QtWebEngineCore.QWebEnginePage.hasSelection(self)->bool",
    "PySide6.QtWebEngineCore.QWebEnginePage.history(self)->PySide6.QtWebEngineCore.QWebEngineHistory",
    "PySide6.QtWebEngineCore.QWebEnginePage.icon(self)->PySide6.QtGui.QIcon",
    "PySide6.QtWebEngineCore.QWebEnginePage.iconUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEnginePage.inspectedPage(self)->PySide6.QtWebEngineCore.QWebEnginePage",
    "PySide6.QtWebEngineCore.QWebEnginePage.isAudioMuted(self)->bool",
    "PySide6.QtWebEngineCore.QWebEnginePage.isLoading(self)->bool",
    "PySide6.QtWebEngineCore.QWebEnginePage.isVisible(self)->bool",
    "PySide6.QtWebEngineCore.QWebEnginePage.javaScriptAlert(self,securityOrigin:typing.Union[PySide6.QtCore.QUrl, QString],msg:QString)",
    "PySide6.QtWebEngineCore.QWebEnginePage.javaScriptConfirm(self,securityOrigin:typing.Union[PySide6.QtCore.QUrl, QString],msg:QString)->bool",
    "PySide6.QtWebEngineCore.QWebEnginePage.javaScriptConsoleMessage(self,level:PySide6.QtWebEngineCore.QWebEnginePage.JavaScriptConsoleMessageLevel,message:QString,lineNumber:int,sourceID:QString)",
    "PySide6.QtWebEngineCore.QWebEnginePage.javaScriptPrompt(self,securityOrigin:typing.Union[PySide6.QtCore.QUrl, QString],msg:QString,defaultValue:QString)->Tuple[bool, str]",
    "PySide6.QtWebEngineCore.QWebEnginePage.lifecycleState(self)->PySide6.QtWebEngineCore.QWebEnginePage.LifecycleState",
    "1:PySide6.QtWebEngineCore.QWebEnginePage.load(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "0:PySide6.QtWebEngineCore.QWebEnginePage.load(self,request:PySide6.QtWebEngineCore.QWebEngineHttpRequest)",
    "PySide6.QtWebEngineCore.QWebEnginePage.printToPdf(self,filePath:QString,layout:PySide6.QtGui.QPageLayout=QPageLayout(QPageSize(QPageSize.A4), QPageLayout.Portrait, QMarginsF()),ranges:PySide6.QtGui.QPageRanges={})",
    "PySide6.QtWebEngineCore.QWebEnginePage.profile(self)->PySide6.QtWebEngineCore.QWebEngineProfile",
    "PySide6.QtWebEngineCore.QWebEnginePage.recentlyAudible(self)->bool",
    "PySide6.QtWebEngineCore.QWebEnginePage.recommendedState(self)->PySide6.QtWebEngineCore.QWebEnginePage.LifecycleState",
    "PySide6.QtWebEngineCore.QWebEnginePage.renderProcessPid(self)->qint64",
    "PySide6.QtWebEngineCore.QWebEnginePage.replaceMisspelledWord(self,replacement:QString)",
    "PySide6.QtWebEngineCore.QWebEnginePage.requestedUrl(self)->PySide6.QtCore.QUrl",
    "1:PySide6.QtWebEngineCore.QWebEnginePage.runJavaScript(self,arg__1:QString,arg__2:quint32,arg__3:PyObject)",
    "0:PySide6.QtWebEngineCore.QWebEnginePage.runJavaScript(self,scriptSource:QString,worldId:quint32=0)",
    "PySide6.QtWebEngineCore.QWebEnginePage.save(self,filePath:QString,format:PySide6.QtWebEngineCore.QWebEngineDownloadRequest.SavePageFormat=QWebEngineDownloadRequest.MimeHtmlSaveFormat)",
    "PySide6.QtWebEngineCore.QWebEnginePage.scripts(self)->PySide6.QtWebEngineCore.QWebEngineScriptCollection",
    "PySide6.QtWebEngineCore.QWebEnginePage.scrollPosition(self)->PySide6.QtCore.QPointF",
    "PySide6.QtWebEngineCore.QWebEnginePage.selectedText(self)->QString",
    "PySide6.QtWebEngineCore.QWebEnginePage.setAudioMuted(self,muted:bool)",
    "PySide6.QtWebEngineCore.QWebEnginePage.setBackgroundColor(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtWebEngineCore.QWebEnginePage.setContent(self,data:typing.Union[PySide6.QtCore.QByteArray, char*],mimeType:QString=QString(),baseUrl:typing.Union[PySide6.QtCore.QUrl, QString]=QUrl())",
    "PySide6.QtWebEngineCore.QWebEnginePage.setDevToolsPage(self,page:PySide6.QtWebEngineCore.QWebEnginePage)",
    "PySide6.QtWebEngineCore.QWebEnginePage.setFeaturePermission(self,securityOrigin:typing.Union[PySide6.QtCore.QUrl, QString],feature:PySide6.QtWebEngineCore.QWebEnginePage.Feature,policy:PySide6.QtWebEngineCore.QWebEnginePage.PermissionPolicy)",
    "PySide6.QtWebEngineCore.QWebEnginePage.setHtml(self,html:QString,baseUrl:typing.Union[PySide6.QtCore.QUrl, QString]=QUrl())",
    "PySide6.QtWebEngineCore.QWebEnginePage.setInspectedPage(self,page:PySide6.QtWebEngineCore.QWebEnginePage)",
    "PySide6.QtWebEngineCore.QWebEnginePage.setLifecycleState(self,state:PySide6.QtWebEngineCore.QWebEnginePage.LifecycleState)",
    "PySide6.QtWebEngineCore.QWebEnginePage.setUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtWebEngineCore.QWebEnginePage.setUrlRequestInterceptor(self,interceptor:PySide6.QtWebEngineCore.QWebEngineUrlRequestInterceptor)",
    "PySide6.QtWebEngineCore.QWebEnginePage.setVisible(self,visible:bool)",
    "PySide6.QtWebEngineCore.QWebEnginePage.setWebChannel(self,arg__1:PySide6.QtWebChannel.QWebChannel,worldId:quint32=0)",
    "PySide6.QtWebEngineCore.QWebEnginePage.setZoomFactor(self,factor:qreal)",
    "PySide6.QtWebEngineCore.QWebEnginePage.settings(self)->PySide6.QtWebEngineCore.QWebEngineSettings",
    "PySide6.QtWebEngineCore.QWebEnginePage.title(self)->QString",
    "PySide6.QtWebEngineCore.QWebEnginePage.toHtml(self,arg__1:PyObject)",
    "PySide6.QtWebEngineCore.QWebEnginePage.toPlainText(self,arg__1:PyObject)",
    "PySide6.QtWebEngineCore.QWebEnginePage.triggerAction(self,action:PySide6.QtWebEngineCore.QWebEnginePage.WebAction,checked:bool=false)",
    "PySide6.QtWebEngineCore.QWebEnginePage.url(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEnginePage.webChannel(self)->PySide6.QtWebChannel.QWebChannel",
    "PySide6.QtWebEngineCore.QWebEnginePage.zoomFactor(self)->qreal",
    nullptr}; // Sentinel

PyTypeObject *init_QWebEnginePage(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEnginePage_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QWebEnginePage_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEnginePage",
        "QWebEnginePage*",
        &Sbk_QWebEnginePage_spec,
        &Shiboken::callCppDestructor< QWebEnginePage >,
        Sbk_QWebEnginePage_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWebEnginePage_TypeF(); // references _Sbk_QWebEnginePage_Type
    InitSignatureStrings(pyType, QWebEnginePage_SignatureStrings);
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEnginePage_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEnginePage_PythonToCpp_QWebEnginePage_PTR,
        is_QWebEnginePage_PythonToCpp_QWebEnginePage_PTR_Convertible,
        QWebEnginePage_PTR_CppToPython_QWebEnginePage);

    Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage");
    Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEnginePage).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QWebEnginePageWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QWebEnginePage_TypeF(), &Sbk_QWebEnginePage_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWebEnginePage_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'WebAction'.
    const char *WebAction_Initializer[] = {
        "NoWebAction",
        "Back",
        "Forward",
        "Stop",
        "Reload",
        "Cut",
        "Copy",
        "Paste",
        "Undo",
        "Redo",
        "SelectAll",
        "ReloadAndBypassCache",
        "PasteAndMatchStyle",
        "OpenLinkInThisWindow",
        "OpenLinkInNewWindow",
        "OpenLinkInNewTab",
        "CopyLinkToClipboard",
        "DownloadLinkToDisk",
        "CopyImageToClipboard",
        "CopyImageUrlToClipboard",
        "DownloadImageToDisk",
        "CopyMediaUrlToClipboard",
        "ToggleMediaControls",
        "ToggleMediaLoop",
        "ToggleMediaPlayPause",
        "ToggleMediaMute",
        "DownloadMediaToDisk",
        "InspectElement",
        "ExitFullScreen",
        "RequestClose",
        "Unselect",
        "SavePage",
        "OpenLinkInNewBackgroundTab",
        "ViewSource",
        "ToggleBold",
        "ToggleItalic",
        "ToggleUnderline",
        "ToggleStrikethrough",
        "AlignLeft",
        "AlignCenter",
        "AlignRight",
        "AlignJustified",
        "Indent",
        "Outdent",
        "InsertOrderedList",
        "InsertUnorderedList",
        "ChangeTextDirectionLTR",
        "ChangeTextDirectionRTL",
        "WebActionCount",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t WebAction_InitializerValues[] = {
        int8_t(QWebEnginePage::WebAction::NoWebAction),                // -0x01 -1
        int8_t(QWebEnginePage::WebAction::Back),                       //  0x00  0
        int8_t(QWebEnginePage::WebAction::Forward),                    //  0x01  1
        int8_t(QWebEnginePage::WebAction::Stop),                       //  0x02  2
        int8_t(QWebEnginePage::WebAction::Reload),                     //  0x03  3
        int8_t(QWebEnginePage::WebAction::Cut),                        //  0x04  4
        int8_t(QWebEnginePage::WebAction::Copy),                       //  0x05  5
        int8_t(QWebEnginePage::WebAction::Paste),                      //  0x06  6
        int8_t(QWebEnginePage::WebAction::Undo),                       //  0x07  7
        int8_t(QWebEnginePage::WebAction::Redo),                       //  0x08  8
        int8_t(QWebEnginePage::WebAction::SelectAll),                  //  0x09  9
        int8_t(QWebEnginePage::WebAction::ReloadAndBypassCache),       //  0x0a  10
        int8_t(QWebEnginePage::WebAction::PasteAndMatchStyle),         //  0x0b  11
        int8_t(QWebEnginePage::WebAction::OpenLinkInThisWindow),       //  0x0c  12
        int8_t(QWebEnginePage::WebAction::OpenLinkInNewWindow),        //  0x0d  13
        int8_t(QWebEnginePage::WebAction::OpenLinkInNewTab),           //  0x0e  14
        int8_t(QWebEnginePage::WebAction::CopyLinkToClipboard),        //  0x0f  15
        int8_t(QWebEnginePage::WebAction::DownloadLinkToDisk),         //  0x10  16
        int8_t(QWebEnginePage::WebAction::CopyImageToClipboard),       //  0x11  17
        int8_t(QWebEnginePage::WebAction::CopyImageUrlToClipboard),    //  0x12  18
        int8_t(QWebEnginePage::WebAction::DownloadImageToDisk),        //  0x13  19
        int8_t(QWebEnginePage::WebAction::CopyMediaUrlToClipboard),    //  0x14  20
        int8_t(QWebEnginePage::WebAction::ToggleMediaControls),        //  0x15  21
        int8_t(QWebEnginePage::WebAction::ToggleMediaLoop),            //  0x16  22
        int8_t(QWebEnginePage::WebAction::ToggleMediaPlayPause),       //  0x17  23
        int8_t(QWebEnginePage::WebAction::ToggleMediaMute),            //  0x18  24
        int8_t(QWebEnginePage::WebAction::DownloadMediaToDisk),        //  0x19  25
        int8_t(QWebEnginePage::WebAction::InspectElement),             //  0x1a  26
        int8_t(QWebEnginePage::WebAction::ExitFullScreen),             //  0x1b  27
        int8_t(QWebEnginePage::WebAction::RequestClose),               //  0x1c  28
        int8_t(QWebEnginePage::WebAction::Unselect),                   //  0x1d  29
        int8_t(QWebEnginePage::WebAction::SavePage),                   //  0x1e  30
        int8_t(QWebEnginePage::WebAction::OpenLinkInNewBackgroundTab), //  0x1f  31
        int8_t(QWebEnginePage::WebAction::ViewSource),                 //  0x20  32
        int8_t(QWebEnginePage::WebAction::ToggleBold),                 //  0x21  33
        int8_t(QWebEnginePage::WebAction::ToggleItalic),               //  0x22  34
        int8_t(QWebEnginePage::WebAction::ToggleUnderline),            //  0x23  35
        int8_t(QWebEnginePage::WebAction::ToggleStrikethrough),        //  0x24  36
        int8_t(QWebEnginePage::WebAction::AlignLeft),                  //  0x25  37
        int8_t(QWebEnginePage::WebAction::AlignCenter),                //  0x26  38
        int8_t(QWebEnginePage::WebAction::AlignRight),                 //  0x27  39
        int8_t(QWebEnginePage::WebAction::AlignJustified),             //  0x28  40
        int8_t(QWebEnginePage::WebAction::Indent),                     //  0x29  41
        int8_t(QWebEnginePage::WebAction::Outdent),                    //  0x2a  42
        int8_t(QWebEnginePage::WebAction::InsertOrderedList),          //  0x2b  43
        int8_t(QWebEnginePage::WebAction::InsertUnorderedList),        //  0x2c  44
        int8_t(QWebEnginePage::WebAction::ChangeTextDirectionLTR),     //  0x2d  45
        int8_t(QWebEnginePage::WebAction::ChangeTextDirectionRTL),     //  0x2e  46
        int8_t(QWebEnginePage::WebAction::WebActionCount)              //  0x2f  47
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEnginePage_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEnginePage.WebAction",
        WebAction_Initializer, WebAction_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_WebAction_IDX].type = EType;
    // Register converter for enum 'QWebEnginePage::WebAction'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEnginePage_WebAction_CppToPython_QWebEnginePage_WebAction);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_WebAction_PythonToCpp_QWebEnginePage_WebAction,
            is_QWebEnginePage_WebAction_PythonToCpp_QWebEnginePage_WebAction_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::WebAction");
        Shiboken::Conversions::registerConverterName(converter, "WebAction");
    }
    // End of 'WebAction' enum.

    // Initialization of enum 'FindFlag'.
    const char *FindFlag_Initializer[] = {
        "FindBackward",
        "FindCaseSensitively",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FindFlag_InitializerValues[] = {
        uint8_t(QWebEnginePage::FindFlag::FindBackward),       //  0x01  1
        uint8_t(QWebEnginePage::FindFlag::FindCaseSensitively) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEnginePage_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEnginePage.FindFlag",
        FindFlag_Initializer, FindFlag_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_FindFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QFlags_QWebEnginePage_FindFlag_IDX].type =
        EType;
    // Register converter for enum 'QWebEnginePage::FindFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEnginePage_FindFlag_CppToPython_QWebEnginePage_FindFlag);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_FindFlag_PythonToCpp_QWebEnginePage_FindFlag,
            is_QWebEnginePage_FindFlag_PythonToCpp_QWebEnginePage_FindFlag_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::FindFlag");
        Shiboken::Conversions::registerConverterName(converter, "FindFlag");
        // Register converter for flag 'QFlags<QWebEnginePage::FindFlag>'.
        Shiboken::Conversions::registerConverterName(converter, "QFlags<QWebEnginePage::FindFlag>");
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::FindFlags");
    }
    // End of 'FindFlag' enum/flags.

    // Initialization of enum 'WebWindowType'.
    const char *WebWindowType_Initializer[] = {
        "WebBrowserWindow",
        "WebBrowserTab",
        "WebDialog",
        "WebBrowserBackgroundTab",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t WebWindowType_InitializerValues[] = {
        uint8_t(QWebEnginePage::WebWindowType::WebBrowserWindow),       //  0x00  0
        uint8_t(QWebEnginePage::WebWindowType::WebBrowserTab),          //  0x01  1
        uint8_t(QWebEnginePage::WebWindowType::WebDialog),              //  0x02  2
        uint8_t(QWebEnginePage::WebWindowType::WebBrowserBackgroundTab) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEnginePage_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEnginePage.WebWindowType",
        WebWindowType_Initializer, WebWindowType_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_WebWindowType_IDX].type = EType;
    // Register converter for enum 'QWebEnginePage::WebWindowType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEnginePage_WebWindowType_CppToPython_QWebEnginePage_WebWindowType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_WebWindowType_PythonToCpp_QWebEnginePage_WebWindowType,
            is_QWebEnginePage_WebWindowType_PythonToCpp_QWebEnginePage_WebWindowType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::WebWindowType");
        Shiboken::Conversions::registerConverterName(converter, "WebWindowType");
    }
    // End of 'WebWindowType' enum.

    // Initialization of enum 'PermissionPolicy'.
    const char *PermissionPolicy_Initializer[] = {
        "PermissionUnknown",
        "PermissionGrantedByUser",
        "PermissionDeniedByUser",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PermissionPolicy_InitializerValues[] = {
        uint8_t(QWebEnginePage::PermissionPolicy::PermissionUnknown),       //  0x00  0
        uint8_t(QWebEnginePage::PermissionPolicy::PermissionGrantedByUser), //  0x01  1
        uint8_t(QWebEnginePage::PermissionPolicy::PermissionDeniedByUser)   //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEnginePage_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEnginePage.PermissionPolicy",
        PermissionPolicy_Initializer, PermissionPolicy_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_PermissionPolicy_IDX].type = EType;
    // Register converter for enum 'QWebEnginePage::PermissionPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEnginePage_PermissionPolicy_CppToPython_QWebEnginePage_PermissionPolicy);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_PermissionPolicy_PythonToCpp_QWebEnginePage_PermissionPolicy,
            is_QWebEnginePage_PermissionPolicy_PythonToCpp_QWebEnginePage_PermissionPolicy_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::PermissionPolicy");
        Shiboken::Conversions::registerConverterName(converter, "PermissionPolicy");
    }
    // End of 'PermissionPolicy' enum.

    // Initialization of enum 'NavigationType'.
    const char *NavigationType_Initializer[] = {
        "NavigationTypeLinkClicked",
        "NavigationTypeTyped",
        "NavigationTypeFormSubmitted",
        "NavigationTypeBackForward",
        "NavigationTypeReload",
        "NavigationTypeOther",
        "NavigationTypeRedirect",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t NavigationType_InitializerValues[] = {
        uint8_t(QWebEnginePage::NavigationType::NavigationTypeLinkClicked),   //  0x00  0
        uint8_t(QWebEnginePage::NavigationType::NavigationTypeTyped),         //  0x01  1
        uint8_t(QWebEnginePage::NavigationType::NavigationTypeFormSubmitted), //  0x02  2
        uint8_t(QWebEnginePage::NavigationType::NavigationTypeBackForward),   //  0x03  3
        uint8_t(QWebEnginePage::NavigationType::NavigationTypeReload),        //  0x04  4
        uint8_t(QWebEnginePage::NavigationType::NavigationTypeOther),         //  0x05  5
        uint8_t(QWebEnginePage::NavigationType::NavigationTypeRedirect)       //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEnginePage_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEnginePage.NavigationType",
        NavigationType_Initializer, NavigationType_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_NavigationType_IDX].type = EType;
    // Register converter for enum 'QWebEnginePage::NavigationType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEnginePage_NavigationType_CppToPython_QWebEnginePage_NavigationType);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_NavigationType_PythonToCpp_QWebEnginePage_NavigationType,
            is_QWebEnginePage_NavigationType_PythonToCpp_QWebEnginePage_NavigationType_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::NavigationType");
        Shiboken::Conversions::registerConverterName(converter, "NavigationType");
    }
    // End of 'NavigationType' enum.

    // Initialization of enum 'Feature'.
    const char *Feature_Initializer[] = {
        "Notifications",
        "Geolocation",
        "MediaAudioCapture",
        "MediaVideoCapture",
        "MediaAudioVideoCapture",
        "MouseLock",
        "DesktopVideoCapture",
        "DesktopAudioVideoCapture",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Feature_InitializerValues[] = {
        uint8_t(QWebEnginePage::Feature::Notifications),           //  0x00  0
        uint8_t(QWebEnginePage::Feature::Geolocation),             //  0x01  1
        uint8_t(QWebEnginePage::Feature::MediaAudioCapture),       //  0x02  2
        uint8_t(QWebEnginePage::Feature::MediaVideoCapture),       //  0x03  3
        uint8_t(QWebEnginePage::Feature::MediaAudioVideoCapture),  //  0x04  4
        uint8_t(QWebEnginePage::Feature::MouseLock),               //  0x05  5
        uint8_t(QWebEnginePage::Feature::DesktopVideoCapture),     //  0x06  6
        uint8_t(QWebEnginePage::Feature::DesktopAudioVideoCapture) //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEnginePage_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEnginePage.Feature",
        Feature_Initializer, Feature_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_Feature_IDX].type = EType;
    // Register converter for enum 'QWebEnginePage::Feature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEnginePage_Feature_CppToPython_QWebEnginePage_Feature);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_Feature_PythonToCpp_QWebEnginePage_Feature,
            is_QWebEnginePage_Feature_PythonToCpp_QWebEnginePage_Feature_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::Feature");
        Shiboken::Conversions::registerConverterName(converter, "Feature");
    }
    // End of 'Feature' enum.

    // Initialization of enum 'FileSelectionMode'.
    const char *FileSelectionMode_Initializer[] = {
        "FileSelectOpen",
        "FileSelectOpenMultiple",
        "FileSelectUploadFolder",
        "FileSelectSave",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FileSelectionMode_InitializerValues[] = {
        uint8_t(QWebEnginePage::FileSelectionMode::FileSelectOpen),         //  0x00  0
        uint8_t(QWebEnginePage::FileSelectionMode::FileSelectOpenMultiple), //  0x01  1
        uint8_t(QWebEnginePage::FileSelectionMode::FileSelectUploadFolder), //  0x02  2
        uint8_t(QWebEnginePage::FileSelectionMode::FileSelectSave)          //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEnginePage_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEnginePage.FileSelectionMode",
        FileSelectionMode_Initializer, FileSelectionMode_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_FileSelectionMode_IDX].type = EType;
    // Register converter for enum 'QWebEnginePage::FileSelectionMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEnginePage_FileSelectionMode_CppToPython_QWebEnginePage_FileSelectionMode);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_FileSelectionMode_PythonToCpp_QWebEnginePage_FileSelectionMode,
            is_QWebEnginePage_FileSelectionMode_PythonToCpp_QWebEnginePage_FileSelectionMode_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::FileSelectionMode");
        Shiboken::Conversions::registerConverterName(converter, "FileSelectionMode");
    }
    // End of 'FileSelectionMode' enum.

    // Initialization of enum 'JavaScriptConsoleMessageLevel'.
    const char *JavaScriptConsoleMessageLevel_Initializer[] = {
        "InfoMessageLevel",
        "WarningMessageLevel",
        "ErrorMessageLevel",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t JavaScriptConsoleMessageLevel_InitializerValues[] = {
        uint8_t(QWebEnginePage::JavaScriptConsoleMessageLevel::InfoMessageLevel),    //  0x00  0
        uint8_t(QWebEnginePage::JavaScriptConsoleMessageLevel::WarningMessageLevel), //  0x01  1
        uint8_t(QWebEnginePage::JavaScriptConsoleMessageLevel::ErrorMessageLevel)    //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEnginePage_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEnginePage.JavaScriptConsoleMessageLevel",
        JavaScriptConsoleMessageLevel_Initializer, JavaScriptConsoleMessageLevel_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_JavaScriptConsoleMessageLevel_IDX].type = EType;
    // Register converter for enum 'QWebEnginePage::JavaScriptConsoleMessageLevel'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEnginePage_JavaScriptConsoleMessageLevel_CppToPython_QWebEnginePage_JavaScriptConsoleMessageLevel);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_JavaScriptConsoleMessageLevel_PythonToCpp_QWebEnginePage_JavaScriptConsoleMessageLevel,
            is_QWebEnginePage_JavaScriptConsoleMessageLevel_PythonToCpp_QWebEnginePage_JavaScriptConsoleMessageLevel_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::JavaScriptConsoleMessageLevel");
        Shiboken::Conversions::registerConverterName(converter, "JavaScriptConsoleMessageLevel");
    }
    // End of 'JavaScriptConsoleMessageLevel' enum.

    // Initialization of enum 'RenderProcessTerminationStatus'.
    const char *RenderProcessTerminationStatus_Initializer[] = {
        "NormalTerminationStatus",
        "AbnormalTerminationStatus",
        "CrashedTerminationStatus",
        "KilledTerminationStatus",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RenderProcessTerminationStatus_InitializerValues[] = {
        uint8_t(QWebEnginePage::RenderProcessTerminationStatus::NormalTerminationStatus),   //  0x00  0
        uint8_t(QWebEnginePage::RenderProcessTerminationStatus::AbnormalTerminationStatus), //  0x01  1
        uint8_t(QWebEnginePage::RenderProcessTerminationStatus::CrashedTerminationStatus),  //  0x02  2
        uint8_t(QWebEnginePage::RenderProcessTerminationStatus::KilledTerminationStatus)    //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEnginePage_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEnginePage.RenderProcessTerminationStatus",
        RenderProcessTerminationStatus_Initializer, RenderProcessTerminationStatus_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_RenderProcessTerminationStatus_IDX].type = EType;
    // Register converter for enum 'QWebEnginePage::RenderProcessTerminationStatus'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEnginePage_RenderProcessTerminationStatus_CppToPython_QWebEnginePage_RenderProcessTerminationStatus);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_RenderProcessTerminationStatus_PythonToCpp_QWebEnginePage_RenderProcessTerminationStatus,
            is_QWebEnginePage_RenderProcessTerminationStatus_PythonToCpp_QWebEnginePage_RenderProcessTerminationStatus_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::RenderProcessTerminationStatus");
        Shiboken::Conversions::registerConverterName(converter, "RenderProcessTerminationStatus");
    }
    // End of 'RenderProcessTerminationStatus' enum.

    // Initialization of enum 'LifecycleState'.
    const char *LifecycleState_Initializer[] = {
        "Active",
        "Frozen",
        "Discarded",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t LifecycleState_InitializerValues[] = {
        int8_t(QWebEnginePage::LifecycleState::Active),   //  0x00  0
        int8_t(QWebEnginePage::LifecycleState::Frozen),   //  0x01  1
        int8_t(QWebEnginePage::LifecycleState::Discarded) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEnginePage_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEnginePage.LifecycleState",
        LifecycleState_Initializer, LifecycleState_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEnginePage_LifecycleState_IDX].type = EType;
    // Register converter for enum 'QWebEnginePage::LifecycleState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEnginePage_LifecycleState_CppToPython_QWebEnginePage_LifecycleState);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            QWebEnginePage_LifecycleState_PythonToCpp_QWebEnginePage_LifecycleState,
            is_QWebEnginePage_LifecycleState_PythonToCpp_QWebEnginePage_LifecycleState_Convertible);
        Shiboken::Enum::setTypeConverter(EType, converter);
        Shiboken::Conversions::registerConverterName(converter, "QWebEnginePage::LifecycleState");
        Shiboken::Conversions::registerConverterName(converter, "LifecycleState");
    }
    // End of 'LifecycleState' enum.

    PySide::Signal::registerSignals(pyType, &::QWebEnginePage::staticMetaObject);
    qRegisterMetaType< ::QWebEnginePage::WebAction >("QWebEnginePage::WebAction");
    qRegisterMetaType< ::QWebEnginePage::FindFlag >("QWebEnginePage::FindFlag");
    qRegisterMetaType< ::QWebEnginePage::WebWindowType >("QWebEnginePage::WebWindowType");
    qRegisterMetaType< ::QWebEnginePage::PermissionPolicy >("QWebEnginePage::PermissionPolicy");
    qRegisterMetaType< ::QWebEnginePage::NavigationType >("QWebEnginePage::NavigationType");
    qRegisterMetaType< ::QWebEnginePage::Feature >("QWebEnginePage::Feature");
    qRegisterMetaType< ::QWebEnginePage::FileSelectionMode >("QWebEnginePage::FileSelectionMode");
    qRegisterMetaType< ::QWebEnginePage::JavaScriptConsoleMessageLevel >("QWebEnginePage::JavaScriptConsoleMessageLevel");
    qRegisterMetaType< ::QWebEnginePage::RenderProcessTerminationStatus >("QWebEnginePage::RenderProcessTerminationStatus");
    qRegisterMetaType< ::QWebEnginePage::LifecycleState >("QWebEnginePage::LifecycleState");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QWebEnginePage::staticMetaObject, sizeof(QWebEnginePageWrapper));

    return pyType;
}
